@@ -99,7 +99,7 @@ static ULONG WINAPI ldap_Release(IParseDisplayName *iface)
     if (!ref)
     {
         TRACE("destroying %p\n", iface);
-        heap_free(ldap);
+        free(ldap);
     }
 
     return ref;
@@ -147,7 +147,7 @@ static HRESULT LDAP_create(REFIID riid, void **obj)
     LDAP_PARSE *ldap;
     HRESULT hr;
 
-    ldap = heap_alloc(sizeof(*ldap));
+    ldap = malloc(sizeof(*ldap));
     if (!ldap) return E_OUTOFMEMORY;
 
     ldap->IParseDisplayName_iface.lpVtbl = &LDAP_PARSE_vtbl;
@@ -204,7 +204,7 @@ static ULONG WINAPI sysinfo_Release(IADsADSystemInfo *iface)
     if (!ref)
     {
         TRACE("destroying %p\n", iface);
-        heap_free(sysinfo);
+        free(sysinfo);
     }
 
     return ref;
@@ -218,21 +218,21 @@ static HRESULT WINAPI sysinfo_GetTypeInfoCount(IADsADSystemInfo *iface, UINT *co
 
 static HRESULT WINAPI sysinfo_GetTypeInfo(IADsADSystemInfo *iface, UINT index, LCID lcid, ITypeInfo **info)
 {
-    FIXME("%p,%u,%#x,%p: stub\n", iface, index, lcid, info);
+    FIXME("%p,%u,%#lx,%p: stub\n", iface, index, lcid, info);
     return E_NOTIMPL;
 }
 
 static HRESULT WINAPI sysinfo_GetIDsOfNames(IADsADSystemInfo *iface, REFIID riid, LPOLESTR *names,
                                             UINT count, LCID lcid, DISPID *dispid)
 {
-    FIXME("%p,%s,%p,%u,%u,%p: stub\n", iface, debugstr_guid(riid), names, count, lcid, dispid);
+    FIXME("%p,%s,%p,%u,%lu,%p: stub\n", iface, debugstr_guid(riid), names, count, lcid, dispid);
     return E_NOTIMPL;
 }
 
 static HRESULT WINAPI sysinfo_Invoke(IADsADSystemInfo *iface, DISPID dispid, REFIID riid, LCID lcid, WORD flags,
                                      DISPPARAMS *params, VARIANT *result, EXCEPINFO *excepinfo, UINT *argerr)
 {
-    FIXME("%p,%d,%s,%04x,%04x,%p,%p,%p,%p: stub\n", iface, dispid, debugstr_guid(riid), lcid, flags,
+    FIXME("%p,%ld,%s,%04lx,%04x,%p,%p,%p,%p: stub\n", iface, dispid, debugstr_guid(riid), lcid, flags,
           params, result, excepinfo, argerr);
     return E_NOTIMPL;
 }
@@ -245,7 +245,7 @@ static HRESULT WINAPI sysinfo_get_UserName(IADsADSystemInfo *iface, BSTR *retval
 
 static HRESULT WINAPI sysinfo_get_ComputerName(IADsADSystemInfo *iface, BSTR *retval)
 {
-    UINT size;
+    ULONG size;
     WCHAR *name;
 
     TRACE("%p,%p\n", iface, retval);
@@ -363,7 +363,7 @@ static HRESULT ADSystemInfo_create(REFIID riid, void **obj)
     AD_sysinfo *sysinfo;
     HRESULT hr;
 
-    sysinfo = heap_alloc(sizeof(*sysinfo));
+    sysinfo = malloc(sizeof(*sysinfo));
     if (!sysinfo) return E_OUTOFMEMORY;
 
     sysinfo->IADsADSystemInfo_iface.lpVtbl = &IADsADSystemInfo_vtbl;
@@ -400,6 +400,7 @@ typedef struct
     {
         ADS_SCOPEENUM scope;
         int pagesize;
+        int size_limit;
         BOOL cache_results;
         BOOL attribtypes_only;
         BOOL tombstone;
@@ -483,7 +484,7 @@ static void free_attributes(LDAP_namespace *ldap)
         ldap_value_freeW(ldap->attrs[i].values);
     }
 
-    heap_free(ldap->attrs);
+    free(ldap->attrs);
     ldap->attrs = NULL;
     ldap->attrs_count = 0;
 }
@@ -501,7 +502,7 @@ static ULONG WINAPI ldapns_Release(IADs *iface)
         SysFreeString(ldap->object);
         free_attributes(ldap);
         free_attribute_types(ldap->at, ldap->at_single_count + ldap->at_multiple_count);
-        heap_free(ldap);
+        free(ldap);
     }
 
     return ref;
@@ -515,21 +516,21 @@ static HRESULT WINAPI ldapns_GetTypeInfoCount(IADs *iface, UINT *count)
 
 static HRESULT WINAPI ldapns_GetTypeInfo(IADs *iface, UINT index, LCID lcid, ITypeInfo **info)
 {
-    FIXME("%p,%u,%#x,%p: stub\n", iface, index, lcid, info);
+    FIXME("%p,%u,%#lx,%p: stub\n", iface, index, lcid, info);
     return E_NOTIMPL;
 }
 
 static HRESULT WINAPI ldapns_GetIDsOfNames(IADs *iface, REFIID riid, LPOLESTR *names,
                                            UINT count, LCID lcid, DISPID *dispid)
 {
-    FIXME("%p,%s,%p,%u,%u,%p: stub\n", iface, debugstr_guid(riid), names, count, lcid, dispid);
+    FIXME("%p,%s,%p,%u,%lu,%p: stub\n", iface, debugstr_guid(riid), names, count, lcid, dispid);
     return E_NOTIMPL;
 }
 
 static HRESULT WINAPI ldapns_Invoke(IADs *iface, DISPID dispid, REFIID riid, LCID lcid, WORD flags,
                                     DISPPARAMS *params, VARIANT *result, EXCEPINFO *excepinfo, UINT *argerr)
 {
-    FIXME("%p,%d,%s,%04x,%04x,%p,%p,%p,%p: stub\n", iface, dispid, debugstr_guid(riid), lcid, flags,
+    FIXME("%p,%ld,%s,%04lx,%04x,%p,%p,%p,%p: stub\n", iface, dispid, debugstr_guid(riid), lcid, flags,
           params, result, excepinfo, argerr);
     return E_NOTIMPL;
 }
@@ -626,7 +627,7 @@ static HRESULT WINAPI ldapns_Get(IADs *iface, BSTR name, VARIANT *prop)
                 VARIANT item;
                 LONG idx;
 
-                TRACE("attr %s has %u values\n", debugstr_w(ldap->attrs[i].name), count);
+                TRACE("attr %s has %lu values\n", debugstr_w(ldap->attrs[i].name), count);
 
                 sa = SafeArrayCreateVector(VT_VARIANT, 0, count);
                 if (!sa) return E_OUTOFMEMORY;
@@ -682,7 +683,7 @@ static HRESULT WINAPI ldapns_GetEx(IADs *iface, BSTR name, VARIANT *prop)
 
 static HRESULT WINAPI ldapns_PutEx(IADs *iface, LONG code, BSTR name, VARIANT prop)
 {
-    FIXME("%p,%d,%s,%s: stub\n", iface, code, debugstr_w(name), wine_dbgstr_variant(&prop));
+    FIXME("%p,%ld,%s,%s: stub\n", iface, code, debugstr_w(name), wine_dbgstr_variant(&prop));
     return E_NOTIMPL;
 }
 
@@ -692,13 +693,13 @@ static HRESULT add_attribute(LDAP_namespace *ldap, WCHAR *name, WCHAR **values)
 
     if (!ldap->attrs)
     {
-        ldap->attrs = heap_alloc(256 * sizeof(ldap->attrs[0]));
+        ldap->attrs = malloc(256 * sizeof(ldap->attrs[0]));
         if (!ldap->attrs) return E_OUTOFMEMORY;
         ldap->attrs_count_allocated = 256;
     }
     else if (ldap->attrs_count_allocated < ldap->attrs_count + 1)
     {
-        new_attrs = heap_realloc(ldap->attrs, (ldap->attrs_count_allocated * 2) * sizeof(*new_attrs));
+        new_attrs = realloc(ldap->attrs, (ldap->attrs_count_allocated * 2) * sizeof(*new_attrs));
         if (!new_attrs) return E_OUTOFMEMORY;
 
         ldap->attrs_count_allocated *= 2;
@@ -723,7 +724,7 @@ static HRESULT WINAPI ldapns_GetInfoEx(IADs *iface, VARIANT prop, LONG reserved)
     LDAPMessage *res = NULL, *entry;
     BerElement *ber;
 
-    TRACE("%p,%s,%d\n", iface, wine_dbgstr_variant(&prop), reserved);
+    TRACE("%p,%s,%ld\n", iface, wine_dbgstr_variant(&prop), reserved);
 
     free_attributes(ldap);
 
@@ -742,7 +743,7 @@ static HRESULT WINAPI ldapns_GetInfoEx(IADs *iface, VARIANT prop, LONG reserved)
     count = sa->rgsabound[0].cElements;
     if (count)
     {
-        props = heap_alloc((count + 1) * sizeof(props[0]));
+        props = malloc((count + 1) * sizeof(props[0]));
         if (!props)
         {
             hr = E_OUTOFMEMORY;
@@ -764,7 +765,7 @@ static HRESULT WINAPI ldapns_GetInfoEx(IADs *iface, VARIANT prop, LONG reserved)
     err = ldap_search_sW(ldap->ld, NULL, LDAP_SCOPE_BASE, (WCHAR *)L"(objectClass=*)", props, FALSE, &res);
     if (err != LDAP_SUCCESS)
     {
-        TRACE("ldap_search_sW error %#x\n", err);
+        TRACE("ldap_search_sW error %#lx\n", err);
         hr = HRESULT_FROM_WIN32(map_ldap_error(err));
         goto exit;
     }
@@ -797,7 +798,7 @@ static HRESULT WINAPI ldapns_GetInfoEx(IADs *iface, VARIANT prop, LONG reserved)
 
 exit:
     if (res) ldap_msgfree(res);
-    heap_free(props);
+    free(props);
     SafeArrayUnaccessData(sa);
     return hr;
 }
@@ -870,21 +871,21 @@ static HRESULT WINAPI openobj_GetTypeInfoCount(IADsOpenDSObject *iface, UINT *co
 
 static HRESULT WINAPI openobj_GetTypeInfo(IADsOpenDSObject *iface, UINT index, LCID lcid, ITypeInfo **info)
 {
-    FIXME("%p,%u,%#x,%p: stub\n", iface, index, lcid, info);
+    FIXME("%p,%u,%#lx,%p: stub\n", iface, index, lcid, info);
     return E_NOTIMPL;
 }
 
 static HRESULT WINAPI openobj_GetIDsOfNames(IADsOpenDSObject *iface, REFIID riid, LPOLESTR *names,
                                             UINT count, LCID lcid, DISPID *dispid)
 {
-    FIXME("%p,%s,%p,%u,%u,%p: stub\n", iface, debugstr_guid(riid), names, count, lcid, dispid);
+    FIXME("%p,%s,%p,%u,%lu,%p: stub\n", iface, debugstr_guid(riid), names, count, lcid, dispid);
     return E_NOTIMPL;
 }
 
 static HRESULT WINAPI openobj_Invoke(IADsOpenDSObject *iface, DISPID dispid, REFIID riid, LCID lcid, WORD flags,
                                      DISPPARAMS *params, VARIANT *result, EXCEPINFO *excepinfo, UINT *argerr)
 {
-    FIXME("%p,%d,%s,%04x,%04x,%p,%p,%p,%p: stub\n", iface, dispid, debugstr_guid(riid), lcid, flags,
+    FIXME("%p,%ld,%s,%04lx,%04x,%p,%p,%p,%p: stub\n", iface, dispid, debugstr_guid(riid), lcid, flags,
           params, result, excepinfo, argerr);
     return E_NOTIMPL;
 }
@@ -964,12 +965,12 @@ static HRESULT WINAPI openobj_OpenDSObject(IADsOpenDSObject *iface, BSTR path, B
     ULONG err, at_single_count = 0, at_multiple_count = 0;
     struct attribute_type *at = NULL;
 
-    TRACE("%p,%s,%s,%p,%08x,%p\n", iface, debugstr_w(path), debugstr_w(user), password, flags, obj);
+    TRACE("%p,%s,%s,%p,%08lx,%p\n", iface, debugstr_w(path), debugstr_w(user), password, flags, obj);
 
     hr = parse_path(path, &host, &port, &object);
     if (hr != S_OK) return hr;
 
-    TRACE("host %s, port %u, object %s\n", debugstr_w(host), port, debugstr_w(object));
+    TRACE("host %s, port %lu, object %s\n", debugstr_w(host), port, debugstr_w(object));
 
     if (host)
     {
@@ -1043,7 +1044,7 @@ static HRESULT WINAPI openobj_OpenDSObject(IADsOpenDSObject *iface, BSTR path, B
             err = ldap_bind_sW(ld, NULL, (WCHAR *)&id, LDAP_AUTH_NEGOTIATE);
             if (err != LDAP_SUCCESS)
             {
-                TRACE("ldap_bind_sW error %#x\n", err);
+                TRACE("ldap_bind_sW error %#lx\n", err);
                 hr = HRESULT_FROM_WIN32(map_ldap_error(err));
                 ldap_unbind(ld);
                 goto fail;
@@ -1054,7 +1055,7 @@ static HRESULT WINAPI openobj_OpenDSObject(IADsOpenDSObject *iface, BSTR path, B
             err = ldap_simple_bind_sW(ld, user, password);
             if (err != LDAP_SUCCESS)
             {
-                TRACE("ldap_simple_bind_sW error %#x\n", err);
+                TRACE("ldap_simple_bind_sW error %#lx\n", err);
                 hr = HRESULT_FROM_WIN32(map_ldap_error(err));
                 ldap_unbind(ld);
                 goto fail;
@@ -1140,7 +1141,7 @@ static HRESULT WINAPI search_SetSearchPreference(IDirectorySearch *iface, PADS_S
     HRESULT hr = S_OK;
     DWORD i;
 
-    TRACE("%p,%p,%u\n", iface, prefs, count);
+    TRACE("%p,%p,%lu\n", iface, prefs, count);
 
     for (i = 0; i < count; i++)
     {
@@ -1159,7 +1160,7 @@ static HRESULT WINAPI search_SetSearchPreference(IDirectorySearch *iface, PADS_S
             case ADS_SCOPE_BASE:
             case ADS_SCOPE_ONELEVEL:
             case ADS_SCOPE_SUBTREE:
-                TRACE("SEARCH_SCOPE: %d\n", prefs[i].vValue.u.Integer);
+                TRACE("SEARCH_SCOPE: %ld\n", prefs[i].vValue.u.Integer);
                 ldap->search.scope = prefs[i].vValue.u.Integer;
                 prefs[i].dwStatus = ADS_STATUS_S_OK;
                 break;
@@ -1185,7 +1186,7 @@ static HRESULT WINAPI search_SetSearchPreference(IDirectorySearch *iface, PADS_S
                 break;
             }
 
-            TRACE("SECURITY_MASK: %08x\n", prefs[i].vValue.u.Integer);
+            TRACE("SECURITY_MASK: %08lx\n", prefs[i].vValue.u.Integer);
             security_mask = prefs[i].vValue.u.Integer;
             if (!security_mask)
                 security_mask = ADS_SECURITY_INFO_OWNER;
@@ -1208,7 +1209,7 @@ static HRESULT WINAPI search_SetSearchPreference(IDirectorySearch *iface, PADS_S
             err = ldap_set_optionW(ldap->ld, LDAP_OPT_SERVER_CONTROLS, ctrls);
             if (err != LDAP_SUCCESS)
             {
-                TRACE("ldap_set_option error %#x\n", err);
+                TRACE("ldap_set_option error %#lx\n", err);
                 prefs[i].dwStatus = ADS_STATUS_INVALID_SEARCHPREF;
                 hr = S_ADS_ERRORSOCCURRED;
             }
@@ -1228,7 +1229,7 @@ static HRESULT WINAPI search_SetSearchPreference(IDirectorySearch *iface, PADS_S
                 break;
             }
 
-            TRACE("PAGESIZE: %d\n", prefs[i].vValue.u.Integer);
+            TRACE("PAGESIZE: %ld\n", prefs[i].vValue.u.Integer);
             ldap->search.pagesize = prefs[i].vValue.u.Integer;
             prefs[i].dwStatus = ADS_STATUS_S_OK;
             break;
@@ -1241,7 +1242,7 @@ static HRESULT WINAPI search_SetSearchPreference(IDirectorySearch *iface, PADS_S
                 break;
             }
 
-            TRACE("CACHE_RESULTS: %d\n", prefs[i].vValue.u.Boolean);
+            TRACE("CACHE_RESULTS: %ld\n", prefs[i].vValue.u.Boolean);
             ldap->search.cache_results = prefs[i].vValue.u.Boolean;
             prefs[i].dwStatus = ADS_STATUS_S_OK;
             break;
@@ -1254,7 +1255,7 @@ static HRESULT WINAPI search_SetSearchPreference(IDirectorySearch *iface, PADS_S
                 break;
             }
 
-            TRACE("ATTRIBTYPES_ONLY: %d\n", prefs[i].vValue.u.Boolean);
+            TRACE("ATTRIBTYPES_ONLY: %ld\n", prefs[i].vValue.u.Boolean);
             ldap->search.attribtypes_only = prefs[i].vValue.u.Boolean;
             prefs[i].dwStatus = ADS_STATUS_S_OK;
             break;
@@ -1267,11 +1268,24 @@ static HRESULT WINAPI search_SetSearchPreference(IDirectorySearch *iface, PADS_S
                 break;
             }
 
-            TRACE("TOMBSTONE: %d\n", prefs[i].vValue.u.Boolean);
+            TRACE("TOMBSTONE: %ld\n", prefs[i].vValue.u.Boolean);
             ldap->search.tombstone = prefs[i].vValue.u.Boolean;
             prefs[i].dwStatus = ADS_STATUS_S_OK;
             break;
 
+        case ADS_SEARCHPREF_SIZE_LIMIT:
+            if (prefs[i].vValue.dwType != ADSTYPE_INTEGER)
+            {
+                FIXME("ADS_SEARCHPREF_SIZE_LIMIT: unsupported dwType %d\n", prefs[i].vValue.dwType);
+                prefs[i].dwStatus = ADS_STATUS_INVALID_SEARCHPREFVALUE;
+                break;
+            }
+
+            TRACE("SIZE_LIMIT: %ld\n", prefs[i].vValue.u.Integer);
+            ldap->search.size_limit = prefs[i].vValue.u.Integer;
+            prefs[i].dwStatus = ADS_STATUS_S_OK;
+            break;
+
         default:
             FIXME("pref %d, type %u: stub\n", prefs[i].dwSearchPref, prefs[i].vValue.dwType);
             prefs[i].dwStatus = ADS_STATUS_INVALID_SEARCHPREF;
@@ -1291,23 +1305,27 @@ static HRESULT WINAPI search_ExecuteSearch(IDirectorySearch *iface, LPWSTR filte
     LDAPControlW **ctrls = NULL, *ctrls_a[2], tombstone;
     struct ldap_search_context *ldap_ctx;
 
-    TRACE("%p,%s,%p,%u,%p\n", iface, debugstr_w(filter), names, count, res);
+    TRACE("%p,%s,%p,%lu,%p\n", iface, debugstr_w(filter), names, count, res);
 
     if (!res) return E_ADS_BAD_PARAMETER;
 
-    ldap_ctx = heap_alloc_zero(sizeof(*ldap_ctx));
+    ldap_ctx = calloc(1, sizeof(*ldap_ctx));
     if (!ldap_ctx) return E_OUTOFMEMORY;
 
     if (count == 0xffffffff)
         props = NULL;
     else
     {
-        if (count && !names) return E_ADS_BAD_PARAMETER;
+        if (count && !names)
+        {
+            free(ldap_ctx);
+            return E_ADS_BAD_PARAMETER;
+        }
 
-        props = heap_alloc((count + 1) * sizeof(props[0]));
+        props = malloc((count + 1) * sizeof(props[0]));
         if (!props)
         {
-            heap_free(ldap_ctx);
+            free(ldap_ctx);
             return E_OUTOFMEMORY;
         }
 
@@ -1335,7 +1353,7 @@ static HRESULT WINAPI search_ExecuteSearch(IDirectorySearch *iface, LPWSTR filte
     {
         ldap_ctx->page = ldap_search_init_pageW(ldap->ld, ldap->object, ldap->search.scope,
                                                 filter, props, ldap->search.attribtypes_only,
-                                                ctrls, NULL, 0, 0, NULL);
+                                                ctrls, NULL, 0, ldap->search.size_limit, NULL);
         if (ldap_ctx->page)
             err = ldap_get_next_page_s(ldap->ld, ldap_ctx->page, NULL,
                                        ldap->search.pagesize, &count, &ldap_ctx->res);
@@ -1344,14 +1362,15 @@ static HRESULT WINAPI search_ExecuteSearch(IDirectorySearch *iface, LPWSTR filte
     }
     else
         err = ldap_search_ext_sW(ldap->ld, ldap->object, ldap->search.scope, filter, props,
-                                 ldap->search.attribtypes_only, ctrls, NULL, NULL, 0, &ldap_ctx->res);
-    heap_free(props);
+                                 ldap->search.attribtypes_only, ctrls, NULL, NULL, ldap->search.size_limit,
+                                 &ldap_ctx->res);
+    free(props);
     if (err != LDAP_SUCCESS)
     {
-        TRACE("ldap_search_sW error %#x\n", err);
+        TRACE("ldap_search_sW error %#lx\n", err);
         if (ldap_ctx->page)
             ldap_search_abandon_page(ldap->ld, ldap_ctx->page);
-        heap_free(ldap_ctx);
+        free(ldap_ctx);
         return HRESULT_FROM_WIN32(map_ldap_error(err));
     }
 
@@ -1423,7 +1442,7 @@ static HRESULT WINAPI search_GetNextRow(IDirectorySearch *iface, ADS_SEARCH_HAND
 
                 if (err != LDAP_NO_RESULTS_RETURNED)
                 {
-                    TRACE("ldap_get_next_page_s error %#x\n", err);
+                    TRACE("ldap_get_next_page_s error %#lx\n", err);
                     return HRESULT_FROM_WIN32(map_ldap_error(err));
                 }
                 /* fall through */
@@ -1512,7 +1531,7 @@ static HRESULT add_column_values(LDAP_namespace *ldap, struct ldap_search_contex
             return E_ADS_COLUMN_NOT_SET;
         count = ldap_count_valuesW(values);
 
-        col->pADsValues = heap_alloc_zero(count * sizeof(col->pADsValues[0]));
+        col->pADsValues = calloc(count, sizeof(col->pADsValues[0]));
         if (!col->pADsValues)
         {
             ldap_value_freeW(values);
@@ -1537,7 +1556,7 @@ static HRESULT add_column_values(LDAP_namespace *ldap, struct ldap_search_contex
             return E_ADS_COLUMN_NOT_SET;
         count = ldap_count_valuesW(values);
 
-        col->pADsValues = heap_alloc_zero(count * sizeof(col->pADsValues[0]));
+        col->pADsValues = calloc(count, sizeof(col->pADsValues[0]));
         if (!col->pADsValues)
         {
             ldap_value_freeW(values);
@@ -1557,7 +1576,7 @@ static HRESULT add_column_values(LDAP_namespace *ldap, struct ldap_search_contex
                 FIXME("not recognized boolean value %s\n", debugstr_w(values[i]));
                 col->pADsValues[i].u.Boolean = 0;
             }
-            TRACE("%s => %d\n", debugstr_w(values[i]), col->pADsValues[i].u.Boolean);
+            TRACE("%s => %ld\n", debugstr_w(values[i]), col->pADsValues[i].u.Boolean);
         }
 
         ldap_value_freeW(values);
@@ -1573,7 +1592,7 @@ static HRESULT add_column_values(LDAP_namespace *ldap, struct ldap_search_contex
             return E_ADS_COLUMN_NOT_SET;
         count = ldap_count_values_len(values);
 
-        col->pADsValues = heap_alloc_zero(count * sizeof(col->pADsValues[0]));
+        col->pADsValues = calloc(count, sizeof(col->pADsValues[0]));
         if (!col->pADsValues)
         {
             ldap_value_free_len(values);
@@ -1592,7 +1611,7 @@ static HRESULT add_column_values(LDAP_namespace *ldap, struct ldap_search_contex
             else
             {
                 col->pADsValues[i].u.Integer = atol(values[i]->bv_val);
-                TRACE("%s => %d\n", debugstr_an(values[i]->bv_val, values[i]->bv_len), col->pADsValues[i].u.Integer);
+                TRACE("%s => %ld\n", debugstr_an(values[i]->bv_val, values[i]->bv_len), col->pADsValues[i].u.Integer);
             }
         }
 
@@ -1609,7 +1628,7 @@ static HRESULT add_column_values(LDAP_namespace *ldap, struct ldap_search_contex
             return E_ADS_COLUMN_NOT_SET;
         count = ldap_count_values_len(values);
 
-        col->pADsValues = heap_alloc_zero(count * sizeof(col->pADsValues[0]));
+        col->pADsValues = calloc(count, sizeof(col->pADsValues[0]));
         if (!col->pADsValues)
         {
             ldap_value_free_len(values);
@@ -1635,7 +1654,7 @@ static HRESULT add_column_values(LDAP_namespace *ldap, struct ldap_search_contex
             return E_ADS_COLUMN_NOT_SET;
         count = ldap_count_values_len(values);
 
-        col->pADsValues = heap_alloc_zero(count * sizeof(col->pADsValues[0]));
+        col->pADsValues = calloc(count, sizeof(col->pADsValues[0]));
         if (!col->pADsValues)
         {
             ldap_value_free_len(values);
@@ -1689,7 +1708,7 @@ static HRESULT add_column_values(LDAP_namespace *ldap, struct ldap_search_contex
             return E_ADS_COLUMN_NOT_SET;
         count = ldap_count_valuesW(values);
 
-        col->pADsValues = heap_alloc_zero(count * (sizeof(col->pADsValues[0]) + sizeof(col->pADsValues[0].u.pDNWithBinary[0])));
+        col->pADsValues = calloc(count, sizeof(col->pADsValues[0]) + sizeof(col->pADsValues[0].u.pDNWithBinary[0]));
         if (!col->pADsValues)
         {
             ldap_value_freeW(values);
@@ -1734,7 +1753,7 @@ static HRESULT add_column_values(LDAP_namespace *ldap, struct ldap_search_contex
                 FIXME("wrong DN with binary separator '%c'\n", *p);
             col->pADsValues[i].u.pDNWithBinary->pszDNString = p + 1;
 
-            TRACE("%s => %u,%s,%s\n", debugstr_w(values[i]),
+            TRACE("%s => %lu,%s,%s\n", debugstr_w(values[i]),
                   col->pADsValues[i].u.pDNWithBinary->dwLength,
                   debugstr_an((char *)col->pADsValues[i].u.pDNWithBinary->lpBinaryValue, col->pADsValues[i].u.pDNWithBinary->dwLength),
                   debugstr_w(col->pADsValues[i].u.pDNWithBinary->pszDNString));
@@ -1747,7 +1766,7 @@ static HRESULT add_column_values(LDAP_namespace *ldap, struct ldap_search_contex
 
     col->dwADsType = type;
     col->dwNumValues = count;
-    col->pszAttrName = strdupW(name);
+    col->pszAttrName = wcsdup(name);
 
     return S_OK;
 }
@@ -1770,7 +1789,7 @@ static HRESULT WINAPI search_GetColumn(IDirectorySearch *iface, ADS_SEARCH_HANDL
     {
         WCHAR *dn = ldap_get_dnW(ldap->ld, ldap_ctx->entry);
 
-        col->pADsValues = heap_alloc(sizeof(col->pADsValues[0]));
+        col->pADsValues = malloc(sizeof(col->pADsValues[0]));
         if (!col->pADsValues)
         {
             hr = E_OUTOFMEMORY;
@@ -1780,7 +1799,7 @@ static HRESULT WINAPI search_GetColumn(IDirectorySearch *iface, ADS_SEARCH_HANDL
         count = sizeof(L"LDAP://") + (wcslen(ldap->host) + 1 /* '/' */) * sizeof(WCHAR);
         if (dn) count += wcslen(dn) * sizeof(WCHAR);
 
-        col->pADsValues[0].u.CaseIgnoreString = heap_alloc(count);
+        col->pADsValues[0].u.CaseIgnoreString = malloc(count);
         if (!col->pADsValues[0].u.CaseIgnoreString)
         {
             hr = E_OUTOFMEMORY;
@@ -1794,7 +1813,7 @@ static HRESULT WINAPI search_GetColumn(IDirectorySearch *iface, ADS_SEARCH_HANDL
         col->pADsValues[0].dwType = ADSTYPE_CASE_IGNORE_STRING;
         col->dwADsType = ADSTYPE_CASE_IGNORE_STRING;
         col->dwNumValues = 1;
-        col->pszAttrName = strdupW(name);
+        col->pszAttrName = wcsdup(name);
         col->hReserved = NULL;
 
         TRACE("=> %s\n", debugstr_w(col->pADsValues[0].u.CaseIgnoreString));
@@ -1814,9 +1833,9 @@ static HRESULT WINAPI search_FreeColumn(IDirectorySearch *iface, PADS_SEARCH_COL
     if (!col) return E_ADS_BAD_PARAMETER;
 
     if (!wcsicmp(col->pszAttrName, L"ADsPath"))
-        heap_free(col->pADsValues[0].u.CaseIgnoreString);
-    heap_free(col->pADsValues);
-    heap_free(col->pszAttrName);
+        free(col->pADsValues[0].u.CaseIgnoreString);
+    free(col->pADsValues);
+    free(col->pszAttrName);
 
     if (col->hReserved)
     {
@@ -1844,7 +1863,7 @@ static HRESULT WINAPI search_CloseSearchHandle(IDirectorySearch *iface, ADS_SEAR
         ldap_msgfree(ldap_ctx->res);
     if (ldap_ctx->ber)
         ber_free(ldap_ctx->ber, 0);
-    heap_free(ldap_ctx);
+    free(ldap_ctx);
 
     return S_OK;
 }
@@ -1911,21 +1930,21 @@ static HRESULT WINAPI dirobj_GetObjectInformation(IDirectoryObject *iface, PADS_
 static HRESULT WINAPI dirobj_GetObjectAttributes(IDirectoryObject *iface, LPWSTR *names,
                                                  DWORD count, PADS_ATTR_INFO *attrs, DWORD *count_returned)
 {
-    FIXME("%p,%p,%u,%p,%p: stub\n", iface, names, count, attrs, count_returned);
+    FIXME("%p,%p,%lu,%p,%p: stub\n", iface, names, count, attrs, count_returned);
     return E_NOTIMPL;
 }
 
 static HRESULT WINAPI dirobj_SetObjectAttributes(IDirectoryObject *iface, PADS_ATTR_INFO attrs,
                                                  DWORD count, DWORD *count_set)
 {
-    FIXME("%p,%p,%u,%p: stub\n", iface, attrs, count, count_set);
+    FIXME("%p,%p,%lu,%p: stub\n", iface, attrs, count, count_set);
     return E_NOTIMPL;
 }
 
 static HRESULT WINAPI dirobj_CreateDSObject(IDirectoryObject *iface, LPWSTR name,
                                             PADS_ATTR_INFO attrs, DWORD count, IDispatch **obj)
 {
-    FIXME("%p,%s,%p,%u,%p: stub\n", iface, debugstr_w(name), attrs, count, obj);
+    FIXME("%p,%s,%p,%lu,%p: stub\n", iface, debugstr_w(name), attrs, count, obj);
     return E_NOTIMPL;
 }
 
@@ -1952,7 +1971,7 @@ static HRESULT LDAPNamespace_create(REFIID riid, void **obj)
     LDAP_namespace *ldap;
     HRESULT hr;
 
-    ldap = heap_alloc(sizeof(*ldap));
+    ldap = malloc(sizeof(*ldap));
     if (!ldap) return E_OUTOFMEMORY;
 
     ldap->IADs_iface.lpVtbl = &IADs_vtbl;
@@ -1968,6 +1987,7 @@ static HRESULT LDAPNamespace_create(REFIID riid, void **obj)
     ldap->attrs = NULL;
     ldap->search.scope = ADS_SCOPE_SUBTREE;
     ldap->search.pagesize = 0;
+    ldap->search.size_limit = 0;
     ldap->search.cache_results = TRUE;
     ldap->search.attribtypes_only = FALSE;
     ldap->search.tombstone = FALSE;
@@ -2028,7 +2048,7 @@ static ULONG WINAPI factory_AddRef(IClassFactory *iface)
     class_factory *factory = impl_from_IClassFactory(iface);
     ULONG ref = InterlockedIncrement(&factory->ref);
 
-    TRACE("(%p) ref %u\n", iface, ref);
+    TRACE("(%p) ref %lu\n", iface, ref);
 
     return ref;
 }
@@ -2038,10 +2058,10 @@ static ULONG WINAPI factory_Release(IClassFactory *iface)
     class_factory *factory = impl_from_IClassFactory(iface);
     ULONG ref = InterlockedDecrement(&factory->ref);
 
-    TRACE("(%p) ref %u\n", iface, ref);
+    TRACE("(%p) ref %lu\n", iface, ref);
 
     if (!ref)
-        heap_free(factory);
+        free(factory);
 
     return ref;
 }
@@ -2080,7 +2100,7 @@ static HRESULT factory_constructor(const struct class_info *info, REFIID riid, v
     class_factory *factory;
     HRESULT hr;
 
-    factory = heap_alloc(sizeof(*factory));
+    factory = malloc(sizeof(*factory));
     if (!factory) return E_OUTOFMEMORY;
 
     factory->IClassFactory_iface.lpVtbl = &factory_vtbl;
