@@ -143,7 +143,7 @@ static void test_winmodule(void)
 
     winmod.cbSize = 0xdeadbeef;
     hres = AtlWinModuleInit(&winmod);
-    ok(hres == E_INVALIDARG, "AtlWinModuleInit failed: %08x\n", hres);
+    ok(hres == E_INVALIDARG, "AtlWinModuleInit failed: %08lx\n", hres);
 
     winmod.cbSize = sizeof(winmod);
     winmod.m_pCreateWndList = (void*)0xdeadbeef;
@@ -152,9 +152,9 @@ static void test_winmodule(void)
     winmod.m_rgWindowClassAtoms.m_nSize = 0xdeadbeef;
     winmod.m_rgWindowClassAtoms.m_nAllocSize = 0xdeadbeef;
     hres = AtlWinModuleInit(&winmod);
-    ok(hres == S_OK, "AtlWinModuleInit failed: %08x\n", hres);
+    ok(hres == S_OK, "AtlWinModuleInit failed: %08lx\n", hres);
     ok(!winmod.m_pCreateWndList, "winmod.m_pCreateWndList = %p\n", winmod.m_pCreateWndList);
-    ok(winmod.m_csWindowCreate.LockCount == -1, "winmod.m_csWindowCreate.LockCount = %d\n",
+    ok(winmod.m_csWindowCreate.LockCount == -1, "winmod.m_csWindowCreate.LockCount = %ld\n",
        winmod.m_csWindowCreate.LockCount);
     ok(winmod.m_rgWindowClassAtoms.m_aT == (void*)0xdeadbeef, "winmod.m_rgWindowClassAtoms.m_aT = %p\n",
        winmod.m_rgWindowClassAtoms.m_aT);
@@ -168,21 +168,21 @@ static void test_winmodule(void)
     AtlWinModuleAddCreateWndData(&winmod, create_data, (void*)0xdead0001);
     ok(winmod.m_pCreateWndList == create_data, "winmod.m_pCreateWndList != create_data\n");
     ok(create_data[0].m_pThis == (void*)0xdead0001, "unexpected create_data[0].m_pThis %p\n", create_data[0].m_pThis);
-    ok(create_data[0].m_dwThreadID == GetCurrentThreadId(), "unexpected create_data[0].m_dwThreadID %x\n",
+    ok(create_data[0].m_dwThreadID == GetCurrentThreadId(), "unexpected create_data[0].m_dwThreadID %lx\n",
        create_data[0].m_dwThreadID);
     ok(!create_data[0].m_pNext, "unexpected create_data[0].m_pNext %p\n", create_data[0].m_pNext);
 
     AtlWinModuleAddCreateWndData(&winmod, create_data+1, (void*)0xdead0002);
     ok(winmod.m_pCreateWndList == create_data+1, "winmod.m_pCreateWndList != create_data\n");
     ok(create_data[1].m_pThis == (void*)0xdead0002, "unexpected create_data[1].m_pThis %p\n", create_data[1].m_pThis);
-    ok(create_data[1].m_dwThreadID == GetCurrentThreadId(), "unexpected create_data[1].m_dwThreadID %x\n",
+    ok(create_data[1].m_dwThreadID == GetCurrentThreadId(), "unexpected create_data[1].m_dwThreadID %lx\n",
        create_data[1].m_dwThreadID);
     ok(create_data[1].m_pNext == create_data, "unexpected create_data[1].m_pNext %p\n", create_data[1].m_pNext);
 
     AtlWinModuleAddCreateWndData(&winmod, create_data+2, (void*)0xdead0003);
     ok(winmod.m_pCreateWndList == create_data+2, "winmod.m_pCreateWndList != create_data\n");
     ok(create_data[2].m_pThis == (void*)0xdead0003, "unexpected create_data[2].m_pThis %p\n", create_data[2].m_pThis);
-    ok(create_data[2].m_dwThreadID == GetCurrentThreadId(), "unexpected create_data[2].m_dwThreadID %x\n",
+    ok(create_data[2].m_dwThreadID == GetCurrentThreadId(), "unexpected create_data[2].m_dwThreadID %lx\n",
        create_data[2].m_dwThreadID);
     ok(create_data[2].m_pNext == create_data+1, "unexpected create_data[2].m_pNext %p\n", create_data[2].m_pNext);
 
@@ -223,7 +223,7 @@ static void _test_key_not_exists(unsigned line, HKEY root, const char *key_name)
     DWORD res;
 
     res = RegOpenKeyA(root, key_name, &key);
-    ok_(__FILE__,line)(res == ERROR_FILE_NOT_FOUND, "Attempting to open %s returned %u\n", key_name, res);
+    ok_(__FILE__,line)(res == ERROR_FILE_NOT_FOUND, "Attempting to open %s returned %lu\n", key_name, res);
     if(res == ERROR_SUCCESS)
         RegCloseKey(key);
 }
@@ -246,14 +246,14 @@ static void test_regcat(void)
     }
 
     hres = AtlRegisterClassCategoriesHelper(&CLSID_Test, catmap, TRUE);
-    ok(hres == S_OK, "AtlRegisterClassCategoriesHelper failed: %08x\n", hres);
+    ok(hres == S_OK, "AtlRegisterClassCategoriesHelper failed: %08lx\n", hres);
 
     test_key_exists(HKEY_CLASSES_ROOT, "CLSID\\{" CLSID_TEST_STR "}");
     test_key_exists(HKEY_CLASSES_ROOT, "CLSID\\{" CLSID_TEST_STR "}\\Implemented Categories\\{" CATID_CATTEST1_STR "}");
     test_key_exists(HKEY_CLASSES_ROOT, "CLSID\\{" CLSID_TEST_STR "}\\Required Categories\\{" CATID_CATTEST2_STR "}");
 
     hres = AtlRegisterClassCategoriesHelper(&CLSID_Test, catmap, FALSE);
-    ok(hres == S_OK, "AtlRegisterClassCategoriesHelper failed: %08x\n", hres);
+    ok(hres == S_OK, "AtlRegisterClassCategoriesHelper failed: %08lx\n", hres);
 
     test_key_not_exists(HKEY_CLASSES_ROOT, "CLSID\\{" CLSID_TEST_STR "}\\Implemented Categories");
     test_key_not_exists(HKEY_CLASSES_ROOT, "CLSID\\{" CLSID_TEST_STR "}\\Required Categories");
@@ -262,13 +262,13 @@ static void test_regcat(void)
     ok(RegDeleteKeyA(HKEY_CLASSES_ROOT, "CLSID\\{" CLSID_TEST_STR "}") == ERROR_SUCCESS, "Could not delete key\n");
 
     hres = AtlRegisterClassCategoriesHelper(&CLSID_Test, NULL, TRUE);
-    ok(hres == S_OK, "AtlRegisterClassCategoriesHelper failed: %08x\n", hres);
+    ok(hres == S_OK, "AtlRegisterClassCategoriesHelper failed: %08lx\n", hres);
 
     test_key_not_exists(HKEY_CLASSES_ROOT, "CLSID\\{" CLSID_TEST_STR "}");
 
     b = 10;
     hres = AtlGetPerUserRegistration(&b);
-    ok(hres == S_OK, "AtlGetPerUserRegistration failed: %08x\n", hres);
+    ok(hres == S_OK, "AtlGetPerUserRegistration failed: %08lx\n", hres);
     ok(!b, "AtlGetPerUserRegistration returned %x\n", b);
 }
 
@@ -285,7 +285,7 @@ static void test_typelib(void)
 
     typelib = NULL;
     hres = AtlLoadTypeLib(inst, NULL, &path, &typelib);
-    ok(hres == S_OK, "AtlLoadTypeLib failed: %08x\n", hres);
+    ok(hres == S_OK, "AtlLoadTypeLib failed: %08lx\n", hres);
     FreeLibrary(inst);
 
     len = SysStringLen(path);
@@ -301,7 +301,7 @@ static void test_typelib(void)
 
     typelib = NULL;
     hres = AtlLoadTypeLib(inst, NULL, &path, &typelib);
-    ok(hres == S_OK, "AtlLoadTypeLib failed: %08x\n", hres);
+    ok(hres == S_OK, "AtlLoadTypeLib failed: %08lx\n", hres);
     FreeLibrary(inst);
 
     len = SysStringLen(path);
@@ -360,7 +360,7 @@ static HRESULT WINAPI ConnectionPoint_Advise(IConnectionPoint *iface, IUnknown *
 
 static HRESULT WINAPI ConnectionPoint_Unadvise(IConnectionPoint *iface, DWORD dwCookie)
 {
-    ok(dwCookie == 0xdeadbeef, "dwCookie = %x\n", dwCookie);
+    ok(dwCookie == 0xdeadbeef, "dwCookie = %lx\n", dwCookie);
     advise_cnt--;
     return S_OK;
 }
@@ -439,18 +439,18 @@ static void test_cp(void)
     HRESULT hres;
 
     hres = AtlAdvise(NULL, (IUnknown*)0xdeed0000, &CLSID_Test, &cookie);
-    ok(hres == E_INVALIDARG, "expect E_INVALIDARG, returned %08x\n", hres);
+    ok(hres == E_INVALIDARG, "expect E_INVALIDARG, returned %08lx\n", hres);
 
     hres = AtlUnadvise(NULL, &CLSID_Test, 0xdeadbeef);
-    ok(hres == E_INVALIDARG, "expect E_INVALIDARG, returned %08x\n", hres);
+    ok(hres == E_INVALIDARG, "expect E_INVALIDARG, returned %08lx\n", hres);
 
     hres = AtlAdvise((IUnknown*)&ConnectionPointContainer, (IUnknown*)0xdead0000, &CLSID_Test, &cookie);
-    ok(hres == S_OK, "AtlAdvise failed: %08x\n", hres);
-    ok(cookie == 0xdeadbeef, "cookie = %x\n", cookie);
+    ok(hres == S_OK, "AtlAdvise failed: %08lx\n", hres);
+    ok(cookie == 0xdeadbeef, "cookie = %lx\n", cookie);
     ok(advise_cnt == 1, "advise_cnt = %d\n", advise_cnt);
 
     hres = AtlUnadvise((IUnknown*)&ConnectionPointContainer, &CLSID_Test, 0xdeadbeef);
-    ok(hres == S_OK, "AtlUnadvise failed: %08x\n", hres);
+    ok(hres == S_OK, "AtlUnadvise failed: %08lx\n", hres);
     ok(!advise_cnt, "advise_cnt = %d\n", advise_cnt);
 }
 
@@ -511,7 +511,7 @@ static HRESULT WINAPI ProvideClassInfo2_GetClassInfo(IProvideClassInfo2 *iface,
 
 static HRESULT WINAPI ProvideClassInfo2_GetGUID(IProvideClassInfo2 *iface, DWORD dwGuidKind, GUID *pGUID)
 {
-    ok(dwGuidKind == GUIDKIND_DEFAULT_SOURCE_DISP_IID, "unexpected dwGuidKind %x\n", dwGuidKind);
+    ok(dwGuidKind == GUIDKIND_DEFAULT_SOURCE_DISP_IID, "unexpected dwGuidKind %lx\n", dwGuidKind);
     *pGUID = DIID_DispHTMLBody;
     return S_OK;
 }
@@ -575,13 +575,13 @@ static HRESULT WINAPI Dispatch_GetTypeInfo(IDispatch *iface, UINT iTInfo, LCID l
     HRESULT hres;
 
     ok(!iTInfo, "iTInfo = %d\n", iTInfo);
-    ok(!lcid, "lcid = %x\n", lcid);
+    ok(!lcid, "lcid = %lx\n", lcid);
 
     hres = LoadTypeLib(L"mshtml.tlb", &typelib);
-    ok(hres == S_OK, "LoadTypeLib failed: %08x\n", hres);
+    ok(hres == S_OK, "LoadTypeLib failed: %08lx\n", hres);
 
     hres = ITypeLib_GetTypeInfoOfGuid(typelib, &IID_IHTMLElement, ppTInfo);
-    ok(hres == S_OK, "GetTypeInfoOfGuid failed: %08x\n", hres);
+    ok(hres == S_OK, "GetTypeInfoOfGuid failed: %08lx\n", hres);
 
     ITypeLib_Release(typelib);
     return S_OK;
@@ -624,7 +624,7 @@ static void test_source_iface(void)
 
     maj_ver = min_ver = 0xdead;
     hres = AtlGetObjectSourceInterface((IUnknown*)&Dispatch, &libid, &iid, &maj_ver, &min_ver);
-    ok(hres == S_OK, "AtlGetObjectSourceInterface failed: %08x\n", hres);
+    ok(hres == S_OK, "AtlGetObjectSourceInterface failed: %08lx\n", hres);
     ok(IsEqualGUID(&libid, &LIBID_MSHTML), "libid = %s\n", wine_dbgstr_guid(&libid));
     ok(IsEqualGUID(&iid, &DIID_DispHTMLBody), "iid = %s\n", wine_dbgstr_guid(&iid));
     ok(maj_ver == 4 && min_ver == 0, "ver = %d.%d\n", maj_ver, min_ver);
@@ -634,7 +634,7 @@ static void test_source_iface(void)
 
     maj_ver = min_ver = 0xdead;
     hres = AtlGetObjectSourceInterface((IUnknown*)&Dispatch, &libid, &iid, &maj_ver, &min_ver);
-    ok(hres == S_OK, "AtlGetObjectSourceInterface failed: %08x\n", hres);
+    ok(hres == S_OK, "AtlGetObjectSourceInterface failed: %08lx\n", hres);
     ok(IsEqualGUID(&libid, &LIBID_MSHTML), "libid = %s\n", wine_dbgstr_guid(&libid));
     ok(IsEqualGUID(&iid, &DIID_HTMLDocumentEvents), "iid = %s\n", wine_dbgstr_guid(&iid));
     ok(maj_ver == 4 && min_ver == 0, "ver = %d.%d\n", maj_ver, min_ver);
@@ -643,7 +643,7 @@ static void test_source_iface(void)
 
     maj_ver = min_ver = 0xdead;
     hres = AtlGetObjectSourceInterface((IUnknown*)&Dispatch, &libid, &iid, &maj_ver, &min_ver);
-    ok(hres == S_OK, "AtlGetObjectSourceInterface failed: %08x\n", hres);
+    ok(hres == S_OK, "AtlGetObjectSourceInterface failed: %08lx\n", hres);
     ok(IsEqualGUID(&libid, &LIBID_MSHTML), "libid = %s\n", wine_dbgstr_guid(&libid));
     ok(IsEqualGUID(&iid, &IID_NULL), "iid = %s\n", wine_dbgstr_guid(&iid));
     ok(maj_ver == 4 && min_ver == 0, "ver = %d.%d\n", maj_ver, min_ver);
@@ -684,7 +684,7 @@ static void test_ax_win(void)
         ok(hwnd != NULL, "CreateWindow failed!\n");
         control = (IUnknown *)0xdeadbeef;
         res = AtlAxGetControl(hwnd, &control);
-        ok(res == E_FAIL, "Expected E_FAIL, returned %08x\n", res);
+        ok(res == E_FAIL, "Expected E_FAIL, returned %08lx\n", res);
         ok(!control, "returned %p\n", control);
         if (control) IUnknown_Release(control);
         DestroyWindow(hwnd);
@@ -693,7 +693,7 @@ static void test_ax_win(void)
         ok(hwnd != NULL, "CreateWindow failed!\n");
         control = (IUnknown *)0xdeadbeef;
         res = AtlAxGetControl(hwnd, &control);
-        ok(res == E_FAIL, "Expected E_FAIL, returned %08x\n", res);
+        ok(res == E_FAIL, "Expected E_FAIL, returned %08lx\n", res);
         ok(!control, "returned %p\n", control);
         if (control) IUnknown_Release(control);
         DestroyWindow(hwnd);
@@ -706,7 +706,7 @@ static void test_ax_win(void)
         ok(hwnd != NULL, "CreateWindow failed!\n");
         control = NULL;
         res = AtlAxGetControl(hwnd, &control);
-        ok(res == S_OK, "AtlAxGetControl failed with res %08x\n", res);
+        ok(res == S_OK, "AtlAxGetControl failed with res %08lx\n", res);
         ok(control != NULL, "AtlAxGetControl failed!\n");
         IUnknown_Release(control);
         DestroyWindow(hwnd);
@@ -715,7 +715,7 @@ static void test_ax_win(void)
         ok(hwnd != NULL, "CreateWindow failed!\n");
         control = NULL;
         res = AtlAxGetControl(hwnd, &control);
-        ok(res == S_OK, "AtlAxGetControl failed with res %08x\n", res);
+        ok(res == S_OK, "AtlAxGetControl failed with res %08lx\n", res);
         ok(control != NULL, "AtlAxGetControl failed!\n");
         IUnknown_Release(control);
         DestroyWindow(hwnd);
@@ -724,7 +724,7 @@ static void test_ax_win(void)
         ok(hwnd != NULL, "CreateWindow failed!\n");
         control = NULL;
         res = AtlAxGetControl(hwnd, &control);
-        ok(res == S_OK, "AtlAxGetControl failed with res %08x\n", res);
+        ok(res == S_OK, "AtlAxGetControl failed with res %08lx\n", res);
         ok(control != NULL, "AtlAxGetControl failed!\n");
         IUnknown_Release(control);
         DestroyWindow(hwnd);
@@ -734,7 +734,7 @@ static void test_ax_win(void)
         ok(hwnd != NULL, "CreateWindow failed!\n");
         control = NULL;
         res = AtlAxGetControl(hwnd, &control);
-        ok(res == S_OK, "AtlAxGetControl failed with res %08x\n", res);
+        ok(res == S_OK, "AtlAxGetControl failed with res %08lx\n", res);
         ok(control != NULL, "AtlAxGetControl failed!\n");
         IUnknown_Release(control);
         DestroyWindow(hwnd);
@@ -743,7 +743,7 @@ static void test_ax_win(void)
         ok(hwnd != NULL, "CreateWindow failed!\n");
         control = NULL;
         res = AtlAxGetControl(hwnd, &control);
-        ok(res == S_OK, "AtlAxGetControl failed with res %08x\n", res);
+        ok(res == S_OK, "AtlAxGetControl failed with res %08lx\n", res);
         ok(control != NULL, "AtlAxGetControl failed!\n");
         IUnknown_Release(control);
         DestroyWindow(hwnd);
@@ -767,7 +767,7 @@ static void test_ax_win(void)
         ok(hwnd != NULL, "CreateWindow failed!\n");
         control = NULL;
         res = AtlAxGetControl(hwnd, &control);
-        ok(res == S_OK, "AtlAxGetControl failed with res %08x\n", res);
+        ok(res == S_OK, "AtlAxGetControl failed with res %08lx\n", res);
         ok(control != NULL, "AtlAxGetControl failed!\n");
         IUnknown_Release(control);
         DestroyWindow(hwnd);
@@ -779,7 +779,7 @@ static void test_ax_win(void)
         ok(hwnd != NULL, "CreateWindow failed!\n");
         control = NULL;
         res = AtlAxGetControl(hwnd, &control);
-        ok(res == S_OK, "AtlAxGetControl failed with res %08x\n", res);
+        ok(res == S_OK, "AtlAxGetControl failed with res %08lx\n", res);
         ok(control != NULL, "AtlAxGetControl failed!\n");
         IUnknown_Release(control);
         DestroyWindow(hwnd);
@@ -791,7 +791,7 @@ static void test_ax_win(void)
         ok(hwnd != NULL, "CreateWindow failed!\n");
         control = NULL;
         res = AtlAxGetControl(hwnd, &control);
-        ok(res == S_OK, "AtlAxGetControl failed with res %08x\n", res);
+        ok(res == S_OK, "AtlAxGetControl failed with res %08lx\n", res);
         ok(control != NULL, "AtlAxGetControl failed!\n");
         IUnknown_Release(control);
         DestroyWindow(hwnd);
@@ -832,29 +832,29 @@ static void test_AtlAxAttachControl(void)
     LONG val;
 
     hr = AtlAxAttachControl(NULL, NULL, NULL);
-    ok(hr == E_INVALIDARG, "Expected AtlAxAttachControl to return E_INVALIDARG, got 0x%08x\n", hr);
+    ok(hr == E_INVALIDARG, "Expected AtlAxAttachControl to return E_INVALIDARG, got 0x%08lx\n", hr);
 
     container = (IUnknown *)0xdeadbeef;
     hr = AtlAxAttachControl(NULL, NULL, &container);
-    ok(hr == E_INVALIDARG, "Expected AtlAxAttachControl to return E_INVALIDARG, got 0x%08x\n", hr);
+    ok(hr == E_INVALIDARG, "Expected AtlAxAttachControl to return E_INVALIDARG, got 0x%08lx\n", hr);
     ok(container == (IUnknown *)0xdeadbeef,
        "Expected the output container pointer to be untouched, got %p\n", container);
 
     hwnd = create_container_window();
     hr = AtlAxAttachControl(NULL, hwnd, NULL);
-    ok(hr == E_INVALIDARG, "Expected AtlAxAttachControl to return E_INVALIDARG, got 0x%08x\n", hr);
+    ok(hr == E_INVALIDARG, "Expected AtlAxAttachControl to return E_INVALIDARG, got 0x%08lx\n", hr);
     DestroyWindow(hwnd);
 
     hwnd = create_container_window();
     container = (IUnknown *)0xdeadbeef;
     hr = AtlAxAttachControl(NULL, hwnd, &container);
-    ok(hr == E_INVALIDARG, "Expected AtlAxAttachControl to return E_INVALIDARG, got 0x%08x\n", hr);
+    ok(hr == E_INVALIDARG, "Expected AtlAxAttachControl to return E_INVALIDARG, got 0x%08lx\n", hr);
     ok(container == (IUnknown *)0xdeadbeef, "returned %p\n", container);
     DestroyWindow(hwnd);
 
     hr = CoCreateInstance(&CLSID_WebBrowser, NULL, CLSCTX_INPROC_SERVER | CLSCTX_INPROC_HANDLER,
                           &IID_IOleObject, (void **)&control);
-    ok(hr == S_OK, "Expected CoCreateInstance to return S_OK, got 0x%08x\n", hr);
+    ok(hr == S_OK, "Expected CoCreateInstance to return S_OK, got 0x%08lx\n", hr);
 
     if (FAILED(hr))
     {
@@ -863,31 +863,31 @@ static void test_AtlAxAttachControl(void)
     }
 
     hr = AtlAxAttachControl(control, NULL, NULL);
-    ok(hr == S_FALSE, "Expected AtlAxAttachControl to return S_FALSE, got 0x%08x\n", hr);
+    ok(hr == S_FALSE, "Expected AtlAxAttachControl to return S_FALSE, got 0x%08lx\n", hr);
 
     container = NULL;
     hr = AtlAxAttachControl(control, NULL, &container);
-    ok(hr == S_FALSE, "Expected AtlAxAttachControl to return S_FALSE, got 0x%08x\n", hr);
+    ok(hr == S_FALSE, "Expected AtlAxAttachControl to return S_FALSE, got 0x%08lx\n", hr);
     ok(container != NULL, "got %p\n", container);
     IUnknown_Release(container);
 
     hwnd = create_container_window();
     SetWindowLongW(hwnd, GWLP_USERDATA, 0xdeadbeef);
     hr = AtlAxAttachControl(control, hwnd, NULL);
-    ok(hr == S_OK, "Expected AtlAxAttachControl to return S_OK, got 0x%08x\n", hr);
+    ok(hr == S_OK, "Expected AtlAxAttachControl to return S_OK, got 0x%08lx\n", hr);
     val = GetWindowLongW(hwnd, GWLP_USERDATA);
-    ok(val == 0xdeadbeef, "returned %08x\n", val);
+    ok(val == 0xdeadbeef, "returned %08lx\n", val);
     DestroyWindow(hwnd);
 
     hwnd = create_container_window();
     SetWindowLongW(hwnd, GWLP_USERDATA, 0xdeadbeef);
     container = NULL;
     hr = AtlAxAttachControl(control, hwnd, &container);
-    ok(hr == S_OK, "Expected AtlAxAttachControl to return S_OK, got 0x%08x\n", hr);
+    ok(hr == S_OK, "Expected AtlAxAttachControl to return S_OK, got 0x%08lx\n", hr);
     ok(container != NULL, "Expected not NULL!\n");
     IUnknown_Release(container);
     val = GetWindowLongW(hwnd, GWLP_USERDATA);
-    ok(val == 0xdeadbeef, "Expected unchanged, returned %08x\n", val);
+    ok(val == 0xdeadbeef, "Expected unchanged, returned %08lx\n", val);
     DestroyWindow(hwnd);
 
     IUnknown_Release(control);
@@ -905,7 +905,7 @@ static void test_AtlAxCreateControl(void)
     container = NULL;
     control = (IUnknown *)0xdeadbeef;
     hr = AtlAxCreateControlEx(NULL, NULL, NULL, &container, &control, NULL, NULL);
-    todo_wine ok(hr == S_FALSE, "got 0x%08x\n", hr);
+    todo_wine ok(hr == S_FALSE, "got 0x%08lx\n", hr);
     todo_wine ok(container != NULL, "returned %p\n", container);
     ok(!control, "returned %p\n", control);
 
@@ -914,7 +914,7 @@ static void test_AtlAxCreateControl(void)
     hwnd = create_container_window();
     ok(hwnd != NULL, "create window failed!\n");
     hr = AtlAxCreateControlEx(NULL, hwnd, NULL, &container, &control, &IID_NULL, NULL);
-    ok(hr == S_OK, "got 0x%08x\n", hr);
+    ok(hr == S_OK, "got 0x%08lx\n", hr);
     todo_wine ok(container != NULL, "returned %p!\n", container);
     ok(!control, "returned %p\n", control);
     DestroyWindow(hwnd);
@@ -924,7 +924,7 @@ static void test_AtlAxCreateControl(void)
     hwnd = create_container_window();
     ok(hwnd != NULL, "create window failed!\n");
     hr = AtlAxCreateControlEx(L"", hwnd, NULL, &container, &control, &IID_NULL, NULL);
-    ok(hr == S_OK, "got 0x%08x\n", hr);
+    ok(hr == S_OK, "got 0x%08lx\n", hr);
     todo_wine ok(container != NULL, "returned %p!\n", container);
     ok(!control, "returned %p\n", control);
     DestroyWindow(hwnd);
@@ -934,7 +934,7 @@ static void test_AtlAxCreateControl(void)
     hwnd = create_container_window();
     ok(hwnd != NULL, "create window failed!\n");
     hr = AtlAxCreateControlEx(L"random", hwnd, NULL, &container, &control, &IID_NULL, NULL);
-    ok(hr == CO_E_CLASSSTRING, "got 0x%08x\n", hr);
+    ok(hr == CO_E_CLASSSTRING, "got 0x%08lx\n", hr);
     ok(!container, "returned %p!\n", container);
     ok(!control, "returned %p\n", control);
     DestroyWindow(hwnd);
@@ -944,7 +944,7 @@ static void test_AtlAxCreateControl(void)
     hwnd = create_container_window();
     ok(hwnd != NULL, "create window failed!\n");
     hr = AtlAxCreateControlEx(progid1W, hwnd, NULL, &container, &control, &IID_NULL, NULL);
-    ok(hr == S_OK, "got 0x%08x\n", hr);
+    ok(hr == S_OK, "got 0x%08lx\n", hr);
     ok(container != NULL, "returned %p!\n", container);
     ok(control != NULL, "returned %p\n", control);
     IUnknown_Release(container);
@@ -956,7 +956,7 @@ static void test_AtlAxCreateControl(void)
     hwnd = create_container_window();
     ok(hwnd != NULL, "create window failed!\n");
     hr = AtlAxCreateControlEx(clsid1W, hwnd, NULL, &container, &control, &IID_NULL, NULL);
-    ok(hr == S_OK, "got 0x%08x\n", hr);
+    ok(hr == S_OK, "got 0x%08lx\n", hr);
     ok(container != NULL, "returned %p!\n", container);
     ok(control != NULL, "returned %p\n", control);
     IUnknown_Release(container);
@@ -968,7 +968,7 @@ static void test_AtlAxCreateControl(void)
     hwnd = create_container_window();
     ok(hwnd != NULL, "create window failed!\n");
     hr = AtlAxCreateControlEx(url1W, hwnd, NULL, &container, &control, &IID_NULL, NULL);
-    ok(hr == S_OK, "got 0x%08x\n", hr);
+    ok(hr == S_OK, "got 0x%08lx\n", hr);
     ok(container != NULL, "returned %p!\n", container);
     ok(control != NULL, "returned %p\n", control);
     IUnknown_Release(container);
@@ -980,7 +980,7 @@ static void test_AtlAxCreateControl(void)
     hwnd = create_container_window();
     ok(hwnd != NULL, "create window failed!\n");
     hr = AtlAxCreateControlEx(mshtml1W, hwnd, NULL, &container, &control, &IID_NULL, NULL);
-    ok(hr == S_OK, "got 0x%08x\n", hr);
+    ok(hr == S_OK, "got 0x%08lx\n", hr);
     ok(container != NULL, "returned %p!\n", container);
     ok(control != NULL, "returned %p\n", control);
     IUnknown_Release(container);
@@ -992,7 +992,7 @@ static void test_AtlAxCreateControl(void)
     hwnd = create_container_window();
     ok(hwnd != NULL, "create window failed!\n");
     hr = AtlAxCreateControlEx(mshtml2W, hwnd, NULL, &container, &control, &IID_NULL, NULL);
-    ok(hr == S_OK, "got 0x%08x\n", hr);
+    ok(hr == S_OK, "got 0x%08lx\n", hr);
     ok(container != NULL, "returned %p!\n", container);
     ok(control != NULL, "returned %p\n", control);
     IUnknown_Release(container);
@@ -1004,7 +1004,7 @@ static void test_AtlAxCreateControl(void)
     hwnd = create_container_window();
     ok(hwnd != NULL, "create window failed!\n");
     hr = AtlAxCreateControlEx(mshtml3W, hwnd, NULL, &container, &control, &IID_NULL, NULL);
-    ok(hr == CO_E_CLASSSTRING, "got 0x%08x\n", hr);
+    ok(hr == CO_E_CLASSSTRING, "got 0x%08lx\n", hr);
     ok(!container, "returned %p!\n", container);
     ok(!control, "returned %p\n", control);
     DestroyWindow(hwnd);
@@ -1024,7 +1024,7 @@ static void test_AtlAxCreateControl(void)
     hwnd = create_container_window();
     ok(hwnd != NULL, "create window failed!\n");
     hr = AtlAxCreateControlEx(pathW, hwnd, NULL, &container, &control, &IID_NULL, NULL);
-    ok(hr == S_OK, "got 0x%08x\n", hr);
+    ok(hr == S_OK, "got 0x%08lx\n", hr);
     ok(container != NULL, "returned %p!\n", container);
     ok(control != NULL, "returned %p\n", control);
     IUnknown_Release(container);
@@ -1039,7 +1039,7 @@ static void test_AtlAxCreateControl(void)
     hwnd = create_container_window();
     ok(hwnd != NULL, "create window failed!\n");
     hr = AtlAxCreateControlEx(file_uri1W, hwnd, NULL, &container, &control, &IID_NULL, NULL);
-    ok(hr == S_OK, "got 0x%08x\n", hr);
+    ok(hr == S_OK, "got 0x%08lx\n", hr);
     ok(container != NULL, "returned %p!\n", container);
     ok(control != NULL, "returned %p\n", control);
     IUnknown_Release(container);
@@ -1054,7 +1054,7 @@ static void test_AtlAxCreateControl(void)
     hwnd = create_container_window();
     ok(hwnd != NULL, "create window failed!\n");
     hr = AtlAxCreateControlEx(file_uri1W, hwnd, NULL, &container, &control, &IID_NULL, NULL);
-    ok(hr == S_OK, "got 0x%08x\n", hr);
+    ok(hr == S_OK, "got 0x%08lx\n", hr);
     ok(container != NULL, "returned %p!\n", container);
     ok(control != NULL, "returned %p\n", control);
     IUnknown_Release(container);
@@ -1062,6 +1062,84 @@ static void test_AtlAxCreateControl(void)
     DestroyWindow(hwnd);
 }
 
+static void test_AtlComModuleGetClassObject(void)
+{
+    _ATL_OBJMAP_ENTRY *null_entry = NULL;
+    _ATL_COM_MODULE module;
+    HRESULT hr;
+    void *ret;
+
+    /* Test NULL module */
+    hr = AtlComModuleGetClassObject(NULL, &GUID_NULL, &IID_NULL, &ret);
+    ok(hr == E_INVALIDARG, "Unexpected hr %#lx.\n", hr);
+
+    /* Test NULL m_ppAutoObjMapFirst and m_ppAutoObjMapLast */
+    module.cbSize = sizeof(module);
+    module.m_ppAutoObjMapFirst = NULL;
+    module.m_ppAutoObjMapLast = NULL;
+    hr = AtlComModuleGetClassObject(&module, &GUID_NULL, &IID_NULL, &ret);
+    ok(hr == CLASS_E_CLASSNOTAVAILABLE, "Unexpected hr %#lx.\n", hr);
+
+    /* Test m_ppAutoObjMapFirst and m_ppAutoObjMapLast both pointing to a NULL entry */
+    module.cbSize = sizeof(module);
+    module.m_ppAutoObjMapFirst = &null_entry;
+    module.m_ppAutoObjMapLast = &null_entry;
+    hr = AtlComModuleGetClassObject(&module, &GUID_NULL, &IID_NULL, &ret);
+    ok(hr == CLASS_E_CLASSNOTAVAILABLE, "Unexpected hr %#lx.\n", hr);
+}
+
+static void test_AtlComModuleRegisterClassObjects(void)
+{
+    _ATL_OBJMAP_ENTRY *null_entry = NULL;
+    _ATL_COM_MODULE module;
+    HRESULT hr;
+
+    /* Test NULL module */
+    hr = AtlComModuleRegisterClassObjects(NULL, CLSCTX_INPROC_SERVER, REGCLS_MULTIPLEUSE);
+    ok(hr == E_INVALIDARG, "Unexpected hr %#lx.\n", hr);
+
+    /* Test NULL m_ppAutoObjMapFirst and m_ppAutoObjMapLast */
+    module.cbSize = sizeof(module);
+    module.m_ppAutoObjMapFirst = NULL;
+    module.m_ppAutoObjMapLast = NULL;
+    hr = AtlComModuleRegisterClassObjects(&module, CLSCTX_INPROC_SERVER, REGCLS_MULTIPLEUSE);
+    todo_wine_if(hr == S_OK)
+    ok(hr == S_FALSE, "Unexpected hr %#lx.\n", hr);
+
+    /* Test m_ppAutoObjMapFirst and m_ppAutoObjMapLast both pointing to a NULL entry */
+    module.cbSize = sizeof(module);
+    module.m_ppAutoObjMapFirst = &null_entry;
+    module.m_ppAutoObjMapLast = &null_entry;
+    hr = AtlComModuleRegisterClassObjects(&module, CLSCTX_INPROC_SERVER, REGCLS_MULTIPLEUSE);
+    todo_wine_if(hr == S_OK)
+    ok(hr == S_FALSE, "Unexpected hr %#lx.\n", hr);
+}
+
+static void test_AtlComModuleRevokeClassObjects(void)
+{
+    _ATL_OBJMAP_ENTRY *null_entry = NULL;
+    _ATL_COM_MODULE module;
+    HRESULT hr;
+
+    /* Test NULL module */
+    hr = AtlComModuleRevokeClassObjects(NULL);
+    ok(hr == E_INVALIDARG, "Unexpected hr %#lx.\n", hr);
+
+    /* Test NULL m_ppAutoObjMapFirst and m_ppAutoObjMapLast */
+    module.cbSize = sizeof(module);
+    module.m_ppAutoObjMapFirst = NULL;
+    module.m_ppAutoObjMapLast = NULL;
+    hr = AtlComModuleRevokeClassObjects(&module);
+    ok(hr == S_OK, "Unexpected hr %#lx.\n", hr);
+
+    /* Test m_ppAutoObjMapFirst and m_ppAutoObjMapLast both pointing to a NULL entry */
+    module.cbSize = sizeof(module);
+    module.m_ppAutoObjMapFirst = &null_entry;
+    module.m_ppAutoObjMapLast = &null_entry;
+    hr = AtlComModuleRevokeClassObjects(&module);
+    ok(hr == S_OK, "Unexpected hr %#lx.\n", hr);
+}
+
 START_TEST(atl)
 {
     if (!register_class())
@@ -1077,6 +1155,9 @@ START_TEST(atl)
     test_ax_win();
     test_AtlAxAttachControl();
     test_AtlAxCreateControl();
+    test_AtlComModuleGetClassObject();
+    test_AtlComModuleRegisterClassObjects();
+    test_AtlComModuleRevokeClassObjects();
 
     CoUninitialize();
 }
