@@ -34,8 +34,6 @@
 #include "shlguid.h"
 #include "shlobj.h"
 
-#include "wine/heap.h"
-
 #include "browseui.h"
 #include "resids.h"
 
@@ -88,17 +86,8 @@ static inline ProgressDialog *impl_from_IOleWindow(IOleWindow *iface)
 
 static void set_buffer(LPWSTR *buffer, LPCWSTR string)
 {
-    IMalloc *malloc;
-    ULONG cb;
-
-    if (string == NULL)
-        string = L"";
-    CoGetMalloc(MEMCTX_TASK, &malloc);
-
-    cb = (lstrlenW(string) + 1)*sizeof(WCHAR);
-    if (*buffer == NULL || cb > IMalloc_GetSize(malloc, *buffer))
-        *buffer = IMalloc_Realloc(malloc, *buffer, cb);
-    memcpy(*buffer, string, cb);
+    free(*buffer);
+    *buffer = wcsdup(string ? string : L"");
 }
 
 struct create_params
@@ -114,7 +103,7 @@ static LPWSTR load_string(HINSTANCE hInstance, UINT uiResourceId)
     LPWSTR ret;
 
     LoadStringW(hInstance, uiResourceId, string, ARRAY_SIZE(string));
-    ret = HeapAlloc(GetProcessHeap(), 0, (lstrlenW(string) + 1) * sizeof(WCHAR));
+    ret = malloc((lstrlenW(string) + 1) * sizeof(WCHAR));
     lstrcpyW(ret, string);
     return ret;
 }
@@ -277,17 +266,17 @@ static void ProgressDialog_Destructor(ProgressDialog *This)
     TRACE("destroying %p\n", This);
     if (This->hwnd)
         end_dialog(This);
-    for (i = 0; i < 3; i++)
-        heap_free(This->lines[i]);
-    heap_free(This->cancelMsg);
-    heap_free(This->title);
-    for (i = 0; i < 2; i++)
-        heap_free(This->remainingMsg[i]);
-    for (i = 0; i < 3; i++)
-        heap_free(This->timeMsg[i]);
+    for (i = 0; i < ARRAY_SIZE(This->lines); i++)
+        free(This->lines[i]);
+    free(This->cancelMsg);
+    free(This->title);
+    for (i = 0; i < ARRAY_SIZE(This->remainingMsg); i++)
+        free(This->remainingMsg[i]);
+    for (i = 0; i < ARRAY_SIZE(This->timeMsg); i++)
+        free(This->timeMsg[i]);
     This->cs.DebugInfo->Spare[0] = 0;
     DeleteCriticalSection(&This->cs);
-    heap_free(This);
+    free(This);
     InterlockedDecrement(&BROWSEUI_refCount);
 }
 
@@ -343,7 +332,7 @@ static HRESULT WINAPI ProgressDialog_StartProgressDialog(IProgressDialog *iface,
     struct create_params params;
     HANDLE hThread;
 
-    TRACE("(%p, %p, %x, %p)\n", iface, punkEnableModeless, dwFlags, reserved);
+    TRACE("(%p, %p, %lx, %p)\n", iface, punkEnableModeless, dwFlags, reserved);
     if (punkEnableModeless || reserved)
         FIXME("Reserved parameters not null (%p, %p)\n", punkEnableModeless, reserved);
     if (dwFlags & PROGDLG_NOTIME)
@@ -509,7 +498,7 @@ static HRESULT WINAPI ProgressDialog_SetLine(IProgressDialog *iface, DWORD dwLin
     ProgressDialog *This = impl_from_IProgressDialog(iface);
     HWND hwnd;
 
-    TRACE("(%p, %d, %s, %d)\n", This, dwLineNum, wine_dbgstr_w(pwzLine), bPath);
+    TRACE("(%p, %ld, %s, %d)\n", This, dwLineNum, wine_dbgstr_w(pwzLine), bPath);
 
     if (reserved)
         FIXME("reserved pointer not null (%p)\n", reserved);
@@ -556,7 +545,7 @@ static HRESULT WINAPI ProgressDialog_Timer(IProgressDialog *iface, DWORD dwTimer
 {
     ProgressDialog *This = impl_from_IProgressDialog(iface);
 
-    FIXME("(%p, %d, %p) - stub\n", This, dwTimerAction, reserved);
+    FIXME("(%p, %ld, %p) - stub\n", This, dwTimerAction, reserved);
 
     if (reserved)
         FIXME("Reserved field not NULL but %p\n", reserved);
@@ -635,8 +624,7 @@ HRESULT ProgressDialog_Constructor(IUnknown *pUnkOuter, IUnknown **ppOut)
     if (pUnkOuter)
         return CLASS_E_NOAGGREGATION;
 
-    This = heap_alloc_zero(sizeof(ProgressDialog));
-    if (This == NULL)
+    if (!(This = calloc(1, sizeof(*This))))
         return E_OUTOFMEMORY;
 
     This->IProgressDialog_iface.lpVtbl = &ProgressDialogVtbl;
