@@ -46,6 +46,7 @@ static HMODULE hComctl32;
 enum seq_index
 {
     CHILD_SEQ_INDEX,
+    PARENT_SEQ_INDEX,
     NUM_MSG_SEQUENCES
 };
 
@@ -218,7 +219,7 @@ static void test_Alloc(void)
     size = pGetSize(p);
     ok(size == 1 ||
        broken(size == min), /* win9x */
-       "Expected 1, got %d\n", size);
+       "Expected 1, got %ld\n", size);
 
     /* reallocate the block */
     p = pReAlloc(p, 2);
@@ -228,7 +229,7 @@ static void test_Alloc(void)
     size = pGetSize(p);
     ok(size == 2 ||
        broken(size == min), /* win9x */
-       "Expected 2, got %d\n", size);
+       "Expected 2, got %ld\n", size);
 
     /* free the block */
     res = pFree(p);
@@ -278,7 +279,7 @@ static void test_LoadIconWithScaleDown(void)
     GetTempFileNameW(tmp_path, L"ICO", 0, icon_path);
     handle = CreateFileW(icon_path, GENERIC_READ | GENERIC_WRITE, 0, NULL, CREATE_ALWAYS,
                          FILE_ATTRIBUTE_NORMAL, NULL);
-    ok(handle != INVALID_HANDLE_VALUE, "CreateFileW failed with error %u\n", GetLastError());
+    ok(handle != INVALID_HANDLE_VALUE, "CreateFileW failed with error %lu\n", GetLastError());
     res = WriteFile(handle, testicon_data, sizeof(testicon_data), &written, NULL);
     ok(res && written == sizeof(testicon_data), "Failed to write icon file\n");
     CloseHandle(handle);
@@ -295,43 +296,43 @@ static void test_LoadIconWithScaleDown(void)
     /* invalid arguments */
     icon = (HICON)0x1234;
     hr = pLoadIconMetric(NULL, (LPWSTR)IDI_APPLICATION, 0x100, &icon);
-    ok(hr == E_INVALIDARG, "Expected E_INVALIDARG, got %x\n", hr);
+    ok(hr == E_INVALIDARG, "Expected E_INVALIDARG, got %lx\n", hr);
     ok(icon == NULL, "Expected NULL, got %p\n", icon);
 
     icon = (HICON)0x1234;
     hr = pLoadIconMetric(NULL, NULL, LIM_LARGE, &icon);
-    ok(hr == E_INVALIDARG, "Expected E_INVALIDARG, got %x\n", hr);
+    ok(hr == E_INVALIDARG, "Expected E_INVALIDARG, got %lx\n", hr);
     ok(icon == NULL, "Expected NULL, got %p\n", icon);
 
     icon = (HICON)0x1234;
     hr = pLoadIconWithScaleDown(NULL, NULL, 32, 32, &icon);
-    ok(hr == E_INVALIDARG, "Expected E_INVALIDARG, got %x\n", hr);
+    ok(hr == E_INVALIDARG, "Expected E_INVALIDARG, got %lx\n", hr);
     ok(icon == NULL, "Expected NULL, got %p\n", icon);
 
     /* non-existing filename */
     hr = pLoadIconMetric(NULL, L"nonexisting.ico", LIM_LARGE, &icon);
     ok(hr == HRESULT_FROM_WIN32(ERROR_RESOURCE_TYPE_NOT_FOUND) || hr == HRESULT_FROM_WIN32(ERROR_FILE_NOT_FOUND) /* Win7 */,
-       "Expected HRESULT_FROM_WIN32(ERROR_RESOURCE_TYPE_NOT_FOUND), got %x\n", hr);
+       "Expected HRESULT_FROM_WIN32(ERROR_RESOURCE_TYPE_NOT_FOUND), got %lx\n", hr);
 
     hr = pLoadIconWithScaleDown(NULL, L"nonexisting.ico", 32, 32, &icon);
     todo_wine
     ok(hr == HRESULT_FROM_WIN32(ERROR_RESOURCE_TYPE_NOT_FOUND),
-       "Expected HRESULT_FROM_WIN32(ERROR_RESOURCE_TYPE_NOT_FOUND), got %x\n", hr);
+       "Expected HRESULT_FROM_WIN32(ERROR_RESOURCE_TYPE_NOT_FOUND), got %lx\n", hr);
 
     /* non-existing resource name */
     hr = pLoadIconMetric(hinst, L"Nonexisting", LIM_LARGE, &icon);
     ok(hr == HRESULT_FROM_WIN32(ERROR_RESOURCE_TYPE_NOT_FOUND),
-       "Expected HRESULT_FROM_WIN32(ERROR_RESOURCE_TYPE_NOT_FOUND), got %x\n", hr);
+       "Expected HRESULT_FROM_WIN32(ERROR_RESOURCE_TYPE_NOT_FOUND), got %lx\n", hr);
 
     hr = pLoadIconWithScaleDown(hinst, L"Noneexisting", 32, 32, &icon);
     ok(hr == HRESULT_FROM_WIN32(ERROR_RESOURCE_TYPE_NOT_FOUND),
-       "Expected HRESULT_FROM_WIN32(ERROR_RESOURCE_TYPE_NOT_FOUND), got %x\n", hr);
+       "Expected HRESULT_FROM_WIN32(ERROR_RESOURCE_TYPE_NOT_FOUND), got %lx\n", hr);
 
     /* load icon using predefined identifier */
     hr = pLoadIconMetric(NULL, (LPWSTR)IDI_APPLICATION, LIM_SMALL, &icon);
-    ok(hr == S_OK, "Expected S_OK, got %x\n", hr);
+    ok(hr == S_OK, "Expected S_OK, got %lx\n", hr);
     res = GetIconInfo(icon, &info);
-    ok(res, "Failed to get icon info, error %u\n", GetLastError());
+    ok(res, "Failed to get icon info, error %lu\n", GetLastError());
     bytes = GetObjectA(info.hbmColor, sizeof(bmp), &bmp);
     ok(bytes > 0, "Failed to get bitmap info for icon\n");
     ok(bmp.bmWidth  == GetSystemMetrics(SM_CXSMICON), "Wrong icon width %d\n", bmp.bmWidth);
@@ -339,9 +340,9 @@ static void test_LoadIconWithScaleDown(void)
     DestroyIcon(icon);
 
     hr = pLoadIconMetric(NULL, (LPWSTR)IDI_APPLICATION, LIM_LARGE, &icon);
-    ok(hr == S_OK, "Expected S_OK, got %x\n", hr);
+    ok(hr == S_OK, "Expected S_OK, got %lx\n", hr);
     res = GetIconInfo(icon, &info);
-    ok(res, "Failed to get icon info, error %u\n", GetLastError());
+    ok(res, "Failed to get icon info, error %lu\n", GetLastError());
     bytes = GetObjectA(info.hbmColor, sizeof(bmp), &bmp);
     ok(bytes > 0, "Failed to get bitmap info for icon\n");
     ok(bmp.bmWidth  == GetSystemMetrics(SM_CXICON), "Wrong icon width %d\n", bmp.bmWidth);
@@ -349,9 +350,9 @@ static void test_LoadIconWithScaleDown(void)
     DestroyIcon(icon);
 
     hr = pLoadIconWithScaleDown(NULL, (LPWSTR)IDI_APPLICATION, 42, 42, &icon);
-    ok(hr == S_OK, "Expected S_OK, got %x\n", hr);
+    ok(hr == S_OK, "Expected S_OK, got %lx\n", hr);
     res = GetIconInfo(icon, &info);
-    ok(res, "Failed to get icon info, error %u\n", GetLastError());
+    ok(res, "Failed to get icon info, error %lu\n", GetLastError());
     bytes = GetObjectA(info.hbmColor, sizeof(bmp), &bmp);
     ok(bytes > 0, "Failed to get bitmap info for icon\n");
     ok(bmp.bmWidth  == 42, "Wrong icon width %d\n", bmp.bmWidth);
@@ -360,9 +361,9 @@ static void test_LoadIconWithScaleDown(void)
 
     /* load icon from file */
     hr = pLoadIconMetric(NULL, icon_path, LIM_SMALL, &icon);
-    ok(hr == S_OK, "Expected S_OK, got %x\n", hr);
+    ok(hr == S_OK, "Expected S_OK, got %lx\n", hr);
     res = GetIconInfo(icon, &info);
-    ok(res, "Failed to get icon info, error %u\n", GetLastError());
+    ok(res, "Failed to get icon info, error %lu\n", GetLastError());
     bytes = GetObjectA(info.hbmColor, sizeof(bmp), &bmp);
     ok(bytes > 0, "Failed to get bitmap info for icon\n");
     ok(bmp.bmWidth  == GetSystemMetrics(SM_CXSMICON), "Wrong icon width %d\n", bmp.bmWidth);
@@ -370,9 +371,9 @@ static void test_LoadIconWithScaleDown(void)
     DestroyIcon(icon);
 
     hr = pLoadIconWithScaleDown(NULL, icon_path, 42, 42, &icon);
-    ok(hr == S_OK, "Expected S_OK, got %x\n", hr);
+    ok(hr == S_OK, "Expected S_OK, got %lx\n", hr);
     res = GetIconInfo(icon, &info);
-    ok(res, "Failed to get icon info, error %u\n", GetLastError());
+    ok(res, "Failed to get icon info, error %lu\n", GetLastError());
     bytes = GetObjectA(info.hbmColor, sizeof(bmp), &bmp);
     ok(bytes > 0, "Failed to get bitmap info for icon\n");
     ok(bmp.bmWidth  == 42, "Wrong icon width %d\n", bmp.bmWidth);
@@ -392,14 +393,14 @@ static void check_class( const char *name, int must_exist, UINT style, UINT igno
         char buff[64];
         HWND hwnd;
 
-todo_wine_if(!strcmp(name, "SysLink") && !must_exist && !v6)
+        todo_wine_if(!strcmp(name, "SysLink") && !must_exist && !v6)
         ok( must_exist, "System class %s should %sexist\n", name, must_exist ? "" : "NOT " );
         if (!must_exist) return;
 
-todo_wine_if(!strcmp(name, "ScrollBar") || (!strcmp(name, "tooltips_class32") && v6))
+        todo_wine_if(!strcmp(name, "ScrollBar") || (!strcmp(name, "tooltips_class32") && v6))
         ok( !(~wc.style & style & ~ignore), "System class %s is missing bits %x (%08x/%08x)\n",
             name, ~wc.style & style, wc.style, style );
-todo_wine_if((!strcmp(name, "tooltips_class32") && v6) || !strcmp(name, "SysLink"))
+        todo_wine_if((!strcmp(name, "tooltips_class32") && v6) || !strcmp(name, "SysLink"))
         ok( !(wc.style & ~style), "System class %s has extra bits %x (%08x/%08x)\n",
             name, wc.style & ~style, wc.style, style );
         ok( !wc.hInstance, "System class %s has hInstance %p\n", name, wc.hInstance );
@@ -521,7 +522,7 @@ static HWND create_control(const char *class, DWORD style, HWND parent, DWORD_PT
     if (parent)
         style |= WS_CHILD;
     hwnd = CreateWindowExA(0, class, "test", style, 0, 0, 50, 20, parent, 0, 0, NULL);
-    ok(!!hwnd, "Failed to create %s style %#x parent %p\n", class, style, parent);
+    ok(!!hwnd, "Failed to create %s style %#lx parent %p\n", class, style, parent);
     pSetWindowSubclass(hwnd, test_wm_themechanged_proc, 0, data);
     return hwnd;
 }
@@ -530,7 +531,8 @@ static const struct message wm_themechanged_paint_erase_seq[] =
 {
     {WM_THEMECHANGED, sent | wparam | lparam},
     {WM_PAINT, sent | wparam | lparam},
-    {WM_ERASEBKGND, sent | defwinproc},
+    /* TestBot w7u_2qxl VM occasionally doesn't send WM_ERASEBKGND, hence the 'optional' */
+    {WM_ERASEBKGND, sent | defwinproc | optional},
     {0},
 };
 
@@ -579,7 +581,7 @@ static void test_WM_THEMECHANGED(void)
         {TOOLTIPS_CLASSA, wm_themechanged_no_paint_seq},
         {TRACKBAR_CLASSA, wm_themechanged_paint_seq},
         {WC_TREEVIEWA, wm_themechanged_paint_erase_seq, 1, {0x1128}},
-        {UPDOWN_CLASSA, wm_themechanged_paint_erase_seq},
+        {UPDOWN_CLASSA, wm_themechanged_paint_erase_seq, 1, {WM_NCPAINT}},
         {WC_SCROLLBARA, wm_themechanged_paint_erase_seq, 1, {SBM_GETSCROLLINFO}},
     };
 
@@ -635,13 +637,13 @@ static void test_WM_SYSCOLORCHANGE(void)
 
     parent = CreateWindowExA(0, WC_STATICA, "parent", WS_OVERLAPPEDWINDOW | WS_VISIBLE, 100, 100,
                              200, 200, 0, 0, 0, NULL);
-    ok(!!parent, "CreateWindowExA failed, error %d\n", GetLastError());
+    ok(!!parent, "CreateWindowExA failed, error %ld\n", GetLastError());
 
     temp.tmplate.style = WS_CHILD | WS_VISIBLE;
     temp.tmplate.cx = 50;
     temp.tmplate.cy = 50;
     dialog = CreateDialogIndirectParamA(NULL, &temp.tmplate, parent, wm_syscolorchange_dlg_proc, 0);
-    ok(!!dialog, "CreateDialogIndirectParamA failed, error %d\n", GetLastError());
+    ok(!!dialog, "CreateDialogIndirectParamA failed, error %ld\n", GetLastError());
     flush_events();
     flush_sequences(sequences, NUM_MSG_SEQUENCES);
 
@@ -652,17 +654,514 @@ static void test_WM_SYSCOLORCHANGE(void)
     DestroyWindow(parent);
 }
 
+static const struct message empty_seq[] =
+{
+    {0}
+};
+
+static const struct message wm_erasebkgnd_seq[] =
+{
+    {WM_ERASEBKGND, sent},
+    {0}
+};
+
+static const struct message wm_ctlcolorstatic_seq[] =
+{
+    {WM_CTLCOLORSTATIC, sent},
+    {0}
+};
+
+static const struct message drawthemeparentbackground_seq[] =
+{
+    {WM_ERASEBKGND, sent},
+    {WM_PRINTCLIENT, sent},
+    {0}
+};
+
+static const struct message drawthemeparentbackground_optional_seq[] =
+{
+    {WM_ERASEBKGND, sent | optional},
+    {WM_PRINTCLIENT, sent | optional},
+    {0}
+};
+
+static const struct message pushbutton_seq[] =
+{
+    {WM_ERASEBKGND, sent},
+    {WM_PRINTCLIENT, sent},
+    {WM_CTLCOLORBTN, sent},
+    {0}
+};
+
+static const struct message defpushbutton_seq[] =
+{
+    {WM_ERASEBKGND, sent},
+    {WM_PRINTCLIENT, sent},
+    {WM_CTLCOLORBTN, sent},
+    {WM_ERASEBKGND, sent | optional},
+    {WM_PRINTCLIENT, sent | optional},
+    {WM_CTLCOLORBTN, sent | optional},
+    {0}
+};
+
+static const struct message checkbox_seq[] =
+{
+    {WM_ERASEBKGND, sent | optional},
+    {WM_PRINTCLIENT, sent | optional},
+    {WM_CTLCOLORSTATIC, sent},
+    {0}
+};
+
+static const struct message radiobutton_seq[] =
+{
+    {WM_ERASEBKGND, sent},
+    {WM_PRINTCLIENT, sent},
+    {WM_CTLCOLORSTATIC, sent},
+    {0}
+};
+
+static const struct message groupbox_seq[] =
+{
+    {WM_CTLCOLORSTATIC, sent},
+    {WM_ERASEBKGND, sent},
+    {WM_PRINTCLIENT, sent},
+    {0}
+};
+
+static const struct message ownerdrawbutton_seq[] =
+{
+    {WM_CTLCOLORBTN, sent},
+    {WM_CTLCOLORBTN, sent},
+    {0}
+};
+
+static const struct message splitbutton_seq[] =
+{
+    {WM_ERASEBKGND, sent},
+    {WM_PRINTCLIENT, sent},
+    /* Either WM_CTLCOLORSTATIC or WM_CTLCOLORBTN */
+    {WM_CTLCOLORSTATIC, sent | optional},
+    {WM_CTLCOLORBTN, sent | optional},
+    /* BS_DEFSPLITBUTTON or BS_DEFCOMMANDLINK */
+    {WM_ERASEBKGND, sent | optional},
+    {WM_PRINTCLIENT, sent | optional},
+    {WM_CTLCOLORSTATIC, sent | optional},
+    {WM_CTLCOLORBTN, sent | optional},
+    {0}
+};
+
+static const struct message combobox_seq[] =
+{
+    {WM_ERASEBKGND, sent | optional},
+    {WM_PRINTCLIENT, sent | optional},
+    {WM_CTLCOLOREDIT, sent},
+    {WM_CTLCOLORLISTBOX, sent},
+    {WM_CTLCOLORLISTBOX, sent | optional},
+    {WM_CTLCOLOREDIT, sent | optional},
+    {WM_CTLCOLOREDIT, sent | optional},
+    {0}
+};
+
+static const struct message edit_seq[] =
+{
+    {WM_CTLCOLOREDIT, sent},
+    {WM_CTLCOLOREDIT, sent | optional},
+    {0}
+};
+
+static const struct message listbox_seq[] =
+{
+    {WM_CTLCOLORLISTBOX, sent},
+    {WM_CTLCOLORLISTBOX, sent},
+    {0}
+};
+
+static const struct message treeview_seq[] =
+{
+    {WM_CTLCOLOREDIT, sent | optional},
+    {WM_CTLCOLOREDIT, sent | optional},
+    {0}
+};
+
+static const struct message scrollbar_seq[] =
+{
+    {WM_CTLCOLORSCROLLBAR, sent},
+    {WM_CTLCOLORSCROLLBAR, sent | optional},
+    {0}
+};
+
+static LRESULT WINAPI test_themed_background_proc(HWND hwnd, UINT message, WPARAM wp, LPARAM lp)
+{
+    struct message msg = {0};
+    HBRUSH brush;
+    RECT rect;
+
+    if (message == WM_ERASEBKGND || message == WM_PRINTCLIENT || (message >= WM_CTLCOLORMSGBOX
+        && message <= WM_CTLCOLORSTATIC))
+    {
+        msg.message = message;
+        msg.flags = sent;
+        add_message(sequences, PARENT_SEQ_INDEX, &msg);
+    }
+
+    if (message == WM_ERASEBKGND)
+    {
+        brush = CreateSolidBrush(RGB(255, 0, 0));
+        GetClientRect(hwnd, &rect);
+        FillRect((HDC)wp, &rect, brush);
+        DeleteObject(brush);
+        return 1;
+    }
+    else if (message >= WM_CTLCOLORMSGBOX && message <= WM_CTLCOLORSTATIC)
+    {
+        return (LRESULT)GetStockObject(GRAY_BRUSH);
+    }
+
+    return DefWindowProcA(hwnd, message, wp, lp);
+}
+
+static void test_themed_background(void)
+{
+    DPI_AWARENESS_CONTEXT (WINAPI *pSetThreadDpiAwarenessContext)(DPI_AWARENESS_CONTEXT);
+    DPI_AWARENESS_CONTEXT old_context = NULL;
+    BOOL (WINAPI *pIsThemeActive)(void);
+    HWND child, parent;
+    HMODULE uxtheme;
+    COLORREF color;
+    WNDCLASSA cls;
+    HDC hdc;
+    int i;
+
+    static const struct test
+    {
+        const CHAR *class_name;
+        DWORD style;
+        const struct message *seq;
+        BOOL todo;
+    }
+    tests[] =
+    {
+        {ANIMATE_CLASSA, 0, empty_seq, TRUE},
+        {WC_BUTTONA, BS_PUSHBUTTON, pushbutton_seq},
+        {WC_BUTTONA, BS_DEFPUSHBUTTON, defpushbutton_seq},
+        {WC_BUTTONA, BS_CHECKBOX, checkbox_seq},
+        {WC_BUTTONA, BS_AUTOCHECKBOX, checkbox_seq},
+        {WC_BUTTONA, BS_RADIOBUTTON, radiobutton_seq},
+        {WC_BUTTONA, BS_3STATE, checkbox_seq},
+        {WC_BUTTONA, BS_AUTO3STATE, checkbox_seq},
+        {WC_BUTTONA, BS_GROUPBOX, groupbox_seq},
+        {WC_BUTTONA, BS_USERBUTTON, pushbutton_seq},
+        {WC_BUTTONA, BS_AUTORADIOBUTTON, radiobutton_seq},
+        {WC_BUTTONA, BS_PUSHBOX, radiobutton_seq, TRUE},
+        {WC_BUTTONA, BS_OWNERDRAW, ownerdrawbutton_seq},
+        {WC_BUTTONA, BS_SPLITBUTTON, splitbutton_seq},
+        {WC_BUTTONA, BS_DEFSPLITBUTTON, splitbutton_seq},
+        {WC_BUTTONA, BS_COMMANDLINK, splitbutton_seq},
+        {WC_BUTTONA, BS_DEFCOMMANDLINK, splitbutton_seq},
+        {WC_COMBOBOXA, 0, combobox_seq, TRUE},
+        {WC_COMBOBOXEXA, 0, drawthemeparentbackground_optional_seq},
+        {DATETIMEPICK_CLASSA, 0, drawthemeparentbackground_optional_seq, TRUE},
+        {WC_EDITA, 0, edit_seq},
+        {WC_HEADERA, 0, empty_seq},
+        {HOTKEY_CLASSA, 0, empty_seq, TRUE},
+        {WC_IPADDRESSA, 0, empty_seq},
+        {WC_LISTBOXA, 0, listbox_seq, TRUE},
+        {WC_LISTVIEWA, 0, empty_seq},
+        {MONTHCAL_CLASSA, 0, empty_seq},
+        {WC_NATIVEFONTCTLA, 0, empty_seq},
+        {WC_PAGESCROLLERA, 0, wm_erasebkgnd_seq},
+        {PROGRESS_CLASSA, 0, drawthemeparentbackground_optional_seq},
+        {REBARCLASSNAMEA, 0, empty_seq},
+        {WC_STATICA, SS_LEFT, wm_ctlcolorstatic_seq},
+        {WC_STATICA, SS_ICON, wm_ctlcolorstatic_seq},
+        {WC_STATICA, SS_BLACKRECT, wm_ctlcolorstatic_seq},
+        {WC_STATICA, SS_OWNERDRAW, wm_ctlcolorstatic_seq},
+        {WC_STATICA, SS_BITMAP, wm_ctlcolorstatic_seq},
+        {WC_STATICA, SS_ENHMETAFILE, wm_ctlcolorstatic_seq},
+        {WC_STATICA, SS_ETCHEDHORZ, wm_ctlcolorstatic_seq},
+        {STATUSCLASSNAMEA, 0, empty_seq},
+        {"SysLink", 0, wm_ctlcolorstatic_seq},
+        {WC_TABCONTROLA, 0, drawthemeparentbackground_seq},
+        {TOOLBARCLASSNAMEA, 0, empty_seq, TRUE},
+        {TOOLTIPS_CLASSA, 0, empty_seq},
+        {TRACKBAR_CLASSA, 0, wm_ctlcolorstatic_seq},
+        {WC_TREEVIEWA, 0, treeview_seq},
+        {UPDOWN_CLASSA, 0, empty_seq},
+        {WC_SCROLLBARA, 0, scrollbar_seq},
+        {WC_SCROLLBARA, SBS_SIZEBOX, empty_seq},
+        {WC_SCROLLBARA, SBS_SIZEGRIP, empty_seq},
+        /* Scrollbars in non-client area */
+        {"ChildClass", WS_HSCROLL, empty_seq},
+        {"ChildClass", WS_VSCROLL, empty_seq},
+    };
+
+    uxtheme = LoadLibraryA("uxtheme.dll");
+    pIsThemeActive = (void *)GetProcAddress(uxtheme, "IsThemeActive");
+    if (!pIsThemeActive())
+    {
+        skip("Theming is inactive.\n");
+        FreeLibrary(uxtheme);
+        return;
+    }
+    FreeLibrary(uxtheme);
+
+    pSetThreadDpiAwarenessContext = (void *)GetProcAddress(GetModuleHandleA("user32.dll"),
+                                                           "SetThreadDpiAwarenessContext");
+    if (pSetThreadDpiAwarenessContext)
+        pSetThreadDpiAwarenessContext(DPI_AWARENESS_CONTEXT_PER_MONITOR_AWARE);
+
+    memset(&cls, 0, sizeof(cls));
+    cls.hInstance = GetModuleHandleA(0);
+    cls.hCursor = LoadCursorA(0, (LPCSTR)IDC_ARROW);
+    cls.hbrBackground = GetStockObject(WHITE_BRUSH);
+    cls.lpfnWndProc = test_themed_background_proc;
+    cls.lpszClassName = "ParentClass";
+    RegisterClassA(&cls);
+
+    cls.lpfnWndProc = DefWindowProcA;
+    cls.lpszClassName = "ChildClass";
+    RegisterClassA(&cls);
+
+    parent = CreateWindowA("ParentClass", "parent", WS_POPUP | WS_VISIBLE, 100, 100, 100, 100,
+                           0, 0, 0, 0);
+    ok(parent != NULL, "CreateWindowA failed, error %lu.\n", GetLastError());
+
+    for (i = 0; i < ARRAY_SIZE(tests); ++i)
+    {
+        winetest_push_context("%s %#lx", tests[i].class_name, tests[i].style);
+
+        child = CreateWindowA(tests[i].class_name, "    ", WS_CHILD | WS_VISIBLE | tests[i].style,
+                              0, 0, 50, 100, parent, 0, 0, 0);
+        ok(child != NULL, "CreateWindowA failed, error %lu.\n", GetLastError());
+        flush_events();
+        flush_sequences(sequences, NUM_MSG_SEQUENCES);
+
+        RedrawWindow(child, NULL, NULL, RDW_INVALIDATE | RDW_ERASE | RDW_UPDATENOW | RDW_ERASENOW | RDW_FRAME);
+        ok_sequence(sequences, PARENT_SEQ_INDEX, tests[i].seq, "paint background", tests[i].todo);
+
+        /* For message sequences that contain both DrawThemeParentBackground() messages and
+         * WM_CTLCOLOR*, do a color test to check which is really in effect for controls that can be
+         * tested automatically. For WM_ERASEBKGND from DrawThemeParentBackground(), a red brush is
+         * used. For WM_CTLCOLOR*, a gray brush is returned. If there are only WM_CTLCOLOR* messages
+         * in the message sequence, then surely DrawThemeParentBackground() is not used.
+         *
+         * For tests that use pushbutton_seq and defpushbutton_seq, manual tests on XP show that
+         * a brush from WM_CTLCOLORBTN is used to fill background even after a successful
+         * DrawThemeParentBackground(). This behavior can be verified by returning a gray or hollow
+         * brush in test_themed_background_proc() when handling WM_CTLCOLORBTN. It can't be tested
+         * automatically here because stock Windows themes don't use transparent button bitmaps */
+        if (tests[i].seq == radiobutton_seq || tests[i].seq == groupbox_seq)
+        {
+            hdc = GetDC(child);
+
+            if (tests[i].seq == radiobutton_seq)
+            {
+                /* WM_CTLCOLORSTATIC is used to fill background */
+                color = GetPixel(hdc, 40, 40);
+                /* BS_PUSHBOX is unimplemented on Wine */
+                todo_wine_if(i == 11)
+                ok(color == 0x808080, "Expected color %#x, got %#lx.\n", 0x808080, color);
+            }
+            else if (tests[i].seq == groupbox_seq)
+            {
+                /* DrawThemeParentBackground() is used to fill content background */
+                color = GetPixel(hdc, 40, 40);
+                ok(color == 0xff, "Expected color %#x, got %#lx.\n", 0xff, color);
+
+                /* WM_CTLCOLORSTATIC is used to fill text background */
+                color = GetPixel(hdc, 10, 10);
+                ok(color == 0x808080, "Expected color %#x, got %#lx.\n", 0x808080, color);
+            }
+            else if (tests[i].seq == scrollbar_seq)
+            {
+                /* WM_CTLCOLORSCROLLBAR is used to fill tracks only */
+                color = GetPixel(hdc, 10, 10);
+                ok(color != RGB(255, 0, 0), "Got unexpected color %#08lx.\n", color);
+
+                color = GetPixel(hdc, 10, 60);
+                ok(color == RGB(255, 0, 0) || broken(color == CLR_INVALID), /* Win7 on TestBots */
+                   "Got unexpected color %#08lx.\n", color);
+            }
+
+            ReleaseDC(child, hdc);
+        }
+
+        DestroyWindow(child);
+        winetest_pop_context();
+    }
+
+    DestroyWindow(parent);
+    UnregisterClassA("ChildClass", GetModuleHandleA(0));
+    UnregisterClassA("ParentClass", GetModuleHandleA(0));
+    if (pSetThreadDpiAwarenessContext)
+        pSetThreadDpiAwarenessContext(old_context);
+}
+
+static WNDPROC old_proc;
+
+static const struct message wm_stylechanged_seq[] =
+{
+    {WM_STYLECHANGED, sent},
+    {0}
+};
+
+static const struct message wm_stylechanged_repaint_seq[] =
+{
+    {WM_STYLECHANGED, sent},
+    {WM_PAINT, sent},
+    {WM_ERASEBKGND, sent | defwinproc},
+    {0}
+};
+
+static const struct message wm_stylechanged_combox_seq[] =
+{
+    {WM_STYLECHANGED, sent},
+    {WM_ERASEBKGND, sent | defwinproc},
+    {WM_PAINT, sent},
+    {0}
+};
+
+static const struct message wm_stylechanged_pager_seq[] =
+{
+    {WM_STYLECHANGED, sent},
+    {WM_PAINT, sent},
+    {WM_NCPAINT, sent | defwinproc},
+    {WM_ERASEBKGND, sent | defwinproc},
+    {0}
+};
+
+static const struct message wm_stylechanged_progress_seq[] =
+{
+    {WM_STYLECHANGED, sent},
+    {WM_PAINT, sent | optional}, /* WM_PAINT and WM_ERASEBKGND are missing with comctl32 v5 */
+    {WM_ERASEBKGND, sent | defwinproc | optional},
+    {0}
+};
+
+static const struct message wm_stylechanged_trackbar_seq[] =
+{
+    {WM_STYLECHANGED, sent},
+    {WM_PAINT, sent | defwinproc},
+    {WM_PAINT, sent},
+    {0}
+};
+
+static LRESULT WINAPI test_wm_stylechanged_proc(HWND hwnd, UINT message, WPARAM wp, LPARAM lp)
+{
+    static int defwndproc_counter = 0;
+    struct message msg = {0};
+    LRESULT ret;
+
+    if (message == WM_STYLECHANGED
+        || message == WM_PAINT
+        || message == WM_ERASEBKGND
+        || message == WM_NCPAINT)
+    {
+        msg.message = message;
+        msg.flags = sent | wparam | lparam;
+        if (defwndproc_counter)
+            msg.flags |= defwinproc;
+        msg.wParam = wp;
+        msg.lParam = lp;
+        add_message(sequences, CHILD_SEQ_INDEX, &msg);
+    }
+
+    ++defwndproc_counter;
+    ret = CallWindowProcA(old_proc, hwnd, message, wp, lp);
+    --defwndproc_counter;
+    return ret;
+}
+
+static void test_WM_STYLECHANGED(void)
+{
+    HWND parent, hwnd;
+    STYLESTRUCT style;
+    unsigned int i;
+
+    static const struct test
+    {
+        const CHAR *class_name;
+        const struct message *seq;
+        BOOL todo;
+    }
+    tests[] =
+    {
+        {ANIMATE_CLASSA, wm_stylechanged_seq},
+        {WC_BUTTONA, wm_stylechanged_seq},
+        {WC_COMBOBOXA, wm_stylechanged_combox_seq, TRUE},
+        {WC_COMBOBOXEXA, wm_stylechanged_seq},
+        {DATETIMEPICK_CLASSA, wm_stylechanged_seq},
+        {WC_EDITA, wm_stylechanged_seq},
+        {WC_HEADERA, wm_stylechanged_repaint_seq, TRUE},
+        {HOTKEY_CLASSA, wm_stylechanged_seq},
+        {WC_IPADDRESSA, wm_stylechanged_seq},
+        {WC_LISTBOXA, wm_stylechanged_repaint_seq, TRUE},
+        {WC_LISTVIEWA, wm_stylechanged_seq},
+        {MONTHCAL_CLASSA, wm_stylechanged_repaint_seq, TRUE},
+        {WC_NATIVEFONTCTLA, wm_stylechanged_seq},
+        {WC_PAGESCROLLERA, wm_stylechanged_pager_seq, TRUE},
+        {PROGRESS_CLASSA, wm_stylechanged_progress_seq},
+        {REBARCLASSNAMEA, wm_stylechanged_seq},
+        {WC_STATICA, wm_stylechanged_seq},
+        {STATUSCLASSNAMEA, wm_stylechanged_seq},
+        {"SysLink", wm_stylechanged_seq},
+        {WC_TABCONTROLA, wm_stylechanged_seq},
+        {TOOLBARCLASSNAMEA, wm_stylechanged_seq},
+        {TOOLTIPS_CLASSA, wm_stylechanged_seq},
+        {TRACKBAR_CLASSA, wm_stylechanged_trackbar_seq, TRUE},
+        {WC_TREEVIEWA, wm_stylechanged_seq},
+        {UPDOWN_CLASSA, wm_stylechanged_seq},
+        {WC_SCROLLBARA, wm_stylechanged_seq},
+    };
+
+    parent = CreateWindowA(WC_STATICA, "parent", WS_POPUP | WS_VISIBLE, 100, 100, 100, 100,
+                           0, 0, 0, 0);
+    ok(parent != NULL, "CreateWindowA failed, error %lu.\n", GetLastError());
+
+    for (i = 0; i < ARRAY_SIZE(tests); ++i)
+    {
+        winetest_push_context("%s", tests[i].class_name);
+
+        hwnd = CreateWindowA(tests[i].class_name, "test", WS_CHILD | WS_VISIBLE, 0, 0, 50, 50,
+                             parent, 0, 0, 0);
+        /* SysLink is unavailable in comctl32 v5 */
+        if (!hwnd && !lstrcmpA(tests[i].class_name, "SysLink"))
+        {
+            winetest_pop_context();
+            continue;
+        }
+        ok(hwnd != NULL, "CreateWindowA failed, error %lu.\n", GetLastError());
+        old_proc = (WNDPROC)SetWindowLongPtrA(hwnd, GWLP_WNDPROC, (LONG_PTR)test_wm_stylechanged_proc);
+        ok(old_proc != NULL, "SetWindowLongPtrA failed, error %lu.\n", GetLastError());
+        flush_events();
+        flush_sequences(sequences, NUM_MSG_SEQUENCES);
+
+        style.styleOld = GetWindowLongA(hwnd, GWL_STYLE);
+        style.styleNew = style.styleOld | WS_TABSTOP;
+        SendMessageA(hwnd, WM_STYLECHANGED, GWL_STYLE, (LPARAM)&style);
+        flush_events();
+        ok_sequence(sequences, CHILD_SEQ_INDEX, tests[i].seq, "WM_STYLECHANGED", tests[i].todo);
+
+        DestroyWindow(hwnd);
+        winetest_pop_context();
+    }
+
+    DestroyWindow(parent);
+}
+
 START_TEST(misc)
 {
     ULONG_PTR ctx_cookie;
     HANDLE hCtx;
 
+    init_msg_sequences(sequences, NUM_MSG_SEQUENCES);
     if(!InitFunctionPtrs())
         return;
 
     test_GetPtrAW();
     test_Alloc();
     test_comctl32_classes(FALSE);
+    test_WM_STYLECHANGED();
 
     FreeLibrary(hComctl32);
 
@@ -670,13 +1169,14 @@ START_TEST(misc)
         return;
     if(!init_functions_v6())
         return;
-    init_msg_sequences(sequences, NUM_MSG_SEQUENCES);
 
     test_comctl32_classes(TRUE);
     test_builtin_classes();
     test_LoadIconWithScaleDown();
+    test_themed_background();
     test_WM_THEMECHANGED();
     test_WM_SYSCOLORCHANGE();
+    test_WM_STYLECHANGED();
 
     unload_v6_module(ctx_cookie, hCtx);
     FreeLibrary(hComctl32);
