@@ -29,93 +29,85 @@
 
 #include "wine/test.h"
 
-
-static BOOL (WINAPI *pCryptEnumOIDInfo)(DWORD,DWORD,void*,PFN_CRYPT_ENUM_OID_INFO);
-
-
 struct OIDToAlgID
 {
     LPCSTR oid;
-    LPCSTR altOid;
     DWORD algID;
     DWORD altAlgID;
 };
 
 static const struct OIDToAlgID oidToAlgID[] = {
- { szOID_RSA_RSA, NULL, CALG_RSA_KEYX },
- { szOID_RSA_MD2RSA, NULL, CALG_MD2 },
- { szOID_RSA_MD4RSA, NULL, CALG_MD4 },
- { szOID_RSA_MD5RSA, NULL, CALG_MD5 },
- { szOID_RSA_SHA1RSA, NULL, CALG_SHA },
- { szOID_RSA_DH, NULL, CALG_DH_SF },
- { szOID_RSA_SMIMEalgESDH, NULL, CALG_DH_EPHEM },
- { szOID_RSA_SMIMEalgCMS3DESwrap, NULL, CALG_3DES },
- { szOID_RSA_SMIMEalgCMSRC2wrap, NULL, CALG_RC2 },
- { szOID_RSA_MD2, NULL, CALG_MD2 },
- { szOID_RSA_MD4, NULL, CALG_MD4 },
- { szOID_RSA_MD5, NULL, CALG_MD5 },
- { szOID_RSA_RC2CBC, NULL, CALG_RC2 },
- { szOID_RSA_RC4, NULL, CALG_RC4 },
- { szOID_RSA_DES_EDE3_CBC, NULL, CALG_3DES },
- { szOID_ANSI_X942_DH, NULL, CALG_DH_SF },
- { szOID_X957_DSA, NULL, CALG_DSS_SIGN },
- { szOID_X957_SHA1DSA, NULL, CALG_SHA },
- { szOID_OIWSEC_md4RSA, NULL, CALG_MD4 },
- { szOID_OIWSEC_md5RSA, NULL, CALG_MD5 },
- { szOID_OIWSEC_md4RSA2, NULL, CALG_MD4 },
- { szOID_OIWSEC_desCBC, NULL, CALG_DES },
- { szOID_OIWSEC_dsa, NULL, CALG_DSS_SIGN },
- { szOID_OIWSEC_shaDSA, NULL, CALG_SHA },
- { szOID_OIWSEC_shaRSA, NULL, CALG_SHA },
- { szOID_OIWSEC_sha, NULL, CALG_SHA },
- { szOID_OIWSEC_rsaXchg, NULL, CALG_RSA_KEYX },
- { szOID_OIWSEC_sha1, NULL, CALG_SHA },
- { szOID_OIWSEC_dsaSHA1, NULL, CALG_SHA },
- { szOID_OIWSEC_sha1RSASign, NULL, CALG_SHA },
- { szOID_OIWDIR_md2RSA, NULL, CALG_MD2 },
- { szOID_INFOSEC_mosaicUpdatedSig, NULL, CALG_SHA },
- { szOID_INFOSEC_mosaicKMandUpdSig, NULL, CALG_DSS_SIGN },
- { szOID_NIST_sha256, NULL, CALG_SHA_256, -1 },
- { szOID_NIST_sha384, NULL, CALG_SHA_384, -1 },
- { szOID_NIST_sha512, NULL, CALG_SHA_512, -1 }
+ { szOID_RSA_RSA, CALG_RSA_KEYX },
+ { szOID_RSA_MD2RSA, CALG_MD2 },
+ { szOID_RSA_MD4RSA, CALG_MD4 },
+ { szOID_RSA_MD5RSA, CALG_MD5 },
+ { szOID_RSA_SHA1RSA, CALG_SHA },
+ { szOID_RSA_DH, CALG_DH_SF },
+ { szOID_RSA_SMIMEalgESDH, CALG_DH_EPHEM },
+ { szOID_RSA_SMIMEalgCMS3DESwrap, CALG_3DES },
+ { szOID_RSA_SMIMEalgCMSRC2wrap, CALG_RC2 },
+ { szOID_RSA_MD2, CALG_MD2 },
+ { szOID_RSA_MD4, CALG_MD4 },
+ { szOID_RSA_MD5, CALG_MD5 },
+ { szOID_RSA_RC2CBC, CALG_RC2 },
+ { szOID_RSA_RC4, CALG_RC4 },
+ { szOID_RSA_DES_EDE3_CBC, CALG_3DES },
+ { szOID_ANSI_X942_DH, CALG_DH_SF },
+ { szOID_X957_DSA, CALG_DSS_SIGN },
+ { szOID_X957_SHA1DSA, CALG_SHA },
+ { szOID_OIWSEC_md4RSA, CALG_MD4 },
+ { szOID_OIWSEC_md5RSA, CALG_MD5 },
+ { szOID_OIWSEC_md4RSA2, CALG_MD4 },
+ { szOID_OIWSEC_desCBC, CALG_DES },
+ { szOID_OIWSEC_dsa, CALG_DSS_SIGN },
+ { szOID_OIWSEC_shaDSA, CALG_SHA },
+ { szOID_OIWSEC_shaRSA, CALG_SHA },
+ { szOID_OIWSEC_sha, CALG_SHA },
+ { szOID_OIWSEC_rsaXchg, CALG_RSA_KEYX },
+ { szOID_OIWSEC_sha1, CALG_SHA },
+ { szOID_OIWSEC_dsaSHA1, CALG_SHA },
+ { szOID_OIWSEC_sha1RSASign, CALG_SHA },
+ { szOID_OIWDIR_md2RSA, CALG_MD2 },
+ { szOID_INFOSEC_mosaicUpdatedSig, CALG_SHA },
+ { szOID_INFOSEC_mosaicKMandUpdSig, CALG_DSS_SIGN },
+ { szOID_NIST_sha256, CALG_SHA_256, -1 },
+ { szOID_NIST_sha384, CALG_SHA_384, -1 },
+ { szOID_NIST_sha512, CALG_SHA_512, -1 }
 };
 
 static const struct OIDToAlgID algIDToOID[] = {
- { szOID_RSA_RSA, NULL, CALG_RSA_KEYX },
- { szOID_RSA_SMIMEalgESDH, NULL, CALG_DH_EPHEM },
- { szOID_RSA_MD2, NULL, CALG_MD2 },
- { szOID_RSA_MD4, NULL, CALG_MD4 },
- { szOID_RSA_MD5, NULL, CALG_MD5 },
- { szOID_RSA_RC2CBC, NULL, CALG_RC2 },
- { szOID_RSA_RC4, NULL, CALG_RC4 },
- { szOID_RSA_DES_EDE3_CBC, NULL, CALG_3DES },
- { szOID_ANSI_X942_DH, NULL, CALG_DH_SF },
- { szOID_X957_DSA, szOID_OIWSEC_dsa /* some Win98 */, CALG_DSS_SIGN },
- { szOID_OIWSEC_desCBC, NULL, CALG_DES },
- { szOID_OIWSEC_sha1, NULL, CALG_SHA },
+ { szOID_RSA_RSA, CALG_RSA_KEYX },
+ { szOID_RSA_SMIMEalgESDH, CALG_DH_EPHEM },
+ { szOID_RSA_MD2, CALG_MD2 },
+ { szOID_RSA_MD4, CALG_MD4 },
+ { szOID_RSA_MD5, CALG_MD5 },
+ { szOID_RSA_RC2CBC, CALG_RC2 },
+ { szOID_RSA_RC4, CALG_RC4 },
+ { szOID_RSA_DES_EDE3_CBC, CALG_3DES },
+ { szOID_ANSI_X942_DH, CALG_DH_SF },
+ { szOID_X957_DSA, CALG_DSS_SIGN },
+ { szOID_OIWSEC_desCBC, CALG_DES },
+ { szOID_OIWSEC_sha1, CALG_SHA },
 };
 
-static const WCHAR bogusDll[] = { 'b','o','g','u','s','.','d','l','l',0 };
-static const WCHAR bogus2Dll[] = { 'b','o','g','u','s','2','.','d','l','l',0 };
-
-static void testOIDToAlgID(void)
+static void test_OIDToAlgID(void)
 {
     int i;
     DWORD alg;
 
     /* Test with a bogus one */
     alg = CertOIDToAlgId("1.2.3");
-    ok(!alg, "Expected failure, got %d\n", alg);
+    ok(!alg, "Expected failure, got %ld\n", alg);
 
     for (i = 0; i < ARRAY_SIZE(oidToAlgID); i++)
     {
         alg = CertOIDToAlgId(oidToAlgID[i].oid);
         ok(alg == oidToAlgID[i].algID || (oidToAlgID[i].altAlgID && alg == oidToAlgID[i].altAlgID),
-         "Expected %d, got %d\n", oidToAlgID[i].algID, alg);
+         "Expected %ld, got %ld\n", oidToAlgID[i].algID, alg);
     }
 }
 
-static void testAlgIDToOID(void)
+static void test_AlgIDToOID(void)
 {
     int i;
     LPCSTR oid;
@@ -124,32 +116,14 @@ static void testAlgIDToOID(void)
     SetLastError(0xdeadbeef);
     oid = CertAlgIdToOID(ALG_CLASS_SIGNATURE | ALG_TYPE_ANY | 80);
     ok(!oid && GetLastError() == 0xdeadbeef,
-     "Didn't expect last error (%08x) to be set\n", GetLastError());
+     "Didn't expect last error (%08lx) to be set\n", GetLastError());
     for (i = 0; i < ARRAY_SIZE(algIDToOID); i++)
     {
         oid = CertAlgIdToOID(algIDToOID[i].algID);
         /* Allow failure, not every version of Windows supports every algo */
-        ok(oid != NULL || broken(!oid), "CertAlgIdToOID failed, expected %s\n", algIDToOID[i].oid);
+        ok(oid != NULL, "CertAlgIdToOID failed, expected %s\n", algIDToOID[i].oid);
         if (oid)
-        {
-            if (strcmp(oid, algIDToOID[i].oid))
-            {
-                if (algIDToOID[i].altOid)
-                    ok(!strcmp(oid, algIDToOID[i].altOid),
-                     "Expected %s or %s, got %s\n", algIDToOID[i].oid,
-                     algIDToOID[i].altOid, oid);
-                else
-                {
-                    /* No need to rerun the test, we already know it failed. */
-                    ok(0, "Expected %s, got %s\n", algIDToOID[i].oid, oid);
-                }
-            }
-            else
-            {
-                /* No need to rerun the test, we already know it succeeded. */
-                ok(1, "Expected %s, got %s\n", algIDToOID[i].oid, oid);
-            }
-        }
+            ok(!strcmp(oid, algIDToOID[i].oid), "Expected %s, got %s\n", algIDToOID[i].oid, oid);
     }
 }
 
@@ -166,7 +140,7 @@ static void test_oidFunctionSet(void)
 
     /* The name doesn't mean much */
     set1 = CryptInitOIDFunctionSet("funky", 0);
-    ok(set1 != 0, "CryptInitOIDFunctionSet failed: %08x\n", GetLastError());
+    ok(set1 != 0, "CryptInitOIDFunctionSet failed: %08lx\n", GetLastError());
     if (set1)
     {
         /* These crash
@@ -175,26 +149,26 @@ static void test_oidFunctionSet(void)
          */
         size = 0;
         ret = CryptGetDefaultOIDDllList(set1, 0, NULL, &size);
-        ok(ret, "CryptGetDefaultOIDDllList failed: %08x\n", GetLastError());
+        ok(ret, "CryptGetDefaultOIDDllList failed: %08lx\n", GetLastError());
         if (ret)
         {
-            buf = HeapAlloc(GetProcessHeap(), 0, size * sizeof(WCHAR));
+            buf = malloc(size * sizeof(WCHAR));
             if (buf)
             {
                 ret = CryptGetDefaultOIDDllList(set1, 0, buf, &size);
-                ok(ret, "CryptGetDefaultOIDDllList failed: %08x\n",
+                ok(ret, "CryptGetDefaultOIDDllList failed: %08lx\n",
                  GetLastError());
                 ok(!*buf, "Expected empty DLL list\n");
-                HeapFree(GetProcessHeap(), 0, buf);
+                free(buf);
             }
         }
     }
 
     /* MSDN says flags must be 0, but it's not checked */
     set1 = CryptInitOIDFunctionSet("", 1);
-    ok(set1 != 0, "CryptInitOIDFunctionSet failed: %08x\n", GetLastError());
+    ok(set1 != 0, "CryptInitOIDFunctionSet failed: %08lx\n", GetLastError());
     set2 = CryptInitOIDFunctionSet("", 0);
-    ok(set2 != 0, "CryptInitOIDFunctionSet failed: %08x\n", GetLastError());
+    ok(set2 != 0, "CryptInitOIDFunctionSet failed: %08lx\n", GetLastError());
     /* There isn't a free function, so there must be only one set per name to
      * limit leaks.  (I guess the sets are freed when crypt32 is unloaded.)
      */
@@ -208,7 +182,7 @@ static void test_oidFunctionSet(void)
 
     /* There's no installed function for a built-in encoding. */
     set1 = CryptInitOIDFunctionSet("CryptDllEncodeObject", 0);
-    ok(set1 != 0, "CryptInitOIDFunctionSet failed: %08x\n", GetLastError());
+    ok(set1 != 0, "CryptInitOIDFunctionSet failed: %08lx\n", GetLastError());
     if (set1)
     {
         void *funcAddr;
@@ -216,9 +190,8 @@ static void test_oidFunctionSet(void)
 
         ret = CryptGetOIDFunctionAddress(set1, X509_ASN_ENCODING, X509_CERT, 0,
          &funcAddr, &hFuncAddr);
-        ok((!ret && GetLastError() == ERROR_FILE_NOT_FOUND) ||
-         broken(ret) /* some Win98 */,
-         "Expected ERROR_FILE_NOT_FOUND, got %08x\n", GetLastError());
+        ok(!ret && GetLastError() == ERROR_FILE_NOT_FOUND,
+         "Expected ERROR_FILE_NOT_FOUND, got %08lx\n", GetLastError());
     }
 }
 
@@ -243,21 +216,21 @@ static void test_installOIDFunctionAddress(void)
     SetLastError(0xdeadbeef);
     ret = CryptInstallOIDFunctionAddress(NULL, 0, "CryptDllEncodeObject", 0,
      NULL, 0);
-    ok(ret && GetLastError() == 0xdeadbeef, "Expected success, got %08x\n",
+    ok(ret && GetLastError() == 0xdeadbeef, "Expected success, got %08lx\n",
      GetLastError());
 
     /* The function name doesn't much matter */
     SetLastError(0xdeadbeef);
     ret = CryptInstallOIDFunctionAddress(NULL, 0, "OhSoFunky", 0, NULL, 0);
-    ok(ret && GetLastError() == 0xdeadbeef, "Expected success, got %08x\n",
+    ok(ret && GetLastError() == 0xdeadbeef, "Expected success, got %08lx\n",
      GetLastError());
     SetLastError(0xdeadbeef);
     entry.pszOID = X509_CERT;
     ret = CryptInstallOIDFunctionAddress(NULL, 0, "OhSoFunky", 1, &entry, 0);
-    ok(ret && GetLastError() == 0xdeadbeef, "Expected success, got %08x\n",
+    ok(ret && GetLastError() == 0xdeadbeef, "Expected success, got %08lx\n",
      GetLastError());
     set = CryptInitOIDFunctionSet("OhSoFunky", 0);
-    ok(set != 0, "CryptInitOIDFunctionSet failed: %08x\n", GetLastError());
+    ok(set != 0, "CryptInitOIDFunctionSet failed: %08lx\n", GetLastError());
     if (set)
     {
         funcY funcAddr = NULL;
@@ -269,17 +242,15 @@ static void test_installOIDFunctionAddress(void)
          */
         ret = CryptGetOIDFunctionAddress(set, X509_ASN_ENCODING, 0, 0,
          (void **)&funcAddr, &hFuncAddr);
-        ok(!ret && (GetLastError() == ERROR_FILE_NOT_FOUND ||
-         GetLastError() == E_INVALIDARG /* some Win98 */),
-         "Expected ERROR_FILE_NOT_FOUND or E_INVALIDARG, got %d\n",
-         GetLastError());
+        ok(!ret && GetLastError() == ERROR_FILE_NOT_FOUND,
+         "Expected ERROR_FILE_NOT_FOUND, got %ld\n", GetLastError());
         ret = CryptGetOIDFunctionAddress(set, X509_ASN_ENCODING, X509_CERT, 0,
          (void **)&funcAddr, &hFuncAddr);
         ok(!ret && GetLastError() == ERROR_FILE_NOT_FOUND,
-         "Expected ERROR_FILE_NOT_FOUND, got %d\n", GetLastError());
+         "Expected ERROR_FILE_NOT_FOUND, got %ld\n", GetLastError());
         ret = CryptGetOIDFunctionAddress(set, 0, X509_CERT, 0,
          (void **)&funcAddr, &hFuncAddr);
-        ok(ret, "CryptGetOIDFunctionAddress failed: %d\n", GetLastError());
+        ok(ret, "CryptGetOIDFunctionAddress failed: %ld\n", GetLastError());
         if (funcAddr)
         {
             int y = funcAddr(0xabadc0da);
@@ -298,55 +269,55 @@ static void test_registerOIDFunction(void)
      * omitted.  This may be a side effect of the registry code, I don't know.
      * I don't check it because I doubt anyone would depend on it.
     ret = CryptRegisterOIDFunction(X509_ASN_ENCODING, NULL,
-     "1.2.3.4.5.6.7.8.9.10", bogusDll, NULL);
+     "1.2.3.4.5.6.7.8.9.10", L"bogus.dll", NULL);
      */
     /* On windows XP, GetLastError is incorrectly being set with an HRESULT,
      * E_INVALIDARG
      */
-    ret = CryptRegisterOIDFunction(X509_ASN_ENCODING, "foo", NULL, bogusDll,
+    ret = CryptRegisterOIDFunction(X509_ASN_ENCODING, "foo", NULL, L"bogus.dll",
      NULL);
     ok(!ret && GetLastError() == E_INVALIDARG,
-     "Expected E_INVALIDARG: %d\n", GetLastError());
+     "Expected E_INVALIDARG: %ld\n", GetLastError());
     /* This has no effect, but "succeeds" on XP */
     ret = CryptRegisterOIDFunction(X509_ASN_ENCODING, "foo",
      "1.2.3.4.5.6.7.8.9.10", NULL, NULL);
-    ok(ret, "Expected pseudo-success, got %d\n", GetLastError());
+    ok(ret, "Expected pseudo-success, got %ld\n", GetLastError());
     SetLastError(0xdeadbeef);
     ret = CryptRegisterOIDFunction(X509_ASN_ENCODING, "CryptDllEncodeObject",
-     "1.2.3.4.5.6.7.8.9.10", bogusDll, NULL);
+     "1.2.3.4.5.6.7.8.9.10", L"bogus.dll", NULL);
     if (!ret && GetLastError() == ERROR_ACCESS_DENIED)
     {
         skip("Need admin rights\n");
         return;
     }
-    ok(ret, "CryptRegisterOIDFunction failed: %d\n", GetLastError());
+    ok(ret, "CryptRegisterOIDFunction failed: %ld\n", GetLastError());
     ret = CryptUnregisterOIDFunction(X509_ASN_ENCODING, "CryptDllEncodeObject",
      "1.2.3.4.5.6.7.8.9.10");
-    ok(ret, "CryptUnregisterOIDFunction failed: %d\n", GetLastError());
+    ok(ret, "CryptUnregisterOIDFunction failed: %ld\n", GetLastError());
     ret = CryptRegisterOIDFunction(X509_ASN_ENCODING, "bogus",
-     "1.2.3.4.5.6.7.8.9.10", bogusDll, NULL);
-    ok(ret, "CryptRegisterOIDFunction failed: %d\n", GetLastError());
+     "1.2.3.4.5.6.7.8.9.10", L"bogus.dll", NULL);
+    ok(ret, "CryptRegisterOIDFunction failed: %ld\n", GetLastError());
     ret = CryptUnregisterOIDFunction(X509_ASN_ENCODING, "bogus",
      "1.2.3.4.5.6.7.8.9.10");
-    ok(ret, "CryptUnregisterOIDFunction failed: %d\n", GetLastError());
+    ok(ret, "CryptUnregisterOIDFunction failed: %ld\n", GetLastError());
     /* Unwanted Cryptography\OID\EncodingType 1\bogus\ will still be there */
     ok(!RegDeleteKeyA(HKEY_LOCAL_MACHINE,
      "SOFTWARE\\Microsoft\\Cryptography\\OID\\EncodingType 1\\bogus"),
      "Could not delete bogus key\n");
     /* Shouldn't have effect but registry keys are created */
     ret = CryptRegisterOIDFunction(PKCS_7_ASN_ENCODING, "CryptDllEncodeObject",
-     "1.2.3.4.5.6.7.8.9.10", bogusDll, NULL);
-    ok(ret, "CryptRegisterOIDFunction failed: %d\n", GetLastError());
+     "1.2.3.4.5.6.7.8.9.10", L"bogus.dll", NULL);
+    ok(ret, "CryptRegisterOIDFunction failed: %ld\n", GetLastError());
     ret = CryptUnregisterOIDFunction(PKCS_7_ASN_ENCODING, "CryptDllEncodeObject",
      "1.2.3.4.5.6.7.8.9.10");
-    ok(ret, "CryptUnregisterOIDFunction failed: %d\n", GetLastError());
+    ok(ret, "CryptUnregisterOIDFunction failed: %ld\n", GetLastError());
     /* Check with bogus encoding type. Registry keys are still created */
     ret = CryptRegisterOIDFunction(0, "CryptDllEncodeObject",
-     "1.2.3.4.5.6.7.8.9.10", bogusDll, NULL);
-    ok(ret, "CryptRegisterOIDFunction failed: %d\n", GetLastError());
+     "1.2.3.4.5.6.7.8.9.10", L"bogus.dll", NULL);
+    ok(ret, "CryptRegisterOIDFunction failed: %ld\n", GetLastError());
     ret = CryptUnregisterOIDFunction(0, "CryptDllEncodeObject",
      "1.2.3.4.5.6.7.8.9.10");
-    ok(ret, "CryptUnregisterOIDFunction failed: %d\n", GetLastError());
+    ok(ret, "CryptUnregisterOIDFunction failed: %ld\n", GetLastError());
     /* Unwanted Cryptography\OID\EncodingType 0\CryptDllEncodeObject\
      * will still be there
      */
@@ -357,11 +328,11 @@ static void test_registerOIDFunction(void)
      * (for now) treated as a mask. Registry keys are created.
      */
     ret = CryptRegisterOIDFunction(3, "CryptDllEncodeObject",
-     "1.2.3.4.5.6.7.8.9.10", bogusDll, NULL);
-    ok(ret, "CryptRegisterOIDFunction failed: %d\n", GetLastError());
+     "1.2.3.4.5.6.7.8.9.10", L"bogus.dll", NULL);
+    ok(ret, "CryptRegisterOIDFunction failed: %ld\n", GetLastError());
     ret = CryptUnregisterOIDFunction(3, "CryptDllEncodeObject",
      "1.2.3.4.5.6.7.8.9.10");
-    ok(ret, "CryptUnregisterOIDFunction failed: %d\n", GetLastError());
+    ok(ret, "CryptUnregisterOIDFunction failed: %ld\n", GetLastError());
     /* Unwanted Cryptography\OID\EncodingType 3\CryptDllEncodeObject
      * will still be there.
      */
@@ -385,84 +356,81 @@ static void test_registerDefaultOIDFunction(void)
 
     ret = CryptRegisterDefaultOIDFunction(0, NULL, 0, NULL);
     ok(!ret && GetLastError() == E_INVALIDARG,
-     "Expected E_INVALIDARG, got %08x\n", GetLastError());
+     "Expected E_INVALIDARG, got %08lx\n", GetLastError());
     /* This succeeds on WinXP, although the bogus entry is unusable.
-    ret = CryptRegisterDefaultOIDFunction(0, NULL, 0, bogusDll);
+    ret = CryptRegisterDefaultOIDFunction(0, NULL, 0, L"bogus.dll");
      */
     /* Register one at index 0 */
     SetLastError(0xdeadbeef);
     ret = CryptRegisterDefaultOIDFunction(0, "CertDllOpenStoreProv", 0,
-     bogusDll);
+     L"bogus.dll");
     if (!ret && GetLastError() == ERROR_ACCESS_DENIED)
     {
         skip("Need admin rights\n");
         return;
     }
-    ok(ret, "CryptRegisterDefaultOIDFunction failed: %08x\n", GetLastError());
+    ok(ret, "CryptRegisterDefaultOIDFunction failed: %08lx\n", GetLastError());
     /* Reregistering should fail */
     ret = CryptRegisterDefaultOIDFunction(0, "CertDllOpenStoreProv", 0,
-     bogusDll);
+     L"bogus.dll");
     ok(!ret && GetLastError() == ERROR_FILE_EXISTS,
-     "Expected ERROR_FILE_EXISTS, got %08x\n", GetLastError());
+     "Expected ERROR_FILE_EXISTS, got %08lx\n", GetLastError());
     /* Registering the same one at index 1 should also fail */
     ret = CryptRegisterDefaultOIDFunction(0, "CertDllOpenStoreProv", 1,
-     bogusDll);
+     L"bogus.dll");
     ok(!ret && GetLastError() == ERROR_FILE_EXISTS,
-     "Expected ERROR_FILE_EXISTS, got %08x\n", GetLastError());
+     "Expected ERROR_FILE_EXISTS, got %08lx\n", GetLastError());
     /* Registering a different one at index 1 succeeds */
     ret = CryptRegisterDefaultOIDFunction(0, "CertDllOpenStoreProv", 1,
-     bogus2Dll);
-    ok(ret, "CryptRegisterDefaultOIDFunction failed: %08x\n", GetLastError());
+     L"bogus2.dll");
+    ok(ret, "CryptRegisterDefaultOIDFunction failed: %08lx\n", GetLastError());
     sprintf(buf, fmt, 0, func);
     rc = RegOpenKeyA(HKEY_LOCAL_MACHINE, buf, &key);
-    ok(rc == 0, "Expected key to exist, RegOpenKeyA failed: %d\n", rc);
+    ok(rc == 0, "Expected key to exist, RegOpenKeyA failed: %ld\n", rc);
     if (rc == 0)
     {
-        static const CHAR dllA[] = "Dll";
-        static const CHAR bogusDll_A[] = "bogus.dll";
-        static const CHAR bogus2Dll_A[] = "bogus2.dll";
         CHAR dllBuf[MAX_PATH];
         DWORD type, size;
         LPSTR ptr;
 
         size = ARRAY_SIZE(dllBuf);
-        rc = RegQueryValueExA(key, dllA, NULL, &type, (LPBYTE)dllBuf, &size);
+        rc = RegQueryValueExA(key, "Dll", NULL, &type, (LPBYTE)dllBuf, &size);
         ok(rc == 0,
-         "Expected Dll value to exist, RegQueryValueExA failed: %d\n", rc);
-        ok(type == REG_MULTI_SZ, "Expected type REG_MULTI_SZ, got %d\n", type);
-        /* bogusDll was registered first, so that should be first */
+         "Expected Dll value to exist, RegQueryValueExA failed: %ld\n", rc);
+        ok(type == REG_MULTI_SZ, "Expected type REG_MULTI_SZ, got %ld\n", type);
+        /* bogus.dll was registered first, so that should be first */
         ptr = dllBuf;
-        ok(!lstrcmpiA(ptr, bogusDll_A), "Unexpected dll\n");
+        ok(!lstrcmpiA(ptr, "bogus.dll"), "Unexpected dll\n");
         ptr += lstrlenA(ptr) + 1;
-        ok(!lstrcmpiA(ptr, bogus2Dll_A), "Unexpected dll\n");
+        ok(!lstrcmpiA(ptr, "bogus2.dll"), "Unexpected dll\n");
         RegCloseKey(key);
     }
     /* Unregister both of them */
     ret = CryptUnregisterDefaultOIDFunction(0, "CertDllOpenStoreProv",
-     bogusDll);
-    ok(ret, "CryptUnregisterDefaultOIDFunction failed: %08x\n",
+     L"bogus.dll");
+    ok(ret, "CryptUnregisterDefaultOIDFunction failed: %08lx\n",
      GetLastError());
     ret = CryptUnregisterDefaultOIDFunction(0, "CertDllOpenStoreProv",
-     bogus2Dll);
-    ok(ret, "CryptUnregisterDefaultOIDFunction failed: %08x\n",
+     L"bogus2.dll");
+    ok(ret, "CryptUnregisterDefaultOIDFunction failed: %08lx\n",
      GetLastError());
     /* Now that they're both unregistered, unregistering should fail */
     ret = CryptUnregisterDefaultOIDFunction(0, "CertDllOpenStoreProv",
-     bogusDll);
+     L"bogus.dll");
     ok(!ret && GetLastError() == ERROR_FILE_NOT_FOUND,
-     "Expected ERROR_FILE_NOT_FOUND, got %d\n", GetLastError());
+     "Expected ERROR_FILE_NOT_FOUND, got %ld\n", GetLastError());
 
     /* Repeat a few tests on the normal encoding type */
     ret = CryptRegisterDefaultOIDFunction(X509_ASN_ENCODING,
-     "CertDllOpenStoreProv", 0, bogusDll);
+     "CertDllOpenStoreProv", 0, L"bogus.dll");
     ok(ret, "CryptRegisterDefaultOIDFunction failed\n");
     ret = CryptUnregisterDefaultOIDFunction(X509_ASN_ENCODING,
-     "CertDllOpenStoreProv", bogusDll);
+     "CertDllOpenStoreProv", L"bogus.dll");
     ok(ret, "CryptUnregisterDefaultOIDFunction failed\n");
     ret = CryptUnregisterDefaultOIDFunction(X509_ASN_ENCODING,
-     "CertDllOpenStoreProv", bogusDll);
+     "CertDllOpenStoreProv", L"bogus.dll");
     ok(!ret && GetLastError() == ERROR_FILE_NOT_FOUND,
-     "Expected ERROR_FILE_NOT_FOUND, got %08x\n", GetLastError());
+     "Expected ERROR_FILE_NOT_FOUND, got %08lx\n", GetLastError());
 }
 
 static void test_getDefaultOIDFunctionAddress(void)
@@ -480,34 +448,34 @@ static void test_getDefaultOIDFunctionAddress(void)
      &hFuncAddr);
      */
     set = CryptInitOIDFunctionSet("CertDllOpenStoreProv", 0);
-    ok(set != 0, "CryptInitOIDFunctionSet failed: %d\n", GetLastError());
+    ok(set != 0, "CryptInitOIDFunctionSet failed: %ld\n", GetLastError());
     /* This crashes if hFuncAddr is not 0 to begin with */
     hFuncAddr = 0;
     ret = CryptGetDefaultOIDFunctionAddress(set, 0, NULL, 0, &funcAddr,
      &hFuncAddr);
     ok(!ret && GetLastError() == ERROR_FILE_NOT_FOUND,
-     "Expected ERROR_FILE_NOT_FOUND, got %d\n", GetLastError());
+     "Expected ERROR_FILE_NOT_FOUND, got %ld\n", GetLastError());
     /* This fails with the normal encoding too, so built-in functions aren't
      * returned.
      */
     ret = CryptGetDefaultOIDFunctionAddress(set, X509_ASN_ENCODING, NULL, 0,
      &funcAddr, &hFuncAddr);
     ok(!ret && GetLastError() == ERROR_FILE_NOT_FOUND,
-     "Expected ERROR_FILE_NOT_FOUND, got %d\n", GetLastError());
+     "Expected ERROR_FILE_NOT_FOUND, got %ld\n", GetLastError());
 
     /* Even with a registered dll, this fails (since the dll doesn't exist) */
     SetLastError(0xdeadbeef);
     ret = CryptRegisterDefaultOIDFunction(0, "CertDllOpenStoreProv", 0,
-     bogusDll);
+     L"bogus.dll");
     if (!ret && GetLastError() == ERROR_ACCESS_DENIED)
         skip("Need admin rights\n");
     else
-        ok(ret, "CryptRegisterDefaultOIDFunction failed: %08x\n", GetLastError());
+        ok(ret, "CryptRegisterDefaultOIDFunction failed: %08lx\n", GetLastError());
     ret = CryptGetDefaultOIDFunctionAddress(set, 0, NULL, 0, &funcAddr,
      &hFuncAddr);
     ok(!ret && GetLastError() == ERROR_FILE_NOT_FOUND,
-     "Expected ERROR_FILE_NOT_FOUND, got %d\n", GetLastError());
-    CryptUnregisterDefaultOIDFunction(0, "CertDllOpenStoreProv", bogusDll);
+     "Expected ERROR_FILE_NOT_FOUND, got %ld\n", GetLastError());
+    CryptUnregisterDefaultOIDFunction(0, "CertDllOpenStoreProv", L"bogus.dll");
 }
 
 static BOOL WINAPI countOidInfo(PCCRYPT_OID_INFO pInfo, void *pvArg)
@@ -526,27 +494,19 @@ static void test_enumOIDInfo(void)
     BOOL ret;
     DWORD count = 0;
 
-    if (!pCryptEnumOIDInfo)
-    {
-        win_skip("CryptEnumOIDInfo() is not available\n");
-        return;
-    }
-
     /* This crashes
-    ret = pCryptEnumOIDInfo(7, 0, NULL, NULL);
+    ret = CryptEnumOIDInfo(7, 0, NULL, NULL);
      */
 
     /* Silly tests, check that more than one thing is enumerated */
-    ret = pCryptEnumOIDInfo(0, 0, &count, countOidInfo);
+    ret = CryptEnumOIDInfo(0, 0, &count, countOidInfo);
     ok(ret && count > 0, "Expected more than item enumerated\n");
-    ret = pCryptEnumOIDInfo(0, 0, NULL, noOidInfo);
+    ret = CryptEnumOIDInfo(0, 0, NULL, noOidInfo);
     ok(!ret, "Expected FALSE\n");
 }
 
 static void test_findOIDInfo(void)
 {
-    static WCHAR sha256ECDSA[] = { 's','h','a','2','5','6','E','C','D','S','A',0 };
-    static WCHAR sha1[] = { 's','h','a','1',0 };
     static CHAR oid_rsa_md5[] = szOID_RSA_MD5, oid_sha256[] = szOID_NIST_sha256;
     static CHAR oid_ecdsa_sha256[] = szOID_ECDSA_SHA256;
     ALG_ID alg = CALG_SHA1;
@@ -561,7 +521,7 @@ static void test_findOIDInfo(void)
     } oid_test_info [] =
     {
         { CRYPT_OID_INFO_OID_KEY, oid_rsa_md5, szOID_RSA_MD5, CALG_MD5 },
-        { CRYPT_OID_INFO_NAME_KEY, sha1, szOID_OIWSEC_sha1, CALG_SHA1 },
+        { CRYPT_OID_INFO_NAME_KEY, (void *)L"sha1", szOID_OIWSEC_sha1, CALG_SHA1 },
         { CRYPT_OID_INFO_ALGID_KEY, &alg, szOID_OIWSEC_sha1, CALG_SHA1 },
         { CRYPT_OID_INFO_SIGN_KEY, algs, szOID_RSA_MD5RSA, CALG_MD5 },
         { CRYPT_OID_INFO_OID_KEY, oid_sha256, szOID_NIST_sha256, CALG_SHA_256, -1 },
@@ -591,20 +551,20 @@ static void test_findOIDInfo(void)
     {
         DWORD *data;
 
-        ok(info->cbSize == sizeof(*info), "Unexpected structure size %d.\n", info->cbSize);
+        ok(info->cbSize == sizeof(*info), "Unexpected structure size %ld.\n", info->cbSize);
         ok(!strcmp(info->pszOID, oid_ecdsa_sha256), "Expected %s, got %s\n", oid_ecdsa_sha256, info->pszOID);
-        ok(!lstrcmpW(info->pwszName, sha256ECDSA), "Expected %s, got %s\n",
-            wine_dbgstr_w(sha256ECDSA), wine_dbgstr_w(info->pwszName));
+        ok(!lstrcmpW(info->pwszName, L"sha256ECDSA"), "Expected %s, got %s\n",
+            wine_dbgstr_w(L"sha256ECDSA"), wine_dbgstr_w(info->pwszName));
         ok(info->dwGroupId == CRYPT_SIGN_ALG_OID_GROUP_ID,
-           "Expected CRYPT_SIGN_ALG_OID_GROUP_ID, got %u\n", info->dwGroupId);
+           "Expected CRYPT_SIGN_ALG_OID_GROUP_ID, got %lu\n", info->dwGroupId);
         ok(U(*info).Algid == CALG_OID_INFO_CNG_ONLY,
            "Expected CALG_OID_INFO_CNG_ONLY, got %d\n", U(*info).Algid);
 
         data = (DWORD *)info->ExtraInfo.pbData;
-        ok(info->ExtraInfo.cbData == 8, "Expected 8, got %d\n", info->ExtraInfo.cbData);
-        ok(data[0] == CALG_OID_INFO_PARAMETERS, "Expected CALG_OID_INFO_PARAMETERS, got %x\n", data[0]);
+        ok(info->ExtraInfo.cbData == 8, "Expected 8, got %ld\n", info->ExtraInfo.cbData);
+        ok(data[0] == CALG_OID_INFO_PARAMETERS, "Expected CALG_OID_INFO_PARAMETERS, got %lx\n", data[0]);
         ok(data[1] == CRYPT_OID_NO_NULL_ALGORITHM_PARA_FLAG,
-            "Expected CRYPT_OID_NO_NULL_ALGORITHM_PARA_FLAG, got %x\n", data[1]);
+            "Expected CRYPT_OID_NO_NULL_ALGORITHM_PARA_FLAG, got %lx\n", data[1]);
 
         ok(!lstrcmpW(info->pwszCNGAlgid, BCRYPT_SHA256_ALGORITHM), "Expected %s, got %s\n",
            wine_dbgstr_w(BCRYPT_SHA256_ALGORITHM), wine_dbgstr_w(info->pwszCNGAlgid));
@@ -617,7 +577,6 @@ static void test_findOIDInfo(void)
 
 static void test_registerOIDInfo(void)
 {
-    static const WCHAR winetestW[] = { 'w','i','n','e','t','e','s','t',0 };
     static char test_oid[] = "1.2.3.4.5.6.7.8.9.10";
     CRYPT_OID_INFO info1;
     const CRYPT_OID_INFO *info2;
@@ -628,26 +587,26 @@ static void test_registerOIDInfo(void)
     SetLastError(0xdeadbeef);
     ret = CryptUnregisterOIDInfo(NULL);
     ok(!ret, "should fail\n");
-    ok(GetLastError() == E_INVALIDARG, "got %#x\n", GetLastError());
+    ok(GetLastError() == E_INVALIDARG, "got %#lx\n", GetLastError());
 
     memset(&info1, 0, sizeof(info1));
     SetLastError(0xdeadbeef);
     ret = CryptUnregisterOIDInfo(&info1);
     ok(!ret, "should fail\n");
-    ok(GetLastError() == E_INVALIDARG, "got %#x\n", GetLastError());
+    ok(GetLastError() == E_INVALIDARG, "got %#lx\n", GetLastError());
 
     info1.cbSize = sizeof(info1);
     SetLastError(0xdeadbeef);
     ret = CryptUnregisterOIDInfo(&info1);
     ok(!ret, "should fail\n");
-    ok(GetLastError() == E_INVALIDARG, "got %#x\n", GetLastError());
+    ok(GetLastError() == E_INVALIDARG, "got %#lx\n", GetLastError());
 
     info1.pszOID = test_oid;
     SetLastError(0xdeadbeef);
     ret = CryptUnregisterOIDInfo(&info1);
     ok(!ret, "should fail\n");
     ok(GetLastError() == ERROR_FILE_NOT_FOUND ||
-       GetLastError() == ERROR_ACCESS_DENIED, "got %u\n", GetLastError());
+       GetLastError() == ERROR_ACCESS_DENIED, "got %lu\n", GetLastError());
 
     info2 = CryptFindOIDInfo(CRYPT_OID_INFO_OID_KEY, (void *)test_oid, 0);
     ok(!info2, "should fail\n");
@@ -657,15 +616,15 @@ static void test_registerOIDInfo(void)
      * registry on Windows because dwGroupId == 0.
      */
     ret = CryptRegisterOIDInfo(&info1, 0);
-    ok(ret, "got %u\n", GetLastError());
+    ok(ret, "got %lu\n", GetLastError());
 
     ret = RegOpenKeyA(HKEY_LOCAL_MACHINE, "Software\\Microsoft\\Cryptography\\OID\\EncodingType 0\\CryptDllFindOIDInfo\\1.2.3.4.5.6.7.8.9.10!1", &key);
-    ok(ret == ERROR_FILE_NOT_FOUND, "got %u\n", ret);
+    ok(ret == ERROR_FILE_NOT_FOUND, "got %lu\n", ret);
 
     info2 = CryptFindOIDInfo(CRYPT_OID_INFO_OID_KEY, (void *)test_oid, 0);
     ok(!info2, "should fail\n");
 
-    info1.pwszName = winetestW;
+    info1.pwszName = L"winetest";
     info1.dwGroupId = CRYPT_HASH_ALG_OID_GROUP_ID;
     SetLastError(0xdeadbeef);
     ret = CryptRegisterOIDInfo(&info1, CRYPT_INSTALL_OID_INFO_BEFORE_FLAG);
@@ -674,7 +633,7 @@ static void test_registerOIDInfo(void)
         skip("Need admin rights\n");
         return;
     }
-    ok(ret, "got %u\n", GetLastError());
+    ok(ret, "got %lu\n", GetLastError());
 
     /* It looks like crypt32 reads the OID info from registry only on load,
      * and CryptFindOIDInfo will find the registered OID on next run
@@ -683,37 +642,34 @@ static void test_registerOIDInfo(void)
     ok(!info2, "should fail\n");
 
     ret = RegCreateKeyA(HKEY_LOCAL_MACHINE, "Software\\Microsoft\\Cryptography\\OID\\EncodingType 0\\CryptDllFindOIDInfo\\1.2.3.4.5.6.7.8.9.10!1", &key);
-    ok(!ret, "got %u\n", ret);
+    ok(!ret, "got %lu\n", ret);
 
     memset(buf, 0, sizeof(buf));
     size = sizeof(buf);
     ret = RegQueryValueExA(key, "Name", NULL, &type, (BYTE *)buf, &size);
-    ok(!ret, "got %u\n", ret);
-    ok(type == REG_SZ, "got %u\n", type);
+    ok(!ret, "got %lu\n", ret);
+    ok(type == REG_SZ, "got %lu\n", type);
     ok(!strcmp(buf, "winetest"), "got %s\n", buf);
 
     value = 0xdeadbeef;
     size = sizeof(value);
     ret = RegQueryValueExA(key, "Flags", NULL, &type, (BYTE *)&value, &size);
-    ok(!ret, "got %u\n", ret);
-    ok(type == REG_DWORD, "got %u\n", type);
-    ok(value == 1, "got %u\n", value);
+    ok(!ret, "got %lu\n", ret);
+    ok(type == REG_DWORD, "got %lu\n", type);
+    ok(value == 1, "got %lu\n", value);
 
     RegCloseKey(key);
 
     CryptUnregisterOIDInfo(&info1);
 
     ret = RegOpenKeyA(HKEY_LOCAL_MACHINE, "Software\\Microsoft\\Cryptography\\OID\\EncodingType 0\\CryptDllFindOIDInfo\\1.2.3.4.5.6.7.8.9.10!1", &key);
-    ok(ret == ERROR_FILE_NOT_FOUND, "got %u\n", ret);
+    ok(ret == ERROR_FILE_NOT_FOUND, "got %lu\n", ret);
 }
 
 START_TEST(oid)
 {
-    HMODULE hCrypt32 = GetModuleHandleA("crypt32.dll");
-    pCryptEnumOIDInfo = (void*)GetProcAddress(hCrypt32, "CryptEnumOIDInfo");
-
-    testOIDToAlgID();
-    testAlgIDToOID();
+    test_OIDToAlgID();
+    test_AlgIDToOID();
     test_enumOIDInfo();
     test_findOIDInfo();
     test_registerOIDInfo();
