@@ -26,6 +26,25 @@ static inline struct d2d_bitmap *impl_from_ID2D1Bitmap1(ID2D1Bitmap1 *iface)
     return CONTAINING_RECORD(iface, struct d2d_bitmap, ID2D1Bitmap1_iface);
 }
 
+static HRESULT d2d_bitmap_unmap(struct d2d_bitmap *bitmap)
+{
+    ID3D11DeviceContext *context;
+    ID3D11Device *device;
+
+    if (!bitmap->mapped_resource.pData)
+        return D2DERR_WRONG_STATE;
+
+    ID3D11Resource_GetDevice(bitmap->resource, &device);
+    ID3D11Device_GetImmediateContext(device, &context);
+    ID3D11DeviceContext_Unmap(context, bitmap->resource, 0);
+    ID3D11DeviceContext_Release(context);
+    ID3D11Device_Release(device);
+
+    memset(&bitmap->mapped_resource, 0, sizeof(bitmap->mapped_resource));
+
+    return S_OK;
+}
+
 static HRESULT STDMETHODCALLTYPE d2d_bitmap_QueryInterface(ID2D1Bitmap1 *iface, REFIID iid, void **out)
 {
     TRACE("iface %p, iid %s, out %p.\n", iface, debugstr_guid(iid), out);
@@ -52,7 +71,7 @@ static ULONG STDMETHODCALLTYPE d2d_bitmap_AddRef(ID2D1Bitmap1 *iface)
     struct d2d_bitmap *bitmap = impl_from_ID2D1Bitmap1(iface);
     ULONG refcount = InterlockedIncrement(&bitmap->refcount);
 
-    TRACE("%p increasing refcount to %u.\n", iface, refcount);
+    TRACE("%p increasing refcount to %lu.\n", iface, refcount);
 
     return refcount;
 }
@@ -62,19 +81,19 @@ static ULONG STDMETHODCALLTYPE d2d_bitmap_Release(ID2D1Bitmap1 *iface)
     struct d2d_bitmap *bitmap = impl_from_ID2D1Bitmap1(iface);
     ULONG refcount = InterlockedDecrement(&bitmap->refcount);
 
-    TRACE("%p decreasing refcount to %u.\n", iface, refcount);
+    TRACE("%p decreasing refcount to %lu.\n", iface, refcount);
 
     if (!refcount)
     {
         if (bitmap->srv)
-            ID3D10ShaderResourceView_Release(bitmap->srv);
+            ID3D11ShaderResourceView_Release(bitmap->srv);
         if (bitmap->rtv)
-            ID3D10RenderTargetView_Release(bitmap->rtv);
+            ID3D11RenderTargetView_Release(bitmap->rtv);
         if (bitmap->surface)
             IDXGISurface_Release(bitmap->surface);
-        ID3D10Resource_Release(bitmap->resource);
+        ID3D11Resource_Release(bitmap->resource);
         ID2D1Factory_Release(bitmap->factory);
-        heap_free(bitmap);
+        free(bitmap);
     }
 
     return refcount;
@@ -133,9 +152,33 @@ static void STDMETHODCALLTYPE d2d_bitmap_GetDpi(ID2D1Bitmap1 *iface, float *dpi_
 static HRESULT STDMETHODCALLTYPE d2d_bitmap_CopyFromBitmap(ID2D1Bitmap1 *iface,
         const D2D1_POINT_2U *dst_point, ID2D1Bitmap *bitmap, const D2D1_RECT_U *src_rect)
 {
-    FIXME("iface %p, dst_point %p, bitmap %p, src_rect %p stub!\n", iface, dst_point, bitmap, src_rect);
+    struct d2d_bitmap *src_bitmap = unsafe_impl_from_ID2D1Bitmap(bitmap);
+    struct d2d_bitmap *dst_bitmap = impl_from_ID2D1Bitmap1(iface);
+    ID3D11DeviceContext *context;
+    ID3D11Device *device;
+    D3D11_BOX box;
 
-    return E_NOTIMPL;
+    TRACE("iface %p, dst_point %p, bitmap %p, src_rect %p.\n", iface, dst_point, bitmap, src_rect);
+
+    if (src_rect)
+    {
+        box.left = src_rect->left;
+        box.top = src_rect->top;
+        box.front = 0;
+        box.right = src_rect->right;
+        box.bottom = src_rect->bottom;
+        box.back = 1;
+    }
+
+    ID3D11Resource_GetDevice(dst_bitmap->resource, &device);
+    ID3D11Device_GetImmediateContext(device, &context);
+    ID3D11DeviceContext_CopySubresourceRegion(context, dst_bitmap->resource, 0,
+            dst_point ? dst_point->x : 0, dst_point ? dst_point->y : 0, 0,
+            src_bitmap->resource, 0, src_rect ? &box : NULL);
+    ID3D11DeviceContext_Release(context);
+    ID3D11Device_Release(device);
+
+    return S_OK;
 }
 
 static HRESULT STDMETHODCALLTYPE d2d_bitmap_CopyFromRenderTarget(ID2D1Bitmap1 *iface,
@@ -150,8 +193,9 @@ static HRESULT STDMETHODCALLTYPE d2d_bitmap_CopyFromMemory(ID2D1Bitmap1 *iface,
         const D2D1_RECT_U *dst_rect, const void *src_data, UINT32 pitch)
 {
     struct d2d_bitmap *bitmap = impl_from_ID2D1Bitmap1(iface);
-    ID3D10Device *device;
-    D3D10_BOX box;
+    ID3D11DeviceContext *context;
+    ID3D11Device *device;
+    D3D11_BOX box;
 
     TRACE("iface %p, dst_rect %p, src_data %p, pitch %u.\n", iface, dst_rect, src_data, pitch);
 
@@ -165,9 +209,11 @@ static HRESULT STDMETHODCALLTYPE d2d_bitmap_CopyFromMemory(ID2D1Bitmap1 *iface,
         box.back = 1;
     }
 
-    ID3D10Resource_GetDevice(bitmap->resource, &device);
-    ID3D10Device_UpdateSubresource(device, bitmap->resource, 0, dst_rect ? &box : NULL, src_data, pitch, 0);
-    ID3D10Device_Release(device);
+    ID3D11Resource_GetDevice(bitmap->resource, &device);
+    ID3D11Device_GetImmediateContext(device, &context);
+    ID3D11DeviceContext_UpdateSubresource(context, bitmap->resource, 0, dst_rect ? &box : NULL, src_data, pitch, 0);
+    ID3D11DeviceContext_Release(context);
+    ID3D11Device_Release(device);
 
     return S_OK;
 }
@@ -202,16 +248,64 @@ static HRESULT STDMETHODCALLTYPE d2d_bitmap_GetSurface(ID2D1Bitmap1 *iface, IDXG
 static HRESULT STDMETHODCALLTYPE d2d_bitmap_Map(ID2D1Bitmap1 *iface, D2D1_MAP_OPTIONS options,
         D2D1_MAPPED_RECT *mapped_rect)
 {
-    FIXME("iface %p, options %#x, mapped_rect %p stub!\n", iface, options, mapped_rect);
+    struct d2d_bitmap *bitmap = impl_from_ID2D1Bitmap1(iface);
+    D3D11_MAPPED_SUBRESOURCE mapped_resource;
+    ID3D11DeviceContext *context;
+    ID3D11Device *device;
+    D3D11_MAP map_type;
+    HRESULT hr;
 
-    return E_NOTIMPL;
+    TRACE("iface %p, options %#x, mapped_rect %p.\n", iface, options, mapped_rect);
+
+    if (!(bitmap->options & D2D1_BITMAP_OPTIONS_CPU_READ))
+        return E_INVALIDARG;
+
+    if (bitmap->mapped_resource.pData)
+        return D2DERR_WRONG_STATE;
+
+    if (options == D2D1_MAP_OPTIONS_READ)
+        map_type = D3D11_MAP_READ;
+    else if (options == D2D1_MAP_OPTIONS_WRITE)
+        map_type = D3D11_MAP_WRITE;
+    else if (options == (D2D1_MAP_OPTIONS_READ | D2D1_MAP_OPTIONS_WRITE))
+        map_type = D3D11_MAP_READ_WRITE;
+    else if (options == (D2D1_MAP_OPTIONS_WRITE | D2D1_MAP_OPTIONS_DISCARD))
+        map_type = D3D11_MAP_WRITE_DISCARD;
+    else
+    {
+        WARN("Invalid mapping options %#x.\n", options);
+        return E_INVALIDARG;
+    }
+
+    ID3D11Resource_GetDevice(bitmap->resource, &device);
+    ID3D11Device_GetImmediateContext(device, &context);
+    if (SUCCEEDED(hr = ID3D11DeviceContext_Map(context, bitmap->resource, 0, map_type,
+            0, &mapped_resource)))
+    {
+        bitmap->mapped_resource = mapped_resource;
+    }
+    ID3D11DeviceContext_Release(context);
+    ID3D11Device_Release(device);
+
+    if (FAILED(hr))
+    {
+        WARN("Failed to map resource, hr %#lx.\n", hr);
+        return E_INVALIDARG;
+    }
+
+    mapped_rect->pitch = bitmap->mapped_resource.RowPitch;
+    mapped_rect->bits  = bitmap->mapped_resource.pData;
+
+    return S_OK;
 }
 
 static HRESULT STDMETHODCALLTYPE d2d_bitmap_Unmap(ID2D1Bitmap1 *iface)
 {
-    FIXME("iface %p stub!\n", iface);
+    struct d2d_bitmap *bitmap = impl_from_ID2D1Bitmap1(iface);
 
-    return E_NOTIMPL;
+    TRACE("iface %p.\n", iface);
+
+    return d2d_bitmap_unmap(bitmap);
 }
 
 static const struct ID2D1Bitmap1Vtbl d2d_bitmap_vtbl =
@@ -270,15 +364,15 @@ static BOOL format_supported(const D2D1_PIXEL_FORMAT *format)
 }
 
 static void d2d_bitmap_init(struct d2d_bitmap *bitmap, struct d2d_device_context *context,
-        ID3D10Resource *resource, D2D1_SIZE_U size, const D2D1_BITMAP_PROPERTIES1 *desc)
+        ID3D11Resource *resource, D2D1_SIZE_U size, const D2D1_BITMAP_PROPERTIES1 *desc)
 {
-    ID3D10Device *d3d_device;
+    ID3D11Device *d3d_device;
     HRESULT hr;
 
     bitmap->ID2D1Bitmap1_iface.lpVtbl = &d2d_bitmap_vtbl;
     bitmap->refcount = 1;
     ID2D1Factory_AddRef(bitmap->factory = context->factory);
-    ID3D10Resource_AddRef(bitmap->resource = resource);
+    ID3D11Resource_AddRef(bitmap->resource = resource);
     bitmap->pixel_size = size;
     bitmap->format = desc->pixelFormat;
     bitmap->dpi_x = desc->dpiX;
@@ -286,21 +380,21 @@ static void d2d_bitmap_init(struct d2d_bitmap *bitmap, struct d2d_device_context
     bitmap->options = desc->bitmapOptions;
 
     if (d2d_device_context_is_dxgi_target(context))
-        ID3D10Resource_QueryInterface(resource, &IID_IDXGISurface, (void **)&bitmap->surface);
+        ID3D11Resource_QueryInterface(resource, &IID_IDXGISurface, (void **)&bitmap->surface);
 
-    ID3D10Resource_GetDevice(resource, &d3d_device);
+    ID3D11Resource_GetDevice(resource, &d3d_device);
     if (bitmap->options & D2D1_BITMAP_OPTIONS_TARGET)
     {
-        if (FAILED(hr = ID3D10Device_CreateRenderTargetView(d3d_device, resource, NULL, &bitmap->rtv)))
-            WARN("Failed to create RTV, hr %#x.\n", hr);
+        if (FAILED(hr = ID3D11Device_CreateRenderTargetView(d3d_device, resource, NULL, &bitmap->rtv)))
+            WARN("Failed to create RTV, hr %#lx.\n", hr);
     }
 
     if (!(bitmap->options & D2D1_BITMAP_OPTIONS_CANNOT_DRAW))
     {
-        if (FAILED(hr = ID3D10Device_CreateShaderResourceView(d3d_device, resource, NULL, &bitmap->srv)))
-            WARN("Failed to create SRV, hr %#x.\n", hr);
+        if (FAILED(hr = ID3D11Device_CreateShaderResourceView(d3d_device, resource, NULL, &bitmap->srv)))
+            WARN("Failed to create SRV, hr %#lx.\n", hr);
     }
-    ID3D10Device_Release(d3d_device);
+    ID3D11Device_Release(d3d_device);
 
     if (bitmap->dpi_x == 0.0f && bitmap->dpi_y == 0.0f)
     {
@@ -309,13 +403,30 @@ static void d2d_bitmap_init(struct d2d_bitmap *bitmap, struct d2d_device_context
     }
 }
 
+static BOOL check_bitmap_options(unsigned int options)
+{
+    switch (options)
+    {
+        case D2D1_BITMAP_OPTIONS_NONE:
+        case D2D1_BITMAP_OPTIONS_TARGET:
+        case D2D1_BITMAP_OPTIONS_TARGET | D2D1_BITMAP_OPTIONS_CANNOT_DRAW:
+        case D2D1_BITMAP_OPTIONS_TARGET | D2D1_BITMAP_OPTIONS_CANNOT_DRAW | D2D1_BITMAP_OPTIONS_GDI_COMPATIBLE:
+        case D2D1_BITMAP_OPTIONS_TARGET | D2D1_BITMAP_OPTIONS_GDI_COMPATIBLE:
+        case D2D1_BITMAP_OPTIONS_CANNOT_DRAW | D2D1_BITMAP_OPTIONS_CPU_READ:
+            return TRUE;
+        default:
+            WARN("Invalid bitmap options %#x.\n", options);
+            return FALSE;
+    }
+}
+
 HRESULT d2d_bitmap_create(struct d2d_device_context *context, D2D1_SIZE_U size, const void *src_data,
         UINT32 pitch, const D2D1_BITMAP_PROPERTIES1 *desc, struct d2d_bitmap **bitmap)
 {
-    D3D10_SUBRESOURCE_DATA resource_data;
+    D3D11_SUBRESOURCE_DATA resource_data;
     D2D1_BITMAP_PROPERTIES1 bitmap_desc;
-    D3D10_TEXTURE2D_DESC texture_desc;
-    ID3D10Texture2D *texture;
+    D3D11_TEXTURE2D_DESC texture_desc;
+    ID3D11Texture2D *texture;
     HRESULT hr;
 
     if (!format_supported(&desc->pixelFormat))
@@ -337,6 +448,9 @@ HRESULT d2d_bitmap_create(struct d2d_device_context *context, D2D1_SIZE_U size,
         return E_INVALIDARG;
     }
 
+    if (!check_bitmap_options(desc->bitmapOptions))
+        return E_INVALIDARG;
+
     texture_desc.Width = size.width;
     texture_desc.Height = size.height;
     if (!texture_desc.Width || !texture_desc.Height)
@@ -346,37 +460,65 @@ HRESULT d2d_bitmap_create(struct d2d_device_context *context, D2D1_SIZE_U size,
     texture_desc.Format = desc->pixelFormat.format;
     texture_desc.SampleDesc.Count = 1;
     texture_desc.SampleDesc.Quality = 0;
-    texture_desc.Usage = D3D10_USAGE_DEFAULT;
+    texture_desc.Usage = D3D11_USAGE_DEFAULT;
+    if (desc->bitmapOptions & D2D1_BITMAP_OPTIONS_CPU_READ)
+        texture_desc.Usage = D3D11_USAGE_STAGING;
     texture_desc.BindFlags = 0;
     if (desc->bitmapOptions & D2D1_BITMAP_OPTIONS_TARGET)
-        texture_desc.BindFlags |= D3D10_BIND_RENDER_TARGET;
+        texture_desc.BindFlags |= D3D11_BIND_RENDER_TARGET;
     if (!(desc->bitmapOptions & D2D1_BITMAP_OPTIONS_CANNOT_DRAW))
-        texture_desc.BindFlags |= D3D10_BIND_SHADER_RESOURCE;
+        texture_desc.BindFlags |= D3D11_BIND_SHADER_RESOURCE;
     texture_desc.CPUAccessFlags = 0;
+    if (desc->bitmapOptions & D2D1_BITMAP_OPTIONS_CPU_READ)
+        texture_desc.CPUAccessFlags |= D3D11_CPU_ACCESS_READ;
     texture_desc.MiscFlags = 0;
     if (desc->bitmapOptions & D2D1_BITMAP_OPTIONS_GDI_COMPATIBLE)
-        texture_desc.MiscFlags |= D3D10_RESOURCE_MISC_GDI_COMPATIBLE;
+        texture_desc.MiscFlags |= D3D11_RESOURCE_MISC_GDI_COMPATIBLE;
 
     resource_data.pSysMem = src_data;
     resource_data.SysMemPitch = pitch;
 
-    if (FAILED(hr = ID3D10Device_CreateTexture2D(context->d3d_device, &texture_desc,
+    if (FAILED(hr = ID3D11Device1_CreateTexture2D(context->d3d_device, &texture_desc,
             src_data ? &resource_data : NULL, &texture)))
     {
-        ERR("Failed to create texture, hr %#x.\n", hr);
+        ERR("Failed to create texture, hr %#lx.\n", hr);
         return hr;
     }
 
-    if ((*bitmap = heap_alloc_zero(sizeof(**bitmap))))
+    if ((*bitmap = calloc(1, sizeof(**bitmap))))
     {
-        d2d_bitmap_init(*bitmap, context, (ID3D10Resource *)texture, size, desc);
+        d2d_bitmap_init(*bitmap, context, (ID3D11Resource *)texture, size, desc);
         TRACE("Created bitmap %p.\n", *bitmap);
     }
-    ID3D10Texture2D_Release(texture);
+    ID3D11Texture2D_Release(texture);
 
     return *bitmap ? S_OK : E_OUTOFMEMORY;
 }
 
+unsigned int d2d_get_bitmap_options_for_surface(IDXGISurface *surface)
+{
+    D3D11_TEXTURE2D_DESC desc;
+    unsigned int options = 0;
+    ID3D11Texture2D *texture;
+
+    if (FAILED(IDXGISurface_QueryInterface(surface, &IID_ID3D11Texture2D, (void **)&texture)))
+        return 0;
+
+    ID3D11Texture2D_GetDesc(texture, &desc);
+    ID3D11Texture2D_Release(texture);
+
+    if (desc.BindFlags & D3D11_BIND_RENDER_TARGET)
+        options |= D2D1_BITMAP_OPTIONS_TARGET;
+    if (!(desc.BindFlags & D3D11_BIND_SHADER_RESOURCE))
+        options |= D2D1_BITMAP_OPTIONS_CANNOT_DRAW;
+    if (desc.MiscFlags & D3D11_RESOURCE_MISC_GDI_COMPATIBLE)
+        options |= D2D1_BITMAP_OPTIONS_GDI_COMPATIBLE;
+    if (desc.Usage == D3D11_USAGE_STAGING && desc.CPUAccessFlags & D3D11_CPU_ACCESS_READ)
+        options |= D2D1_BITMAP_OPTIONS_CPU_READ;
+
+    return options;
+}
+
 HRESULT d2d_bitmap_create_shared(struct d2d_device_context *context, REFIID iid, void *data,
         const D2D1_BITMAP_PROPERTIES1 *desc, struct d2d_bitmap **bitmap)
 {
@@ -385,7 +527,7 @@ HRESULT d2d_bitmap_create_shared(struct d2d_device_context *context, REFIID iid,
     if (IsEqualGUID(iid, &IID_ID2D1Bitmap))
     {
         struct d2d_bitmap *src_impl = unsafe_impl_from_ID2D1Bitmap(data);
-        ID3D10Device *device;
+        ID3D11Device *device;
         HRESULT hr = S_OK;
 
         if (src_impl->factory != context->factory)
@@ -394,23 +536,31 @@ HRESULT d2d_bitmap_create_shared(struct d2d_device_context *context, REFIID iid,
             goto failed;
         }
 
-        ID3D10Resource_GetDevice(src_impl->resource, &device);
-        ID3D10Device_Release(device);
-        if (device != context->d3d_device)
+        ID3D11Resource_GetDevice(src_impl->resource, &device);
+        ID3D11Device_Release(device);
+        if (device != (ID3D11Device *)context->d3d_device)
         {
             hr = D2DERR_UNSUPPORTED_OPERATION;
             goto failed;
         }
 
-        if (!desc)
+        if (desc)
+        {
+            d = *desc;
+            if (d.pixelFormat.format == DXGI_FORMAT_UNKNOWN)
+                d.pixelFormat.format = src_impl->format.format;
+            if (d.pixelFormat.alphaMode == D2D1_ALPHA_MODE_UNKNOWN)
+                d.pixelFormat.alphaMode = src_impl->format.alphaMode;
+        }
+        else
         {
             d.pixelFormat = src_impl->format;
             d.dpiX = src_impl->dpi_x;
             d.dpiY = src_impl->dpi_y;
             d.bitmapOptions = src_impl->options;
             d.colorContext = NULL;
-            desc = &d;
         }
+        desc = &d;
 
         if (!format_supported(&desc->pixelFormat))
         {
@@ -420,7 +570,7 @@ HRESULT d2d_bitmap_create_shared(struct d2d_device_context *context, REFIID iid,
             goto failed;
         }
 
-        if (!(*bitmap = heap_alloc_zero(sizeof(**bitmap))))
+        if (!(*bitmap = calloc(1, sizeof(**bitmap))))
         {
             hr = E_OUTOFMEMORY;
             goto failed;
@@ -437,36 +587,36 @@ HRESULT d2d_bitmap_create_shared(struct d2d_device_context *context, REFIID iid,
     {
         DXGI_SURFACE_DESC surface_desc;
         IDXGISurface *surface = data;
-        ID3D10Resource *resource;
+        ID3D11Resource *resource;
         D2D1_SIZE_U pixel_size;
-        ID3D10Device *device;
+        ID3D11Device *device;
         HRESULT hr;
 
-        if (FAILED(IDXGISurface_QueryInterface(surface, &IID_ID3D10Resource, (void **)&resource)))
+        if (FAILED(IDXGISurface_QueryInterface(surface, &IID_ID3D11Resource, (void **)&resource)))
         {
             WARN("Failed to get d3d resource from dxgi surface.\n");
             return E_FAIL;
         }
 
-        ID3D10Resource_GetDevice(resource, &device);
-        ID3D10Device_Release(device);
-        if (device != context->d3d_device)
+        ID3D11Resource_GetDevice(resource, &device);
+        ID3D11Device_Release(device);
+        if (device != (ID3D11Device *)context->d3d_device)
         {
-            ID3D10Resource_Release(resource);
+            ID3D11Resource_Release(resource);
             return D2DERR_UNSUPPORTED_OPERATION;
         }
 
-        if (!(*bitmap = heap_alloc_zero(sizeof(**bitmap))))
+        if (!(*bitmap = calloc(1, sizeof(**bitmap))))
         {
-            ID3D10Resource_Release(resource);
+            ID3D11Resource_Release(resource);
             return E_OUTOFMEMORY;
         }
 
 
         if (FAILED(hr = IDXGISurface_GetDesc(surface, &surface_desc)))
         {
-            WARN("Failed to get surface desc, hr %#x.\n", hr);
-            ID3D10Resource_Release(resource);
+            WARN("Failed to get surface desc, hr %#lx.\n", hr);
+            ID3D11Resource_Release(resource);
             return hr;
         }
 
@@ -474,6 +624,7 @@ HRESULT d2d_bitmap_create_shared(struct d2d_device_context *context, REFIID iid,
         {
             memset(&d, 0, sizeof(d));
             d.pixelFormat.format = surface_desc.Format;
+            d.bitmapOptions = d2d_get_bitmap_options_for_surface(surface);
         }
         else
         {
@@ -494,7 +645,7 @@ HRESULT d2d_bitmap_create_shared(struct d2d_device_context *context, REFIID iid,
         pixel_size.height = surface_desc.Height;
 
         d2d_bitmap_init(*bitmap, context, resource, pixel_size, &d);
-        ID3D10Resource_Release(resource);
+        ID3D11Resource_Release(resource);
         TRACE("Created bitmap %p.\n", *bitmap);
 
         return S_OK;
@@ -533,7 +684,7 @@ HRESULT d2d_bitmap_create_from_wic_bitmap(struct d2d_device_context *context, IW
 
     if (FAILED(hr = IWICBitmapSource_GetSize(bitmap_source, &size.width, &size.height)))
     {
-        WARN("Failed to get bitmap size, hr %#x.\n", hr);
+        WARN("Failed to get bitmap size, hr %#lx.\n", hr);
         return hr;
     }
 
@@ -553,7 +704,7 @@ HRESULT d2d_bitmap_create_from_wic_bitmap(struct d2d_device_context *context, IW
 
     if (FAILED(hr = IWICBitmapSource_GetPixelFormat(bitmap_source, &wic_format)))
     {
-        WARN("Failed to get bitmap format, hr %#x.\n", hr);
+        WARN("Failed to get bitmap format, hr %#lx.\n", hr);
         return hr;
     }
 
@@ -592,7 +743,7 @@ HRESULT d2d_bitmap_create_from_wic_bitmap(struct d2d_device_context *context, IW
     pitch = ((bpp * size.width) + 15) & ~15;
     if (pitch / bpp < size.width)
         return E_OUTOFMEMORY;
-    if (!(data = heap_calloc(size.height, pitch)))
+    if (!(data = calloc(size.height, pitch)))
         return E_OUTOFMEMORY;
     data_size = size.height * pitch;
 
@@ -602,14 +753,14 @@ HRESULT d2d_bitmap_create_from_wic_bitmap(struct d2d_device_context *context, IW
     rect.Height = size.height;
     if (FAILED(hr = IWICBitmapSource_CopyPixels(bitmap_source, &rect, pitch, data_size, data)))
     {
-        WARN("Failed to copy bitmap pixels, hr %#x.\n", hr);
-        heap_free(data);
+        WARN("Failed to copy bitmap pixels, hr %#lx.\n", hr);
+        free(data);
         return hr;
     }
 
     hr = d2d_bitmap_create(context, size, data, pitch, &bitmap_desc, bitmap);
 
-    heap_free(data);
+    free(data);
 
     return hr;
 }
