@@ -20,7 +20,6 @@
 #define __WINE_D3D11_PRIVATE_H
 
 #include "wine/debug.h"
-#include "wine/heap.h"
 
 #include <assert.h>
 
@@ -72,6 +71,8 @@ DWORD wined3d_map_flags_from_d3d11_map_type(D3D11_MAP map_type) DECLSPEC_HIDDEN;
 DWORD wined3d_map_flags_from_d3d10_map_type(D3D10_MAP map_type) DECLSPEC_HIDDEN;
 DWORD wined3d_clear_flags_from_d3d11_clear_flags(UINT clear_flags) DECLSPEC_HIDDEN;
 unsigned int wined3d_access_from_d3d11(D3D11_USAGE usage, UINT cpu_access) DECLSPEC_HIDDEN;
+HRESULT d3d_device_create_dxgi_resource(IUnknown *device, struct wined3d_resource *wined3d_resource,
+        IUnknown *outer, BOOL needs_surface, IUnknown **dxgi_resource) DECLSPEC_HIDDEN;
 
 enum D3D11_USAGE d3d11_usage_from_d3d10_usage(enum D3D10_USAGE usage) DECLSPEC_HIDDEN;
 enum D3D10_USAGE d3d10_usage_from_d3d11_usage(enum D3D11_USAGE usage) DECLSPEC_HIDDEN;
@@ -129,8 +130,7 @@ struct d3d_texture1d
     ID3D10Texture1D ID3D10Texture1D_iface;
     LONG refcount;
 
-    struct wined3d_private_store private_store;
-    IUnknown *dxgi_surface;
+    IUnknown *dxgi_resource;
     struct wined3d_texture *wined3d_texture;
     D3D11_TEXTURE1D_DESC desc;
     ID3D11Device2 *device;
@@ -148,8 +148,7 @@ struct d3d_texture2d
     ID3D10Texture2D ID3D10Texture2D_iface;
     LONG refcount;
 
-    struct wined3d_private_store private_store;
-    IUnknown *dxgi_surface;
+    IUnknown *dxgi_resource;
     struct wined3d_texture *wined3d_texture;
     D3D11_TEXTURE2D_DESC desc;
     ID3D11Device2 *device;
@@ -172,7 +171,7 @@ struct d3d_texture3d
     ID3D10Texture3D ID3D10Texture3D_iface;
     LONG refcount;
 
-    struct wined3d_private_store private_store;
+    IUnknown *dxgi_resource;
     struct wined3d_texture *wined3d_texture;
     D3D11_TEXTURE3D_DESC desc;
     ID3D11Device2 *device;
@@ -190,7 +189,7 @@ struct d3d_buffer
     ID3D10Buffer ID3D10Buffer_iface;
     LONG refcount;
 
-    struct wined3d_private_store private_store;
+    IUnknown *dxgi_resource;
     struct wined3d_buffer *wined3d_buffer;
     D3D11_BUFFER_DESC desc;
     ID3D11Device2 *device;
@@ -408,26 +407,26 @@ struct d3d11_class_linkage
 HRESULT d3d11_class_linkage_create(struct d3d_device *device,
         struct d3d11_class_linkage **class_linkage) DECLSPEC_HIDDEN;
 
-/* ID3D11BlendState, ID3D10BlendState1 */
+/* ID3D11BlendState1, ID3D10BlendState1 */
 struct d3d_blend_state
 {
-    ID3D11BlendState ID3D11BlendState_iface;
+    ID3D11BlendState1 ID3D11BlendState1_iface;
     ID3D10BlendState1 ID3D10BlendState1_iface;
     LONG refcount;
 
     struct wined3d_private_store private_store;
     struct wined3d_blend_state *wined3d_state;
-    D3D11_BLEND_DESC desc;
+    D3D11_BLEND_DESC1 desc;
     struct wine_rb_entry entry;
     ID3D11Device2 *device;
 };
 
-static inline struct d3d_blend_state *impl_from_ID3D11BlendState(ID3D11BlendState *iface)
+static inline struct d3d_blend_state *impl_from_ID3D11BlendState1(ID3D11BlendState1 *iface)
 {
-    return CONTAINING_RECORD(iface, struct d3d_blend_state, ID3D11BlendState_iface);
+    return CONTAINING_RECORD(iface, struct d3d_blend_state, ID3D11BlendState1_iface);
 }
 
-HRESULT d3d_blend_state_create(struct d3d_device *device, const D3D11_BLEND_DESC *desc,
+HRESULT d3d_blend_state_create(struct d3d_device *device, const D3D11_BLEND_DESC1 *desc,
         struct d3d_blend_state **state) DECLSPEC_HIDDEN;
 struct d3d_blend_state *unsafe_impl_from_ID3D11BlendState(ID3D11BlendState *iface) DECLSPEC_HIDDEN;
 struct d3d_blend_state *unsafe_impl_from_ID3D10BlendState(ID3D10BlendState *iface) DECLSPEC_HIDDEN;
@@ -461,18 +460,18 @@ struct d3d_depthstencil_state *unsafe_impl_from_ID3D10DepthStencilState(
 /* ID3D11RasterizerState, ID3D10RasterizerState */
 struct d3d_rasterizer_state
 {
-    ID3D11RasterizerState ID3D11RasterizerState_iface;
+    ID3D11RasterizerState1 ID3D11RasterizerState1_iface;
     ID3D10RasterizerState ID3D10RasterizerState_iface;
     LONG refcount;
 
     struct wined3d_private_store private_store;
     struct wined3d_rasterizer_state *wined3d_state;
-    D3D11_RASTERIZER_DESC desc;
+    D3D11_RASTERIZER_DESC1 desc;
     struct wine_rb_entry entry;
     ID3D11Device2 *device;
 };
 
-HRESULT d3d_rasterizer_state_create(struct d3d_device *device, const D3D11_RASTERIZER_DESC *desc,
+HRESULT d3d_rasterizer_state_create(struct d3d_device *device, const D3D11_RASTERIZER_DESC1 *desc,
         struct d3d_rasterizer_state **state) DECLSPEC_HIDDEN;
 struct d3d_rasterizer_state *unsafe_impl_from_ID3D11RasterizerState(ID3D11RasterizerState *iface) DECLSPEC_HIDDEN;
 struct d3d_rasterizer_state *unsafe_impl_from_ID3D10RasterizerState(ID3D10RasterizerState *iface) DECLSPEC_HIDDEN;
@@ -516,25 +515,42 @@ struct d3d_query *unsafe_impl_from_ID3D11Query(ID3D11Query *iface) DECLSPEC_HIDD
 struct d3d_query *unsafe_impl_from_ID3D10Query(ID3D10Query *iface) DECLSPEC_HIDDEN;
 struct d3d_query *unsafe_impl_from_ID3D11Asynchronous(ID3D11Asynchronous *iface) DECLSPEC_HIDDEN;
 
+struct d3d_device_context_state_entry
+{
+    struct d3d_device *device;
+    struct wined3d_state *wined3d_state;
+};
+
 /* ID3DDeviceContextState */
 struct d3d_device_context_state
 {
     ID3DDeviceContextState ID3DDeviceContextState_iface;
-    LONG refcount;
+    LONG refcount, private_refcount;
 
     struct wined3d_private_store private_store;
-
+    D3D_FEATURE_LEVEL feature_level;
     GUID emulated_interface;
+
+    struct d3d_device_context_state_entry *entries;
+    SIZE_T entries_size;
+    SIZE_T entry_count;
+
+    struct wined3d_device *wined3d_device;
     ID3D11Device2 *device;
 };
 
-/* ID3D11DeviceContext - immediate context */
-struct d3d11_immediate_context
+/* ID3D11DeviceContext */
+struct d3d11_device_context
 {
     ID3D11DeviceContext1 ID3D11DeviceContext1_iface;
     ID3D11Multithread ID3D11Multithread_iface;
+    ID3DUserDefinedAnnotation ID3DUserDefinedAnnotation_iface;
     LONG refcount;
 
+    D3D11_DEVICE_CONTEXT_TYPE type;
+    struct wined3d_device_context *wined3d_context;
+    struct d3d_device *device;
+
     struct wined3d_private_store private_store;
 };
 
@@ -549,10 +565,10 @@ struct d3d_device
     IUnknown *outer_unk;
     LONG refcount;
 
-    D3D_FEATURE_LEVEL feature_level;
     BOOL d3d11_only;
 
-    struct d3d11_immediate_context immediate_context;
+    struct d3d_device_context_state *state;
+    struct d3d11_device_context immediate_context;
 
     struct wined3d_device_parent device_parent;
     struct wined3d_device *wined3d_device;
@@ -562,7 +578,19 @@ struct d3d_device
     struct wine_rb_tree rasterizer_states;
     struct wine_rb_tree sampler_states;
 
-    UINT stencil_ref;
+    struct d3d_device_context_state **context_states;
+    SIZE_T context_states_size;
+    SIZE_T context_state_count;
+};
+
+struct d3d11_command_list
+{
+    ID3D11CommandList ID3D11CommandList_iface;
+    LONG refcount;
+
+    ID3D11Device2 *device;
+    struct wined3d_command_list *wined3d_list;
+    struct wined3d_private_store private_store;
 };
 
 static inline struct d3d_device *impl_from_ID3D11Device(ID3D11Device *iface)
