@@ -44,7 +44,7 @@ WINE_DEFAULT_DEBUG_CHANNEL(dbghelp);
 PIMAGE_DEBUG_INFORMATION WINAPI MapDebugInformation(HANDLE FileHandle, PCSTR FileName,
                                                     PCSTR SymbolPath, ULONG ImageBase)
 {
-    FIXME("(%p, %s, %s, 0x%08x): stub\n", FileHandle, FileName, SymbolPath, ImageBase);
+    FIXME("(%p, %s, %s, 0x%08lx): stub\n", FileHandle, FileName, SymbolPath, ImageBase);
     SetLastError(ERROR_CALL_NOT_IMPLEMENTED);
     return NULL;
 }
