@@ -186,10 +186,8 @@ struct module* module_new(struct process* pcs, const WCHAR* name,
     module->next = pcs->lmodules;
     pcs->lmodules = module;
 
-    TRACE("=> %s %s-%s %s\n",
-          get_module_type(type, virtual),
-	  wine_dbgstr_longlong(mod_addr), wine_dbgstr_longlong(mod_addr + size),
-          debugstr_w(name));
+    TRACE("=> %s %I64x-%I64x %s\n",
+          get_module_type(type, virtual), mod_addr, mod_addr + size, debugstr_w(name));
 
     pool_init(&module->pool, 65536);
 
@@ -489,7 +487,7 @@ static BOOL image_check_debug_link_crc(const WCHAR* file, struct image_file_map*
     crc = calc_crc32(handle);
     if (crc != link_crc)
     {
-        WARN("Bad CRC for file %s (got %08x while expecting %08x)\n",  debugstr_w(file), crc, link_crc);
+        WARN("Bad CRC for file %s (got %08lx while expecting %08lx)\n",  debugstr_w(file), crc, link_crc);
         CloseHandle(handle);
         return FALSE;
     }
@@ -645,6 +643,71 @@ static WCHAR* append_hex(WCHAR* dst, const BYTE* id, const BYTE* end)
     return dst;
 }
 
+/******************************************************************
+ *		image_locate_build_id_target
+ *
+ * Try to find the .so file containing the debug info out of the build-id note information
+ */
+static BOOL image_locate_build_id_target(struct image_file_map* fmap, const BYTE* id, unsigned idlen)
+{
+    struct image_file_map* fmap_link = NULL;
+    DWORD sz;
+    WCHAR* p;
+    WCHAR* z;
+
+    fmap_link = HeapAlloc(GetProcessHeap(), 0, sizeof(*fmap_link));
+    if (!fmap_link) return FALSE;
+
+    p = malloc(sizeof(L"/usr/lib/debug/.build-id/") +
+               (idlen * 2 + 1) * sizeof(WCHAR) + sizeof(L".debug"));
+    wcscpy(p, L"/usr/lib/debug/.build-id/");
+    z = p + wcslen(p);
+    if (idlen)
+    {
+        z = append_hex(z, id, id + 1);
+        if (idlen > 1)
+        {
+            *z++ = L'/';
+            z = append_hex(z, id + 1, id + idlen);
+        }
+    }
+    wcscpy(z, L".debug");
+    TRACE("checking %s\n", wine_dbgstr_w(p));
+
+    if (image_check_debug_link_gnu_id(p, fmap_link, id, idlen))
+    {
+        free(p);
+        fmap->alternate = fmap_link;
+        return TRUE;
+    }
+
+    sz = GetEnvironmentVariableW(L"WINEHOMEDIR", NULL, 0);
+    if (sz)
+    {
+        p = realloc(p, sz * sizeof(WCHAR) +
+                    sizeof(L"\\.cache\\debuginfod_client\\") +
+                    idlen * 2 * sizeof(WCHAR) + sizeof(L"\\debuginfo") + 500);
+        GetEnvironmentVariableW(L"WINEHOMEDIR", p, sz);
+        z = p + sz - 1;
+        wcscpy(z, L"\\.cache\\debuginfod_client\\");
+        z += wcslen(z);
+        z = append_hex(z, id, id + idlen);
+        wcscpy(z, L"\\debuginfo");
+        TRACE("checking %ls\n", p);
+        if (image_check_debug_link_gnu_id(p, fmap_link, id, idlen))
+        {
+            free(p);
+            fmap->alternate = fmap_link;
+            return TRUE;
+        }
+    }
+
+    TRACE("not found\n");
+    free(p);
+    HeapFree(GetProcessHeap(), 0, fmap_link);
+    return FALSE;
+}
+
 /******************************************************************
  *		image_load_debugaltlink
  *
@@ -676,9 +739,12 @@ struct image_file_map* image_load_debugaltlink(struct image_file_map* fmap, stru
         unsigned sect_len;
         const BYTE* id;
         /* The content of the section is:
-         * + a \0 terminated string
+         * + a \0 terminated string (filename)
          * + followed by the build-id
-         * We try loading the dwz_alternate, either as absolute path, or relative to the embedded build-id
+         * We try loading the dwz_alternate:
+         * - from the filename: either as absolute path, or relative to the embedded build-id
+         * - from the build-id
+         * In both cases, checking that found .so file matches the requested build-id
          */
         sect_len = image_get_map_size(&debugaltlink_sect);
         id = memchr(data, '\0', sect_len);
@@ -728,8 +794,13 @@ struct image_file_map* image_load_debugaltlink(struct image_file_map* fmap, stru
                 if (!ret)
                 {
                     HeapFree(GetProcessHeap(), 0, fmap_link);
-                    WARN("Couldn't find a match for .gnu_debugaltlink section %s for %s\n", data, debugstr_w(module->modulename));
-                    fmap_link = NULL;
+                    /* didn't work out with filename, try file lookup based on build-id */
+                    ret = image_locate_build_id_target(fmap, id, idlen);
+                    if (!ret)
+                    {
+                        WARN("Couldn't find a match for .gnu_debugaltlink section %s for %s\n", data, debugstr_w(module->modulename));
+                        fmap_link = NULL;
+                    }
                 }
             }
         }
@@ -739,49 +810,6 @@ struct image_file_map* image_load_debugaltlink(struct image_file_map* fmap, stru
     return fmap_link;
 }
 
-/******************************************************************
- *		image_locate_build_id_target
- *
- * Try to find the .so file containing the debug info out of the build-id note information
- */
-static BOOL image_locate_build_id_target(struct image_file_map* fmap, const BYTE* id, unsigned idlen)
-{
-    struct image_file_map* fmap_link = NULL;
-    WCHAR* p;
-    WCHAR* z;
-
-    fmap_link = HeapAlloc(GetProcessHeap(), 0, sizeof(*fmap_link));
-    if (!fmap_link) return FALSE;
-
-    p = malloc(sizeof(L"/usr/lib/debug/.build-id/") +
-               (idlen * 2 + 1) * sizeof(WCHAR) + sizeof(L".debug"));
-    wcscpy(p, L"/usr/lib/debug/.build-id/");
-    z = p + wcslen(p);
-    if (idlen)
-    {
-        z = append_hex(z, id, id + 1);
-        if (idlen > 1)
-        {
-            *z++ = L'/';
-            z = append_hex(z, id + 1, id + idlen);
-        }
-    }
-    memcpy(z, L".debug", sizeof(L".debug"));
-    TRACE("checking %s\n", wine_dbgstr_w(p));
-
-    if (image_check_debug_link_gnu_id(p, fmap_link, id, idlen))
-    {
-        free(p);
-        fmap->alternate = fmap_link;
-        return TRUE;
-    }
-
-    TRACE("not found\n");
-    free(p);
-    HeapFree(GetProcessHeap(), 0, fmap_link);
-    return FALSE;
-}
-
 /******************************************************************
  *		image_check_alternate
  *
@@ -858,9 +886,9 @@ DWORD64 WINAPI  SymLoadModuleEx(HANDLE hProcess, HANDLE hFile, PCSTR ImageName,
     unsigned    len;
     DWORD64     ret;
 
-    TRACE("(%p %p %s %s %s %08x %p %08x)\n",
+    TRACE("(%p %p %s %s %I64x %08lx %p %08lx)\n",
           hProcess, hFile, debugstr_a(ImageName), debugstr_a(ModuleName),
-          wine_dbgstr_longlong(BaseOfDll), DllSize, Data, Flags);
+          BaseOfDll, DllSize, Data, Flags);
 
     if (ImageName)
     {
@@ -895,9 +923,9 @@ DWORD64 WINAPI  SymLoadModuleExW(HANDLE hProcess, HANDLE hFile, PCWSTR wImageNam
     struct module*      module = NULL;
     struct module*      altmodule;
 
-    TRACE("(%p %p %s %s %s %08x %p %08x)\n",
+    TRACE("(%p %p %s %s %I64x %08lx %p %08lx)\n",
           hProcess, hFile, debugstr_w(wImageName), debugstr_w(wModuleName),
-          wine_dbgstr_longlong(BaseOfDll), SizeOfDll, Data, Flags);
+          BaseOfDll, SizeOfDll, Data, Flags);
 
     if (Data)
         FIXME("Unsupported load data parameter %p for %s\n",
@@ -906,7 +934,7 @@ DWORD64 WINAPI  SymLoadModuleExW(HANDLE hProcess, HANDLE hFile, PCWSTR wImageNam
     if (!(pcs = process_find_by_handle(hProcess))) return 0;
 
     if (Flags & ~(SLMFLAG_VIRTUAL))
-        FIXME("Unsupported Flags %08x for %s\n", Flags, debugstr_w(wImageName));
+        FIXME("Unsupported Flags %08lx for %s\n", Flags, debugstr_w(wImageName));
 
     pcs->loader->synchronize_module_list(pcs);
 
@@ -1009,6 +1037,23 @@ BOOL module_remove(struct process* pcs, struct module* module)
 
     TRACE("%s (%p)\n", debugstr_w(module->modulename), module);
 
+    /* remove local scope if symbol is from this module */
+    if (pcs->localscope_symt)
+    {
+        struct symt* locsym = pcs->localscope_symt;
+        if (symt_check_tag(locsym, SymTagInlineSite))
+            locsym = &symt_get_function_from_inlined((struct symt_function*)locsym)->symt;
+        if (symt_check_tag(locsym, SymTagFunction))
+        {
+            locsym = ((struct symt_function*)locsym)->container;
+            if (symt_check_tag(locsym, SymTagCompiland) &&
+                module == ((struct symt_compiland*)locsym)->container->module)
+            {
+                pcs->localscope_pc = 0;
+                pcs->localscope_symt = NULL;
+            }
+        }
+    }
     for (i = 0; i < DFI_LAST; i++)
     {
         if ((modfmt = module->format_info[i]) && modfmt->remove)
@@ -1058,13 +1103,6 @@ BOOL WINAPI SymUnloadModule64(HANDLE hProcess, DWORD64 BaseOfDll)
     if (!pcs) return FALSE;
     module = module_find_by_addr(pcs, BaseOfDll, DMT_UNKNOWN);
     if (!module) return FALSE;
-    /* remove local scope if defined inside this module */
-    if (pcs->localscope_pc >= module->module.BaseOfImage &&
-        pcs->localscope_pc < module->module.BaseOfImage + module->module.ImageSize)
-    {
-        pcs->localscope_pc = 0;
-        pcs->localscope_symt = NULL;
-    }
     module_remove(pcs, module);
     return TRUE;
 }
@@ -1342,7 +1380,7 @@ BOOL  WINAPI SymGetModuleInfo64(HANDLE hProcess, DWORD64 dwAddr,
     if (sizeof(mi64) < ModuleInfo->SizeOfStruct)
     {
         SetLastError(ERROR_MOD_NOT_FOUND); /* NOTE: native returns this error */
-        WARN("Wrong size %u\n", ModuleInfo->SizeOfStruct);
+        WARN("Wrong size %lu\n", ModuleInfo->SizeOfStruct);
         return FALSE;
     }
 
@@ -1392,7 +1430,7 @@ BOOL  WINAPI SymGetModuleInfoW64(HANDLE hProcess, DWORD64 dwAddr,
     struct module*      module;
     IMAGEHLP_MODULEW64  miw64;
 
-    TRACE("%p %s %p\n", hProcess, wine_dbgstr_longlong(dwAddr), ModuleInfo);
+    TRACE("%p %I64x %p\n", hProcess, dwAddr, ModuleInfo);
 
     if (!pcs) return FALSE;
     if (ModuleInfo->SizeOfStruct > sizeof(*ModuleInfo)) return FALSE;
