@@ -121,10 +121,9 @@ void viewport_deactivate(struct d3d_viewport *viewport)
 void viewport_alloc_active_light_index(struct d3d_light *light)
 {
     struct d3d_viewport *vp = light->active_viewport;
-    unsigned int i;
-    DWORD map;
+    unsigned int i, map;
 
-    TRACE("vp %p, light %p, index %u, active_lights_count %u.\n",
+    TRACE("vp %p, light %p, index %lu, active_lights_count %lu.\n",
             vp, light, light->active_light_index, vp->active_lights_count);
 
     if (light->active_light_index)
@@ -161,7 +160,7 @@ void viewport_free_active_light_index(struct d3d_light *light)
 {
     struct d3d_viewport *vp = light->active_viewport;
 
-    TRACE("vp %p, light %p, index %u, active_lights_count %u, map_lights %#x.\n",
+    TRACE("vp %p, light %p, index %lu, active_lights_count %lu, map_lights %#lx.\n",
             vp, light, light->active_light_index, vp->active_lights_count, vp->map_lights);
 
     if (!light->active_light_index)
@@ -182,9 +181,9 @@ void viewport_free_active_light_index(struct d3d_light *light)
  *****************************************************************************/
 static void _dump_D3DVIEWPORT(const D3DVIEWPORT *lpvp)
 {
-    TRACE("    - dwSize = %d   dwX = %d   dwY = %d\n",
+    TRACE("    - dwSize = %lu   dwX = %lu   dwY = %lu\n",
             lpvp->dwSize, lpvp->dwX, lpvp->dwY);
-    TRACE("    - dwWidth = %d   dwHeight = %d\n",
+    TRACE("    - dwWidth = %lu   dwHeight = %lu\n",
             lpvp->dwWidth, lpvp->dwHeight);
     TRACE("    - dvScaleX = %f   dvScaleY = %f\n",
             lpvp->dvScaleX, lpvp->dvScaleY);
@@ -196,9 +195,9 @@ static void _dump_D3DVIEWPORT(const D3DVIEWPORT *lpvp)
 
 static void _dump_D3DVIEWPORT2(const D3DVIEWPORT2 *lpvp)
 {
-    TRACE("    - dwSize = %d   dwX = %d   dwY = %d\n",
+    TRACE("    - dwSize = %lu   dwX = %lu   dwY = %lu\n",
             lpvp->dwSize, lpvp->dwX, lpvp->dwY);
-    TRACE("    - dwWidth = %d   dwHeight = %d\n",
+    TRACE("    - dwWidth = %lu   dwHeight = %lu\n",
             lpvp->dwWidth, lpvp->dwHeight);
     TRACE("    - dvClipX = %f   dvClipY = %f\n",
             lpvp->dvClipX, lpvp->dvClipY);
@@ -267,7 +266,7 @@ static ULONG WINAPI d3d_viewport_AddRef(IDirect3DViewport3 *iface)
     struct d3d_viewport *viewport = impl_from_IDirect3DViewport3(iface);
     ULONG ref = InterlockedIncrement(&viewport->ref);
 
-    TRACE("%p increasing refcount to %u.\n", viewport, ref);
+    TRACE("%p increasing refcount to %lu.\n", viewport, ref);
 
     return ref;
 }
@@ -286,7 +285,7 @@ static ULONG WINAPI d3d_viewport_Release(IDirect3DViewport3 *iface)
     struct d3d_viewport *viewport = impl_from_IDirect3DViewport3(iface);
     ULONG ref = InterlockedDecrement(&viewport->ref);
 
-    TRACE("%p decreasing refcount to %u.\n", viewport, ref);
+    TRACE("%p decreasing refcount to %lu.\n", viewport, ref);
 
     if (!ref)
         heap_free(viewport);
@@ -386,7 +385,7 @@ static HRESULT WINAPI d3d_viewport_SetViewport(IDirect3DViewport3 *iface, D3DVIE
 
     if (vp->dwSize != sizeof(*vp))
     {
-        WARN("Invalid D3DVIEWPORT size %u.\n", vp->dwSize);
+        WARN("Invalid D3DVIEWPORT size %lu.\n", vp->dwSize);
         return DDERR_INVALIDPARAMS;
     }
 
@@ -493,7 +492,7 @@ static HRESULT WINAPI d3d_viewport_TransformVertices(IDirect3DViewport3 *iface,
     struct d3d_device *device = viewport->active_device;
     BOOL activate = device->current_viewport != viewport;
 
-    TRACE("iface %p, vertex_count %u, data %p, flags %#x, offscreen %p.\n",
+    TRACE("iface %p, vertex_count %lu, data %p, flags %#lx, offscreen %p.\n",
             iface, dwVertexCount, data, dwFlags, offscreen);
 
     /* Tests on windows show that Windows crashes when this occurs,
@@ -614,7 +613,7 @@ static HRESULT WINAPI d3d_viewport_TransformVertices(IDirect3DViewport3 *iface,
 static HRESULT WINAPI d3d_viewport_LightElements(IDirect3DViewport3 *iface,
         DWORD element_count, D3DLIGHTDATA *data)
 {
-    TRACE("iface %p, element_count %u, data %p.\n", iface, element_count, data);
+    TRACE("iface %p, element_count %lu, data %p.\n", iface, element_count, data);
 
     return DDERR_UNSUPPORTED;
 }
@@ -624,13 +623,13 @@ static HRESULT WINAPI d3d_viewport_SetBackground(IDirect3DViewport3 *iface, D3DM
     struct d3d_viewport *viewport = impl_from_IDirect3DViewport3(iface);
     struct d3d_material *m;
 
-    TRACE("iface %p, material %#x.\n", iface, material);
+    TRACE("iface %p, material %#lx.\n", iface, material);
 
     wined3d_mutex_lock();
 
     if (!(m = ddraw_get_object(&viewport->ddraw->d3ddevice->handle_table, material - 1, DDRAW_HANDLE_MATERIAL)))
     {
-        WARN("Invalid material handle %#x.\n", material);
+        WARN("Invalid material handle %#lx.\n", material);
         wined3d_mutex_unlock();
         return DDERR_INVALIDPARAMS;
     }
@@ -742,11 +741,11 @@ static HRESULT WINAPI d3d_viewport_Clear(IDirect3DViewport3 *iface,
     IDirect3DViewport3 *current_viewport;
     IDirect3DDevice3 *d3d_device3;
 
-    TRACE("iface %p, rect_count %u, rects %p, flags %#x.\n", iface, rect_count, rects, flags);
+    TRACE("iface %p, rect_count %lu, rects %p, flags %#lx.\n", iface, rect_count, rects, flags);
 
     if (!rects || !rect_count)
     {
-        WARN("rect_count = %u, rects = %p, ignoring clear\n", rect_count, rects);
+        WARN("rect_count = %lu, rects = %p, ignoring clear\n", rect_count, rects);
         return D3D_OK;
     }
 
@@ -891,7 +890,7 @@ static HRESULT WINAPI d3d_viewport_NextLight(IDirect3DViewport3 *iface,
     struct list *entry;
     HRESULT hr;
 
-    TRACE("iface %p, light %p, next_light %p, flags %#x.\n",
+    TRACE("iface %p, light %p, next_light %p, flags %#lx.\n",
             iface, lpDirect3DLight, lplpDirect3DLight, flags);
 
     if (!lplpDirect3DLight)
@@ -922,7 +921,7 @@ static HRESULT WINAPI d3d_viewport_NextLight(IDirect3DViewport3 *iface,
 
         default:
             entry = NULL;
-            WARN("Invalid flags %#x.\n", flags);
+            WARN("Invalid flags %#lx.\n", flags);
             break;
     }
 
@@ -1015,7 +1014,7 @@ static HRESULT WINAPI d3d_viewport_SetViewport2(IDirect3DViewport3 *iface, D3DVI
 
     if (vp->dwSize != sizeof(*vp))
     {
-        WARN("Invalid D3DVIEWPORT2 size %u.\n", vp->dwSize);
+        WARN("Invalid D3DVIEWPORT2 size %lu.\n", vp->dwSize);
         return DDERR_INVALIDPARAMS;
     }
 
@@ -1136,12 +1135,12 @@ static HRESULT WINAPI d3d_viewport_Clear2(IDirect3DViewport3 *iface, DWORD rect_
     IDirect3DViewport3 *current_viewport;
     IDirect3DDevice3 *d3d_device3;
 
-    TRACE("iface %p, rect_count %u, rects %p, flags %#x, color 0x%08x, depth %.8e, stencil %u.\n",
+    TRACE("iface %p, rect_count %lu, rects %p, flags %#lx, color 0x%08lx, depth %.8e, stencil %lu.\n",
             iface, rect_count, rects, flags, color, depth, stencil);
 
     if (!rects || !rect_count)
     {
-        WARN("rect_count = %u, rects = %p, ignoring clear\n", rect_count, rects);
+        WARN("rect_count = %lu, rects = %p, ignoring clear\n", rect_count, rects);
         return D3D_OK;
     }
 
