@@ -42,10 +42,10 @@ LONG DMCOMPOS_refCount = 0;
 
 typedef struct {
         IClassFactory IClassFactory_iface;
-        HRESULT WINAPI (*fnCreateInstance)(REFIID riid, void **ret_iface);
+        HRESULT (*fnCreateInstance)(REFIID riid, void **ret_iface);
 } IClassFactoryImpl;
 
-static HRESULT WINAPI create_direct_music_template(REFIID riid, void **ret_iface)
+static HRESULT create_direct_music_template(REFIID riid, void **ret_iface)
 {
         FIXME("(%s, %p) stub\n", debugstr_dmguid(riid), ret_iface);
 
