@@ -35,6 +35,8 @@ typedef struct IDirectMusicSegment8Impl {
     struct list Tracks;
 } IDirectMusicSegment8Impl;
 
+IDirectMusicSegment8Impl *create_segment(void);
+
 static inline IDirectMusicSegment8Impl *impl_from_IDirectMusicSegment8(IDirectMusicSegment8 *iface)
 {
   return CONTAINING_RECORD(iface, IDirectMusicSegment8Impl, IDirectMusicSegment8_iface);
@@ -71,7 +73,7 @@ static ULONG WINAPI IDirectMusicSegment8Impl_AddRef(IDirectMusicSegment8 *iface)
     IDirectMusicSegment8Impl *This = impl_from_IDirectMusicSegment8(iface);
     LONG ref = InterlockedIncrement(&This->ref);
 
-    TRACE("(%p) ref=%d\n", This, ref);
+    TRACE("(%p) ref=%ld\n", This, ref);
 
     return ref;
 }
@@ -81,7 +83,7 @@ static ULONG WINAPI IDirectMusicSegment8Impl_Release(IDirectMusicSegment8 *iface
     IDirectMusicSegment8Impl *This = impl_from_IDirectMusicSegment8(iface);
     LONG ref = InterlockedDecrement(&This->ref);
 
-    TRACE("(%p) ref=%d\n", This, ref);
+    TRACE("(%p) ref=%ld\n", This, ref);
 
     if (!ref) {
         HeapFree(GetProcessHeap(), 0, This);
@@ -109,7 +111,7 @@ static HRESULT WINAPI IDirectMusicSegment8Impl_SetLength(IDirectMusicSegment8 *i
 {
   IDirectMusicSegment8Impl *This = impl_from_IDirectMusicSegment8(iface);
 
-  TRACE("(%p, %d)\n", This, mtLength);
+  TRACE("(%p, %ld)\n", This, mtLength);
   This->header.mtLength = mtLength;
   return S_OK;
 }
@@ -132,7 +134,7 @@ static HRESULT WINAPI IDirectMusicSegment8Impl_SetRepeats(IDirectMusicSegment8 *
 {
   IDirectMusicSegment8Impl *This = impl_from_IDirectMusicSegment8(iface);
 
-  TRACE("(%p, %d)\n", This, dwRepeats);
+  TRACE("(%p, %ld)\n", This, dwRepeats);
   This->header.dwRepeats = dwRepeats;
   return S_OK;
 }
@@ -155,7 +157,7 @@ static HRESULT WINAPI IDirectMusicSegment8Impl_SetDefaultResolution(IDirectMusic
 {
   IDirectMusicSegment8Impl *This = impl_from_IDirectMusicSegment8(iface);
 
-  TRACE("(%p, %d)\n", This, dwResolution);
+  TRACE("(%p, %ld)\n", This, dwResolution);
   This->header.dwResolution = dwResolution;
   return S_OK;
 }
@@ -170,7 +172,7 @@ static HRESULT WINAPI IDirectMusicSegment8Impl_GetTrack(IDirectMusicSegment8 *if
   IPersistStream* pCLSIDStream = NULL;
   HRESULT hr = S_OK;
 
-  TRACE("(%p, %s, %#x, %#x, %p)\n", This, debugstr_dmguid(rguidType), dwGroupBits, dwIndex, ppTrack);
+  TRACE("(%p, %s, %#lx, %#lx, %p)\n", This, debugstr_dmguid(rguidType), dwGroupBits, dwIndex, ppTrack);
 
   if (NULL == ppTrack) {
     return E_POINTER;
@@ -178,7 +180,7 @@ static HRESULT WINAPI IDirectMusicSegment8Impl_GetTrack(IDirectMusicSegment8 *if
 
   LIST_FOR_EACH (pEntry, &This->Tracks) {
     pIt = LIST_ENTRY(pEntry, DMUS_PRIVATE_SEGMENT_TRACK, entry);
-    TRACE(" - %p -> 0x%x,%p\n", pIt, pIt->dwGroupBits, pIt->pTrack);
+    TRACE(" - %p -> %#lx,%p\n", pIt, pIt->dwGroupBits, pIt->pTrack);
     if (0xFFFFFFFF != dwGroupBits && 0 == (pIt->dwGroupBits & dwGroupBits)) continue ;
     if (FALSE == IsEqualGUID(&GUID_NULL, rguidType)) {
       /**
@@ -224,7 +226,7 @@ static HRESULT WINAPI IDirectMusicSegment8Impl_GetTrackGroup(IDirectMusicSegment
 
   LIST_FOR_EACH (pEntry, &This->Tracks) {
     pIt = LIST_ENTRY(pEntry, DMUS_PRIVATE_SEGMENT_TRACK, entry);
-    TRACE(" - %p -> %#x, %p\n", pIt, pIt->dwGroupBits, pIt->pTrack);
+    TRACE(" - %p -> %#lx, %p\n", pIt, pIt->dwGroupBits, pIt->pTrack);
     if (NULL != pIt && pIt->pTrack == pTrack) {
       *pdwGroupBits = pIt->dwGroupBits;
       return S_OK;
@@ -243,7 +245,7 @@ static HRESULT WINAPI IDirectMusicSegment8Impl_InsertTrack(IDirectMusicSegment8
   LPDMUS_PRIVATE_SEGMENT_TRACK pIt = NULL;
   LPDMUS_PRIVATE_SEGMENT_TRACK pNewSegTrack = NULL;
 
-  TRACE("(%p, %p, %#x)\n", This, pTrack, group);
+  TRACE("(%p, %p, %#lx)\n", This, pTrack, group);
 
   if (!group)
     return E_INVALIDARG;
@@ -251,7 +253,7 @@ static HRESULT WINAPI IDirectMusicSegment8Impl_InsertTrack(IDirectMusicSegment8
   LIST_FOR_EACH (pEntry, &This->Tracks) {
     i++;
     pIt = LIST_ENTRY(pEntry, DMUS_PRIVATE_SEGMENT_TRACK, entry);
-    TRACE(" - #%u: %p -> %#x, %p\n", i, pIt, pIt->dwGroupBits, pIt->pTrack);
+    TRACE(" - #%lu: %p -> %#lx, %p\n", i, pIt, pIt->dwGroupBits, pIt->pTrack);
     if (NULL != pIt && pIt->pTrack == pTrack) {
       ERR("(%p, %p): track is already in list\n", This, pTrack);
       return E_FAIL;
@@ -303,7 +305,7 @@ static HRESULT WINAPI IDirectMusicSegment8Impl_InitPlay(IDirectMusicSegment8 *if
   IDirectMusicSegment8Impl *This = impl_from_IDirectMusicSegment8(iface);
   HRESULT hr;
 
-  FIXME("(%p, %p, %p, %d): semi-stub\n", This, ppSegState, pPerformance, dwFlags);
+  FIXME("(%p, %p, %p, %ld): semi-stub\n", This, ppSegState, pPerformance, dwFlags);
   if (NULL == ppSegState) {
     return E_POINTER;
   }
@@ -376,7 +378,7 @@ static HRESULT WINAPI IDirectMusicSegment8Impl_GetParam(IDirectMusicSegment8 *if
     unsigned int i, count;
     HRESULT hr = DMUS_E_TRACK_NOT_FOUND;
 
-    TRACE("(%p, %s, %#x, %u, %d, %p, %p)\n", This, debugstr_dmguid(type), group, index, time,
+    TRACE("(%p, %s, %#lx, %lu, %ld, %p, %p)\n", This, debugstr_dmguid(type), group, index, time,
             next, param);
 
     if (!type)
@@ -406,16 +408,54 @@ static HRESULT WINAPI IDirectMusicSegment8Impl_SetParam(IDirectMusicSegment8 *if
         REFGUID rguidType, DWORD dwGroupBits, DWORD dwIndex, MUSIC_TIME mtTime, void *pParam)
 {
   IDirectMusicSegment8Impl *This = impl_from_IDirectMusicSegment8(iface);
-  FIXME("(%p, %s, %#x, %d, %d, %p): stub\n", This, debugstr_dmguid(rguidType), dwGroupBits, dwIndex, mtTime, pParam);
+  FIXME("(%p, %s, %#lx, %ld, %ld, %p): stub\n", This, debugstr_dmguid(rguidType), dwGroupBits, dwIndex, mtTime, pParam);
   return S_OK;
 }
 
-static HRESULT WINAPI IDirectMusicSegment8Impl_Clone(IDirectMusicSegment8 *iface,
-        MUSIC_TIME mtStart, MUSIC_TIME mtEnd, IDirectMusicSegment **ppSegment)
+static HRESULT WINAPI IDirectMusicSegment8Impl_Clone(IDirectMusicSegment8 *iface, MUSIC_TIME start, MUSIC_TIME end,
+        IDirectMusicSegment **segment)
 {
-  IDirectMusicSegment8Impl *This = impl_from_IDirectMusicSegment8(iface);
-  FIXME("(%p, %d, %d, %p): stub\n", This, mtStart, mtEnd, ppSegment);
-  return S_OK;
+    IDirectMusicSegment8Impl *This = impl_from_IDirectMusicSegment8(iface);
+    IDirectMusicSegment8Impl *clone;
+    IDirectMusicTrack *track;
+    DMUS_PRIVATE_SEGMENT_TRACK *track_item, *cloned_item;
+    HRESULT hr;
+    BOOL track_clone_fail = FALSE;
+
+    TRACE("(%p, %ld, %ld, %p)\n", This, start, end, segment);
+
+    if (!segment)
+        return E_POINTER;
+
+    if (!(clone = create_segment())) {
+        *segment = NULL;
+        return E_OUTOFMEMORY;
+    }
+
+    clone->header = This->header;
+    clone->pGraph = This->pGraph;
+    if (clone->pGraph)
+        IDirectMusicGraph_AddRef(clone->pGraph);
+
+    LIST_FOR_EACH_ENTRY(track_item, &This->Tracks, DMUS_PRIVATE_SEGMENT_TRACK, entry) {
+        if (SUCCEEDED(hr = IDirectMusicTrack_Clone(track_item->pTrack, start, end, &track))) {
+            if ((cloned_item = HeapAlloc(GetProcessHeap(), 0, sizeof(*cloned_item)))) {
+                cloned_item->dwGroupBits = track_item->dwGroupBits;
+                cloned_item->flags = track_item->flags;
+                cloned_item->pTrack = track;
+                list_add_tail(&clone->Tracks, &cloned_item->entry);
+                continue;
+            } else {
+                IDirectMusicTrack_Release(track);
+            }
+        }
+        WARN("Failed to clone track %p: %#lx\n", track_item->pTrack, hr);
+        track_clone_fail = TRUE;
+    }
+
+    *segment = (IDirectMusicSegment *)&clone->IDirectMusicSegment8_iface;
+
+    return track_clone_fail ? S_FALSE : S_OK;
 }
 
 static HRESULT WINAPI IDirectMusicSegment8Impl_SetStartPoint(IDirectMusicSegment8 *iface,
@@ -423,7 +463,7 @@ static HRESULT WINAPI IDirectMusicSegment8Impl_SetStartPoint(IDirectMusicSegment
 {
   IDirectMusicSegment8Impl *This = impl_from_IDirectMusicSegment8(iface);
 
-  TRACE("(%p, %d)\n", This, mtStart);
+  TRACE("(%p, %ld)\n", This, mtStart);
   if (mtStart >= This->header.mtLength) {
     return DMUS_E_OUT_OF_RANGE;
   }
@@ -449,7 +489,7 @@ static HRESULT WINAPI IDirectMusicSegment8Impl_SetLoopPoints(IDirectMusicSegment
 {
     IDirectMusicSegment8Impl *This = impl_from_IDirectMusicSegment8(iface);
 
-    TRACE("(%p, %d, %d)\n", This, start, end);
+    TRACE("(%p, %ld, %ld)\n", This, start, end);
 
     if ((end || start) &&
             (start >= This->header.mtLength || end > This->header.mtLength || start > end))
@@ -479,7 +519,7 @@ static HRESULT WINAPI IDirectMusicSegment8Impl_SetPChannelsUsed(IDirectMusicSegm
         DWORD dwNumPChannels, DWORD *paPChannels)
 {
         IDirectMusicSegment8Impl *This = impl_from_IDirectMusicSegment8(iface);
-	FIXME("(%p, %d, %p): stub\n", This, dwNumPChannels, paPChannels);
+	FIXME("(%p, %ld, %p): stub\n", This, dwNumPChannels, paPChannels);
 	return S_OK;
 }
 
@@ -488,7 +528,7 @@ static HRESULT WINAPI IDirectMusicSegment8Impl_SetTrackConfig(IDirectMusicSegmen
         DWORD dwFlagsOff)
 {
         IDirectMusicSegment8Impl *This = impl_from_IDirectMusicSegment8(iface);
-	FIXME("(%p, %s, %#x, %d, %d, %d): stub\n", This, debugstr_dmguid(rguidTrackClassID), dwGroupBits, dwIndex, dwFlagsOn, dwFlagsOff);
+	FIXME("(%p, %s, %#lx, %ld, %ld, %ld): stub\n", This, debugstr_dmguid(rguidTrackClassID), dwGroupBits, dwIndex, dwFlagsOn, dwFlagsOff);
 	return S_OK;
 }
 
@@ -505,7 +545,7 @@ static HRESULT WINAPI IDirectMusicSegment8Impl_Compose(IDirectMusicSegment8 *ifa
         IDirectMusicSegment **ppComposedSegment)
 {
         IDirectMusicSegment8Impl *This = impl_from_IDirectMusicSegment8(iface);
-	FIXME("(%p, %d, %p, %p, %p): stub\n", This, mtTime, pFromSegment, pToSegment, ppComposedSegment);
+	FIXME("(%p, %ld, %p, %p, %p): stub\n", This, mtTime, pFromSegment, pToSegment, ppComposedSegment);
 	return S_OK;
 }
 
@@ -629,7 +669,7 @@ static HRESULT parse_track_form(IDirectMusicSegment8Impl *This, IStream *stream,
         return hr;
     TRACE("Found DMUS_IO_TRACK_HEADER\n");
     TRACE("\tclass: %s\n", debugstr_guid (&thdr.guidClassID));
-    TRACE("\tdwGroup: %#x\n", thdr.dwGroup);
+    TRACE("\tdwGroup: %#lx\n", thdr.dwGroup);
     TRACE("\tckid: %s\n", debugstr_fourcc (thdr.ckid));
     TRACE("\tfccType: %s\n", debugstr_fourcc (thdr.fccType));
 
@@ -649,7 +689,7 @@ static HRESULT parse_track_form(IDirectMusicSegment8Impl *This, IStream *stream,
         if (chunk.id == DMUS_FOURCC_TRACK_EXTRAS_CHUNK &&
                 SUCCEEDED(stream_chunk_get_data(stream, &chunk, &txhdr, sizeof(txhdr)))) {
             FIXME("DMUS_IO_TRACK_EXTRAS_HEADER chunk not fully handled\n");
-            TRACE("dwFlags: %#x, dwPriority: %u\n", txhdr.dwFlags, txhdr.dwPriority);
+            TRACE("dwFlags: %#lx, dwPriority: %lu\n", txhdr.dwFlags, txhdr.dwPriority);
         }
     }
     if (hr != S_OK)
@@ -713,16 +753,16 @@ static inline void dump_segment_header(DMUS_IO_SEGMENT_HEADER *h, DWORD size)
     else if (size == offsetof(DMUS_IO_SEGMENT_HEADER, rtLoopStart))
         dx = 8;
     TRACE("Found DirectX%d DMUS_IO_SEGMENT_HEADER\n", dx);
-    TRACE("\tdwRepeats: %u\n", h->dwRepeats);
-    TRACE("\tmtLength: %u\n", h->mtLength);
-    TRACE("\tmtPlayStart: %u\n", h->mtPlayStart);
-    TRACE("\tmtLoopStart: %u\n", h->mtLoopStart);
-    TRACE("\tmtLoopEnd: %u\n", h->mtLoopEnd);
-    TRACE("\tdwResolution: %u\n", h->dwResolution);
+    TRACE("\tdwRepeats: %lu\n", h->dwRepeats);
+    TRACE("\tmtLength: %lu\n", h->mtLength);
+    TRACE("\tmtPlayStart: %lu\n", h->mtPlayStart);
+    TRACE("\tmtLoopStart: %lu\n", h->mtLoopStart);
+    TRACE("\tmtLoopEnd: %lu\n", h->mtLoopEnd);
+    TRACE("\tdwResolution: %lu\n", h->dwResolution);
     if (dx >= 8) {
         TRACE("\trtLength: %s\n", wine_dbgstr_longlong(h->rtLength));
-        TRACE("\tdwFlags: %u\n", h->dwFlags);
-        TRACE("\tdwReserved: %u\n", h->dwReserved);
+        TRACE("\tdwFlags: %lu\n", h->dwFlags);
+        TRACE("\tdwReserved: %lu\n", h->dwReserved);
     }
     if (dx == 9) {
         TRACE("\trtLoopStart: %s\n", wine_dbgstr_longlong(h->rtLoopStart));
@@ -826,28 +866,38 @@ static const IPersistStreamVtbl persiststream_vtbl = {
     unimpl_IPersistStream_GetSizeMax
 };
 
-/* for ClassFactory */
-HRESULT WINAPI create_dmsegment(REFIID lpcGUID, void **ppobj)
+IDirectMusicSegment8Impl *create_segment(void)
 {
-  IDirectMusicSegment8Impl* obj;
-  HRESULT hr;
+    IDirectMusicSegment8Impl *obj;
 
-  obj = HeapAlloc(GetProcessHeap(), HEAP_ZERO_MEMORY, sizeof(IDirectMusicSegment8Impl));
-  if (NULL == obj) {
-    *ppobj = NULL;
-    return E_OUTOFMEMORY;
-  }
-  obj->IDirectMusicSegment8_iface.lpVtbl = &dmsegment8_vtbl;
-  obj->ref = 1;
-  dmobject_init(&obj->dmobj, &CLSID_DirectMusicSegment,
-          (IUnknown *)&obj->IDirectMusicSegment8_iface);
-  obj->dmobj.IDirectMusicObject_iface.lpVtbl = &dmobject_vtbl;
-  obj->dmobj.IPersistStream_iface.lpVtbl = &persiststream_vtbl;
-  list_init (&obj->Tracks);
+    if (!(obj = HeapAlloc(GetProcessHeap(), HEAP_ZERO_MEMORY, sizeof(*obj))))
+        return NULL;
 
-  DMIME_LockModule();
-  hr = IDirectMusicSegment8_QueryInterface(&obj->IDirectMusicSegment8_iface, lpcGUID, ppobj);
-  IDirectMusicSegment8_Release(&obj->IDirectMusicSegment8_iface);
+    obj->IDirectMusicSegment8_iface.lpVtbl = &dmsegment8_vtbl;
+    obj->ref = 1;
+    dmobject_init(&obj->dmobj, &CLSID_DirectMusicSegment, (IUnknown *)&obj->IDirectMusicSegment8_iface);
+    obj->dmobj.IDirectMusicObject_iface.lpVtbl = &dmobject_vtbl;
+    obj->dmobj.IPersistStream_iface.lpVtbl = &persiststream_vtbl;
+    list_init (&obj->Tracks);
 
-  return hr;
+    DMIME_LockModule();
+
+    return obj;
+}
+
+/* for ClassFactory */
+HRESULT create_dmsegment(REFIID guid, void **ret_iface)
+{
+    IDirectMusicSegment8Impl *obj;
+    HRESULT hr;
+
+    if (!(obj = create_segment())) {
+        *ret_iface = NULL;
+        return E_OUTOFMEMORY;
+    }
+
+    hr = IDirectMusicSegment8_QueryInterface(&obj->IDirectMusicSegment8_iface, guid, ret_iface);
+    IDirectMusicSegment8_Release(&obj->IDirectMusicSegment8_iface);
+
+    return hr;
 }
