@@ -59,7 +59,7 @@ static ULONG WINAPI IDirectSoundNotifyImpl_AddRef(IDirectSoundNotify *iface)
     IDirectSoundBufferImpl *This = impl_from_IDirectSoundNotify(iface);
     ULONG ref = InterlockedIncrement(&This->refn);
 
-    TRACE("(%p) ref %d\n", This, ref);
+    TRACE("(%p) ref %ld\n", This, ref);
 
     if(ref == 1)
         InterlockedIncrement(&This->numIfaces);
@@ -72,7 +72,7 @@ static ULONG WINAPI IDirectSoundNotifyImpl_Release(IDirectSoundNotify *iface)
     IDirectSoundBufferImpl *This = impl_from_IDirectSoundNotify(iface);
     ULONG ref = InterlockedDecrement(&This->refn);
 
-    TRACE("(%p) ref %d\n", This, ref);
+    TRACE("(%p) ref %ld\n", This, ref);
 
     if (!ref && !InterlockedDecrement(&This->numIfaces))
         secondarybuffer_destroy(This);
@@ -101,12 +101,33 @@ static int __cdecl notify_compar(const void *l, const void *r)
     return 1;
 }
 
+static void commit_next_chunk(IDirectSoundBufferImpl *dsb)
+{
+    void *dstbuff = dsb->committedbuff, *srcbuff = dsb->buffer->memory;
+    DWORD srcoff = dsb->sec_mixpos, srcsize = dsb->buflen, cpysize = dsb->writelead;
+
+    if(dsb->state != STATE_PLAYING)
+        return;
+
+    if(cpysize > srcsize - srcoff) {
+        DWORD overflow = cpysize - (srcsize - srcoff);
+        memcpy(dstbuff, (BYTE*)srcbuff + srcoff, srcsize - srcoff);
+        memcpy((BYTE*)dstbuff + (srcsize - srcoff), srcbuff, overflow);
+    }else{
+        memcpy(dstbuff, (BYTE*)srcbuff + srcoff, cpysize);
+    }
+
+    dsb->use_committed = TRUE;
+    dsb->committed_mixpos = 0;
+    TRACE("committing %lu bytes from offset %lu\n", dsb->writelead, dsb->sec_mixpos);
+}
+
 static HRESULT WINAPI IDirectSoundNotifyImpl_SetNotificationPositions(IDirectSoundNotify *iface,
         DWORD howmuch, const DSBPOSITIONNOTIFY *notify)
 {
         IDirectSoundBufferImpl *This = impl_from_IDirectSoundNotify(iface);
 
-	TRACE("(%p,0x%08x,%p)\n",This,howmuch,notify);
+	TRACE("(%p,0x%08lx,%p)\n",This,howmuch,notify);
 
         if (howmuch > 0 && notify == NULL) {
 	    WARN("invalid parameter: notify == NULL\n");
@@ -116,7 +137,7 @@ static HRESULT WINAPI IDirectSoundNotifyImpl_SetNotificationPositions(IDirectSou
 	if (TRACE_ON(dsound)) {
 	    unsigned int	i;
 	    for (i=0;i<howmuch;i++)
-		TRACE("notify at %d to %p\n",
+		TRACE("notify at %ld to %p\n",
 		    notify[i].dwOffset,notify[i].hEventNotify);
 	}
 
@@ -187,15 +208,15 @@ static HRESULT WINAPI IDirectSoundBufferImpl_SetVolume(IDirectSoundBuffer8 *ifac
 
 	HRESULT hres = DS_OK;
 
-	TRACE("(%p,%d)\n",This,vol);
+	TRACE("(%p,%ld)\n",This,vol);
 
 	if (!(This->dsbd.dwFlags & DSBCAPS_CTRLVOLUME)) {
-		WARN("control unavailable: This->dsbd.dwFlags = 0x%08x\n", This->dsbd.dwFlags);
+		WARN("control unavailable: This->dsbd.dwFlags = 0x%08lx\n", This->dsbd.dwFlags);
 		return DSERR_CONTROLUNAVAIL;
 	}
 
 	if ((vol > DSBVOLUME_MAX) || (vol < DSBVOLUME_MIN)) {
-		WARN("invalid parameter: vol = %d\n", vol);
+		WARN("invalid parameter: vol = %ld\n", vol);
 		return DSERR_INVALIDPARAM;
 	}
 
@@ -244,8 +265,9 @@ static HRESULT WINAPI IDirectSoundBufferImpl_SetFrequency(IDirectSoundBuffer8 *i
 {
         IDirectSoundBufferImpl *This = impl_from_IDirectSoundBuffer8(iface);
 	DWORD oldFreq;
+	void *newcommitted;
 
-	TRACE("(%p,%d)\n",This,freq);
+	TRACE("(%p,%ld)\n",This,freq);
 
         if (is_primary_buffer(This)) {
                 WARN("not available for primary buffers.\n");
@@ -261,7 +283,7 @@ static HRESULT WINAPI IDirectSoundBufferImpl_SetFrequency(IDirectSoundBuffer8 *i
 		freq = This->pwfx->nSamplesPerSec;
 
 	if ((freq < DSBFREQUENCY_MIN) || (freq > DSBFREQUENCY_MAX)) {
-		WARN("invalid parameter: freq = %d\n", freq);
+		WARN("invalid parameter: freq = %ld\n", freq);
 		return DSERR_INVALIDPARAM;
 	}
 
@@ -274,6 +296,13 @@ static HRESULT WINAPI IDirectSoundBufferImpl_SetFrequency(IDirectSoundBuffer8 *i
 		This->freqAdjustDen = This->device->pwfx->nSamplesPerSec;
 		This->nAvgBytesPerSec = freq * This->pwfx->nBlockAlign;
 		DSOUND_RecalcFormat(This);
+
+		newcommitted = HeapReAlloc(GetProcessHeap(), 0, This->committedbuff, This->writelead);
+		if(!newcommitted) {
+			ReleaseSRWLockExclusive(&This->lock);
+			return DSERR_OUTOFMEMORY;
+		}
+		This->committedbuff = newcommitted;
 	}
 
 	ReleaseSRWLockExclusive(&This->lock);
@@ -288,7 +317,7 @@ static HRESULT WINAPI IDirectSoundBufferImpl_Play(IDirectSoundBuffer8 *iface, DW
 	HRESULT hres = DS_OK;
 	int i;
 
-	TRACE("(%p,%08x,%08x,%08x)\n",This,reserved1,reserved2,flags);
+	TRACE("(%p,%08lx,%08lx,%08lx)\n",This,reserved1,reserved2,flags);
 
 	AcquireSRWLockExclusive(&This->lock);
 
@@ -319,6 +348,8 @@ static HRESULT WINAPI IDirectSoundBufferImpl_Stop(IDirectSoundBuffer8 *iface)
 	if (This->state == STATE_PLAYING || This->state == STATE_STARTING)
 	{
 		This->state = STATE_STOPPED;
+		This->use_committed = FALSE;
+		This->committed_mixpos = 0;
 		DSOUND_CheckEvent(This, 0, 0);
 	}
 
@@ -332,7 +363,7 @@ static ULONG WINAPI IDirectSoundBufferImpl_AddRef(IDirectSoundBuffer8 *iface)
     IDirectSoundBufferImpl *This = impl_from_IDirectSoundBuffer8(iface);
     ULONG ref = InterlockedIncrement(&This->ref);
 
-    TRACE("(%p) ref %d\n", This, ref);
+    TRACE("(%p) ref %ld\n", This, ref);
 
     if(ref == 1)
         InterlockedIncrement(&This->numIfaces);
@@ -349,7 +380,7 @@ static ULONG WINAPI IDirectSoundBufferImpl_Release(IDirectSoundBuffer8 *iface)
         ref = capped_refcount_dec(&This->ref);
         if(!ref)
             capped_refcount_dec(&This->numIfaces);
-        TRACE("(%p) ref %d\n", This, ref);
+        TRACE("(%p) ref %ld\n", This, ref);
         return ref;
     }
 
@@ -357,7 +388,7 @@ static ULONG WINAPI IDirectSoundBufferImpl_Release(IDirectSoundBuffer8 *iface)
     if (!ref && !InterlockedDecrement(&This->numIfaces))
             secondarybuffer_destroy(This);
 
-    TRACE("(%p) ref %d\n", This, ref);
+    TRACE("(%p) ref %ld\n", This, ref);
 
     return ref;
 }
@@ -376,7 +407,7 @@ static HRESULT WINAPI IDirectSoundBufferImpl_GetCurrentPosition(IDirectSoundBuff
 
 	/* sanity */
 	if (pos >= This->buflen){
-		FIXME("Bad play position. playpos: %d, buflen: %d\n", pos, This->buflen);
+		FIXME("Bad play position. playpos: %ld, buflen: %ld\n", pos, This->buflen);
 		pos %= This->buflen;
 	}
 
@@ -393,7 +424,7 @@ static HRESULT WINAPI IDirectSoundBufferImpl_GetCurrentPosition(IDirectSoundBuff
 
 	ReleaseSRWLockShared(&This->lock);
 
-	TRACE("playpos = %d, writepos = %d, buflen=%d (%p, time=%d)\n",
+	TRACE("playpos = %ld, writepos = %ld, buflen=%ld (%p, time=%ld)\n",
 		playpos?*playpos:-1, writepos?*writepos:-1, This->buflen, This, GetTickCount());
 
 	return DS_OK;
@@ -421,7 +452,7 @@ static HRESULT WINAPI IDirectSoundBufferImpl_GetStatus(IDirectSoundBuffer8 *ifac
 		*status |= DSBSTATUS_LOCSOFTWARE;
 	ReleaseSRWLockShared(&This->lock);
 
-	TRACE("status=%x\n", *status);
+	TRACE("status=%lx\n", *status);
 	return DS_OK;
 }
 
@@ -432,7 +463,7 @@ static HRESULT WINAPI IDirectSoundBufferImpl_GetFormat(IDirectSoundBuffer8 *ifac
     IDirectSoundBufferImpl *This = impl_from_IDirectSoundBuffer8(iface);
     DWORD size;
 
-    TRACE("(%p,%p,%d,%p)\n",This,lpwf,wfsize,wfwritten);
+    TRACE("(%p,%p,%ld,%p)\n",This,lpwf,wfsize,wfwritten);
 
     size = sizeof(WAVEFORMATEX) + This->pwfx->cbSize;
 
@@ -467,7 +498,7 @@ static HRESULT WINAPI IDirectSoundBufferImpl_Lock(IDirectSoundBuffer8 *iface, DW
         IDirectSoundBufferImpl *This = impl_from_IDirectSoundBuffer8(iface);
 	HRESULT hres = DS_OK;
 
-        TRACE("(%p,%d,%d,%p,%p,%p,%p,0x%08x) at %d\n", This, writecursor, writebytes, lplpaudioptr1,
+        TRACE("(%p,%ld,%ld,%p,%p,%p,%p,0x%08lx) at %ld\n", This, writecursor, writebytes, lplpaudioptr1,
                 audiobytes1, lplpaudioptr2, audiobytes2, flags, GetTickCount());
 
         if (!audiobytes1)
@@ -488,13 +519,13 @@ static HRESULT WINAPI IDirectSoundBufferImpl_Lock(IDirectSoundBuffer8 *iface, DW
 		writebytes = This->buflen;
 
 	if (writecursor >= This->buflen) {
-		WARN("Invalid parameter, writecursor: %u >= buflen: %u\n",
+		WARN("Invalid parameter, writecursor: %lu >= buflen: %lu\n",
 		     writecursor, This->buflen);
 		return DSERR_INVALIDPARAM;
         }
 
 	if (writebytes > This->buflen) {
-		WARN("Invalid parameter, writebytes: %u > buflen: %u\n",
+		WARN("Invalid parameter, writebytes: %lu > buflen: %lu\n",
 		     writebytes, This->buflen);
 		return DSERR_INVALIDPARAM;
         }
@@ -503,33 +534,39 @@ static HRESULT WINAPI IDirectSoundBufferImpl_Lock(IDirectSoundBuffer8 *iface, DW
 
 	if (writecursor+writebytes <= This->buflen) {
 		*(LPBYTE*)lplpaudioptr1 = This->buffer->memory+writecursor;
-		if (This->sec_mixpos >= writecursor && This->sec_mixpos < writecursor + writebytes && This->state == STATE_PLAYING)
+		if (This->sec_mixpos >= writecursor && This->sec_mixpos < writecursor + writebytes && This->state == STATE_PLAYING) {
 			WARN("Overwriting mixing position, case 1\n");
+			commit_next_chunk(This);
+		}
 		*audiobytes1 = writebytes;
 		if (lplpaudioptr2)
 			*(LPBYTE*)lplpaudioptr2 = NULL;
 		if (audiobytes2)
 			*audiobytes2 = 0;
-		TRACE("Locked %p(%i bytes) and %p(%i bytes) writecursor=%d\n",
+		TRACE("Locked %p(%li bytes) and %p(%li bytes) writecursor=%ld\n",
 		  *(LPBYTE*)lplpaudioptr1, *audiobytes1, lplpaudioptr2 ? *(LPBYTE*)lplpaudioptr2 : NULL, audiobytes2 ? *audiobytes2: 0, writecursor);
-		TRACE("->%d.0\n",writebytes);
+		TRACE("->%ld.0\n",writebytes);
 		This->buffer->lockedbytes += writebytes;
 	} else {
 		DWORD remainder = writebytes + writecursor - This->buflen;
 		*(LPBYTE*)lplpaudioptr1 = This->buffer->memory+writecursor;
 		*audiobytes1 = This->buflen-writecursor;
 		This->buffer->lockedbytes += *audiobytes1;
-		if (This->sec_mixpos >= writecursor && This->sec_mixpos < writecursor + writebytes && This->state == STATE_PLAYING)
+		if (This->sec_mixpos >= writecursor && This->sec_mixpos < writecursor + writebytes && This->state == STATE_PLAYING) {
 			WARN("Overwriting mixing position, case 2\n");
+			commit_next_chunk(This);
+		}
 		if (lplpaudioptr2)
 			*(LPBYTE*)lplpaudioptr2 = This->buffer->memory;
 		if (audiobytes2) {
 			*audiobytes2 = writebytes-(This->buflen-writecursor);
 			This->buffer->lockedbytes += *audiobytes2;
 		}
-		if (audiobytes2 && This->sec_mixpos < remainder && This->state == STATE_PLAYING)
+		if (audiobytes2 && This->sec_mixpos < remainder && This->state == STATE_PLAYING) {
 			WARN("Overwriting mixing position, case 3\n");
-		TRACE("Locked %p(%i bytes) and %p(%i bytes) writecursor=%d\n", *(LPBYTE*)lplpaudioptr1, *audiobytes1, lplpaudioptr2 ? *(LPBYTE*)lplpaudioptr2 : NULL, audiobytes2 ? *audiobytes2: 0, writecursor);
+			commit_next_chunk(This);
+		}
+		TRACE("Locked %p(%li bytes) and %p(%li bytes) writecursor=%ld\n", *(LPBYTE*)lplpaudioptr1, *audiobytes1, lplpaudioptr2 ? *(LPBYTE*)lplpaudioptr2 : NULL, audiobytes2 ? *audiobytes2: 0, writecursor);
 	}
 
 	ReleaseSRWLockShared(&This->lock);
@@ -543,7 +580,7 @@ static HRESULT WINAPI IDirectSoundBufferImpl_SetCurrentPosition(IDirectSoundBuff
         IDirectSoundBufferImpl *This = impl_from_IDirectSoundBuffer8(iface);
 	HRESULT hres = DS_OK;
 
-	TRACE("(%p,%d)\n",This,newpos);
+	TRACE("(%p,%ld)\n",This,newpos);
 
 	AcquireSRWLockExclusive(&This->lock);
 
@@ -552,6 +589,9 @@ static HRESULT WINAPI IDirectSoundBufferImpl_SetCurrentPosition(IDirectSoundBuff
 	newpos -= newpos%This->pwfx->nBlockAlign;
 	This->sec_mixpos = newpos;
 
+	This->use_committed = FALSE;
+	This->committed_mixpos = 0;
+
 	/* at this point, do not attempt to reset buffers, mess with primary mix position,
            or anything like that to reduce latency. The data already prebuffered cannot be changed */
 
@@ -565,10 +605,10 @@ static HRESULT WINAPI IDirectSoundBufferImpl_SetPan(IDirectSoundBuffer8 *iface,
         IDirectSoundBufferImpl *This = impl_from_IDirectSoundBuffer8(iface);
 	HRESULT hres = DS_OK;
 
-	TRACE("(%p,%d)\n",This,pan);
+	TRACE("(%p,%ld)\n",This,pan);
 
 	if ((pan > DSBPAN_RIGHT) || (pan < DSBPAN_LEFT)) {
-		WARN("invalid parameter: pan = %d\n", pan);
+		WARN("invalid parameter: pan = %ld\n", pan);
 		return DSERR_INVALIDPARAM;
 	}
 
@@ -616,7 +656,7 @@ static HRESULT WINAPI IDirectSoundBufferImpl_Unlock(IDirectSoundBuffer8 *iface,
         IDirectSoundBufferImpl *This = impl_from_IDirectSoundBuffer8(iface), *iter;
 	HRESULT hres = DS_OK;
 
-	TRACE("(%p,%p,%d,%p,%d)\n", This,p1,x1,p2,x2);
+	TRACE("(%p,%p,%ld,%p,%ld)\n", This,p1,x1,p2,x2);
 
 	if (!p2)
 		x2 = 0;
@@ -674,7 +714,7 @@ static HRESULT WINAPI IDirectSoundBufferImpl_GetFrequency(IDirectSoundBuffer8 *i
 	}
 
 	*freq = This->freq;
-	TRACE("-> %d\n", *freq);
+	TRACE("-> %ld\n", *freq);
 
 	return DS_OK;
 }
@@ -706,7 +746,7 @@ static HRESULT WINAPI IDirectSoundBufferImpl_SetFX(IDirectSoundBuffer8 *iface, D
 	DMO_MEDIA_TYPE dmt;
 	WAVEFORMATEX wfx;
 
-	TRACE("(%p,%u,%p,%p)\n", This, dwEffectsCount, pDSFXDesc, pdwResultCodes);
+	TRACE("(%p,%lu,%p,%p)\n", This, dwEffectsCount, pDSFXDesc, pdwResultCodes);
 
 	if (pdwResultCodes)
 		for (u=0; u<dwEffectsCount; u++) pdwResultCodes[u] = DSFXR_UNKNOWN;
@@ -768,7 +808,7 @@ static HRESULT WINAPI IDirectSoundBufferImpl_SetFX(IDirectSoundBuffer8 *iface, D
 	dmt.pbFormat = (BYTE*)&wfx;
 
 	for (u = 0; u < dwEffectsCount; u++) {
-		TRACE("%d: 0x%08x, %s\n", u, pDSFXDesc[u].dwFlags, dump_DSFX_guid(&pDSFXDesc[u]));
+		TRACE("%ld: 0x%08lx, %s\n", u, pDSFXDesc[u].dwFlags, dump_DSFX_guid(&pDSFXDesc[u]));
 
 		hr2 = CoCreateInstance(&pDSFXDesc[u].guidDSFXClass, NULL, CLSCTX_INPROC_SERVER, &IID_IMediaObject, (LPVOID*)&filters[u].obj);
 
@@ -834,7 +874,7 @@ static HRESULT WINAPI IDirectSoundBufferImpl_AcquireResources(IDirectSoundBuffer
         IDirectSoundBufferImpl *This = impl_from_IDirectSoundBuffer8(iface);
 	DWORD u;
 
-	FIXME("(%p,%08u,%u,%p): stub, faking success\n",This,dwFlags,dwEffectsCount,pdwResultCodes);
+	FIXME("(%p,%08lu,%lu,%p): stub, faking success\n",This,dwFlags,dwEffectsCount,pdwResultCodes);
 
 	if (pdwResultCodes)
 		for (u=0; u<dwEffectsCount; u++) pdwResultCodes[u] = DSFXR_UNKNOWN;
@@ -849,7 +889,7 @@ static HRESULT WINAPI IDirectSoundBufferImpl_GetObjectInPath(IDirectSoundBuffer8
     IDirectSoundBufferImpl *This = impl_from_IDirectSoundBuffer8(iface);
     DWORD i, count = 0;
 
-    TRACE("(%p,%s,%u,%s,%p)\n", This, debugstr_guid(clsid), index, debugstr_guid(iid), out);
+    TRACE("(%p,%s,%lu,%s,%p)\n", This, debugstr_guid(clsid), index, debugstr_guid(iid), out);
 
     if (!out)
         return E_INVALIDARG;
@@ -886,7 +926,7 @@ static HRESULT WINAPI IDirectSoundBufferImpl_GetCaps(IDirectSoundBuffer8 *iface,
 	}
 
 	if (caps->dwSize < sizeof(*caps)) {
-		WARN("invalid parameter: caps->dwSize = %d\n",caps->dwSize);
+		WARN("invalid parameter: caps->dwSize = %ld\n",caps->dwSize);
 		return DSERR_INVALIDPARAM;
 	}
 
@@ -1001,7 +1041,7 @@ HRESULT secondarybuffer_create(DirectSoundDevice *device, const DSBUFFERDESC *ds
         TRACE("(%p,%p,%p)\n", device, dsbd, buffer);
 
 	if (dsbd->dwBufferBytes < DSBSIZE_MIN || dsbd->dwBufferBytes > DSBSIZE_MAX) {
-		WARN("invalid parameter: dsbd->dwBufferBytes = %d\n", dsbd->dwBufferBytes);
+		WARN("invalid parameter: dsbd->dwBufferBytes = %ld\n", dsbd->dwBufferBytes);
 		return DSERR_INVALIDPARAM; /* FIXME: which error? */
 	}
 
@@ -1049,7 +1089,7 @@ HRESULT secondarybuffer_create(DirectSoundDevice *device, const DSBUFFERDESC *ds
 	if (wfex->wBitsPerSample==16) capf |= DSCAPS_SECONDARY16BIT;
 	else capf |= DSCAPS_SECONDARY8BIT;
 
-	TRACE("capf = 0x%08x, device->drvcaps.dwFlags = 0x%08x\n", capf, device->drvcaps.dwFlags);
+	TRACE("capf = 0x%08lx, device->drvcaps.dwFlags = 0x%08lx\n", capf, device->drvcaps.dwFlags);
 
 	/* Allocate an empty buffer */
 	bufsize = (sizeof(*(dsb->buffer)) + sizeof(void *) - 1) & ~(sizeof(void *) - 1);
@@ -1081,6 +1121,12 @@ HRESULT secondarybuffer_create(DirectSoundDevice *device, const DSBUFFERDESC *ds
 	/* calculate fragment size and write lead */
 	DSOUND_RecalcFormat(dsb);
 
+	dsb->committedbuff = HeapAlloc(GetProcessHeap(), 0, dsb->writelead);
+	if(!dsb->committedbuff) {
+		IDirectSoundBuffer8_Release(&dsb->IDirectSoundBuffer8_iface);
+		return DSERR_OUTOFMEMORY;
+	}
+
 	if (dsb->dsbd.dwFlags & DSBCAPS_CTRL3D) {
 		dsb->ds3db_ds3db.dwSize = sizeof(DS3DBUFFER);
 		dsb->ds3db_ds3db.vPosition.x = 0.0;
@@ -1121,7 +1167,7 @@ void secondarybuffer_destroy(IDirectSoundBufferImpl *This)
     ULONG ref = InterlockedIncrement(&This->numIfaces);
 
     if (ref > 1)
-        WARN("Destroying buffer with %u in use interfaces\n", ref - 1);
+        WARN("Destroying buffer with %lu in use interfaces\n", ref - 1);
 
     if (This->dsbd.dwFlags & DSBCAPS_LOCHARDWARE)
         This->device->drvcaps.dwFreeHwMixingAllBuffers++;
@@ -1135,6 +1181,7 @@ void secondarybuffer_destroy(IDirectSoundBufferImpl *This)
 
     HeapFree(GetProcessHeap(), 0, This->notifies);
     HeapFree(GetProcessHeap(), 0, This->pwfx);
+    HeapFree(GetProcessHeap(), 0, This->committedbuff);
 
     if (This->filters) {
         int i;
@@ -1145,9 +1192,20 @@ void secondarybuffer_destroy(IDirectSoundBufferImpl *This)
         HeapFree(GetProcessHeap(), 0, This->filters);
     }
 
-    HeapFree(GetProcessHeap(), 0, This);
-
     TRACE("(%p) released\n", This);
+
+    HeapFree(GetProcessHeap(), 0, This);
+}
+
+BOOL secondarybuffer_is_audible(IDirectSoundBufferImpl *This)
+{
+    UINT i;
+    for (i = 0; i < This->device->pwfx->nChannels; i++) {
+        if (This->volpan.dwTotalAmpFactor[i] != 0)
+            return TRUE;
+    }
+
+   return FALSE;
 }
 
 HRESULT IDirectSoundBufferImpl_Duplicate(
@@ -1157,6 +1215,7 @@ HRESULT IDirectSoundBufferImpl_Duplicate(
 {
     IDirectSoundBufferImpl *dsb;
     HRESULT hres = DS_OK;
+    VOID *committedbuff;
     TRACE("(%p,%p,%p)\n", device, ppdsb, pdsb);
 
     dsb = HeapAlloc(GetProcessHeap(),0,sizeof(*dsb));
@@ -1166,6 +1225,13 @@ HRESULT IDirectSoundBufferImpl_Duplicate(
         return DSERR_OUTOFMEMORY;
     }
 
+    committedbuff = HeapAlloc(GetProcessHeap(),0,pdsb->writelead);
+    if (committedbuff == NULL) {
+        HeapFree(GetProcessHeap(),0,dsb);
+        *ppdsb = NULL;
+        return DSERR_OUTOFMEMORY;
+    }
+
     AcquireSRWLockShared(&pdsb->lock);
 
     CopyMemory(dsb, pdsb, sizeof(*dsb));
@@ -1175,6 +1241,7 @@ HRESULT IDirectSoundBufferImpl_Duplicate(
     ReleaseSRWLockShared(&pdsb->lock);
 
     if (dsb->pwfx == NULL) {
+        HeapFree(GetProcessHeap(),0,committedbuff);
         HeapFree(GetProcessHeap(),0,dsb);
         *ppdsb = NULL;
         return DSERR_OUTOFMEMORY;
@@ -1192,6 +1259,9 @@ HRESULT IDirectSoundBufferImpl_Duplicate(
     dsb->notifies = NULL;
     dsb->nrofnotifies = 0;
     dsb->device = device;
+    dsb->committedbuff = committedbuff;
+    dsb->use_committed = FALSE;
+    dsb->committed_mixpos = 0;
     DSOUND_RecalcFormat(dsb);
 
     InitializeSRWLock(&dsb->lock);
@@ -1202,6 +1272,7 @@ HRESULT IDirectSoundBufferImpl_Duplicate(
         list_remove(&dsb->entry);
         dsb->buffer->ref--;
         HeapFree(GetProcessHeap(),0,dsb->pwfx);
+        HeapFree(GetProcessHeap(),0,dsb->committedbuff);
         HeapFree(GetProcessHeap(),0,dsb);
         dsb = NULL;
     }else
@@ -1236,7 +1307,7 @@ static ULONG WINAPI IKsPropertySetImpl_AddRef(IKsPropertySet *iface)
     IDirectSoundBufferImpl *This = impl_from_IKsPropertySet(iface);
     ULONG ref = InterlockedIncrement(&This->refiks);
 
-    TRACE("(%p) ref %d\n", This, ref);
+    TRACE("(%p) ref %ld\n", This, ref);
 
     if(ref == 1)
         InterlockedIncrement(&This->numIfaces);
@@ -1253,7 +1324,7 @@ static ULONG WINAPI IKsPropertySetImpl_Release(IKsPropertySet *iface)
         ref = capped_refcount_dec(&This->refiks);
         if(!ref)
             capped_refcount_dec(&This->numIfaces);
-        TRACE("(%p) ref %d\n", This, ref);
+        TRACE("(%p) ref %ld\n", This, ref);
         return ref;
     }
 
@@ -1261,7 +1332,7 @@ static ULONG WINAPI IKsPropertySetImpl_Release(IKsPropertySet *iface)
     if (!ref && !InterlockedDecrement(&This->numIfaces))
         secondarybuffer_destroy(This);
 
-    TRACE("(%p) ref %d\n", This, ref);
+    TRACE("(%p) ref %ld\n", This, ref);
 
     return ref;
 }
@@ -1272,7 +1343,7 @@ static HRESULT WINAPI IKsPropertySetImpl_Get(IKsPropertySet *iface, REFGUID guid
 {
     IDirectSoundBufferImpl *This = impl_from_IKsPropertySet(iface);
 
-    TRACE("(iface=%p,guidPropSet=%s,dwPropID=%d,pInstanceData=%p,cbInstanceData=%d,pPropData=%p,cbPropData=%d,pcbReturned=%p)\n",
+    TRACE("(iface=%p,guidPropSet=%s,dwPropID=%ld,pInstanceData=%p,cbInstanceData=%ld,pPropData=%p,cbPropData=%ld,pcbReturned=%p)\n",
     This,debugstr_guid(guidPropSet),dwPropID,pInstanceData,cbInstanceData,pPropData,cbPropData,pcbReturned);
 
     return E_PROP_ID_UNSUPPORTED;
@@ -1284,7 +1355,7 @@ static HRESULT WINAPI IKsPropertySetImpl_Set(IKsPropertySet *iface, REFGUID guid
 {
     IDirectSoundBufferImpl *This = impl_from_IKsPropertySet(iface);
 
-    TRACE("(%p,%s,%d,%p,%d,%p,%d)\n",This,debugstr_guid(guidPropSet),dwPropID,pInstanceData,cbInstanceData,pPropData,cbPropData);
+    TRACE("(%p,%s,%ld,%p,%ld,%p,%ld)\n",This,debugstr_guid(guidPropSet),dwPropID,pInstanceData,cbInstanceData,pPropData,cbPropData);
 
     return E_PROP_ID_UNSUPPORTED;
 }
@@ -1294,7 +1365,7 @@ static HRESULT WINAPI IKsPropertySetImpl_QuerySupport(IKsPropertySet *iface, REF
 {
     IDirectSoundBufferImpl *This = impl_from_IKsPropertySet(iface);
 
-    TRACE("(%p,%s,%d,%p)\n",This,debugstr_guid(guidPropSet),dwPropID,pTypeSupport);
+    TRACE("(%p,%s,%ld,%p)\n",This,debugstr_guid(guidPropSet),dwPropID,pTypeSupport);
 
     return E_PROP_ID_UNSUPPORTED;
 }
