@@ -17,8 +17,6 @@
  *
  */
 
-#include "config.h"
-
 #include "dxgi_private.h"
 
 WINE_DEFAULT_DEBUG_CHANNEL(dxgi);
@@ -73,7 +71,7 @@ static ULONG STDMETHODCALLTYPE dxgi_device_AddRef(IWineDXGIDevice *iface)
     struct dxgi_device *device = impl_from_IWineDXGIDevice(iface);
     ULONG refcount = InterlockedIncrement(&device->refcount);
 
-    TRACE("%p increasing refcount to %u\n", device, refcount);
+    TRACE("%p increasing refcount to %lu\n", device, refcount);
 
     return refcount;
 }
@@ -83,7 +81,7 @@ static ULONG STDMETHODCALLTYPE dxgi_device_Release(IWineDXGIDevice *iface)
     struct dxgi_device *device = impl_from_IWineDXGIDevice(iface);
     ULONG refcount = InterlockedDecrement(&device->refcount);
 
-    TRACE("%p decreasing refcount to %u.\n", device, refcount);
+    TRACE("%p decreasing refcount to %lu.\n", device, refcount);
 
     if (!refcount)
     {
@@ -143,7 +141,7 @@ static HRESULT STDMETHODCALLTYPE dxgi_device_GetParent(IWineDXGIDevice *iface, R
     hr = IWineDXGIDevice_GetAdapter(iface, &adapter);
     if (FAILED(hr))
     {
-        ERR("Failed to get adapter, hr %#x.\n", hr);
+        ERR("Failed to get adapter, hr %#lx.\n", hr);
         return hr;
     }
 
@@ -211,7 +209,7 @@ static HRESULT STDMETHODCALLTYPE dxgi_device_CreateSurface(IWineDXGIDevice *ifac
         if (FAILED(hr = device_parent->ops->create_swapchain_texture(device_parent,
                 NULL, &surface_desc, 0, &wined3d_texture)))
         {
-            ERR("Failed to create surface, hr %#x.\n", hr);
+            ERR("Failed to create surface, hr %#lx.\n", hr);
             goto fail;
         }
 
@@ -328,31 +326,31 @@ static void STDMETHODCALLTYPE dxgi_device_Trim(IWineDXGIDevice *iface)
 
 /* IWineDXGIDevice methods */
 
-static HRESULT STDMETHODCALLTYPE dxgi_device_create_surface(IWineDXGIDevice *iface,
-        struct wined3d_texture *wined3d_texture, DXGI_USAGE usage,
-        const DXGI_SHARED_RESOURCE *shared_resource, IUnknown *outer, void **surface)
+static HRESULT STDMETHODCALLTYPE dxgi_device_create_resource(IWineDXGIDevice *iface,
+        struct wined3d_resource *wined3d_resource, DXGI_USAGE usage,
+        const DXGI_SHARED_RESOURCE *shared_resource, IUnknown *outer, BOOL needs_surface, void **resource)
 {
-    struct dxgi_surface *object;
+    struct dxgi_resource *object;
     HRESULT hr;
 
-    TRACE("iface %p, wined3d_texture %p, usage %#x, shared_resource %p, outer %p, surface %p.\n",
-            iface, wined3d_texture, usage, shared_resource, outer, surface);
+    TRACE("iface %p, wined3d_resource %p, usage %#x, shared_resource %p, outer %p, surface %p.\n",
+            iface, wined3d_resource, usage, shared_resource, outer, resource);
 
     if (!(object = heap_alloc_zero(sizeof(*object))))
     {
-        ERR("Failed to allocate DXGI surface object memory.\n");
+        ERR("Failed to allocate DXGI resource object memory.\n");
         return E_OUTOFMEMORY;
     }
 
-    if (FAILED(hr = dxgi_surface_init(object, (IDXGIDevice *)iface, outer, wined3d_texture)))
+    if (FAILED(hr = dxgi_resource_init(object, (IDXGIDevice *)iface, outer, needs_surface, wined3d_resource)))
     {
-        WARN("Failed to initialize surface, hr %#x.\n", hr);
+        WARN("Failed to initialize resource, hr %#lx.\n", hr);
         heap_free(object);
         return hr;
     }
 
-    TRACE("Created IDXGISurface %p.\n", object);
-    *surface = outer ? &object->IUnknown_iface : (IUnknown *)&object->IDXGISurface1_iface;
+    TRACE("Created resource %p.\n", object);
+    *resource = outer ? &object->IUnknown_iface : (IUnknown *)&object->IDXGIResource_iface;
 
     return S_OK;
 }
@@ -384,7 +382,7 @@ static const struct IWineDXGIDeviceVtbl dxgi_device_vtbl =
     /* IDXGIDevice3 methods */
     dxgi_device_Trim,
     /* IWineDXGIDevice methods */
-    dxgi_device_create_surface,
+    dxgi_device_create_resource,
 };
 
 static inline struct dxgi_device *impl_from_IWineDXGISwapChainFactory(IWineDXGISwapChainFactory *iface)
@@ -442,7 +440,7 @@ static HRESULT STDMETHODCALLTYPE dxgi_swapchain_factory_create_swapchain(IWineDX
 
     if (FAILED(hr = dxgi_get_output_from_window(&dxgi_factory->IWineDXGIFactory_iface, window, &containing_output)))
     {
-        WARN("Failed to get output from window %p, hr %#x.\n", window, hr);
+        WARN("Failed to get output from window %p, hr %#lx.\n", window, hr);
         return hr;
     }
 
@@ -460,7 +458,7 @@ static HRESULT STDMETHODCALLTYPE dxgi_swapchain_factory_create_swapchain(IWineDX
 
     if (FAILED(hr = d3d11_swapchain_init(object, device, &wined3d_desc)))
     {
-        WARN("Failed to initialise swapchain, hr %#x.\n", hr);
+        WARN("Failed to initialise swapchain, hr %#lx.\n", hr);
         heap_free(object);
         return hr;
     }
@@ -519,7 +517,7 @@ HRESULT dxgi_device_init(struct dxgi_device *device, struct dxgi_device_layer *l
     if (FAILED(hr = layer->create(layer->id, &layer_base, 0,
             device, &IID_IUnknown, (void **)&device->child_layer)))
     {
-        WARN("Failed to create device, returning %#x.\n", hr);
+        WARN("Failed to create device, returning %#lx.\n", hr);
         wined3d_private_store_cleanup(&device->private_store);
         wined3d_mutex_unlock();
         return hr;
@@ -542,7 +540,7 @@ HRESULT dxgi_device_init(struct dxgi_device *device, struct dxgi_device_layer *l
             (const enum wined3d_feature_level *)feature_levels, level_count,
             wined3d_device_parent, &device->wined3d_device)))
     {
-        WARN("Failed to create a wined3d device, returning %#x.\n", hr);
+        WARN("Failed to create a wined3d device, returning %#lx.\n", hr);
         IUnknown_Release(device->child_layer);
         wined3d_private_store_cleanup(&device->private_store);
         wined3d_mutex_unlock();
@@ -581,7 +579,7 @@ HRESULT dxgi_device_init(struct dxgi_device *device, struct dxgi_device_layer *l
 
     if (FAILED(hr = d3d11_swapchain_init(swapchain, device, &swapchain_desc)))
     {
-        WARN("Failed to initialize swapchain, hr %#x.\n", hr);
+        WARN("Failed to initialize swapchain, hr %#lx.\n", hr);
         heap_free(swapchain);
         wined3d_device_decref(device->wined3d_device);
         IUnknown_Release(device->child_layer);
