@@ -65,6 +65,7 @@ struct sample_queue
     unsigned int used;
     unsigned int front;
     unsigned int back;
+    IMFSample *last_presented;
 };
 
 struct streaming_thread
@@ -120,6 +121,7 @@ struct video_presenter
     struct
     {
         int presented;
+        LONGLONG sampletime;
     } frame_stats;
 
     CRITICAL_SECTION cs;
@@ -282,7 +284,7 @@ static void video_presenter_reset_media_type(struct video_presenter *presenter)
 
 static HRESULT video_presenter_set_media_type(struct video_presenter *presenter, IMFMediaType *media_type)
 {
-    unsigned int flags;
+    DWORD flags;
     HRESULT hr;
 
     if (!media_type)
@@ -320,7 +322,7 @@ static HRESULT video_presenter_set_media_type(struct video_presenter *presenter,
         presenter->frame_time_threshold = frametime / 4;
     }
     else
-        WARN("Failed to initialize sample allocator, hr %#x.\n", hr);
+        WARN("Failed to initialize sample allocator, hr %#lx.\n", hr);
 
     return hr;
 }
@@ -328,9 +330,9 @@ static HRESULT video_presenter_set_media_type(struct video_presenter *presenter,
 static HRESULT video_presenter_configure_output_type(struct video_presenter *presenter, const MFVideoArea *aperture,
         IMFMediaType *media_type)
 {
-    unsigned int size;
     GUID subtype;
     LONG stride;
+    DWORD size;
     HRESULT hr;
 
     hr = IMFMediaType_SetUINT64(media_type, &MF_MT_FRAME_SIZE, (UINT64)aperture->Area.cx << 32 | aperture->Area.cy);
@@ -387,7 +389,7 @@ static HRESULT video_presenter_invalidate_media_type(struct video_presenter *pre
         /* FIXME: check that d3d device supports this format */
 
         if (FAILED(hr = IMFMediaType_CopyAllItems(candidate_type, (IMFAttributes *)media_type)))
-            WARN("Failed to clone a media type, hr %#x.\n", hr);
+            WARN("Failed to clone a media type, hr %#lx.\n", hr);
         IMFMediaType_Release(candidate_type);
 
         hr = video_presenter_configure_output_type(presenter, &aperture, media_type);
@@ -427,15 +429,20 @@ static HRESULT video_presenter_sample_queue_init(struct video_presenter *present
     return S_OK;
 }
 
-static void video_presenter_sample_queue_push(struct video_presenter *presenter, IMFSample *sample)
+static void video_presenter_sample_queue_push(struct video_presenter *presenter, IMFSample *sample,
+        BOOL at_front)
 {
     struct sample_queue *queue = &presenter->thread.queue;
+    unsigned int idx;
 
     EnterCriticalSection(&presenter->cs);
     if (queue->used != queue->size)
     {
-        queue->back = (queue->back + 1) % queue->size;
-        queue->samples[queue->back] = sample;
+        if (at_front)
+            idx = queue->front = (queue->size + queue->front - 1) % queue->size;
+        else
+            idx = queue->back = (queue->back + 1) % queue->size;
+        queue->samples[idx] = sample;
         queue->used++;
         IMFSample_AddRef(sample);
     }
@@ -485,30 +492,36 @@ static void video_presenter_sample_present(struct video_presenter *presenter, IM
     IDirect3DDevice9 *device;
     HRESULT hr;
 
-    if (!presenter->swapchain)
-        return;
-
     if (FAILED(hr = video_presenter_get_sample_surface(sample, &surface)))
     {
-        WARN("Failed to get sample surface, hr %#x.\n", hr);
+        WARN("Failed to get sample surface, hr %#lx.\n", hr);
         return;
     }
 
-    if (FAILED(hr = IDirect3DSwapChain9_GetBackBuffer(presenter->swapchain, 0, D3DBACKBUFFER_TYPE_MONO, &backbuffer)))
+    if (presenter->swapchain)
     {
-        WARN("Failed to get a backbuffer, hr %#x.\n", hr);
-        IDirect3DSurface9_Release(surface);
-        return;
+        if (SUCCEEDED(hr = IDirect3DSwapChain9_GetBackBuffer(presenter->swapchain, 0, D3DBACKBUFFER_TYPE_MONO, &backbuffer)))
+        {
+            IDirect3DSwapChain9_GetDevice(presenter->swapchain, &device);
+            IDirect3DDevice9_StretchRect(device, surface, NULL, backbuffer, NULL, D3DTEXF_POINT);
+
+            IDirect3DSwapChain9_Present(presenter->swapchain, NULL, NULL, NULL, NULL, 0);
+            presenter->frame_stats.presented++;
+
+            IDirect3DDevice9_Release(device);
+            IDirect3DSurface9_Release(backbuffer);
+        }
+        else
+            WARN("Failed to get a backbuffer, hr %#lx.\n", hr);
     }
 
-    IDirect3DSwapChain9_GetDevice(presenter->swapchain, &device);
-    IDirect3DDevice9_StretchRect(device, surface, NULL, backbuffer, NULL, D3DTEXF_POINT);
+    EnterCriticalSection(&presenter->cs);
+    if (presenter->thread.queue.last_presented)
+        IMFSample_Release(presenter->thread.queue.last_presented);
+    presenter->thread.queue.last_presented = sample;
+    IMFSample_AddRef(presenter->thread.queue.last_presented);
+    LeaveCriticalSection(&presenter->cs);
 
-    IDirect3DSwapChain9_Present(presenter->swapchain, NULL, NULL, NULL, NULL, 0);
-    presenter->frame_stats.presented++;
-
-    IDirect3DDevice9_Release(device);
-    IDirect3DSurface9_Release(backbuffer);
     IDirect3DSurface9_Release(surface);
 }
 
@@ -539,7 +552,7 @@ static void video_presenter_check_queue(struct video_presenter *presenter,
             if (delta > 3 * presenter->frame_time_threshold)
             {
                 /* Convert 100ns -> msec */
-                wait = (delta - 3 * presenter->frame_time_threshold) / 100000;
+                wait = (delta - 3 * presenter->frame_time_threshold) / 10000;
                 present = FALSE;
             }
         }
@@ -547,7 +560,7 @@ static void video_presenter_check_queue(struct video_presenter *presenter,
         if (present)
             video_presenter_sample_present(presenter, sample);
         else
-            video_presenter_sample_queue_push(presenter, sample);
+            video_presenter_sample_queue_push(presenter, sample, TRUE);
 
         IMFSample_Release(sample);
 
@@ -571,7 +584,7 @@ static void video_presenter_schedule_sample(struct video_presenter *presenter, I
 
     if (presenter->clock)
     {
-        video_presenter_sample_queue_push(presenter, sample);
+        video_presenter_sample_queue_push(presenter, sample, FALSE);
         PostThreadMessageW(presenter->thread.tid, EVRM_PRESENT, 0, 0);
     }
     else
@@ -603,7 +616,7 @@ static HRESULT video_presenter_process_input(struct video_presenter *presenter)
 
         if (FAILED(hr = IMFVideoSampleAllocator_AllocateSample(presenter->allocator, &sample)))
         {
-            WARN("Failed to allocate a sample, hr %#x.\n", hr);
+            WARN("Failed to allocate a sample, hr %#lx.\n", hr);
             break;
         }
 
@@ -722,7 +735,7 @@ static HRESULT video_presenter_start_streaming(struct video_presenter *presenter
     CloseHandle(presenter->thread.ready_event);
     presenter->thread.ready_event = NULL;
 
-    TRACE("Started streaming thread, tid %#x.\n", presenter->thread.tid);
+    TRACE("Started streaming thread, tid %#lx.\n", presenter->thread.tid);
 
     return S_OK;
 }
@@ -737,8 +750,10 @@ static HRESULT video_presenter_end_streaming(struct video_presenter *presenter)
     WaitForSingleObject(presenter->thread.hthread, INFINITE);
     CloseHandle(presenter->thread.hthread);
 
-    TRACE("Terminated streaming thread tid %#x.\n", presenter->thread.tid);
+    TRACE("Terminated streaming thread tid %#lx.\n", presenter->thread.tid);
 
+    if (presenter->thread.queue.last_presented)
+        IMFSample_Release(presenter->thread.queue.last_presented);
     memset(&presenter->thread, 0, sizeof(presenter->thread));
     video_presenter_set_allocator_callback(presenter, NULL);
 
@@ -816,7 +831,7 @@ static ULONG WINAPI video_presenter_inner_AddRef(IUnknown *iface)
     struct video_presenter *presenter = impl_from_IUnknown(iface);
     ULONG refcount = InterlockedIncrement(&presenter->refcount);
 
-    TRACE("%p, refcount %u.\n", iface, refcount);
+    TRACE("%p, refcount %lu.\n", iface, refcount);
 
     return refcount;
 }
@@ -839,7 +854,7 @@ static ULONG WINAPI video_presenter_inner_Release(IUnknown *iface)
     struct video_presenter *presenter = impl_from_IUnknown(iface);
     ULONG refcount = InterlockedDecrement(&presenter->refcount);
 
-    TRACE("%p, refcount %u.\n", iface, refcount);
+    TRACE("%p, refcount %lu.\n", iface, refcount);
 
     if (!refcount)
     {
@@ -952,7 +967,7 @@ static HRESULT WINAPI video_presenter_ProcessMessage(IMFVideoPresenter *iface, M
     struct video_presenter *presenter = impl_from_IMFVideoPresenter(iface);
     HRESULT hr;
 
-    TRACE("%p, %d, %lu.\n", iface, message, param);
+    TRACE("%p, %d, %Iu.\n", iface, message, param);
 
     EnterCriticalSection(&presenter->cs);
 
@@ -1095,7 +1110,7 @@ static void video_presenter_set_mixer_rect(struct video_presenter *presenter)
         if (FAILED(hr = IMFAttributes_SetBlob(attributes, &VIDEO_ZOOM_RECT, (const UINT8 *)&presenter->src_rect,
                 sizeof(presenter->src_rect))))
         {
-            WARN("Failed to set zoom rectangle attribute, hr %#x.\n", hr);
+            WARN("Failed to set zoom rectangle attribute, hr %#lx.\n", hr);
         }
         IMFAttributes_Release(attributes);
     }
@@ -1104,15 +1119,15 @@ static void video_presenter_set_mixer_rect(struct video_presenter *presenter)
 static HRESULT video_presenter_attach_mixer(struct video_presenter *presenter, IMFTopologyServiceLookup *service_lookup)
 {
     IMFVideoDeviceID *device_id;
-    unsigned int count;
     GUID id = { 0 };
+    DWORD count;
     HRESULT hr;
 
     count = 1;
     if (FAILED(hr = IMFTopologyServiceLookup_LookupService(service_lookup, MF_SERVICE_LOOKUP_GLOBAL, 0,
             &MR_VIDEO_MIXER_SERVICE, &IID_IMFTransform, (void **)&presenter->mixer, &count)))
     {
-        WARN("Failed to get mixer interface, hr %#x.\n", hr);
+        WARN("Failed to get mixer interface, hr %#lx.\n", hr);
         return hr;
     }
 
@@ -1143,8 +1158,8 @@ static HRESULT WINAPI video_presenter_service_client_InitServicePointers(IMFTopo
         IMFTopologyServiceLookup *service_lookup)
 {
     struct video_presenter *presenter = impl_from_IMFTopologyServiceLookupClient(iface);
-    unsigned int count;
     HRESULT hr = S_OK;
+    DWORD count;
 
     TRACE("%p, %p.\n", iface, service_lookup);
 
@@ -1174,7 +1189,7 @@ static HRESULT WINAPI video_presenter_service_client_InitServicePointers(IMFTopo
             if (FAILED(hr = IMFTopologyServiceLookup_LookupService(service_lookup, MF_SERVICE_LOOKUP_GLOBAL, 0,
                     &MR_VIDEO_RENDER_SERVICE, &IID_IMediaEventSink, (void **)&presenter->event_sink, &count)))
             {
-                WARN("Failed to get renderer event sink, hr %#x.\n", hr);
+                WARN("Failed to get renderer event sink, hr %#lx.\n", hr);
             }
         }
 
@@ -1350,7 +1365,7 @@ static HRESULT WINAPI video_presenter_control_SetAspectRatioMode(IMFVideoDisplay
 {
     struct video_presenter *presenter = impl_from_IMFVideoDisplayControl(iface);
 
-    TRACE("%p, %#x.\n", iface, mode);
+    TRACE("%p, %#lx.\n", iface, mode);
 
     if (mode & ~MFVideoARMode_Mask)
         return E_INVALIDARG;
@@ -1461,14 +1476,93 @@ static HRESULT WINAPI video_presenter_control_RepaintVideo(IMFVideoDisplayContro
 static HRESULT WINAPI video_presenter_control_GetCurrentImage(IMFVideoDisplayControl *iface, BITMAPINFOHEADER *header,
         BYTE **dib, DWORD *dib_size, LONGLONG *timestamp)
 {
-    FIXME("%p, %p, %p, %p, %p.\n", iface, header, dib, dib_size, timestamp);
+    struct video_presenter *presenter = impl_from_IMFVideoDisplayControl(iface);
+    IDirect3DSurface9 *readback = NULL, *surface;
+    D3DSURFACE_DESC surface_desc;
+    D3DLOCKED_RECT mapped_rect;
+    IDirect3DDevice9 *device;
+    IMFSample *sample;
+    LONG stride;
+    HRESULT hr;
 
-    return E_NOTIMPL;
+    TRACE("%p, %p, %p, %p, %p.\n", iface, header, dib, dib_size, timestamp);
+
+    EnterCriticalSection(&presenter->cs);
+
+    sample = presenter->thread.queue.last_presented;
+    presenter->thread.queue.last_presented = NULL;
+
+    if (!sample)
+    {
+        hr = MF_E_INVALIDREQUEST;
+    }
+    else if (SUCCEEDED(hr = video_presenter_get_sample_surface(sample, &surface)))
+    {
+        IDirect3DSurface9_GetDevice(surface, &device);
+        IDirect3DSurface9_GetDesc(surface, &surface_desc);
+
+        if (surface_desc.Format != D3DFMT_X8R8G8B8)
+        {
+            FIXME("Unexpected surface format %d.\n", surface_desc.Format);
+            hr = E_FAIL;
+        }
+
+        if (SUCCEEDED(hr))
+        {
+            if (FAILED(hr = IDirect3DDevice9_CreateOffscreenPlainSurface(device, surface_desc.Width,
+                    surface_desc.Height, D3DFMT_X8R8G8B8, D3DPOOL_SYSTEMMEM, &readback, NULL)))
+            {
+                WARN("Failed to create readback surface, hr %#lx.\n", hr);
+            }
+        }
+
+        if (SUCCEEDED(hr))
+            hr = IDirect3DDevice9_GetRenderTargetData(device, surface, readback);
+
+        if (SUCCEEDED(hr))
+        {
+            MFGetStrideForBitmapInfoHeader(D3DFMT_X8R8G8B8, surface_desc.Width, &stride);
+            *dib_size = abs(stride) * surface_desc.Height;
+            if (!(*dib = CoTaskMemAlloc(*dib_size)))
+                hr = E_OUTOFMEMORY;
+        }
+
+        if (SUCCEEDED(hr))
+        {
+            if (SUCCEEDED(hr = IDirect3DSurface9_LockRect(readback, &mapped_rect, NULL, D3DLOCK_READONLY)))
+            {
+                memcpy(*dib, mapped_rect.pBits, *dib_size);
+                IDirect3DSurface9_UnlockRect(readback);
+            }
+        }
+
+        memset(header, 0, sizeof(*header));
+        header->biSize = sizeof(*header);
+        header->biWidth = surface_desc.Width;
+        header->biHeight = surface_desc.Height;
+        header->biPlanes = 1;
+        header->biBitCount = 32;
+        header->biSizeImage = *dib_size;
+        IMFSample_GetSampleTime(sample, timestamp);
+
+        if (readback)
+            IDirect3DSurface9_Release(readback);
+        IDirect3DSurface9_Release(surface);
+
+        IDirect3DDevice9_Release(device);
+    }
+
+    if (sample)
+        IMFSample_Release(sample);
+
+    LeaveCriticalSection(&presenter->cs);
+
+    return hr;
 }
 
 static HRESULT WINAPI video_presenter_control_SetBorderColor(IMFVideoDisplayControl *iface, COLORREF color)
 {
-    FIXME("%p, %#x.\n", iface, color);
+    FIXME("%p, %#lx.\n", iface, color);
 
     return E_NOTIMPL;
 }
@@ -1482,7 +1576,7 @@ static HRESULT WINAPI video_presenter_control_GetBorderColor(IMFVideoDisplayCont
 
 static HRESULT WINAPI video_presenter_control_SetRenderingPrefs(IMFVideoDisplayControl *iface, DWORD flags)
 {
-    FIXME("%p, %#x.\n", iface, flags);
+    FIXME("%p, %#lx.\n", iface, flags);
 
     return E_NOTIMPL;
 }
@@ -1654,7 +1748,7 @@ static ULONG WINAPI video_presenter_position_mapper_Release(IMFVideoPositionMapp
 static HRESULT WINAPI video_presenter_position_mapper_MapOutputCoordinateToInputStream(IMFVideoPositionMapper *iface,
         float x_out, float y_out, DWORD output_stream, DWORD input_stream, float *x_in, float *y_in)
 {
-    FIXME("%p, %f, %f, %u, %u, %p, %p.\n", iface, x_out, y_out, output_stream, input_stream, x_in, y_in);
+    FIXME("%p, %f, %f, %lu, %lu, %p, %p.\n", iface, x_out, y_out, output_stream, input_stream, x_in, y_in);
 
     return E_NOTIMPL;
 }
@@ -2028,14 +2122,14 @@ static HRESULT video_presenter_init_d3d(struct video_presenter *presenter)
 
     if (FAILED(hr))
     {
-        WARN("Failed to create d3d device, hr %#x.\n", hr);
+        WARN("Failed to create d3d device, hr %#lx.\n", hr);
         return hr;
     }
 
     hr = IDirect3DDeviceManager9_ResetDevice(presenter->device_manager, device, presenter->reset_token);
     IDirect3DDevice9_Release(device);
     if (FAILED(hr))
-        WARN("Failed to set new device for the manager, hr %#x.\n", hr);
+        WARN("Failed to set new device for the manager, hr %#lx.\n", hr);
 
     if (SUCCEEDED(hr = MFCreateVideoSampleAllocator(&IID_IMFVideoSampleAllocator, (void **)&presenter->allocator)))
     {
@@ -2080,7 +2174,7 @@ HRESULT evr_presenter_create(IUnknown *outer, void **out)
 
     if (FAILED(hr = video_presenter_init_d3d(object)))
     {
-        WARN("Failed to initialize d3d device, hr %#x.\n", hr);
+        WARN("Failed to initialize d3d device, hr %#lx.\n", hr);
         goto failed;
     }
 
