@@ -293,7 +293,7 @@ static HRESULT GAMEUX_updateStatisticsFile(struct GAMEUX_STATS *stats)
     SysFreeString(bstrCategory);
     SysFreeString(bstrStatistics);
     SysFreeString(V_BSTR(&vStatsFilePath));
-    TRACE("ret=0x%x\n", hr);
+    TRACE("ret=0x%lx\n", hr);
     return hr;
 }
 /*******************************************************************************
@@ -384,7 +384,7 @@ static HRESULT GAMEUX_getAppIdFromGDFPath(
 
     HeapFree(GetProcessHeap(), 0, lpRegistryPath);
 
-    TRACE("found app id: %s, return: %#x\n", debugstr_w(lpApplicationId), hr);
+    TRACE("found app id: %s, return: %#lx\n", debugstr_w(lpApplicationId), hr);
     return hr;
 }
 /*******************************************************************
@@ -606,7 +606,7 @@ static HRESULT GAMEUX_loadGameStatistics(struct GAMEUX_STATS *pStats,
     if (FAILED(hr)) return hr;
 
     hr = GAMEUX_loadStatisticsFromFile(pStats);
-    TRACE("ldstats finished, res: %#x\n", hr);
+    TRACE("ldstats finished, res: %#lx\n", hr);
     if(hr == S_OK)
     {
         *pOpenResult = GAMESTATS_OPEN_OPENED;
@@ -621,7 +621,7 @@ static HRESULT GAMEUX_loadGameStatistics(struct GAMEUX_STATS *pStats,
     else
         hr = HRESULT_FROM_WIN32(ERROR_FILE_NOT_FOUND);
 
-    TRACE("openResult=%#x ret=%#x\n", *pOpenResult, hr);
+    TRACE("openResult=%#x ret=%#lx\n", *pOpenResult, hr);
     return hr;
 }
  /*******************************************************************
@@ -672,7 +672,7 @@ static ULONG WINAPI GameStatisticsImpl_AddRef(IGameStatistics *iface)
 
     ref = InterlockedIncrement(&This->ref);
 
-    TRACE("(%p): ref=%d\n", This, ref);
+    TRACE("(%p): ref=%ld\n", This, ref);
     return ref;
 }
 
@@ -682,7 +682,7 @@ static ULONG WINAPI GameStatisticsImpl_Release(IGameStatistics *iface)
     LONG ref;
 
     ref = InterlockedDecrement( &This->ref );
-    TRACE("(%p): ref=%d\n", This, ref);
+    TRACE("(%p): ref=%ld\n", This, ref);
 
     if ( ref == 0 )
     {
@@ -1028,7 +1028,7 @@ static ULONG WINAPI GameStatisticsMgrImpl_AddRef(IGameStatisticsMgr *iface)
 
     ref = InterlockedIncrement(&This->ref);
 
-    TRACE("(%p): ref=%d\n", This, ref);
+    TRACE("(%p): ref=%ld\n", This, ref);
     return ref;
 }
 
@@ -1038,7 +1038,7 @@ static ULONG WINAPI GameStatisticsMgrImpl_Release(IGameStatisticsMgr *iface)
     LONG ref;
 
     ref = InterlockedDecrement(&This->ref);
-    TRACE("(%p): ref=%d\n", This, ref);
+    TRACE("(%p): ref=%ld\n", This, ref);
 
     if ( ref == 0 )
     {
