@@ -166,7 +166,7 @@ static HRESULT WINAPI MimeInternat_GetCodePageCharset(IMimeInternational *iface,
     HRESULT hr;
     MIMECPINFO mlang_cp_info;
 
-    TRACE("(%p)->(%d, %d, %p)\n", iface, cpiCodePage, ctCsetType, phCharset);
+    TRACE("(%p)->(%ld, %d, %p)\n", iface, cpiCodePage, ctCsetType, phCharset);
 
     *phCharset = NULL;
 
@@ -315,7 +315,7 @@ static HRESULT WINAPI MimeInternat_CanConvertCodePages(IMimeInternational *iface
     HRESULT hr;
     IMultiLanguage *ml;
 
-    TRACE("(%p)->(%d, %d)\n", iface, cpiSource, cpiDest);
+    TRACE("(%p)->(%ld, %ld)\n", iface, cpiSource, cpiDest);
 
     /* Could call mlang.IsConvertINetStringAvailable() to avoid the COM overhead if need be. */
 
@@ -354,7 +354,7 @@ static HRESULT WINAPI MimeInternat_ConvertBuffer(IMimeInternational *iface, CODE
     HRESULT hr;
     IMultiLanguage *ml;
 
-    TRACE("(%p)->(%d, %d, %p, %p, %p)\n", iface, cpiSource, cpiDest, pIn, pOut, pcbRead);
+    TRACE("(%p)->(%ld, %ld, %p, %p, %p)\n", iface, cpiSource, cpiDest, pIn, pOut, pcbRead);
 
     *pcbRead = 0;
     pOut->cbSize = 0;
@@ -404,7 +404,7 @@ static HRESULT WINAPI MimeInternat_ConvertString(IMimeInternational *iface, CODE
     int src_len;
     IMultiLanguage *ml;
 
-    TRACE("(%p)->(%d, %d, %p %p)\n", iface, cpiSource, cpiDest, pIn, pOut);
+    TRACE("(%p)->(%ld, %ld, %p %p)\n", iface, cpiSource, cpiDest, pIn, pOut);
 
     switch(pIn->vt)
     {
