@@ -83,12 +83,23 @@ void script_release(script_ctx_t *ctx)
     if(ctx->last_match)
         jsstr_release(ctx->last_match);
     assert(!ctx->stack_top);
-    heap_free(ctx->stack);
+    free(ctx->stack);
 
     ctx->jscaller->ctx = NULL;
     IServiceProvider_Release(&ctx->jscaller->IServiceProvider_iface);
 
-    heap_free(ctx);
+    free(ctx);
+}
+
+static void script_globals_release(script_ctx_t *ctx)
+{
+    unsigned i;
+    for(i = 0; i < ARRAY_SIZE(ctx->global_objects); i++) {
+        if(ctx->global_objects[i]) {
+            jsdisp_release(ctx->global_objects[i]);
+            ctx->global_objects[i] = NULL;
+        }
+    }
 }
 
 static void change_state(JScript *This, SCRIPTSTATE state)
@@ -112,7 +123,7 @@ HRESULT create_named_item_script_obj(script_ctx_t *ctx, named_item_t *item)
 {
     static const builtin_info_t disp_info = {
         JSCLASS_GLOBAL,
-        {NULL, NULL, 0},
+        NULL,
         0, NULL,
         NULL,
         NULL
@@ -139,7 +150,7 @@ static HRESULT retrieve_named_item_disp(IActiveScriptSite *site, named_item_t *i
 
     hr = IActiveScriptSite_GetItemInfo(site, item->name, SCRIPTINFO_IUNKNOWN, &unk, NULL);
     if(FAILED(hr)) {
-        WARN("GetItemInfo failed: %08x\n", hr);
+        WARN("GetItemInfo failed: %08lx\n", hr);
         return hr;
     }
 
@@ -181,8 +192,8 @@ void release_named_item(named_item_t *item)
 {
     if(--item->ref) return;
 
-    heap_free(item->name);
-    heap_free(item);
+    free(item->name);
+    free(item);
 }
 
 static inline JScriptError *impl_from_IActiveScriptError(IActiveScriptError *iface)
@@ -215,7 +226,7 @@ static ULONG WINAPI JScriptError_AddRef(IActiveScriptError *iface)
     JScriptError *This = impl_from_IActiveScriptError(iface);
     LONG ref = InterlockedIncrement(&This->ref);
 
-    TRACE("(%p) ref=%d\n", This, ref);
+    TRACE("(%p) ref=%ld\n", This, ref);
 
     return ref;
 }
@@ -225,11 +236,11 @@ static ULONG WINAPI JScriptError_Release(IActiveScriptError *iface)
     JScriptError *This = impl_from_IActiveScriptError(iface);
     LONG ref = InterlockedDecrement(&This->ref);
 
-    TRACE("(%p) ref=%d\n", This, ref);
+    TRACE("(%p) ref=%ld\n", This, ref);
 
     if(!ref) {
         reset_ei(&This->ei);
-        heap_free(This);
+        free(This);
     }
 
     return ref;
@@ -257,8 +268,7 @@ static HRESULT WINAPI JScriptError_GetSourcePosition(IActiveScriptError *iface,
 {
     JScriptError *This = impl_from_IActiveScriptError(iface);
     bytecode_t *code = This->ei.code;
-    const WCHAR *nl, *p;
-    unsigned l;
+    unsigned line_pos, char_pos;
 
     TRACE("(%p)->(%p %p %p)\n", This, source_context, line, character);
 
@@ -272,16 +282,11 @@ static HRESULT WINAPI JScriptError_GetSourcePosition(IActiveScriptError *iface,
     if(!line && !character)
         return S_OK;
 
-    l = code->start_line;
-    for(nl = p = code->source; p < code->source + This->ei.loc; p++) {
-        if(*p != '\n') continue;
-        l++;
-        nl = p + 1;
-    }
+    line_pos = get_location_line(code, This->ei.loc, &char_pos);
     if(line)
-        *line = l;
+        *line = line_pos;
     if(character)
-        *character = code->source + This->ei.loc - nl;
+        *character = char_pos;
     return S_OK;
 }
 
@@ -361,8 +366,8 @@ HRESULT leave_script(script_ctx_t *ctx, HRESULT result)
         ei->error = result;
     }
     if(FAILED(result)) {
-        WARN("%08x\n", result);
-        if(ctx->site && (error = heap_alloc(sizeof(*error)))) {
+        WARN("%08lx\n", result);
+        if(ctx->site && (error = malloc(sizeof(*error)))) {
             HRESULT hres;
 
             error->IActiveScriptError_iface.lpVtbl = &JScriptErrorVtbl;
@@ -489,10 +494,9 @@ static void decrease_state(JScript *This, SCRIPTSTATE state)
                 This->ctx->site = NULL;
             }
 
-            if(This->ctx->global) {
-                jsdisp_release(This->ctx->global);
-                This->ctx->global = NULL;
-            }
+            script_globals_release(This->ctx);
+            gc_run(This->ctx);
+
             /* FALLTHROUGH */
         case SCRIPTSTATE_UNINITIALIZED:
             change_state(This, state);
@@ -556,7 +560,7 @@ static ULONG WINAPI AXSite_AddRef(IServiceProvider *iface)
     AXSite *This = impl_from_IServiceProvider(iface);
     LONG ref = InterlockedIncrement(&This->ref);
 
-    TRACE("(%p) ref=%d\n", This, ref);
+    TRACE("(%p) ref=%ld\n", This, ref);
 
     return ref;
 }
@@ -566,14 +570,14 @@ static ULONG WINAPI AXSite_Release(IServiceProvider *iface)
     AXSite *This = impl_from_IServiceProvider(iface);
     LONG ref = InterlockedDecrement(&This->ref);
 
-    TRACE("(%p) ref=%d\n", This, ref);
+    TRACE("(%p) ref=%ld\n", This, ref);
 
     if(!ref)
     {
         if(This->sp)
             IServiceProvider_Release(This->sp);
 
-        heap_free(This);
+        free(This);
     }
 
     return ref;
@@ -607,10 +611,10 @@ IUnknown *create_ax_site(script_ctx_t *ctx)
 
     hres = IActiveScriptSite_QueryInterface(ctx->site, &IID_IServiceProvider, (void**)&sp);
     if(FAILED(hres)) {
-        TRACE("Could not get IServiceProvider iface: %08x\n", hres);
+        TRACE("Could not get IServiceProvider iface: %08lx\n", hres);
     }
 
-    ret = heap_alloc(sizeof(AXSite));
+    ret = malloc(sizeof(AXSite));
     if(!ret) {
         IServiceProvider_Release(sp);
         return NULL;
@@ -674,7 +678,7 @@ static ULONG WINAPI JScript_AddRef(IActiveScript *iface)
     JScript *This = impl_from_IActiveScript(iface);
     LONG ref = InterlockedIncrement(&This->ref);
 
-    TRACE("(%p) ref=%d\n", This, ref);
+    TRACE("(%p) ref=%ld\n", This, ref);
 
     return ref;
 }
@@ -684,7 +688,7 @@ static ULONG WINAPI JScript_Release(IActiveScript *iface)
     JScript *This = impl_from_IActiveScript(iface);
     LONG ref = InterlockedDecrement(&This->ref);
 
-    TRACE("(%p) ref=%d\n", iface, ref);
+    TRACE("(%p) ref=%ld\n", iface, ref);
 
     if(!ref) {
         if(This->ctx && This->ctx->state != SCRIPTSTATE_CLOSED)
@@ -693,7 +697,7 @@ static ULONG WINAPI JScript_Release(IActiveScript *iface)
             This->ctx->active_script = NULL;
             script_release(This->ctx);
         }
-        heap_free(This);
+        free(This);
         unlock_module();
     }
 
@@ -720,7 +724,7 @@ static HRESULT WINAPI JScript_SetScriptSite(IActiveScript *iface,
         return E_UNEXPECTED;
 
     if(!This->ctx) {
-        script_ctx_t *ctx = heap_alloc_zero(sizeof(script_ctx_t));
+        script_ctx_t *ctx = calloc(1, sizeof(script_ctx_t));
         if(!ctx)
             return E_OUTOFMEMORY;
 
@@ -732,11 +736,12 @@ static HRESULT WINAPI JScript_SetScriptSite(IActiveScript *iface,
         ctx->html_mode = This->html_mode;
         ctx->acc = jsval_undefined();
         list_init(&ctx->named_items);
+        list_init(&ctx->objects);
         heap_pool_init(&ctx->tmp_heap);
 
         hres = create_jscaller(ctx);
         if(FAILED(hres)) {
-            heap_free(ctx);
+            free(ctx);
             return hres;
         }
 
@@ -815,7 +820,7 @@ static HRESULT WINAPI JScript_SetScriptState(IActiveScript *iface, SCRIPTSTATE s
     switch(ss) {
     case SCRIPTSTATE_STARTED:
     case SCRIPTSTATE_CONNECTED: /* FIXME */
-        if(This->ctx->state == SCRIPTSTATE_CLOSED)
+        if(This->ctx->state == SCRIPTSTATE_UNINITIALIZED || This->ctx->state == SCRIPTSTATE_CLOSED)
             return E_UNEXPECTED;
 
         exec_queued_code(This);
@@ -871,7 +876,7 @@ static HRESULT WINAPI JScript_AddNamedItem(IActiveScript *iface,
     IDispatch *disp = NULL;
     HRESULT hres;
 
-    TRACE("(%p)->(%s %x)\n", This, debugstr_w(pstrName), dwFlags);
+    TRACE("(%p)->(%s %lx)\n", This, debugstr_w(pstrName), dwFlags);
 
     if(This->thread_id != GetCurrentThreadId() || !This->ctx || This->ctx->state == SCRIPTSTATE_CLOSED)
         return E_UNEXPECTED;
@@ -881,7 +886,7 @@ static HRESULT WINAPI JScript_AddNamedItem(IActiveScript *iface,
 
         hres = IActiveScriptSite_GetItemInfo(This->site, pstrName, SCRIPTINFO_IUNKNOWN, &unk, NULL);
         if(FAILED(hres)) {
-            WARN("GetItemInfo failed: %08x\n", hres);
+            WARN("GetItemInfo failed: %08lx\n", hres);
             return hres;
         }
 
@@ -893,7 +898,7 @@ static HRESULT WINAPI JScript_AddNamedItem(IActiveScript *iface,
         }
     }
 
-    item = heap_alloc(sizeof(*item));
+    item = malloc(sizeof(*item));
     if(!item) {
         if(disp)
             IDispatch_Release(disp);
@@ -904,11 +909,11 @@ static HRESULT WINAPI JScript_AddNamedItem(IActiveScript *iface,
     item->disp = disp;
     item->flags = dwFlags;
     item->script_obj = NULL;
-    item->name = heap_strdupW(pstrName);
+    item->name = wcsdup(pstrName);
     if(!item->name) {
         if(disp)
             IDispatch_Release(disp);
-        heap_free(item);
+        free(item);
         return E_OUTOFMEMORY;
     }
 
@@ -1055,7 +1060,7 @@ static HRESULT WINAPI JScriptParse_AddScriptlet(IActiveScriptParse *iface,
         BSTR *pbstrName, EXCEPINFO *pexcepinfo)
 {
     JScript *This = impl_from_IActiveScriptParse(iface);
-    FIXME("(%p)->(%s %s %s %s %s %s %s %u %x %p %p)\n", This, debugstr_w(pstrDefaultName),
+    FIXME("(%p)->(%s %s %s %s %s %s %s %lu %lx %p %p)\n", This, debugstr_w(pstrDefaultName),
           debugstr_w(pstrCode), debugstr_w(pstrItemName), debugstr_w(pstrSubItemName),
           debugstr_w(pstrEventName), debugstr_w(pstrDelimiter), wine_dbgstr_longlong(dwSourceContextCookie),
           ulStartingLineNumber, dwFlags, pbstrName, pexcepinfo);
@@ -1073,7 +1078,7 @@ static HRESULT WINAPI JScriptParse_ParseScriptText(IActiveScriptParse *iface,
     jsexcept_t ei;
     HRESULT hres;
 
-    TRACE("(%p)->(%s %s %p %s %s %u %x %p %p)\n", This, debugstr_w(pstrCode),
+    TRACE("(%p)->(%s %s %p %s %s %lu %lx %p %p)\n", This, debugstr_w(pstrCode),
           debugstr_w(pstrItemName), punkContext, debugstr_w(pstrDelimiter),
           wine_dbgstr_longlong(dwSourceContextCookie), ulStartingLine, dwFlags, pvarResult, pexcepinfo);
 
@@ -1176,7 +1181,7 @@ static HRESULT WINAPI JScriptParseProcedure_ParseProcedureText(IActiveScriptPars
     jsexcept_t ei;
     HRESULT hres;
 
-    TRACE("(%p)->(%s %s %s %s %p %s %s %u %x %p)\n", This, debugstr_w(pstrCode), debugstr_w(pstrFormalParams),
+    TRACE("(%p)->(%s %s %s %s %p %s %s %lu %lx %p)\n", This, debugstr_w(pstrCode), debugstr_w(pstrFormalParams),
           debugstr_w(pstrProcedureName), debugstr_w(pstrItemName), punkContext, debugstr_w(pstrDelimiter),
           wine_dbgstr_longlong(dwSourceContextCookie), ulStartingLineNumber, dwFlags, ppdisp);
 
@@ -1195,9 +1200,12 @@ static HRESULT WINAPI JScriptParseProcedure_ParseProcedureText(IActiveScriptPars
     enter_script(This->ctx, &ei);
     hres = compile_script(This->ctx, pstrCode, dwSourceContextCookie, ulStartingLineNumber, pstrFormalParams,
                           pstrDelimiter, FALSE, This->is_encode, item, &code);
-    if(SUCCEEDED(hres))
-        hres = create_source_function(This->ctx, code, &code->global_code, NULL,  &dispex);
+    if(FAILED(hres))
+        return leave_script(This->ctx, hres);
+
+    hres = create_source_function(This->ctx, code, &code->global_code, NULL, &dispex);
     release_bytecode(code);
+
     hres = leave_script(This->ctx, hres);
     if(FAILED(hres))
         return hres;
@@ -1240,7 +1248,7 @@ static HRESULT WINAPI JScriptProperty_GetProperty(IActiveScriptProperty *iface,
         VARIANT *pvarIndex, VARIANT *pvarValue)
 {
     JScript *This = impl_from_IActiveScriptProperty(iface);
-    FIXME("(%p)->(%x %p %p)\n", This, dwProperty, pvarIndex, pvarValue);
+    FIXME("(%p)->(%lx %p %p)\n", This, dwProperty, pvarIndex, pvarValue);
     return E_NOTIMPL;
 }
 
@@ -1249,7 +1257,7 @@ static HRESULT WINAPI JScriptProperty_SetProperty(IActiveScriptProperty *iface,
 {
     JScript *This = impl_from_IActiveScriptProperty(iface);
 
-    TRACE("(%p)->(%x %s %s)\n", This, dwProperty, debugstr_variant(pvarIndex), debugstr_variant(pvarValue));
+    TRACE("(%p)->(%lx %s %s)\n", This, dwProperty, debugstr_variant(pvarIndex), debugstr_variant(pvarValue));
 
     if(pvarIndex)
         FIXME("unsupported pvarIndex\n");
@@ -1266,7 +1274,7 @@ static HRESULT WINAPI JScriptProperty_SetProperty(IActiveScriptProperty *iface,
         This->html_mode = (V_I4(pvarValue) & SCRIPTLANGUAGEVERSION_HTML) != 0;
         break;
     default:
-        FIXME("Unimplemented property %x\n", dwProperty);
+        FIXME("Unimplemented property %lx\n", dwProperty);
         return E_NOTIMPL;
     }
 
@@ -1327,7 +1335,7 @@ static HRESULT WINAPI JScriptSafety_SetInterfaceSafetyOptions(IObjectSafety *ifa
 {
     JScript *This = impl_from_IObjectSafety(iface);
 
-    TRACE("(%p)->(%s %x %x)\n", This, debugstr_guid(riid), dwOptionSetMask, dwEnabledOptions);
+    TRACE("(%p)->(%s %lx %lx)\n", This, debugstr_guid(riid), dwOptionSetMask, dwEnabledOptions);
 
     if(dwOptionSetMask & ~SUPPORTED_OPTIONS)
         return E_FAIL;
@@ -1374,7 +1382,7 @@ static HRESULT WINAPI VariantChangeType_ChangeType(IVariantChangeType *iface, VA
     VARIANT res;
     HRESULT hres;
 
-    TRACE("(%p)->(%p %s %x %s)\n", This, dst, debugstr_variant(src), lcid, debugstr_vt(vt));
+    TRACE("(%p)->(%p %s %lx %s)\n", This, dst, debugstr_variant(src), lcid, debugstr_vt(vt));
 
     if(!This->ctx) {
         FIXME("Object uninitialized\n");
@@ -1409,7 +1417,7 @@ HRESULT create_jscript_object(BOOL is_encode, REFIID riid, void **ppv)
     JScript *ret;
     HRESULT hres;
 
-    ret = heap_alloc_zero(sizeof(*ret));
+    ret = calloc(1, sizeof(*ret));
     if(!ret)
         return E_OUTOFMEMORY;
 
