@@ -303,6 +303,14 @@ void WINAPI DECLSPEC_HOTPATCH RaiseException( DWORD code, DWORD flags, DWORD cou
 }
 __ASM_STDCALL_IMPORT(RaiseException,16)
 
+/*******************************************************************
+ *           RaiseFailFastException  (kernelbase.@)
+ */
+void WINAPI DECLSPEC_HOTPATCH RaiseFailFastException( EXCEPTION_RECORD *record, CONTEXT *context, DWORD flags )
+{
+    FIXME( "(%p, %p, %ld) stub\n", record, context, flags );
+    TerminateProcess( GetCurrentProcess(), STATUS_FAIL_FAST_EXCEPTION );
+}
 
 /***********************************************************************
  *           SetUnhandledExceptionFilter   (kernelbase.@)
@@ -366,14 +374,14 @@ static void format_exception_msg( const EXCEPTION_POINTERS *ptr, char *buffer, i
             len = snprintf( buffer, size, "Unimplemented function %s.%s called",
                             (char *)rec->ExceptionInformation[0], (char *)rec->ExceptionInformation[1] );
         else
-            len = snprintf( buffer, size, "Unimplemented function %s.%ld called",
+            len = snprintf( buffer, size, "Unimplemented function %s.%Id called",
                             (char *)rec->ExceptionInformation[0], rec->ExceptionInformation[1] );
         break;
     case EXCEPTION_WINE_ASSERTION:
         len = snprintf( buffer, size, "Assertion failed" );
         break;
     default:
-        len = snprintf( buffer, size, "Unhandled exception 0x%08x in thread %x",
+        len = snprintf( buffer, size, "Unhandled exception 0x%08lx in thread %lx",
                         rec->ExceptionCode, GetCurrentThreadId());
         break;
     }
@@ -400,7 +408,7 @@ static BOOL start_debugger( EXCEPTION_POINTERS *epointers, HANDLE event )
     char buffer[256];
 
     format_exception_msg( epointers, buffer, sizeof(buffer) );
-    MESSAGE( "wine: %s (thread %04x), starting debugger...\n", buffer, GetCurrentThreadId() );
+    MESSAGE( "wine: %s (thread %04lx), starting debugger...\n", buffer, GetCurrentThreadId() );
 
     attr.Length = sizeof(attr);
     attr.RootDirectory = 0;
@@ -461,13 +469,13 @@ static BOOL start_debugger( EXCEPTION_POINTERS *epointers, HANDLE event )
     {
         size_t format_size = lstrlenW( format ) + 2*20;
         cmdline = HeapAlloc( GetProcessHeap(), 0, format_size * sizeof(WCHAR) );
-        swprintf( cmdline, format_size, format, (long)GetCurrentProcessId(), (long)HandleToLong(event) );
+        swprintf( cmdline, format_size, format, GetCurrentProcessId(), HandleToLong(event) );
         HeapFree( GetProcessHeap(), 0, format );
     }
     else
     {
         cmdline = HeapAlloc( GetProcessHeap(), 0, 80 * sizeof(WCHAR) );
-        swprintf( cmdline, 80, L"winedbg --auto %ld %ld", (long)GetCurrentProcessId(), (long)HandleToLong(event) );
+        swprintf( cmdline, 80, L"winedbg --auto %ld %ld", GetCurrentProcessId(), HandleToLong(event) );
     }
 
     if (!autostart)
@@ -525,7 +533,7 @@ static BOOL start_debugger( EXCEPTION_POINTERS *epointers, HANDLE event )
         WaitForMultipleObjects( 2, handles, FALSE, INFINITE );
         CloseHandle( info.hProcess );
     }
-    else ERR( "Couldn't start debugger %s (%d)\n"
+    else ERR( "Couldn't start debugger %s (%ld)\n"
               "Read the Wine Developers Guide on how to set up winedbg or another debugger\n",
               debugstr_w(cmdline), GetLastError() );
 exit:
@@ -671,7 +679,7 @@ HRESULT WINAPI /* DECLSPEC_HOTPATCH */ WerGetFlags( HANDLE process, DWORD *flags
 HRESULT WINAPI /* DECLSPEC_HOTPATCH */ WerRegisterFile( const WCHAR *file, WER_REGISTER_FILE_TYPE type,
                                                         DWORD flags )
 {
-    FIXME( "(%s, %d, %d) stub\n", debugstr_w(file), type, flags );
+    FIXME( "(%s, %d, %ld) stub\n", debugstr_w(file), type, flags );
     return E_NOTIMPL;
 }
 
@@ -681,7 +689,7 @@ HRESULT WINAPI /* DECLSPEC_HOTPATCH */ WerRegisterFile( const WCHAR *file, WER_R
  */
 HRESULT WINAPI /* DECLSPEC_HOTPATCH */ WerRegisterMemoryBlock( void *block, DWORD size )
 {
-    FIXME( "(%p %d) stub\n", block, size );
+    FIXME( "(%p %ld) stub\n", block, size );
     return E_NOTIMPL;
 }
 
@@ -701,7 +709,7 @@ HRESULT WINAPI /* DECLSPEC_HOTPATCH */ WerRegisterRuntimeExceptionModule( const
  */
 HRESULT WINAPI /* DECLSPEC_HOTPATCH */ WerSetFlags( DWORD flags )
 {
-    FIXME("(%d) stub\n", flags);
+    FIXME("(%ld) stub\n", flags);
     return S_OK;
 }
 
@@ -894,7 +902,7 @@ BOOL WINAPI DECLSPEC_HOTPATCH EmptyWorkingSet( HANDLE process )
  */
 BOOL WINAPI EnumDeviceDrivers( void **image_base, DWORD count, DWORD *needed )
 {
-    FIXME( "(%p, %d, %p): stub\n", image_base, count, needed );
+    FIXME( "(%p, %ld, %p): stub\n", image_base, count, needed );
     if (needed) *needed = 0;
     return TRUE;
 }
@@ -1002,7 +1010,7 @@ BOOL WINAPI DECLSPEC_HOTPATCH EnumProcessModules( HANDLE process, HMODULE *modul
 BOOL WINAPI EnumProcessModulesEx( HANDLE process, HMODULE *module, DWORD count,
                                   DWORD *needed, DWORD filter )
 {
-    FIXME( "(%p, %p, %d, %p, %d) semi-stub\n", process, module, count, needed, filter );
+    FIXME( "(%p, %p, %ld, %p, %ld) semi-stub\n", process, module, count, needed, filter );
     return EnumProcessModules( process, module, count, needed );
 }
 
@@ -1050,7 +1058,7 @@ BOOL WINAPI EnumProcesses( DWORD *ids, DWORD count, DWORD *used )
  */
 DWORD WINAPI DECLSPEC_HOTPATCH GetDeviceDriverBaseNameA( void *image_base, char *name, DWORD size )
 {
-    FIXME( "(%p, %p, %d): stub\n", image_base, name, size );
+    FIXME( "(%p, %p, %ld): stub\n", image_base, name, size );
     if (name && size) name[0] = 0;
     return 0;
 }
@@ -1062,7 +1070,7 @@ DWORD WINAPI DECLSPEC_HOTPATCH GetDeviceDriverBaseNameA( void *image_base, char
  */
 DWORD WINAPI DECLSPEC_HOTPATCH GetDeviceDriverBaseNameW( void *image_base, WCHAR *name, DWORD size )
 {
-    FIXME( "(%p, %p, %d): stub\n", image_base, name, size );
+    FIXME( "(%p, %p, %ld): stub\n", image_base, name, size );
     if (name && size) name[0] = 0;
     return 0;
 }
@@ -1074,7 +1082,7 @@ DWORD WINAPI DECLSPEC_HOTPATCH GetDeviceDriverBaseNameW( void *image_base, WCHAR
  */
 DWORD WINAPI DECLSPEC_HOTPATCH GetDeviceDriverFileNameA( void *image_base, char *name, DWORD size )
 {
-    FIXME( "(%p, %p, %d): stub\n", image_base, name, size );
+    FIXME( "(%p, %p, %ld): stub\n", image_base, name, size );
     if (name && size) name[0] = 0;
     return 0;
 }
@@ -1086,7 +1094,7 @@ DWORD WINAPI DECLSPEC_HOTPATCH GetDeviceDriverFileNameA( void *image_base, char
  */
 DWORD WINAPI DECLSPEC_HOTPATCH GetDeviceDriverFileNameW( void *image_base, WCHAR *name, DWORD size )
 {
-    FIXME( "(%p, %p, %d): stub\n", image_base, name, size );
+    FIXME( "(%p, %p, %ld): stub\n", image_base, name, size );
     if (name && size) name[0] = 0;
     return 0;
 }
@@ -1163,7 +1171,7 @@ DWORD WINAPI DECLSPEC_HOTPATCH GetModuleBaseNameA( HANDLE process, HMODULE modul
     if (!(name_w = HeapAlloc( GetProcessHeap(), 0, sizeof(WCHAR) * size ))) return 0;
 
     len = GetModuleBaseNameW( process, module, name_w, size );
-    TRACE( "%d, %s\n", len, debugstr_w(name_w) );
+    TRACE( "%ld, %s\n", len, debugstr_w(name_w) );
     if (len)
     {
         ret = WideCharToMultiByte( CP_ACP, 0, name_w, len, name, size, NULL, NULL );
@@ -1220,7 +1228,7 @@ DWORD WINAPI DECLSPEC_HOTPATCH GetModuleFileNameExA( HANDLE process, HMODULE mod
     WCHAR *ptr;
     DWORD len;
 
-    TRACE( "(process=%p, module=%p, %p, %d)\n", process, module, name, size );
+    TRACE( "(process=%p, module=%p, %p, %ld)\n", process, module, name, size );
 
     if (!name || !size)
     {
@@ -1352,7 +1360,7 @@ BOOL WINAPI DECLSPEC_HOTPATCH GetPerformanceInfo( PPERFORMANCE_INFORMATION info,
     DWORD info_size;
     NTSTATUS status;
 
-    TRACE( "(%p, %d)\n", info, size );
+    TRACE( "(%p, %ld)\n", info, size );
 
     if (size < sizeof(*info))
     {
@@ -1469,7 +1477,7 @@ BOOL WINAPI DECLSPEC_HOTPATCH GetProcessMemoryInfo( HANDLE process, PROCESS_MEMO
  */
 BOOL WINAPI DECLSPEC_HOTPATCH GetWsChanges( HANDLE process, PSAPI_WS_WATCH_INFORMATION *info, DWORD size )
 {
-    TRACE( "(%p, %p, %d)\n", process, info, size );
+    TRACE( "(%p, %p, %ld)\n", process, info, size );
     return set_ntstatus( NtQueryInformationProcess( process, ProcessWorkingSetWatch, info, size, NULL ));
 }
 
@@ -1504,7 +1512,7 @@ BOOL WINAPI /* DECLSPEC_HOTPATCH */ InitializeProcessForWsWatch( HANDLE process
  */
 BOOL WINAPI DECLSPEC_HOTPATCH QueryWorkingSet( HANDLE process, void *buffer, DWORD size )
 {
-    TRACE( "(%p, %p, %d)\n", process, buffer, size );
+    TRACE( "(%p, %p, %ld)\n", process, buffer, size );
     return set_ntstatus( NtQueryVirtualMemory( process, NULL, MemoryWorkingSetInformation,
                                                buffer, size, NULL ));
 }
@@ -1516,7 +1524,7 @@ BOOL WINAPI DECLSPEC_HOTPATCH QueryWorkingSet( HANDLE process, void *buffer, DWO
  */
 BOOL WINAPI QueryWorkingSetEx( HANDLE process, void *buffer, DWORD size )
 {
-    TRACE( "(%p, %p, %d)\n", process, buffer, size );
+    TRACE( "(%p, %p, %ld)\n", process, buffer, size );
     return set_ntstatus( NtQueryVirtualMemory( process, NULL, MemoryWorkingSetExInformation,
                                                buffer, size, NULL ));
 }
@@ -1567,7 +1575,7 @@ BOOL WINAPI DECLSPEC_HOTPATCH QueryFullProcessImageNameW( HANDLE process, DWORD
 
     if (status) goto cleanup;
 
-    if (flags & PROCESS_NAME_NATIVE)
+    if (flags & PROCESS_NAME_NATIVE && result->Length > 2 * sizeof(WCHAR))
     {
         WCHAR drive[3];
         WCHAR device[1024];
