@@ -78,7 +78,7 @@ static ULONG WINAPI AEV_AddRef(IAudioEndpointVolumeEx *iface)
 {
     AEVImpl *This = impl_from_IAudioEndpointVolumeEx(iface);
     ULONG ref = InterlockedIncrement(&This->ref);
-    TRACE("(%p) new ref %u\n", This, ref);
+    TRACE("(%p) new ref %lu\n", This, ref);
     return ref;
 }
 
@@ -86,7 +86,7 @@ static ULONG WINAPI AEV_Release(IAudioEndpointVolumeEx *iface)
 {
     AEVImpl *This = impl_from_IAudioEndpointVolumeEx(iface);
     ULONG ref = InterlockedDecrement(&This->ref);
-    TRACE("(%p) new ref %u\n", This, ref);
+    TRACE("(%p) new ref %lu\n", This, ref);
     if (!ref)
         AudioEndpointVolume_Destroy(This);
     return ref;
