@@ -122,7 +122,7 @@ static ULONG WINAPI EnumTfInputProcessorProfiles_AddRef(IEnumTfInputProcessorPro
     EnumTfInputProcessorProfiles *This = impl_from_IEnumTfInputProcessorProfiles(iface);
     LONG ref = InterlockedIncrement(&This->ref);
 
-    TRACE("(%p) ref=%d\n", This, ref);
+    TRACE("(%p) ref=%ld\n", This, ref);
 
     return ref;
 }
@@ -132,7 +132,7 @@ static ULONG WINAPI EnumTfInputProcessorProfiles_Release(IEnumTfInputProcessorPr
     EnumTfInputProcessorProfiles *This = impl_from_IEnumTfInputProcessorProfiles(iface);
     LONG ref = InterlockedDecrement(&This->ref);
 
-    TRACE("(%p) ref=%d\n", This, ref);
+    TRACE("(%p) ref=%ld\n", This, ref);
 
     if(!ref)
         HeapFree(GetProcessHeap(), 0, This);
@@ -153,7 +153,7 @@ static HRESULT WINAPI EnumTfInputProcessorProfiles_Next(IEnumTfInputProcessorPro
 {
     EnumTfInputProcessorProfiles *This = impl_from_IEnumTfInputProcessorProfiles(iface);
 
-    FIXME("(%p)->(%u %p %p)\n", This, count, profile, fetch);
+    FIXME("(%p)->(%lu %p %p)\n", This, count, profile, fetch);
 
     if(fetch)
         *fetch = 0;
@@ -170,7 +170,7 @@ static HRESULT WINAPI EnumTfInputProcessorProfiles_Reset(IEnumTfInputProcessorPr
 static HRESULT WINAPI EnumTfInputProcessorProfiles_Skip(IEnumTfInputProcessorProfiles *iface, ULONG count)
 {
     EnumTfInputProcessorProfiles *This = impl_from_IEnumTfInputProcessorProfiles(iface);
-    FIXME("(%p)->(%u)\n", This, count);
+    FIXME("(%p)->(%lu)\n", This, count);
     return E_NOTIMPL;
 }
 
@@ -346,7 +346,7 @@ static HRESULT WINAPI InputProcessorProfiles_AddLanguageProfile(
     static const WCHAR icnf[] = {'I','c','o','n','F','i','l','e',0};
     static const WCHAR icni[] = {'I','c','o','n','I','n','d','e','x',0};
 
-    TRACE("(%p) %s %x %s %s %s %i\n",This,debugstr_guid(rclsid), langid,
+    TRACE("(%p) %s %x %s %s %s %li\n",This,debugstr_guid(rclsid), langid,
             debugstr_guid(guidProfile), debugstr_wn(pchDesc,cchDesc),
             debugstr_wn(pchIconFile,cchFile),uIconIndex);
 
@@ -432,6 +432,7 @@ static HRESULT WINAPI InputProcessorProfiles_GetDefaultLanguageProfile(
     }
     CLSIDFromString(buf,pclsid);
 
+    count = sizeof(buf);
     res = RegQueryValueExW(hkey, szwProfile, 0, NULL, (LPBYTE)buf, &count);
     if (res == ERROR_SUCCESS)
         CLSIDFromString(buf,pguidProfile);
@@ -793,7 +794,7 @@ static HRESULT WINAPI InputProcessorProfileMgr_ActivateProfile(ITfInputProcessor
         LANGID langid, REFCLSID clsid, REFGUID guidProfile, HKL hkl, DWORD dwFlags)
 {
     InputProcessorProfiles *This = impl_from_ITfInputProcessorProfileMgr(iface);
-    FIXME("(%p)->(%d %x %s %s %p %x)\n", This, dwProfileType, langid, debugstr_guid(clsid),
+    FIXME("(%p)->(%ld %x %s %s %p %lx)\n", This, dwProfileType, langid, debugstr_guid(clsid),
           debugstr_guid(guidProfile), hkl, dwFlags);
     return E_NOTIMPL;
 }
@@ -802,7 +803,7 @@ static HRESULT WINAPI InputProcessorProfileMgr_DeactivateProfile(ITfInputProcess
         LANGID langid, REFCLSID clsid, REFGUID guidProfile, HKL hkl, DWORD dwFlags)
 {
     InputProcessorProfiles *This = impl_from_ITfInputProcessorProfileMgr(iface);
-    FIXME("(%p)->(%d %x %s %s %p %x)\n", This, dwProfileType, langid, debugstr_guid(clsid),
+    FIXME("(%p)->(%ld %x %s %s %p %lx)\n", This, dwProfileType, langid, debugstr_guid(clsid),
           debugstr_guid(guidProfile), hkl, dwFlags);
     return E_NOTIMPL;
 }
@@ -811,7 +812,7 @@ static HRESULT WINAPI InputProcessorProfileMgr_GetProfile(ITfInputProcessorProfi
         LANGID langid, REFCLSID clsid, REFGUID guidProfile, HKL hkl, TF_INPUTPROCESSORPROFILE *pProfile)
 {
     InputProcessorProfiles *This = impl_from_ITfInputProcessorProfileMgr(iface);
-    FIXME("(%p)->(%d %x %s %s %p %p)\n", This, dwProfileType, langid, debugstr_guid(clsid),
+    FIXME("(%p)->(%ld %x %s %s %p %p)\n", This, dwProfileType, langid, debugstr_guid(clsid),
           debugstr_guid(guidProfile), hkl, pProfile);
     return E_NOTIMPL;
 }
@@ -839,7 +840,7 @@ static HRESULT WINAPI InputProcessorProfileMgr_ReleaseInputProcessor(ITfInputPro
         DWORD dwFlags)
 {
     InputProcessorProfiles *This = impl_from_ITfInputProcessorProfileMgr(iface);
-    FIXME("(%p)->(%s %x)\n", This, debugstr_guid(rclsid), dwFlags);
+    FIXME("(%p)->(%s %lx)\n", This, debugstr_guid(rclsid), dwFlags);
     return E_NOTIMPL;
 }
 
@@ -849,7 +850,7 @@ static HRESULT WINAPI InputProcessorProfileMgr_RegisterProfile(ITfInputProcessor
         DWORD dwFlags)
 {
     InputProcessorProfiles *This = impl_from_ITfInputProcessorProfileMgr(iface);
-    FIXME("(%p)->(%s %x %s %s %d %s %u %u %p %x %x %x)\n", This, debugstr_guid(rclsid), langid, debugstr_guid(guidProfile),
+    FIXME("(%p)->(%s %x %s %s %ld %s %lu %lu %p %lx %x %lx)\n", This, debugstr_guid(rclsid), langid, debugstr_guid(guidProfile),
           debugstr_w(pchDesc), cchDesc, debugstr_w(pchIconFile), cchFile, uIconIndex, hklsubstitute, dwPreferredLayout,
           bEnabledByDefault, dwFlags);
     return E_NOTIMPL;
@@ -859,7 +860,7 @@ static HRESULT WINAPI InputProcessorProfileMgr_UnregisterProfile(ITfInputProcess
         LANGID langid, REFGUID guidProfile, DWORD dwFlags)
 {
     InputProcessorProfiles *This = impl_from_ITfInputProcessorProfileMgr(iface);
-    FIXME("(%p)->(%s %x %s %x)\n", This, debugstr_guid(rclsid), langid, debugstr_guid(guidProfile), dwFlags);
+    FIXME("(%p)->(%s %x %s %lx)\n", This, debugstr_guid(rclsid), langid, debugstr_guid(guidProfile), dwFlags);
     return E_NOTIMPL;
 }
 
@@ -934,7 +935,7 @@ static HRESULT WINAPI IPPSource_UnadviseSink(ITfSource *iface, DWORD pdwCookie)
 {
     InputProcessorProfiles *This = impl_from_ITfSource(iface);
 
-    TRACE("(%p) %x\n",This,pdwCookie);
+    TRACE("(%p) %lx\n",This,pdwCookie);
 
     if (get_Cookie_magic(pdwCookie)!=COOKIE_MAGIC_IPPSINK)
         return E_INVALIDARG;
