@@ -30,6 +30,9 @@
 
 #include "initguid.h"
 #include "msdasql.h"
+#include "odbcinst.h"
+#include "sqlext.h"
+#include "sqlucode.h"
 
 #include "msdasql_private.h"
 
@@ -37,9 +40,26 @@ WINE_DEFAULT_DEBUG_CHANNEL(msdasql);
 
 DEFINE_GUID(DBPROPSET_DATASOURCEINFO, 0xc8b522bb, 0x5cf3, 0x11ce, 0xad, 0xe5, 0x00, 0xaa, 0x00, 0x44, 0x77, 0x3d);
 DEFINE_GUID(DBPROPSET_DBINIT,    0xc8b522bc, 0x5cf3, 0x11ce, 0xad, 0xe5, 0x00, 0xaa, 0x00, 0x44, 0x77, 0x3d);
+DEFINE_GUID(DBPROPSET_ROWSET,    0xc8b522be, 0x5cf3, 0x11ce, 0xad, 0xe5, 0x00, 0xaa, 0x00, 0x44, 0x77, 0x3d);
 
 DEFINE_GUID(DBGUID_DEFAULT,      0xc8b521fb, 0x5cf3, 0x11ce, 0xad, 0xe5, 0x00, 0xaa, 0x00, 0x44, 0x77, 0x3d);
 
+void dump_sql_diag_records(SQLSMALLINT type, SQLHANDLE handle)
+{
+    SQLCHAR state[6], msg[SQL_MAX_MESSAGE_LENGTH];
+    SQLINTEGER native;
+    SQLSMALLINT i = 1, len;
+
+    if (!TRACE_ON(msdasql))
+        return;
+
+    while(SQLGetDiagRec(type, handle, i, state, &native, msg, sizeof(msg), &len) == SQL_SUCCESS)
+    {
+        WARN("%d: %s: %s\n", i, state, msg);
+        i++;
+    }
+}
+
 static HRESULT WINAPI ClassFactory_QueryInterface(IClassFactory *iface, REFIID riid, void **ppv)
 {
     *ppv = NULL;
@@ -169,7 +189,7 @@ static HRESULT convert_dbproperty_mode(const WCHAR *src, VARIANT *dest)
     {
         V_VT(dest) = VT_I4;
         V_I4(dest) = prop->value;
-        TRACE("%s = %#x\n", debugstr_w(src), prop->value);
+        TRACE("%s = %#lx\n", debugstr_w(src), prop->value);
         return S_OK;
     }
 
@@ -210,6 +230,10 @@ struct msdasql
 
     LONG     ref;
     struct msdasql_prop properties[14];
+
+    /* ODBC Support */
+    HENV henv;
+    HDBC hdbc;
 };
 
 static inline struct msdasql *impl_from_IUnknown(IUnknown *iface)
@@ -280,7 +304,7 @@ static ULONG WINAPI msdsql_AddRef(IUnknown *iface)
     struct msdasql *provider = impl_from_IUnknown(iface);
     ULONG ref = InterlockedIncrement(&provider->ref);
 
-    TRACE("(%p) ref=%u\n", provider, ref);
+    TRACE("(%p) ref=%lu\n", provider, ref);
 
     return ref;
 }
@@ -290,10 +314,14 @@ static ULONG  WINAPI msdsql_Release(IUnknown *iface)
     struct msdasql *provider = impl_from_IUnknown(iface);
     ULONG ref = InterlockedDecrement(&provider->ref);
 
-    TRACE("(%p) ref=%u\n", provider, ref);
+    TRACE("(%p) ref=%lu\n", provider, ref);
 
     if (!ref)
     {
+        SQLDisconnect(provider->hdbc);
+
+        SQLFreeHandle(SQL_HANDLE_DBC, provider->hdbc);
+        SQLFreeHandle(SQL_HANDLE_ENV, provider->henv);
         free(provider);
     }
 
@@ -335,7 +363,7 @@ static HRESULT WINAPI dbprops_GetProperties(IDBProperties *iface, ULONG cPropert
     int i, j, k;
     DBPROPSET *propset;
 
-    TRACE("(%p)->(%d %p %p %p)\n", provider, cPropertyIDSets, rgPropertyIDSets, pcPropertySets, prgPropertySets);
+    TRACE("(%p)->(%ld %p %p %p)\n", provider, cPropertyIDSets, rgPropertyIDSets, pcPropertySets, prgPropertySets);
 
     *pcPropertySets = 1;
 
@@ -370,7 +398,7 @@ static HRESULT WINAPI dbprops_GetProperties(IDBProperties *iface, ULONG cPropert
 
     for (i=0; i < cPropertyIDSets; i++)
     {
-        TRACE("Property id %d (count %d, set %s)\n", i, rgPropertyIDSets[i].cPropertyIDs,
+        TRACE("Property id %d (count %ld, set %s)\n", i, rgPropertyIDSets[i].cPropertyIDs,
                 debugstr_guid(&rgPropertyIDSets[i].guidPropertySet));
 
         propset->cProperties = rgPropertyIDSets[i].cPropertyIDs;
@@ -407,7 +435,7 @@ static HRESULT WINAPI dbprops_GetPropertyInfo(IDBProperties *iface, ULONG cPrope
     int size = 1;
     OLECHAR *ptr;
 
-    TRACE("(%p)->(%d %p %p %p %p)\n", provider, cPropertyIDSets, rgPropertyIDSets, pcPropertyInfoSets,
+    TRACE("(%p)->(%ld %p %p %p %p)\n", provider, cPropertyIDSets, rgPropertyIDSets, pcPropertyInfoSets,
                 prgPropertyInfoSets, ppDescBuffer);
 
     infoset = CoTaskMemAlloc(sizeof(DBPROPINFOSET));
@@ -447,7 +475,7 @@ static HRESULT WINAPI dbprops_SetProperties(IDBProperties *iface, ULONG cPropert
     struct msdasql *provider = impl_from_IDBProperties(iface);
     int i, j, k;
 
-    TRACE("(%p)->(%d %p)\n", provider, cPropertySets, rgPropertySets);
+    TRACE("(%p)->(%ld %p)\n", provider, cPropertySets, rgPropertySets);
 
     for (i=0; i < cPropertySets; i++)
     {
@@ -502,8 +530,33 @@ static ULONG WINAPI dbinit_Release(IDBInitialize *iface)
 static HRESULT WINAPI dbinit_Initialize(IDBInitialize *iface)
 {
     struct msdasql *provider = impl_from_IDBInitialize(iface);
+    int i;
+    SQLRETURN ret;
 
-    FIXME("%p stub\n", provider);
+    FIXME("%p semi-stub\n", provider);
+
+    for(i=0; i < sizeof(provider->properties); i++)
+    {
+        if (provider->properties[i].id == DBPROP_INIT_DATASOURCE)
+            break;
+    }
+
+    if (i >= sizeof(provider->properties))
+    {
+        ERR("Datasource not found\n");
+        return E_FAIL;
+    }
+
+    ret = SQLConnectW( provider->hdbc, (SQLWCHAR *)V_BSTR(&provider->properties[i].value),
+        SQL_NTS, NULL, SQL_NTS, NULL, SQL_NTS );
+    TRACE("SQLConnectW ret %d\n", ret);
+    if (ret != SQL_SUCCESS)
+    {
+        dump_sql_diag_records(SQL_HANDLE_DBC, provider->hdbc);
+
+        if (ret != SQL_SUCCESS_WITH_INFO)
+           return E_FAIL;
+    }
 
     return S_OK;
 }
@@ -559,7 +612,7 @@ static HRESULT WINAPI dbsess_CreateSession(IDBCreateSession *iface, IUnknown *ou
     if (outer)
         FIXME("outer currently not supported.\n");
 
-    hr = create_db_session(riid, &provider->MSDASQL_iface, (void**)session);
+    hr = create_db_session(riid, &provider->MSDASQL_iface, provider->hdbc, (void**)session);
 
     return hr;
 }
@@ -653,6 +706,15 @@ static HRESULT create_msdasql_provider(REFIID riid, void **ppv)
         }
     }
 
+    SQLAllocHandle(SQL_HANDLE_ENV, NULL, &provider->henv );
+    if (SQLSetEnvAttr(provider->henv, SQL_ATTR_ODBC_VERSION, (void *)SQL_OV_ODBC3_80, 0) == SQL_ERROR)
+    {
+        WARN("Falling back to SQL_OV_ODBC3\n");
+        SQLSetEnvAttr(provider->henv, SQL_ATTR_ODBC_VERSION, (void *)SQL_OV_ODBC3, 0);
+    }
+
+    SQLAllocHandle(SQL_HANDLE_DBC, provider->henv, &provider->hdbc);
+
     hr = IUnknown_QueryInterface(&provider->MSDASQL_iface, riid, ppv);
     IUnknown_Release(&provider->MSDASQL_iface);
     return hr;
@@ -696,7 +758,7 @@ static ULONG WINAPI msdasql_enum_AddRef(ISourcesRowset *iface)
     struct msdasql_enum *enumerator = msdasql_enum_from_ISourcesRowset(iface);
     ULONG ref = InterlockedIncrement(&enumerator->ref);
 
-    TRACE("(%p) ref=%u\n", enumerator, ref);
+    TRACE("(%p) ref=%lu\n", enumerator, ref);
 
     return ref;
 }
@@ -706,7 +768,7 @@ static ULONG WINAPI msdasql_enum_Release(ISourcesRowset *iface)
     struct msdasql_enum *enumerator = msdasql_enum_from_ISourcesRowset(iface);
     ULONG ref = InterlockedDecrement(&enumerator->ref);
 
-    TRACE("(%p) ref=%u\n", enumerator, ref);
+    TRACE("(%p) ref=%lu\n", enumerator, ref);
 
     if (!ref)
     {
@@ -764,7 +826,7 @@ static ULONG WINAPI enum_rowset_AddRef(IRowset *iface)
 {
     struct msdasql_enum_rowset *rowset = msdasql_rs_from_IRowset( iface );
     LONG refs = InterlockedIncrement( &rowset->ref );
-    TRACE( "%p new refcount %d\n", rowset, refs );
+    TRACE( "%p new refcount %ld\n", rowset, refs );
     return refs;
 }
 
@@ -772,7 +834,7 @@ static ULONG WINAPI enum_rowset_Release(IRowset *iface)
 {
     struct msdasql_enum_rowset *rowset = msdasql_rs_from_IRowset( iface );
     LONG refs = InterlockedDecrement( &rowset->ref );
-    TRACE( "%p new refcount %d\n", rowset, refs );
+    TRACE( "%p new refcount %ld\n", rowset, refs );
     if (!refs)
     {
         TRACE( "destroying %p\n", rowset );
@@ -786,7 +848,7 @@ static HRESULT WINAPI enum_rowset_AddRefRows(IRowset *iface, DBCOUNTITEM count,
 {
     struct msdasql_enum_rowset *rowset = msdasql_rs_from_IRowset( iface );
 
-    FIXME("%p, %ld, %p, %p, %p\n", rowset, count, rows, ref_counts, status);
+    FIXME("%p, %Iu, %p, %p, %p\n", rowset, count, rows, ref_counts, status);
 
     return E_NOTIMPL;
 }
@@ -795,7 +857,7 @@ static HRESULT WINAPI enum_rowset_GetData(IRowset *iface, HROW row, HACCESSOR ac
 {
     struct msdasql_enum_rowset *rowset = msdasql_rs_from_IRowset( iface );
 
-    FIXME("%p, %ld, %ld, %p\n", rowset, row, accessor, data);
+    FIXME("%p, %Iu, %Iu, %p\n", rowset, row, accessor, data);
 
     return E_NOTIMPL;
 }
@@ -805,7 +867,7 @@ static HRESULT WINAPI enum_rowset_GetNextRows(IRowset *iface, HCHAPTER reserved,
 {
     struct msdasql_enum_rowset *rowset = msdasql_rs_from_IRowset( iface );
 
-    FIXME("%p, %ld, %ld, %ld, %p, %p\n", rowset, reserved, offset, count, obtained, rows);
+    FIXME("%p, %Iu, %Iu, %Iu, %p, %p\n", rowset, reserved, offset, count, obtained, rows);
 
     if (!obtained || !rows)
         return E_INVALIDARG;
@@ -823,7 +885,7 @@ static HRESULT WINAPI enum_rowset_ReleaseRows(IRowset *iface, DBCOUNTITEM count,
 {
     struct msdasql_enum_rowset *rowset = msdasql_rs_from_IRowset( iface );
 
-    FIXME("%p, %ld, %p, %p, %p, %p\n", rowset, count, rows, options, ref_counts, status);
+    FIXME("%p, %Iu, %p, %p, %p, %p\n", rowset, count, rows, options, ref_counts, status);
 
     return S_OK;
 }
@@ -832,7 +894,7 @@ static HRESULT WINAPI enum_rowset_RestartPosition(IRowset *iface, HCHAPTER reser
 {
     struct msdasql_enum_rowset *rowset = msdasql_rs_from_IRowset( iface );
 
-    FIXME("%p, %ld\n", rowset, reserved);
+    FIXME("%p, %Iu\n", rowset, reserved);
 
     return S_OK;
 }
@@ -870,7 +932,7 @@ static ULONG  WINAPI enum_rs_accessor_Release(IAccessor *iface)
 static HRESULT WINAPI enum_rs_accessor_AddRefAccessor(IAccessor *iface, HACCESSOR accessor, DBREFCOUNT *count)
 {
     struct msdasql_enum_rowset *rowset = msdasql_enum_from_IAccessor( iface );
-    FIXME("%p, %lu, %p\n", rowset, accessor, count);
+    FIXME("%p, %Iu, %p\n", rowset, accessor, count);
     return E_NOTIMPL;
 }
 
@@ -880,7 +942,7 @@ static HRESULT WINAPI enum_rs_accessor_CreateAccessor(IAccessor *iface, DBACCESS
 {
     struct msdasql_enum_rowset *rowset = msdasql_enum_from_IAccessor( iface );
 
-    FIXME("%p 0x%08x, %lu, %p, %lu, %p, %p\n", rowset, flags, count, bindings, row_size, accessor, status);
+    FIXME("%p 0x%08lx, %Iu, %p, %Iu, %p, %p\n", rowset, flags, count, bindings, row_size, accessor, status);
 
     if (accessor)
         *accessor = 0xdeadbeef;
@@ -892,7 +954,7 @@ static HRESULT WINAPI enum_rs_accessor_GetBindings(IAccessor *iface, HACCESSOR a
         DBACCESSORFLAGS *flags, DBCOUNTITEM *count, DBBINDING **bindings)
 {
     struct msdasql_enum_rowset *rowset = msdasql_enum_from_IAccessor( iface );
-    FIXME("%p %lu, %p, %p, %p\n", rowset, accessor, flags, count, bindings);
+    FIXME("%p, %Iu, %p, %p, %p\n", rowset, accessor, flags, count, bindings);
     return E_NOTIMPL;
 }
 
@@ -900,7 +962,7 @@ static HRESULT WINAPI enum_rs_accessor_ReleaseAccessor(IAccessor *iface, HACCESS
 {
     struct msdasql_enum_rowset *rowset = msdasql_enum_from_IAccessor( iface );
 
-    FIXME("%p, %lu, %p\n", rowset, accessor, count);
+    FIXME("%p, %Iu, %p\n", rowset, accessor, count);
 
     if (count)
         *count = 0;
@@ -926,7 +988,7 @@ static HRESULT WINAPI msdasql_enum_GetSourcesRowset(ISourcesRowset *iface, IUnkn
     struct msdasql_enum_rowset *enum_rs;
     HRESULT hr;
 
-    TRACE("(%p) %p, %s, %d, %p, %p\n", enumerator, outer, debugstr_guid(riid), sets, properties, rowset);
+    TRACE("(%p) %p, %s, %lu, %p, %p\n", enumerator, outer, debugstr_guid(riid), sets, properties, rowset);
 
     enum_rs = malloc(sizeof(*enum_rs));
     enum_rs->IRowset_iface.lpVtbl = &enum_rowset_vtbl;
