@@ -592,7 +592,7 @@ static HRESULT WINAPI HTMLCurrentStyle_getAttribute(IHTMLCurrentStyle *iface, BS
         LONG lFlags, VARIANT *AttributeValue)
 {
     HTMLCurrentStyle *This = impl_from_IHTMLCurrentStyle(iface);
-    FIXME("(%p)->(%s %x %p)\n", This, debugstr_w(strAttributeName), lFlags, AttributeValue);
+    FIXME("(%p)->(%s %lx %p)\n", This, debugstr_w(strAttributeName), lFlags, AttributeValue);
     return E_NOTIMPL;
 }
 
@@ -1316,14 +1316,14 @@ HRESULT HTMLCurrentStyle_Create(HTMLElement *elem, IHTMLCurrentStyle **p)
     HTMLCurrentStyle *ret;
     nsresult nsres;
 
-    if(!elem->node.doc->nsdoc)  {
-        WARN("NULL nsdoc\n");
+    if(!elem->node.doc->dom_document)  {
+        WARN("NULL dom_document\n");
         return E_UNEXPECTED;
     }
 
-    nsres = nsIDOMHTMLDocument_GetDefaultView(elem->node.doc->nsdoc, &nsview);
+    nsres = nsIDOMDocument_GetDefaultView(elem->node.doc->dom_document, &nsview);
     if(NS_FAILED(nsres)) {
-        ERR("GetDefaultView failed: %08x\n", nsres);
+        ERR("GetDefaultView failed: %08lx\n", nsres);
         return E_FAIL;
     }
 
@@ -1336,7 +1336,7 @@ HRESULT HTMLCurrentStyle_Create(HTMLElement *elem, IHTMLCurrentStyle **p)
     nsAString_Finish(&nsempty_str);
     nsIDOMWindow_Release(nswindow);
     if(NS_FAILED(nsres)) {
-        ERR("GetComputedStyle failed: %08x\n", nsres);
+        ERR("GetComputedStyle failed: %08lx\n", nsres);
         return E_FAIL;
     }
 
@@ -1345,7 +1345,7 @@ HRESULT HTMLCurrentStyle_Create(HTMLElement *elem, IHTMLCurrentStyle **p)
         return E_FAIL;
     }
 
-    ret = heap_alloc_zero(sizeof(HTMLCurrentStyle));
+    ret = calloc(1, sizeof(HTMLCurrentStyle));
     if(!ret) {
         nsIDOMCSSStyleDeclaration_Release(nsstyle);
         return E_OUTOFMEMORY;
