@@ -68,7 +68,7 @@ static void elem_vector_add(elem_vector_t *buf, HTMLElement *elem)
 {
     if(buf->len == buf->size) {
         buf->size <<= 1;
-        buf->buf = heap_realloc(buf->buf, buf->size*sizeof(HTMLElement*));
+        buf->buf = realloc(buf->buf, buf->size * sizeof(HTMLElement*));
     }
 
     buf->buf[buf->len++] = elem;
@@ -77,10 +77,10 @@ static void elem_vector_add(elem_vector_t *buf, HTMLElement *elem)
 static void elem_vector_normalize(elem_vector_t *buf)
 {
     if(!buf->len) {
-        heap_free(buf->buf);
+        free(buf->buf);
         buf->buf = NULL;
     }else if(buf->size > buf->len) {
-        buf->buf = heap_realloc(buf->buf, buf->len*sizeof(HTMLElement*));
+        buf->buf = realloc(buf->buf, buf->len*sizeof(HTMLElement*));
     }
 
     buf->size = buf->len;
@@ -125,7 +125,7 @@ static ULONG WINAPI HTMLElementCollectionEnum_AddRef(IEnumVARIANT *iface)
     HTMLElementCollectionEnum *This = impl_from_IEnumVARIANT(iface);
     LONG ref = InterlockedIncrement(&This->ref);
 
-    TRACE("(%p) ref=%d\n", This, ref);
+    TRACE("(%p) ref=%ld\n", This, ref);
 
     return ref;
 }
@@ -135,11 +135,11 @@ static ULONG WINAPI HTMLElementCollectionEnum_Release(IEnumVARIANT *iface)
     HTMLElementCollectionEnum *This = impl_from_IEnumVARIANT(iface);
     LONG ref = InterlockedDecrement(&This->ref);
 
-    TRACE("(%p) ref=%d\n", This, ref);
+    TRACE("(%p) ref=%ld\n", This, ref);
 
     if(!ref) {
         IHTMLElementCollection_Release(&This->col->IHTMLElementCollection_iface);
-        heap_free(This);
+        free(This);
     }
 
     return ref;
@@ -150,7 +150,7 @@ static HRESULT WINAPI HTMLElementCollectionEnum_Next(IEnumVARIANT *iface, ULONG
     HTMLElementCollectionEnum *This = impl_from_IEnumVARIANT(iface);
     ULONG fetched = 0;
 
-    TRACE("(%p)->(%d %p %p)\n", This, celt, rgVar, pCeltFetched);
+    TRACE("(%p)->(%ld %p %p)\n", This, celt, rgVar, pCeltFetched);
 
     while(This->iter+fetched < This->col->len && fetched < celt) {
         V_VT(rgVar+fetched) = VT_DISPATCH;
@@ -169,7 +169,7 @@ static HRESULT WINAPI HTMLElementCollectionEnum_Skip(IEnumVARIANT *iface, ULONG
 {
     HTMLElementCollectionEnum *This = impl_from_IEnumVARIANT(iface);
 
-    TRACE("(%p)->(%d)\n", This, celt);
+    TRACE("(%p)->(%ld)\n", This, celt);
 
     if(This->iter + celt > This->col->len) {
         This->iter = This->col->len;
@@ -240,7 +240,7 @@ static ULONG WINAPI HTMLElementCollection_AddRef(IHTMLElementCollection *iface)
     HTMLElementCollection *This = impl_from_IHTMLElementCollection(iface);
     LONG ref = InterlockedIncrement(&This->ref);
 
-    TRACE("(%p) ref=%d\n", This, ref);
+    TRACE("(%p) ref=%ld\n", This, ref);
 
     return ref;
 }
@@ -250,17 +250,17 @@ static ULONG WINAPI HTMLElementCollection_Release(IHTMLElementCollection *iface)
     HTMLElementCollection *This = impl_from_IHTMLElementCollection(iface);
     LONG ref = InterlockedDecrement(&This->ref);
 
-    TRACE("(%p) ref=%d\n", This, ref);
+    TRACE("(%p) ref=%ld\n", This, ref);
 
     if(!ref) {
         unsigned i;
 
         for(i=0; i < This->len; i++)
             node_release(&This->elems[i]->node);
-        heap_free(This->elems);
+        free(This->elems);
 
         release_dispex(&This->dispex);
-        heap_free(This);
+        free(This);
     }
 
     return ref;
@@ -311,7 +311,7 @@ static HRESULT WINAPI HTMLElementCollection_put_length(IHTMLElementCollection *i
                                                        LONG v)
 {
     HTMLElementCollection *This = impl_from_IHTMLElementCollection(iface);
-    FIXME("(%p)->(%d)\n", This, v);
+    FIXME("(%p)->(%ld)\n", This, v);
     return E_NOTIMPL;
 }
 
@@ -334,7 +334,7 @@ static HRESULT WINAPI HTMLElementCollection_get__newEnum(IHTMLElementCollection
 
     TRACE("(%p)->(%p)\n", This, p);
 
-    ret = heap_alloc(sizeof(*ret));
+    ret = malloc(sizeof(*ret));
     if(!ret)
         return E_OUTOFMEMORY;
 
@@ -356,7 +356,7 @@ static BOOL is_elem_id(HTMLElement *elem, LPCWSTR name)
 
     hres = IHTMLElement_get_id(&elem->IHTMLElement_iface, &elem_id);
     if(FAILED(hres)){
-        WARN("IHTMLElement_get_id failed: 0x%08x\n", hres);
+        WARN("IHTMLElement_get_id failed: 0x%08lx\n", hres);
         return FALSE;
     }
 
@@ -450,7 +450,7 @@ static HRESULT WINAPI HTMLElementCollection_item(IHTMLElementCollection *iface,
         }else {
             elem_vector_t buf = {NULL, 0, 8};
 
-            buf.buf = heap_alloc(buf.size*sizeof(HTMLElement*));
+            buf.buf = malloc(buf.size * sizeof(HTMLElement*));
 
             for(i=0; i<This->len; i++) {
                 if(is_elem_name(This->elems[i], V_BSTR(&name))) {
@@ -469,7 +469,7 @@ static HRESULT WINAPI HTMLElementCollection_item(IHTMLElementCollection *iface,
                     *pdisp = (IDispatch*)&buf.buf[0]->IHTMLElement_iface;
                 }
 
-                heap_free(buf.buf);
+                free(buf.buf);
             }
         }
         break;
@@ -501,7 +501,7 @@ static HRESULT WINAPI HTMLElementCollection_tags(IHTMLElementCollection *iface,
 
     TRACE("(%p)->(%s %p)\n", This, debugstr_w(V_BSTR(&tagName)), pdisp);
 
-    buf.buf = heap_alloc(buf.size*sizeof(HTMLElement*));
+    buf.buf = malloc(buf.size * sizeof(HTMLElement*));
 
     nsAString_Init(&tag_str, NULL);
 
@@ -522,7 +522,7 @@ static HRESULT WINAPI HTMLElementCollection_tags(IHTMLElementCollection *iface,
     nsAString_Finish(&tag_str);
     elem_vector_normalize(&buf);
 
-    TRACE("found %d tags\n", buf.len);
+    TRACE("found %ld tags\n", buf.len);
 
     *pdisp = (IDispatch*)HTMLElementCollection_Create(buf.buf, buf.len,
                                                       dispex_compat_mode(&This->dispex));
@@ -577,21 +577,35 @@ static HRESULT HTMLElementCollection_get_dispid(DispatchEx *dispex, BSTR name, D
         return DISP_E_UNKNOWNNAME;
 
     *dispid = DISPID_ELEMCOL_0 + idx;
-    TRACE("ret %x\n", *dispid);
+    TRACE("ret %lx\n", *dispid);
     return S_OK;
 }
 
+static HRESULT HTMLElementCollection_get_name(DispatchEx *dispex, DISPID id, BSTR *name)
+{
+    HTMLElementCollection *This = impl_from_DispatchEx(dispex);
+    DWORD idx = id - MSHTML_DISPID_CUSTOM_MIN;
+    WCHAR buf[11];
+    UINT len;
+
+    if(idx >= This->len)
+        return DISP_E_MEMBERNOTFOUND;
+
+    len = swprintf(buf, ARRAY_SIZE(buf), L"%u", idx);
+    return (*name = SysAllocStringLen(buf, len)) ? S_OK : E_OUTOFMEMORY;
+}
+
 static HRESULT HTMLElementCollection_invoke(DispatchEx *dispex, DISPID id, LCID lcid, WORD flags, DISPPARAMS *params,
         VARIANT *res, EXCEPINFO *ei, IServiceProvider *caller)
 {
     HTMLElementCollection *This = impl_from_DispatchEx(dispex);
     DWORD idx;
 
-    TRACE("(%p)->(%x %x %x %p %p %p %p)\n", This, id, lcid, flags, params, res, ei, caller);
+    TRACE("(%p)->(%lx %lx %x %p %p %p %p)\n", This, id, lcid, flags, params, res, ei, caller);
 
     idx = id - DISPID_ELEMCOL_0;
     if(idx >= This->len)
-        return DISP_E_UNKNOWNNAME;
+        return DISP_E_MEMBERNOTFOUND;
 
     switch(flags) {
     case DISPATCH_PROPERTYGET:
@@ -610,6 +624,7 @@ static HRESULT HTMLElementCollection_invoke(DispatchEx *dispex, DISPID id, LCID
 static const dispex_static_data_vtbl_t HTMLElementColection_dispex_vtbl = {
     NULL,
     HTMLElementCollection_get_dispid,
+    HTMLElementCollection_get_name,
     HTMLElementCollection_invoke,
     NULL
 };
@@ -636,7 +651,7 @@ static void create_all_list(HTMLDOMNode *elem, elem_vector_t *buf)
 
     nsres = nsIDOMNode_GetChildNodes(elem->nsnode, &nsnode_list);
     if(NS_FAILED(nsres)) {
-        ERR("GetChildNodes failed: %08x\n", nsres);
+        ERR("GetChildNodes failed: %08lx\n", nsres);
         return;
     }
 
@@ -647,7 +662,7 @@ static void create_all_list(HTMLDOMNode *elem, elem_vector_t *buf)
     for(i=0; i<list_len; i++) {
         nsres = nsIDOMNodeList_Item(nsnode_list, i, &iter);
         if(NS_FAILED(nsres)) {
-            ERR("Item failed: %08x\n", nsres);
+            ERR("Item failed: %08lx\n", nsres);
             continue;
         }
 
@@ -656,7 +671,7 @@ static void create_all_list(HTMLDOMNode *elem, elem_vector_t *buf)
 
             hres = get_node(iter, TRUE, &node);
             if(FAILED(hres)) {
-                FIXME("get_node failed: %08x\n", hres);
+                FIXME("get_node failed: %08lx\n", hres);
                 continue;
             }
 
@@ -670,7 +685,7 @@ IHTMLElementCollection *create_all_collection(HTMLDOMNode *node, BOOL include_ro
 {
     elem_vector_t buf = {NULL, 0, 8};
 
-    buf.buf = heap_alloc(buf.size*sizeof(HTMLElement*));
+    buf.buf = malloc(buf.size * sizeof(HTMLElement*));
 
     if(include_root) {
         node_addref(node);
@@ -697,7 +712,7 @@ IHTMLElementCollection *create_collection_from_nodelist(nsIDOMNodeList *nslist,
     if(length) {
         nsIDOMNode *nsnode;
 
-        buf.buf = heap_alloc(buf.size*sizeof(HTMLElement*));
+        buf.buf = malloc(buf.size * sizeof(HTMLElement*));
 
         for(i=0; i<length; i++) {
             nsIDOMNodeList_Item(nslist, i, &nsnode);
@@ -732,7 +747,7 @@ IHTMLElementCollection *create_collection_from_htmlcol(nsIDOMHTMLCollection *nsc
     if(buf.len) {
         nsIDOMNode *nsnode;
 
-        buf.buf = heap_alloc(buf.size*sizeof(HTMLElement*));
+        buf.buf = malloc(buf.size * sizeof(HTMLElement*));
 
         for(i=0; i<length; i++) {
             nsIDOMHTMLCollection_Item(nscol, i, &nsnode);
@@ -747,7 +762,7 @@ IHTMLElementCollection *create_collection_from_htmlcol(nsIDOMHTMLCollection *nsc
     }
 
     if(FAILED(hres)) {
-        heap_free(buf.buf);
+        free(buf.buf);
         return NULL;
     }
 
@@ -799,7 +814,7 @@ HRESULT get_elem_source_index(HTMLElement *elem, LONG *ret)
 
     /* Create all children collection and find the element in it.
      * This could be optimized if we ever find the reason. */
-    buf.buf = heap_alloc(buf.size*sizeof(*buf.buf));
+    buf.buf = malloc(buf.size * sizeof(*buf.buf));
     if(!buf.buf) {
         IHTMLDOMNode_Release(&node->IHTMLDOMNode_iface);
         return E_OUTOFMEMORY;
@@ -812,7 +827,7 @@ HRESULT get_elem_source_index(HTMLElement *elem, LONG *ret)
             break;
     }
     IHTMLDOMNode_Release(&node->IHTMLDOMNode_iface);
-    heap_free(buf.buf);
+    free(buf.buf);
     if(i == buf.len) {
         FIXME("The element is not in parent's child list?\n");
         return E_UNEXPECTED;
@@ -825,7 +840,7 @@ HRESULT get_elem_source_index(HTMLElement *elem, LONG *ret)
 static IHTMLElementCollection *HTMLElementCollection_Create(HTMLElement **elems, DWORD len,
                                                             compat_mode_t compat_mode)
 {
-    HTMLElementCollection *ret = heap_alloc_zero(sizeof(HTMLElementCollection));
+    HTMLElementCollection *ret = calloc(1, sizeof(HTMLElementCollection));
 
     if (!ret)
         return NULL;
@@ -838,7 +853,7 @@ static IHTMLElementCollection *HTMLElementCollection_Create(HTMLElement **elems,
     init_dispatch(&ret->dispex, (IUnknown*)&ret->IHTMLElementCollection_iface,
                   &HTMLElementCollection_dispex, compat_mode);
 
-    TRACE("ret=%p len=%d\n", ret, len);
+    TRACE("ret=%p len=%ld\n", ret, len);
 
     return &ret->IHTMLElementCollection_iface;
 }
