@@ -127,7 +127,7 @@ static HRESULT WINAPI HTMLInputElement_put_type(IHTMLInputElement *iface, BSTR v
     nsres = nsIDOMHTMLInputElement_SetType(This->nsinput, &type_str);
     nsAString_Finish(&type_str);
     if(NS_FAILED(nsres)) {
-        ERR("SetType failed: %08x\n", nsres);
+        ERR("SetType failed: %08lx\n", nsres);
         return E_FAIL;
     }
 
@@ -159,7 +159,7 @@ static HRESULT WINAPI HTMLInputElement_put_value(IHTMLInputElement *iface, BSTR
     nsres = nsIDOMHTMLInputElement_SetValue(This->nsinput, &val_str);
     nsAString_Finish(&val_str);
     if(NS_FAILED(nsres))
-        ERR("SetValue failed: %08x\n", nsres);
+        ERR("SetValue failed: %08lx\n", nsres);
 
     return S_OK;
 }
@@ -189,7 +189,7 @@ static HRESULT WINAPI HTMLInputElement_put_name(IHTMLInputElement *iface, BSTR v
     nsres = nsIDOMHTMLInputElement_SetName(This->nsinput, &name_str);
     nsAString_Finish(&name_str);
     if(NS_FAILED(nsres)) {
-        ERR("SetName failed: %08x\n", nsres);
+        ERR("SetName failed: %08lx\n", nsres);
         return E_FAIL;
     }
 
@@ -232,7 +232,7 @@ static HRESULT WINAPI HTMLInputElement_put_disabled(IHTMLInputElement *iface, VA
 
     nsres = nsIDOMHTMLInputElement_SetDisabled(This->nsinput, v != VARIANT_FALSE);
     if(NS_FAILED(nsres))
-        ERR("SetDisabled failed: %08x\n", nsres);
+        ERR("SetDisabled failed: %08lx\n", nsres);
 
     return S_OK;
 }
@@ -268,13 +268,13 @@ static HRESULT WINAPI HTMLInputElement_put_size(IHTMLInputElement *iface, LONG v
     UINT32 val = v;
     nsresult nsres;
 
-    TRACE("(%p)->(%d)\n", This, v);
+    TRACE("(%p)->(%ld)\n", This, v);
     if (v <= 0)
         return CTL_E_INVALIDPROPERTYVALUE;
 
     nsres = nsIDOMHTMLInputElement_SetSize(This->nsinput, val);
     if (NS_FAILED(nsres)) {
-        ERR("Set Size(%u) failed: %08x\n", val, nsres);
+        ERR("Set Size(%u) failed: %08lx\n", val, nsres);
         return E_FAIL;
     }
     return S_OK;
@@ -292,7 +292,7 @@ static HRESULT WINAPI HTMLInputElement_get_size(IHTMLInputElement *iface, LONG *
 
     nsres = nsIDOMHTMLInputElement_GetSize(This->nsinput, &val);
     if (NS_FAILED(nsres)) {
-        ERR("Get Size failed: %08x\n", nsres);
+        ERR("Get Size failed: %08lx\n", nsres);
         return E_FAIL;
     }
     *p = val;
@@ -304,7 +304,7 @@ static HRESULT WINAPI HTMLInputElement_put_maxLength(IHTMLInputElement *iface, L
     HTMLInputElement *This = impl_from_IHTMLInputElement(iface);
     nsresult nsres;
 
-    TRACE("(%p)->(%d)\n", This, v);
+    TRACE("(%p)->(%ld)\n", This, v);
 
     nsres = nsIDOMHTMLInputElement_SetMaxLength(This->nsinput, v);
     if(NS_FAILED(nsres)) {
@@ -341,7 +341,7 @@ static HRESULT WINAPI HTMLInputElement_select(IHTMLInputElement *iface)
 
     nsres = nsIDOMHTMLInputElement_Select(This->nsinput);
     if(NS_FAILED(nsres)) {
-        ERR("Select failed: %08x\n", nsres);
+        ERR("Select failed: %08lx\n", nsres);
         return E_FAIL;
     }
 
@@ -392,7 +392,7 @@ static HRESULT WINAPI HTMLInputElement_put_defaultValue(IHTMLInputElement *iface
     nsres = nsIDOMHTMLInputElement_SetDefaultValue(This->nsinput, &nsstr);
     nsAString_Finish(&nsstr);
     if(NS_FAILED(nsres)) {
-        ERR("SetValue failed: %08x\n", nsres);
+        ERR("SetValue failed: %08lx\n", nsres);
         return E_FAIL;
     }
 
@@ -421,7 +421,7 @@ static HRESULT WINAPI HTMLInputElement_put_readOnly(IHTMLInputElement *iface, VA
 
     nsres = nsIDOMHTMLInputElement_SetReadOnly(This->nsinput, v != VARIANT_FALSE);
     if (NS_FAILED(nsres)) {
-        ERR("Set ReadOnly Failed: %08x\n", nsres);
+        ERR("Set ReadOnly Failed: %08lx\n", nsres);
         return E_FAIL;
     }
     return S_OK;
@@ -437,7 +437,7 @@ static HRESULT WINAPI HTMLInputElement_get_readOnly(IHTMLInputElement *iface, VA
 
     nsres = nsIDOMHTMLInputElement_GetReadOnly(This->nsinput, &b);
     if (NS_FAILED(nsres)) {
-        ERR("Get ReadOnly Failed: %08x\n", nsres);
+        ERR("Get ReadOnly Failed: %08lx\n", nsres);
         return E_FAIL;
     }
 
@@ -475,7 +475,7 @@ static HRESULT WINAPI HTMLInputElement_put_defaultChecked(IHTMLInputElement *ifa
 
     nsres = nsIDOMHTMLInputElement_SetDefaultChecked(This->nsinput, v != VARIANT_FALSE);
     if(NS_FAILED(nsres)) {
-        ERR("SetDefaultChecked failed: %08x\n", nsres);
+        ERR("SetDefaultChecked failed: %08lx\n", nsres);
         return E_FAIL;
     }
 
@@ -492,7 +492,7 @@ static HRESULT WINAPI HTMLInputElement_get_defaultChecked(IHTMLInputElement *ifa
 
     nsres = nsIDOMHTMLInputElement_GetDefaultChecked(This->nsinput, &default_checked);
     if(NS_FAILED(nsres)) {
-        ERR("GetDefaultChecked failed: %08x\n", nsres);
+        ERR("GetDefaultChecked failed: %08lx\n", nsres);
         return E_FAIL;
     }
 
@@ -509,7 +509,7 @@ static HRESULT WINAPI HTMLInputElement_put_checked(IHTMLInputElement *iface, VAR
 
     nsres = nsIDOMHTMLInputElement_SetChecked(This->nsinput, v != VARIANT_FALSE);
     if(NS_FAILED(nsres)) {
-        ERR("SetChecked failed: %08x\n", nsres);
+        ERR("SetChecked failed: %08lx\n", nsres);
         return E_FAIL;
     }
 
@@ -526,7 +526,7 @@ static HRESULT WINAPI HTMLInputElement_get_checked(IHTMLInputElement *iface, VAR
 
     nsres = nsIDOMHTMLInputElement_GetChecked(This->nsinput, &checked);
     if(NS_FAILED(nsres)) {
-        ERR("GetChecked failed: %08x\n", nsres);
+        ERR("GetChecked failed: %08lx\n", nsres);
         return E_FAIL;
     }
 
@@ -552,7 +552,7 @@ static HRESULT WINAPI HTMLInputElement_get_border(IHTMLInputElement *iface, VARI
 static HRESULT WINAPI HTMLInputElement_put_vspace(IHTMLInputElement *iface, LONG v)
 {
     HTMLInputElement *This = impl_from_IHTMLInputElement(iface);
-    FIXME("(%p)->(%d)\n", This, v);
+    FIXME("(%p)->(%ld)\n", This, v);
     return E_NOTIMPL;
 }
 
@@ -566,7 +566,7 @@ static HRESULT WINAPI HTMLInputElement_get_vspace(IHTMLInputElement *iface, LONG
 static HRESULT WINAPI HTMLInputElement_put_hspace(IHTMLInputElement *iface, LONG v)
 {
     HTMLInputElement *This = impl_from_IHTMLInputElement(iface);
-    FIXME("(%p)->(%d)\n", This, v);
+    FIXME("(%p)->(%ld)\n", This, v);
     return E_NOTIMPL;
 }
 
@@ -603,7 +603,7 @@ static HRESULT WINAPI HTMLInputElement_put_src(IHTMLInputElement *iface, BSTR v)
     nsres = nsIDOMHTMLInputElement_SetSrc(This->nsinput, &nsstr);
     nsAString_Finish(&nsstr);
     if(NS_FAILED(nsres))
-        ERR("SetSrc failed: %08x\n", nsres);
+        ERR("SetSrc failed: %08lx\n", nsres);
 
     return S_OK;
 }
@@ -621,7 +621,7 @@ static HRESULT WINAPI HTMLInputElement_get_src(IHTMLInputElement *iface, BSTR *p
     nsAString_Init(&src_str, NULL);
     nsres = nsIDOMHTMLInputElement_GetSrc(This->nsinput, &src_str);
     if(NS_FAILED(nsres)) {
-        ERR("GetSrc failed: %08x\n", nsres);
+        ERR("GetSrc failed: %08lx\n", nsres);
         return E_FAIL;
     }
 
@@ -719,15 +719,19 @@ static HRESULT WINAPI HTMLInputElement_get_align(IHTMLInputElement *iface, BSTR
 static HRESULT WINAPI HTMLInputElement_put_onload(IHTMLInputElement *iface, VARIANT v)
 {
     HTMLInputElement *This = impl_from_IHTMLInputElement(iface);
-    FIXME("(%p)->()\n", This);
-    return E_NOTIMPL;
+
+    TRACE("(%p)->()\n", This);
+
+    return set_node_event(&This->element.node, EVENTID_LOAD, &v);
 }
 
 static HRESULT WINAPI HTMLInputElement_get_onload(IHTMLInputElement *iface, VARIANT *p)
 {
     HTMLInputElement *This = impl_from_IHTMLInputElement(iface);
-    FIXME("(%p)->(%p)\n", This, p);
-    return E_NOTIMPL;
+
+    TRACE("(%p)->(%p)\n", This, p);
+
+    return get_node_event(&This->element.node, EVENTID_LOAD, p);
 }
 
 static HRESULT WINAPI HTMLInputElement_put_onerror(IHTMLInputElement *iface, VARIANT v)
@@ -761,7 +765,7 @@ static HRESULT WINAPI HTMLInputElement_get_onabort(IHTMLInputElement *iface, VAR
 static HRESULT WINAPI HTMLInputElement_put_width(IHTMLInputElement *iface, LONG v)
 {
     HTMLInputElement *This = impl_from_IHTMLInputElement(iface);
-    FIXME("(%p)->(%d)\n", This, v);
+    FIXME("(%p)->(%ld)\n", This, v);
     return E_NOTIMPL;
 }
 
@@ -775,7 +779,7 @@ static HRESULT WINAPI HTMLInputElement_get_width(IHTMLInputElement *iface, LONG
 static HRESULT WINAPI HTMLInputElement_put_height(IHTMLInputElement *iface, LONG v)
 {
     HTMLInputElement *This = impl_from_IHTMLInputElement(iface);
-    FIXME("(%p)->(%d)\n", This, v);
+    FIXME("(%p)->(%ld)\n", This, v);
     return E_NOTIMPL;
 }
 
@@ -1036,7 +1040,7 @@ static HRESULT WINAPI HTMLInputTextElement_put_size(IHTMLInputTextElement *iface
 {
     HTMLInputElement *This = impl_from_IHTMLInputTextElement(iface);
 
-    TRACE("(%p)->(%d)\n", This, v);
+    TRACE("(%p)->(%ld)\n", This, v);
 
     return IHTMLInputElement_put_size(&This->IHTMLInputElement_iface, v);
 }
@@ -1054,7 +1058,7 @@ static HRESULT WINAPI HTMLInputTextElement_put_maxLength(IHTMLInputTextElement *
 {
     HTMLInputElement *This = impl_from_IHTMLInputTextElement(iface);
 
-    TRACE("(%p)->(%d)\n", This, v);
+    TRACE("(%p)->(%ld)\n", This, v);
 
     return IHTMLInputElement_put_maxLength(&This->IHTMLInputElement_iface, v);
 }
@@ -1232,11 +1236,11 @@ static HRESULT WINAPI HTMLInputTextElement2_put_selectionStart(IHTMLInputTextEle
     HTMLInputElement *This = impl_from_IHTMLInputTextElement2(iface);
     nsresult nsres;
 
-    TRACE("(%p)->(%d)\n", This, v);
+    TRACE("(%p)->(%ld)\n", This, v);
 
     nsres = nsIDOMHTMLInputElement_SetSelectionStart(This->nsinput, v);
     if(NS_FAILED(nsres)) {
-        ERR("SetSelectionStart failed: %08x\n", nsres);
+        ERR("SetSelectionStart failed: %08lx\n", nsres);
         return E_FAIL;
     }
     return S_OK;
@@ -1245,14 +1249,14 @@ static HRESULT WINAPI HTMLInputTextElement2_put_selectionStart(IHTMLInputTextEle
 static HRESULT WINAPI HTMLInputTextElement2_get_selectionStart(IHTMLInputTextElement2 *iface, LONG *p)
 {
     HTMLInputElement *This = impl_from_IHTMLInputTextElement2(iface);
-    INT32 selection_start;
+    LONG selection_start;
     nsresult nsres;
 
     TRACE("(%p)->(%p)\n", This, p);
 
     nsres = nsIDOMHTMLInputElement_GetSelectionStart(This->nsinput, &selection_start);
     if(NS_FAILED(nsres)) {
-        ERR("GetSelectionStart failed: %08x\n", nsres);
+        ERR("GetSelectionStart failed: %08lx\n", nsres);
         return E_FAIL;
     }
 
@@ -1265,11 +1269,11 @@ static HRESULT WINAPI HTMLInputTextElement2_put_selectionEnd(IHTMLInputTextEleme
     HTMLInputElement *This = impl_from_IHTMLInputTextElement2(iface);
     nsresult nsres;
 
-    TRACE("(%p)->(%d)\n", This, v);
+    TRACE("(%p)->(%ld)\n", This, v);
 
     nsres = nsIDOMHTMLInputElement_SetSelectionEnd(This->nsinput, v);
     if(NS_FAILED(nsres)) {
-        ERR("SetSelectionEnd failed: %08x\n", nsres);
+        ERR("SetSelectionEnd failed: %08lx\n", nsres);
         return E_FAIL;
     }
     return S_OK;
@@ -1278,14 +1282,14 @@ static HRESULT WINAPI HTMLInputTextElement2_put_selectionEnd(IHTMLInputTextEleme
 static HRESULT WINAPI HTMLInputTextElement2_get_selectionEnd(IHTMLInputTextElement2 *iface, LONG *p)
 {
     HTMLInputElement *This = impl_from_IHTMLInputTextElement2(iface);
-    INT32 selection_end;
+    LONG selection_end;
     nsresult nsres;
 
     TRACE("(%p)->(%p)\n", This, p);
 
     nsres = nsIDOMHTMLInputElement_GetSelectionEnd(This->nsinput, &selection_end);
     if(NS_FAILED(nsres)) {
-        ERR("GetSelectionEnd failed: %08x\n", nsres);
+        ERR("GetSelectionEnd failed: %08lx\n", nsres);
         return E_FAIL;
     }
 
@@ -1299,13 +1303,13 @@ static HRESULT WINAPI HTMLInputTextElement2_setSelectionRange(IHTMLInputTextElem
     nsAString none_str;
     nsresult nsres;
 
-    TRACE("(%p)->(%d %d)\n", This, start, end);
+    TRACE("(%p)->(%ld %ld)\n", This, start, end);
 
     nsAString_InitDepend(&none_str, L"none");
     nsres = nsIDOMHTMLInputElement_SetSelectionRange(This->nsinput, start, end, &none_str);
     nsAString_Finish(&none_str);
     if(NS_FAILED(nsres)) {
-        ERR("SetSelectionRange failed: %08x\n", nsres);
+        ERR("SetSelectionRange failed: %08lx\n", nsres);
         return E_FAIL;
     }
     return S_OK;
@@ -1419,6 +1423,7 @@ static const NodeImplVtbl HTMLInputElementImplVtbl = {
     HTMLElement_destructor,
     HTMLElement_cpc,
     HTMLElement_clone,
+    HTMLElement_dispatch_nsevent_hook,
     HTMLElement_handle_event,
     HTMLElement_get_attr_col,
     NULL,
@@ -1429,6 +1434,7 @@ static const NodeImplVtbl HTMLInputElementImplVtbl = {
     NULL,
     NULL,
     NULL,
+    NULL,
     HTMLInputElement_traverse,
     HTMLInputElement_unlink,
     HTMLInputElement_is_text_edit
@@ -1453,7 +1459,7 @@ HRESULT HTMLInputElement_Create(HTMLDocumentNode *doc, nsIDOMElement *nselem, HT
     HTMLInputElement *ret;
     nsresult nsres;
 
-    ret = heap_alloc_zero(sizeof(HTMLInputElement));
+    ret = calloc(1, sizeof(HTMLInputElement));
     if(!ret)
         return E_OUTOFMEMORY;
 
@@ -1552,7 +1558,7 @@ static HRESULT WINAPI HTMLLabelElement_put_htmlFor(IHTMLLabelElement *iface, BST
     nsAString_Finish(&for_str);
     nsAString_Finish(&val_str);
     if(NS_FAILED(nsres)) {
-        ERR("SetAttribute failed: %08x\n", nsres);
+        ERR("SetAttribute failed: %08lx\n", nsres);
         return E_FAIL;
     }
 
@@ -1627,6 +1633,7 @@ static const NodeImplVtbl HTMLLabelElementImplVtbl = {
     HTMLElement_destructor,
     HTMLElement_cpc,
     HTMLElement_clone,
+    HTMLElement_dispatch_nsevent_hook,
     HTMLElement_handle_event,
     HTMLElement_get_attr_col,
 };
@@ -1649,7 +1656,7 @@ HRESULT HTMLLabelElement_Create(HTMLDocumentNode *doc, nsIDOMElement *nselem, HT
 {
     HTMLLabelElement *ret;
 
-    ret = heap_alloc_zero(sizeof(*ret));
+    ret = calloc(1, sizeof(*ret));
     if(!ret)
         return E_OUTOFMEMORY;
 
@@ -1755,7 +1762,7 @@ static HRESULT WINAPI HTMLButtonElement_put_value(IHTMLButtonElement *iface, BST
     nsres = nsIDOMHTMLButtonElement_SetValue(This->nsbutton, &nsstr);
     nsAString_Finish(&nsstr);
     if(NS_FAILED(nsres)) {
-        ERR("SetValue failed: %08x\n", nsres);
+        ERR("SetValue failed: %08lx\n", nsres);
         return E_FAIL;
     }
 
@@ -1787,7 +1794,7 @@ static HRESULT WINAPI HTMLButtonElement_put_name(IHTMLButtonElement *iface, BSTR
     nsres = nsIDOMHTMLButtonElement_SetName(This->nsbutton, &name_str);
     nsAString_Finish(&name_str);
     if(NS_FAILED(nsres)) {
-        ERR("SetName failed: %08x\n", nsres);
+        ERR("SetName failed: %08lx\n", nsres);
         return E_FAIL;
     }
 
@@ -1830,7 +1837,7 @@ static HRESULT WINAPI HTMLButtonElement_put_disabled(IHTMLButtonElement *iface,
 
     nsres = nsIDOMHTMLButtonElement_SetDisabled(This->nsbutton, !!v);
     if(NS_FAILED(nsres)) {
-        ERR("SetDisabled failed: %08x\n", nsres);
+        ERR("SetDisabled failed: %08lx\n", nsres);
         return E_FAIL;
     }
 
@@ -1847,7 +1854,7 @@ static HRESULT WINAPI HTMLButtonElement_get_disabled(IHTMLButtonElement *iface,
 
     nsres = nsIDOMHTMLButtonElement_GetDisabled(This->nsbutton, &disabled);
     if(NS_FAILED(nsres)) {
-        ERR("GetDisabled failed: %08x\n", nsres);
+        ERR("GetDisabled failed: %08lx\n", nsres);
         return E_FAIL;
     }
 
@@ -1963,6 +1970,7 @@ static const NodeImplVtbl HTMLButtonElementImplVtbl = {
     HTMLElement_destructor,
     HTMLElement_cpc,
     HTMLElement_clone,
+    HTMLElement_dispatch_nsevent_hook,
     HTMLElement_handle_event,
     HTMLElement_get_attr_col,
     NULL,
@@ -1973,6 +1981,7 @@ static const NodeImplVtbl HTMLButtonElementImplVtbl = {
     NULL,
     NULL,
     NULL,
+    NULL,
     HTMLButtonElement_traverse,
     HTMLButtonElement_unlink,
     HTMLButtonElement_is_text_edit
@@ -1997,7 +2006,7 @@ HRESULT HTMLButtonElement_Create(HTMLDocumentNode *doc, nsIDOMElement *nselem, H
     HTMLButtonElement *ret;
     nsresult nsres;
 
-    ret = heap_alloc_zero(sizeof(*ret));
+    ret = calloc(1, sizeof(*ret));
     if(!ret)
         return E_OUTOFMEMORY;
 
