@@ -105,7 +105,7 @@ static HRESULT WINAPI HTMLScriptElement_put_src(IHTMLScriptElement *iface, BSTR
     nsres = nsIDOMHTMLScriptElement_SetSrc(This->nsscript, &src_str);
     nsAString_Finish(&src_str);
     if(NS_FAILED(nsres)) {
-        ERR("SetSrc failed: %08x\n", nsres);
+        ERR("SetSrc failed: %08lx\n", nsres);
         return E_FAIL;
     }
 
@@ -126,7 +126,7 @@ static HRESULT WINAPI HTMLScriptElement_put_src(IHTMLScriptElement *iface, BSTR
         nsAString_GetData(&src_str, &src);
         hres = load_script(This, src, TRUE);
     }else {
-        ERR("SetSrc failed: %08x\n", nsres);
+        ERR("SetSrc failed: %08lx\n", nsres);
         hres = E_FAIL;
     }
     nsAString_Finish(&src_str);
@@ -201,7 +201,7 @@ static HRESULT WINAPI HTMLScriptElement_put_text(IHTMLScriptElement *iface, BSTR
     nsres = nsIDOMHTMLScriptElement_SetText(This->nsscript, &text_str);
     nsAString_Finish(&text_str);
     if(NS_FAILED(nsres)) {
-        ERR("SetSrc failed: %08x\n", nsres);
+        ERR("SetSrc failed: %08lx\n", nsres);
         return E_FAIL;
     }
 
@@ -260,7 +260,7 @@ static HRESULT WINAPI HTMLScriptElement_get_defer(IHTMLScriptElement *iface, VAR
 
     nsres = nsIDOMHTMLScriptElement_GetDefer(This->nsscript, &defer);
     if(NS_FAILED(nsres)) {
-        ERR("GetSrc failed: %08x\n", nsres);
+        ERR("GetSrc failed: %08lx\n", nsres);
     }
 
     *p = variant_bool(defer);
@@ -305,7 +305,7 @@ static HRESULT WINAPI HTMLScriptElement_put_type(IHTMLScriptElement *iface, BSTR
     nsAString_Init(&nstype_str, v);
     nsres = nsIDOMHTMLScriptElement_SetType(This->nsscript, &nstype_str);
     if (NS_FAILED(nsres))
-        ERR("SetType failed: %08x\n", nsres);
+        ERR("SetType failed: %08lx\n", nsres);
     nsAString_Finish (&nstype_str);
 
     return S_OK;
@@ -382,7 +382,7 @@ static HRESULT HTMLScriptElement_QI(HTMLDOMNode *iface, REFIID riid, void **ppv)
 static void HTMLScriptElement_destructor(HTMLDOMNode *iface)
 {
     HTMLScriptElement *This = impl_from_HTMLDOMNode(iface);
-    heap_free(This->src_text);
+    free(This->src_text);
     HTMLElement_destructor(&This->element.node);
 }
 
@@ -438,6 +438,7 @@ static const NodeImplVtbl HTMLScriptElementImplVtbl = {
     HTMLScriptElement_destructor,
     HTMLElement_cpc,
     HTMLElement_clone,
+    HTMLElement_dispatch_nsevent_hook,
     HTMLElement_handle_event,
     HTMLElement_get_attr_col,
     NULL,
@@ -447,6 +448,7 @@ static const NodeImplVtbl HTMLScriptElementImplVtbl = {
     HTMLScriptElement_get_readystate,
     NULL,
     NULL,
+    NULL,
     HTMLScriptElement_bind_to_tree,
     HTMLScriptElement_traverse,
     HTMLScriptElement_unlink
@@ -491,7 +493,7 @@ HRESULT HTMLScriptElement_Create(HTMLDocumentNode *doc, nsIDOMElement *nselem, H
     HTMLScriptElement *ret;
     nsresult nsres;
 
-    ret = heap_alloc_zero(sizeof(HTMLScriptElement));
+    ret = calloc(1, sizeof(HTMLScriptElement));
     if(!ret)
         return E_OUTOFMEMORY;
 
