@@ -102,7 +102,7 @@ UINT cp_from_charset_string(BSTR charset)
 
     hres = IMultiLanguage2_GetCharsetInfo(mlang, charset, &info);
     if(FAILED(hres)) {
-        FIXME("GetCharsetInfo failed: %08x\n", hres);
+        FIXME("GetCharsetInfo failed: %08lx\n", hres);
         return CP_UTF8;
     }
 
@@ -119,13 +119,116 @@ BSTR charset_string_from_cp(UINT cp)
 
     hres = IMultiLanguage2_GetCodePageInfo(mlang, cp, GetUserDefaultUILanguage(), &info);
     if(FAILED(hres)) {
-        ERR("GetCodePageInfo failed: %08x\n", hres);
+        ERR("GetCodePageInfo failed: %08lx\n", hres);
         return SysAllocString(NULL);
     }
 
     return SysAllocString(info.wszWebCharset);
 }
 
+HRESULT get_mime_type_display_name(const WCHAR *content_type, BSTR *ret)
+{
+    /* undocumented */
+    extern BOOL WINAPI GetMIMETypeSubKeyW(LPCWSTR,LPWSTR,DWORD);
+
+    WCHAR buffer[128], ext[128], *str, *progid;
+    DWORD type, len;
+    HKEY key = NULL;
+    LSTATUS status;
+    HRESULT hres;
+    CLSID clsid;
+
+    str = buffer;
+    if(!GetMIMETypeSubKeyW(content_type, buffer, ARRAY_SIZE(buffer))) {
+        len = wcslen(content_type) + 32;
+        for(;;) {
+            if(!(str = malloc(len * sizeof(WCHAR))))
+                return E_OUTOFMEMORY;
+            if(GetMIMETypeSubKeyW(content_type, str, len))
+                break;
+            free(str);
+            len *= 2;
+        }
+    }
+
+    status = RegOpenKeyExW(HKEY_CLASSES_ROOT, str, 0, KEY_QUERY_VALUE, &key);
+    if(str != buffer)
+        free(str);
+    if(status != ERROR_SUCCESS)
+        goto fail;
+
+    len = sizeof(ext);
+    status = RegQueryValueExW(key, L"Extension", NULL, &type, (BYTE*)ext, &len);
+    if(status != ERROR_SUCCESS || type != REG_SZ) {
+        len = sizeof(buffer);
+        status = RegQueryValueExW(key, L"CLSID", NULL, &type, (BYTE*)buffer, &len);
+        if(status != ERROR_SUCCESS || type != REG_SZ || CLSIDFromString(buffer, &clsid) != S_OK)
+            goto fail;
+
+        hres = ProgIDFromCLSID(&clsid, &progid);
+        if(hres == E_OUTOFMEMORY) {
+            RegCloseKey(key);
+            return hres;
+        }
+        if(hres != S_OK)
+            goto fail;
+    }else {
+        progid = ext;
+    }
+
+    len = ARRAY_SIZE(buffer);
+    str = buffer;
+    for(;;) {
+        hres = AssocQueryStringW(ASSOCF_NOTRUNCATE, ASSOCSTR_FRIENDLYDOCNAME, progid, NULL, str, &len);
+        if(hres == S_OK && len)
+            break;
+        if(str != buffer)
+            free(str);
+        if(hres != E_POINTER) {
+            if(progid != ext) {
+                CoTaskMemFree(progid);
+                goto fail;
+            }
+
+            /* Try from CLSID */
+            len = sizeof(buffer);
+            status = RegQueryValueExW(key, L"CLSID", NULL, &type, (BYTE*)buffer, &len);
+            if(status != ERROR_SUCCESS || type != REG_SZ || CLSIDFromString(buffer, &clsid) != S_OK)
+                goto fail;
+
+            hres = ProgIDFromCLSID(&clsid, &progid);
+            if(hres == E_OUTOFMEMORY) {
+                RegCloseKey(key);
+                return hres;
+            }
+            if(hres != S_OK)
+                goto fail;
+
+            len = ARRAY_SIZE(buffer);
+            str = buffer;
+            continue;
+        }
+        str = malloc(len * sizeof(WCHAR));
+    }
+    if(progid != ext)
+        CoTaskMemFree(progid);
+    RegCloseKey(key);
+
+    *ret = SysAllocString(str);
+    if(str != buffer)
+        free(str);
+    return *ret ? S_OK : E_OUTOFMEMORY;
+
+fail:
+    RegCloseKey(key);
+
+    WARN("Did not find MIME in database for %s\n", debugstr_w(content_type));
+
+    /* native seems to return "File" when it doesn't know the content type */
+    *ret = SysAllocString(L"File");
+    return *ret ? S_OK : E_OUTOFMEMORY;
+}
+
 IInternetSecurityManager *get_security_manager(void)
 {
     if(!security_manager) {
@@ -154,7 +257,7 @@ static BOOL read_compat_mode(HKEY key, compat_mode_t *r)
     if(status != ERROR_SUCCESS || type != REG_SZ)
         return FALSE;
 
-    return parse_compat_version(version, r);
+    return parse_compat_version(version, r) != NULL;
 }
 
 static BOOL WINAPI load_compat_settings(INIT_ONCE *once, void *param, void **context)
@@ -182,12 +285,12 @@ static BOOL WINAPI load_compat_settings(INIT_ONCE *once, void *param, void **con
             break;
         index++;
         if(res != ERROR_SUCCESS) {
-            WARN("RegEnumKey failed: %u\n", GetLastError());
+            WARN("RegEnumKey failed: %lu\n", GetLastError());
             continue;
         }
 
         name_size = lstrlenW(key_name) + 1;
-        new_entry = heap_alloc(FIELD_OFFSET(compat_config_t, host[name_size]));
+        new_entry = malloc(FIELD_OFFSET(compat_config_t, host[name_size]));
         if(!new_entry)
             continue;
 
@@ -215,7 +318,7 @@ compat_mode_t get_max_compat_mode(IUri *uri)
 {
     compat_config_t *iter;
     size_t len, iter_len;
-    BSTR host;
+    BSTR host = NULL;
     HRESULT hres;
 
     static INIT_ONCE init_once = INIT_ONCE_STATIC_INIT;
@@ -224,8 +327,10 @@ compat_mode_t get_max_compat_mode(IUri *uri)
     if(!uri)
         return global_max_compat_mode;
     hres = IUri_GetHost(uri, &host);
-    if(FAILED(hres))
+    if(hres != S_OK) {
+        SysFreeString(host);
         return global_max_compat_mode;
+    }
     len = SysStringLen(host);
 
     LIST_FOR_EACH_ENTRY(iter, &compat_config, compat_config_t, entry) {
@@ -254,14 +359,15 @@ static void thread_detach(void)
     if(thread_data->thread_hwnd)
         DestroyWindow(thread_data->thread_hwnd);
 
-    heap_free(thread_data);
+    destroy_session_storage(thread_data);
+    free(thread_data);
 }
 
 static void free_strings(void)
 {
     unsigned int i;
     for(i = 0; i < ARRAY_SIZE(status_strings); i++)
-        heap_free(status_strings[i]);
+        free(status_strings[i]);
 }
 
 static void process_detach(void)
@@ -274,7 +380,7 @@ static void process_detach(void)
     while(!list_empty(&compat_config)) {
         config = LIST_ENTRY(list_head(&compat_config), compat_config_t, entry);
         list_remove(&config->entry);
-        heap_free(config);
+        free(config);
     }
 
     if(shdoclc)
@@ -300,11 +406,11 @@ void set_statustext(HTMLDocumentObj* doc, INT id, LPCWSTR arg)
 
     if(!p) {
         len = 255;
-        p = heap_alloc(len * sizeof(WCHAR));
+        p = malloc(len * sizeof(WCHAR));
         len = LoadStringW(hInst, id, p, len) + 1;
-        p = heap_realloc(p, len * sizeof(WCHAR));
+        p = realloc(p, len * sizeof(WCHAR));
         if(InterlockedCompareExchangePointer((void**)&status_strings[index], p, NULL)) {
-            heap_free(p);
+            free(p);
             p = status_strings[index];
         }
     }
@@ -313,7 +419,7 @@ void set_statustext(HTMLDocumentObj* doc, INT id, LPCWSTR arg)
         WCHAR *buf;
 
         len = lstrlenW(p) + lstrlenW(arg) - 1;
-        buf = heap_alloc(len * sizeof(WCHAR));
+        buf = malloc(len * sizeof(WCHAR));
 
         swprintf(buf, len, p, arg);
 
@@ -323,7 +429,7 @@ void set_statustext(HTMLDocumentObj* doc, INT id, LPCWSTR arg)
     IOleInPlaceFrame_SetStatusText(doc->frame, p);
 
     if(arg)
-        heap_free(p);
+        free(p);
 }
 
 HRESULT do_query_service(IUnknown *unk, REFGUID guid_service, REFIID riid, void **ppv)
@@ -397,7 +503,7 @@ static ULONG WINAPI ClassFactory_AddRef(IClassFactory *iface)
 {
     ClassFactory *This = impl_from_IClassFactory(iface);
     ULONG ref = InterlockedIncrement(&This->ref);
-    TRACE("(%p) ref = %u\n", This, ref);
+    TRACE("(%p) ref = %lu\n", This, ref);
     return ref;
 }
 
@@ -406,10 +512,10 @@ static ULONG WINAPI ClassFactory_Release(IClassFactory *iface)
     ClassFactory *This = impl_from_IClassFactory(iface);
     ULONG ref = InterlockedDecrement(&This->ref);
 
-    TRACE("(%p) ref = %u\n", This, ref);
+    TRACE("(%p) ref = %lu\n", This, ref);
 
     if(!ref) {
-        heap_free(This);
+        free(This);
     }
 
     return ref;
@@ -440,7 +546,7 @@ static const IClassFactoryVtbl HTMLClassFactoryVtbl = {
 
 static HRESULT ClassFactory_Create(REFIID riid, void **ppv, CreateInstanceFunc fnCreateInstance)
 {
-    ClassFactory *ret = heap_alloc(sizeof(ClassFactory));
+    ClassFactory *ret = malloc(sizeof(ClassFactory));
     HRESULT hres;
 
     ret->IClassFactory_iface.lpVtbl = &HTMLClassFactoryVtbl;
@@ -449,7 +555,7 @@ static HRESULT ClassFactory_Create(REFIID riid, void **ppv, CreateInstanceFunc f
 
     hres = IClassFactory_QueryInterface(&ret->IClassFactory_iface, riid, ppv);
     if(FAILED(hres)) {
-        heap_free(ret);
+        free(ret);
         *ppv = NULL;
     }
     return hres;
@@ -490,16 +596,6 @@ HRESULT WINAPI DllGetClassObject(REFCLSID rclsid, REFIID riid, LPVOID *ppv)
     return CLASS_E_CLASSNOTAVAILABLE;
 }
 
-/******************************************************************
- *              DllCanUnloadNow (MSHTML.@)
- */
-HRESULT WINAPI DllCanUnloadNow(void)
-{
-    TRACE("()\n");
-    /* The cost of keeping this DLL in memory is small. */
-    return S_FALSE;
-}
-
 /***********************************************************************
  *          RunHTMLApplication (MSHTML.@)
  *
@@ -524,9 +620,15 @@ DWORD WINAPI RNIGetCompatibleVersion(void)
 /***********************************************************************
  *          DllInstall (MSHTML.@)
  */
-HRESULT WINAPI DllInstall(BOOL bInstall, LPCWSTR cmdline)
+HRESULT WINAPI DllInstall(BOOL install, const WCHAR *cmdline)
 {
-    FIXME("stub %d %s: returning S_OK\n", bInstall, debugstr_w(cmdline));
+    TRACE("(%x %s)\n", install, debugstr_w(cmdline));
+
+    if(cmdline && *cmdline)
+        FIXME("unsupported cmdline: %s\n", debugstr_w(cmdline));
+    else if(install)
+        load_gecko();
+
     return S_OK;
 }
 
@@ -630,8 +732,8 @@ static HRESULT register_server(BOOL do_register)
     INF_SET_ID(LIBID_MSHTML);
 
     for(i=0; i < ARRAY_SIZE(pse); i++) {
-        pse[i].pszValue = heap_alloc(39);
-        sprintf(pse[i].pszValue, "{%08X-%04X-%04X-%02X%02X-%02X%02X%02X%02X%02X%02X}",
+        pse[i].pszValue = malloc(39);
+        sprintf(pse[i].pszValue, "{%08lX-%04X-%04X-%02X%02X-%02X%02X%02X%02X%02X%02X}",
                 clsids[i]->Data1, clsids[i]->Data2, clsids[i]->Data3, clsids[i]->Data4[0],
                 clsids[i]->Data4[1], clsids[i]->Data4[2], clsids[i]->Data4[3], clsids[i]->Data4[4],
                 clsids[i]->Data4[5], clsids[i]->Data4[6], clsids[i]->Data4[7]);
@@ -648,10 +750,10 @@ static HRESULT register_server(BOOL do_register)
     FreeLibrary(hAdvpack);
 
     for(i=0; i < ARRAY_SIZE(pse); i++)
-        heap_free(pse[i].pszValue);
+        free(pse[i].pszValue);
 
     if(FAILED(hres))
-        ERR("RegInstall failed: %08x\n", hres);
+        ERR("RegInstall failed: %08lx\n", hres);
 
     return hres;
 }
@@ -666,12 +768,9 @@ HRESULT WINAPI DllRegisterServer(void)
 {
     HRESULT hres;
 
-    hres = __wine_register_resources( hInst );
+    hres = __wine_register_resources();
     if(SUCCEEDED(hres))
         hres = register_server(TRUE);
-    if(SUCCEEDED(hres))
-        load_gecko();
-
     return hres;
 }
 
@@ -680,7 +779,7 @@ HRESULT WINAPI DllRegisterServer(void)
  */
 HRESULT WINAPI DllUnregisterServer(void)
 {
-    HRESULT hres = __wine_unregister_resources( hInst );
+    HRESULT hres = __wine_unregister_resources();
     if(SUCCEEDED(hres)) hres = register_server(FALSE);
     return hres;
 }
