@@ -30,7 +30,6 @@
 #include "tlogstg.h"
 #include "shdeprecated.h"
 
-#include "wine/heap.h"
 #include "wine/list.h"
 #include "wine/rbtree.h"
 
@@ -60,6 +59,7 @@
 #define NS_ERROR_INVALID_ARG      ((nsresult)0x80070057L) 
 #define NS_ERROR_UNEXPECTED       ((nsresult)0x8000ffffL)
 #define NS_ERROR_DOM_NO_MODIFICATION_ALLOWED_ERR ((nsresult)0x80530007)
+#define NS_ERROR_DOM_SYNTAX_ERR   ((nsresult)0x8053000c)
 
 #define NS_ERROR_MODULE_NETWORK    6
 
@@ -72,8 +72,11 @@
 
 #define NSAPI WINAPI
 
-#define MSHTML_E_NODOC    0x800a025c
+#define MSHTML_E_INVALID_PROPERTY 0x800a01b6
+#define MSHTML_E_INVALID_ACTION   0x800a01bd
+#define MSHTML_E_NODOC            0x800a025c
 
+typedef struct DOMEvent DOMEvent;
 typedef struct HTMLDOMNode HTMLDOMNode;
 typedef struct ConnectionPoint ConnectionPoint;
 typedef struct BSCallback BSCallback;
@@ -87,8 +90,12 @@ typedef struct EventTarget EventTarget;
     XDIID(DispDOMCustomEvent) \
     XDIID(DispDOMEvent) \
     XDIID(DispDOMKeyboardEvent) \
+    XDIID(DispDOMMessageEvent) \
     XDIID(DispDOMMouseEvent) \
+    XDIID(DispDOMProgressEvent) \
+    XDIID(DispDOMStorageEvent) \
     XDIID(DispDOMUIEvent) \
+    XDIID(DispDOMDocumentType) \
     XDIID(DispHTMLAnchorElement) \
     XDIID(DispHTMLAreaElement) \
     XDIID(DispHTMLAttributeCollection) \
@@ -147,8 +154,12 @@ typedef struct EventTarget EventTarget;
     XIID(IDOMCustomEvent) \
     XIID(IDOMEvent) \
     XIID(IDOMKeyboardEvent) \
+    XIID(IDOMMessageEvent) \
     XIID(IDOMMouseEvent) \
+    XIID(IDOMProgressEvent) \
+    XIID(IDOMStorageEvent) \
     XIID(IDOMUIEvent) \
+    XIID(IDOMDocumentType) \
     XIID(IDocumentEvent) \
     XIID(IDocumentRange) \
     XIID(IDocumentSelector) \
@@ -263,6 +274,7 @@ typedef struct EventTarget EventTarget;
     XIID(IHTMLWindow6) \
     XIID(IHTMLWindow7) \
     XIID(IHTMLXMLHttpRequest) \
+    XIID(IHTMLXMLHttpRequest2) \
     XIID(IHTMLXMLHttpRequestFactory) \
     XIID(IOmHistory) \
     XIID(IOmNavigator) \
@@ -277,7 +289,10 @@ typedef struct EventTarget EventTarget;
     XIID(IWineHTMLElementPrivate) \
     XIID(IWineHTMLWindowPrivate) \
     XIID(IWineHTMLWindowCompatPrivate) \
-    XIID(IWineMSHTMLConsole)
+    XIID(IWinePageTransitionEvent) \
+    XIID(IWineXMLHttpRequestPrivate) \
+    XIID(IWineMSHTMLConsole) \
+    XIID(IWineMSHTMLMediaQueryList)
 
 typedef enum {
 #define XIID(iface) iface ## _tid,
@@ -291,6 +306,7 @@ PRIVATE_TID_LIST
 } tid_t;
 
 typedef enum {
+    COMPAT_MODE_INVALID = -1,
     COMPAT_MODE_QUIRKS,
     COMPAT_MODE_IE5,
     COMPAT_MODE_IE7,
@@ -322,7 +338,10 @@ typedef struct DispatchEx DispatchEx;
 typedef struct {
     HRESULT (*value)(DispatchEx*,LCID,WORD,DISPPARAMS*,VARIANT*,EXCEPINFO*,IServiceProvider*);
     HRESULT (*get_dispid)(DispatchEx*,BSTR,DWORD,DISPID*);
+    HRESULT (*get_name)(DispatchEx*,DISPID,BSTR*);
     HRESULT (*invoke)(DispatchEx*,DISPID,LCID,WORD,DISPPARAMS*,VARIANT*,EXCEPINFO*,IServiceProvider*);
+    HRESULT (*delete)(DispatchEx*,DISPID);
+    HRESULT (*next_dispid)(DispatchEx*,DISPID,DISPID*);
     compat_mode_t (*get_compat_mode)(DispatchEx*);
     HRESULT (*populate_props)(DispatchEx*);
 } dispex_static_data_vtbl_t;
@@ -343,6 +362,7 @@ typedef HRESULT (*dispex_hook_invoke_t)(DispatchEx*,WORD,DISPPARAMS*,VARIANT*,
 typedef struct {
     DISPID dispid;
     dispex_hook_invoke_t invoke;
+    const WCHAR *name;
 } dispex_hook_t;
 
 struct DispatchEx {
@@ -388,7 +408,7 @@ HRESULT change_type(VARIANT*,VARIANT*,VARTYPE,IServiceProvider*) DECLSPEC_HIDDEN
 HRESULT dispex_get_dprop_ref(DispatchEx*,const WCHAR*,BOOL,VARIANT**) DECLSPEC_HIDDEN;
 HRESULT get_dispids(tid_t,DWORD*,DISPID**) DECLSPEC_HIDDEN;
 HRESULT remove_attribute(DispatchEx*,DISPID,VARIANT_BOOL*) DECLSPEC_HIDDEN;
-HRESULT dispex_get_dynid(DispatchEx*,const WCHAR*,DISPID*) DECLSPEC_HIDDEN;
+HRESULT dispex_get_dynid(DispatchEx*,const WCHAR*,BOOL,DISPID*) DECLSPEC_HIDDEN;
 void dispex_traverse(DispatchEx*,nsCycleCollectionTraversalCallback*) DECLSPEC_HIDDEN;
 void dispex_unlink(DispatchEx*) DECLSPEC_HIDDEN;
 void release_typelib(void) DECLSPEC_HIDDEN;
@@ -484,6 +504,33 @@ typedef struct {
     HTMLInnerWindow *window;
 } OmHistory;
 
+typedef struct {
+    DispatchEx dispex;
+    IHTMLPerformanceTiming IHTMLPerformanceTiming_iface;
+
+    LONG ref;
+
+    ULONG navigation_type;
+    ULONG redirect_count;
+
+    ULONGLONG navigation_start_time;
+    ULONGLONG unload_event_start_time;
+    ULONGLONG unload_event_end_time;
+    ULONGLONG redirect_time;
+    ULONGLONG dns_lookup_time;
+    ULONGLONG connect_time;
+    ULONGLONG request_time;
+    ULONGLONG response_start_time;
+    ULONGLONG response_end_time;
+    ULONGLONG dom_interactive_time;
+    ULONGLONG dom_complete_time;
+    ULONGLONG dom_content_loaded_event_start_time;
+    ULONGLONG dom_content_loaded_event_end_time;
+    ULONGLONG load_event_start_time;
+    ULONGLONG load_event_end_time;
+    ULONGLONG first_paint_time;
+} HTMLPerformanceTiming;
+
 typedef struct nsChannelBSC nsChannelBSC;
 
 struct HTMLWindow {
@@ -560,6 +607,7 @@ struct HTMLInnerWindow {
 
     BOOL performance_initialized;
     VARIANT performance;
+    HTMLPerformanceTiming *performance_timing;
 
     unsigned parser_callback_cnt;
     struct list script_queue;
@@ -621,79 +669,53 @@ struct  ConnectionPoint {
     cp_static_data_t *data;
 };
 
-struct HTMLDocument {
-    IHTMLDocument2              IHTMLDocument2_iface;
-    IHTMLDocument3              IHTMLDocument3_iface;
-    IHTMLDocument4              IHTMLDocument4_iface;
-    IHTMLDocument5              IHTMLDocument5_iface;
-    IHTMLDocument6              IHTMLDocument6_iface;
-    IHTMLDocument7              IHTMLDocument7_iface;
-    IDocumentSelector           IDocumentSelector_iface;
-    IDocumentEvent              IDocumentEvent_iface;
-    IPersistMoniker             IPersistMoniker_iface;
-    IPersistFile                IPersistFile_iface;
-    IPersistHistory             IPersistHistory_iface;
-    IMonikerProp                IMonikerProp_iface;
-    IOleObject                  IOleObject_iface;
-    IOleDocument                IOleDocument_iface;
-    IOleInPlaceActiveObject     IOleInPlaceActiveObject_iface;
-    IOleInPlaceObjectWindowless IOleInPlaceObjectWindowless_iface;
-    IServiceProvider            IServiceProvider_iface;
-    IOleCommandTarget           IOleCommandTarget_iface;
-    IOleControl                 IOleControl_iface;
-    IHlinkTarget                IHlinkTarget_iface;
-    IPersistStreamInit          IPersistStreamInit_iface;
-    IDispatchEx                 IDispatchEx_iface;
-    ISupportErrorInfo           ISupportErrorInfo_iface;
-    IObjectWithSite             IObjectWithSite_iface;
-    IOleContainer               IOleContainer_iface;
-    IObjectSafety               IObjectSafety_iface;
-    IProvideMultipleClassInfo   IProvideMultipleClassInfo_iface;
-    IMarkupServices             IMarkupServices_iface;
-    IMarkupContainer            IMarkupContainer_iface;
-    IDisplayServices            IDisplayServices_iface;
-    IDocumentRange              IDocumentRange_iface;
-
-    IUnknown *outer_unk;
-    IDispatchEx *dispex;
-
-    HTMLDocumentObj *doc_obj;
-    HTMLDocumentNode *doc_node;
-
-    HTMLOuterWindow *window;
-
-    ConnectionPointContainer cp_container;
-};
-
-static inline HRESULT htmldoc_query_interface(HTMLDocument *This, REFIID riid, void **ppv)
-{
-    return IUnknown_QueryInterface(This->outer_unk, riid, ppv);
-}
-
-static inline ULONG htmldoc_addref(HTMLDocument *This)
-{
-    return IUnknown_AddRef(This->outer_unk);
-}
-
-static inline ULONG htmldoc_release(HTMLDocument *This)
-{
-    return IUnknown_Release(This->outer_unk);
-}
-
 struct HTMLDocumentObj {
-    HTMLDocument basedoc;
-    DispatchEx dispex;
     IUnknown IUnknown_inner;
+    IDispatchEx IDispatchEx_iface;
     ICustomDoc ICustomDoc_iface;
+    IHTMLDocument2 IHTMLDocument2_iface;
+    IHTMLDocument3 IHTMLDocument3_iface;
+    IHTMLDocument4 IHTMLDocument4_iface;
+    IHTMLDocument5 IHTMLDocument5_iface;
+    IHTMLDocument6 IHTMLDocument6_iface;
+    IHTMLDocument7 IHTMLDocument7_iface;
+    IDocumentSelector IDocumentSelector_iface;
+    IDocumentEvent IDocumentEvent_iface;
+    ISupportErrorInfo ISupportErrorInfo_iface;
+    IProvideMultipleClassInfo IProvideMultipleClassInfo_iface;
+    IMarkupServices IMarkupServices_iface;
+    IMarkupContainer IMarkupContainer_iface;
+    IDisplayServices IDisplayServices_iface;
+    IDocumentRange IDocumentRange_iface;
     IOleDocumentView IOleDocumentView_iface;
     IViewObjectEx IViewObjectEx_iface;
+    IPersistMoniker IPersistMoniker_iface;
+    IPersistFile IPersistFile_iface;
+    IMonikerProp IMonikerProp_iface;
+    IPersistStreamInit IPersistStreamInit_iface;
+    IPersistHistory IPersistHistory_iface;
+    IHlinkTarget IHlinkTarget_iface;
+    IOleCommandTarget IOleCommandTarget_iface;
+    IOleObject IOleObject_iface;
+    IOleDocument IOleDocument_iface;
+    IOleControl IOleControl_iface;
+    IOleInPlaceActiveObject IOleInPlaceActiveObject_iface;
+    IOleInPlaceObjectWindowless IOleInPlaceObjectWindowless_iface;
+    IObjectWithSite IObjectWithSite_iface;
+    IOleContainer IOleContainer_iface;
+    IObjectSafety IObjectSafety_iface;
+    IServiceProvider IServiceProvider_iface;
     ITargetContainer ITargetContainer_iface;
+    IEventTarget IEventTarget_iface;
 
     IWindowForBindingUI IWindowForBindingUI_iface;
 
     LONG ref;
 
+    IUnknown *outer_unk;
+    HTMLOuterWindow *window;
     GeckoBrowser *nscontainer;
+    HTMLDocumentNode *doc_node;
 
     IOleClientSite *client;
     IDocHostUIHandler *hostui;
@@ -709,6 +731,7 @@ struct HTMLDocumentObj {
     IUnknown *browser_service;
     IOleAdviseHolder *advise_holder;
 
+    ConnectionPointContainer cp_container;
     DOCHOSTUIINFO hostinfo;
 
     IOleUndoManager *undomgr;
@@ -784,6 +807,7 @@ typedef struct {
     void (*destructor)(HTMLDOMNode*);
     const cpc_entry_t *cpc_entries;
     HRESULT (*clone)(HTMLDOMNode*,nsIDOMNode*,HTMLDOMNode**);
+    HRESULT (*dispatch_nsevent_hook)(HTMLDOMNode*,DOMEvent*);
     HRESULT (*handle_event)(HTMLDOMNode*,DWORD,nsIDOMEvent*,BOOL*);
     HRESULT (*get_attr_col)(HTMLDOMNode*,HTMLAttributeCollection**);
     EventTarget *(*get_event_prop_target)(HTMLDOMNode*,int);
@@ -792,6 +816,7 @@ typedef struct {
     HRESULT (*get_document)(HTMLDOMNode*,IDispatch**);
     HRESULT (*get_readystate)(HTMLDOMNode*,BSTR*);
     HRESULT (*get_dispid)(HTMLDOMNode*,BSTR,DWORD,DISPID*);
+    HRESULT (*get_name)(HTMLDOMNode*,DISPID,BSTR*);
     HRESULT (*invoke)(HTMLDOMNode*,DISPID,LCID,WORD,DISPPARAMS*,VARIANT*,EXCEPINFO*,IServiceProvider*);
     HRESULT (*bind_to_tree)(HTMLDOMNode*);
     void (*traverse)(HTMLDOMNode*,nsCycleCollectionTraversalCallback*);
@@ -813,6 +838,8 @@ struct HTMLDOMNode {
     HTMLDocumentNode *doc;
 };
 
+HTMLDOMNode *unsafe_impl_from_IHTMLDOMNode(IHTMLDOMNode*) DECLSPEC_HIDDEN;
+
 static inline void node_addref(HTMLDOMNode *node)
 {
     IHTMLDOMNode_AddRef(&node->IHTMLDOMNode_iface);
@@ -876,15 +903,48 @@ typedef struct nsDocumentEventListener nsDocumentEventListener;
 
 struct HTMLDocumentNode {
     HTMLDOMNode node;
-    HTMLDocument basedoc;
 
+    IDispatchEx                  IDispatchEx_iface;
+    IHTMLDocument2               IHTMLDocument2_iface;
+    IHTMLDocument3               IHTMLDocument3_iface;
+    IHTMLDocument4               IHTMLDocument4_iface;
+    IHTMLDocument5               IHTMLDocument5_iface;
+    IHTMLDocument6               IHTMLDocument6_iface;
+    IHTMLDocument7               IHTMLDocument7_iface;
+    IDocumentSelector            IDocumentSelector_iface;
+    IDocumentEvent               IDocumentEvent_iface;
+    ISupportErrorInfo            ISupportErrorInfo_iface;
+    IProvideMultipleClassInfo    IProvideMultipleClassInfo_iface;
+    IMarkupServices              IMarkupServices_iface;
+    IMarkupContainer             IMarkupContainer_iface;
+    IDisplayServices             IDisplayServices_iface;
+    IDocumentRange               IDocumentRange_iface;
+    IPersistMoniker              IPersistMoniker_iface;
+    IPersistFile                 IPersistFile_iface;
+    IMonikerProp                 IMonikerProp_iface;
+    IPersistStreamInit           IPersistStreamInit_iface;
+    IPersistHistory              IPersistHistory_iface;
+    IHlinkTarget                 IHlinkTarget_iface;
+    IOleCommandTarget            IOleCommandTarget_iface;
+    IOleObject                   IOleObject_iface;
+    IOleDocument                 IOleDocument_iface;
+    IOleControl                  IOleControl_iface;
+    IOleInPlaceActiveObject      IOleInPlaceActiveObject_iface;
+    IOleInPlaceObjectWindowless  IOleInPlaceObjectWindowless_iface;
+    IObjectWithSite              IObjectWithSite_iface;
+    IOleContainer                IOleContainer_iface;
+    IObjectSafety                IObjectSafety_iface;
+    IServiceProvider             IServiceProvider_iface;
     IInternetHostSecurityManager IInternetHostSecurityManager_iface;
 
     nsIDocumentObserver          nsIDocumentObserver_iface;
 
     LONG ref;
 
+    ConnectionPointContainer cp_container;
+    HTMLOuterWindow *outer_window;
     HTMLInnerWindow *window;
+    HTMLDocumentObj *doc_obj;
 
     GeckoBrowser *browser;
     struct list browser_entry;
@@ -892,8 +952,10 @@ struct HTMLDocumentNode {
     compat_mode_t document_mode;
     BOOL document_mode_locked;
 
-    nsIDOMHTMLDocument *nsdoc;
-    BOOL content_ready;
+    nsIDOMDocument *dom_document;
+    nsIDOMHTMLDocument *html_document;
+    BOOL content_ready : 1;
+    BOOL unload_sent : 1;
 
     IHTMLDOMImplementation *dom_implementation;
     IHTMLNamespaceCollection *namespaces;
@@ -920,8 +982,9 @@ struct HTMLDocumentNode {
 HRESULT HTMLDocument_Create(IUnknown*,REFIID,void**) DECLSPEC_HIDDEN;
 HRESULT MHTMLDocument_Create(IUnknown*,REFIID,void**) DECLSPEC_HIDDEN;
 HRESULT HTMLLoadOptions_Create(IUnknown*,REFIID,void**) DECLSPEC_HIDDEN;
-HRESULT create_document_node(nsIDOMHTMLDocument*,GeckoBrowser*,HTMLInnerWindow*,
+HRESULT create_document_node(nsIDOMDocument*,GeckoBrowser*,HTMLInnerWindow*,
                              compat_mode_t,HTMLDocumentNode**) DECLSPEC_HIDDEN;
+HRESULT create_doctype_node(HTMLDocumentNode*,nsIDOMNode*,HTMLDOMNode**) DECLSPEC_HIDDEN;
 
 HRESULT create_outer_window(GeckoBrowser*,mozIDOMWindowProxy*,HTMLOuterWindow*,HTMLOuterWindow**) DECLSPEC_HIDDEN;
 HRESULT update_window_doc(HTMLInnerWindow*) DECLSPEC_HIDDEN;
@@ -933,22 +996,26 @@ HRESULT HTMLXMLHttpRequestFactory_Create(HTMLInnerWindow*,HTMLXMLHttpRequestFact
 HRESULT HTMLLocation_Create(HTMLInnerWindow*,HTMLLocation**) DECLSPEC_HIDDEN;
 HRESULT create_navigator(compat_mode_t,IOmNavigator**) DECLSPEC_HIDDEN;
 HRESULT create_html_screen(compat_mode_t,IHTMLScreen**) DECLSPEC_HIDDEN;
-HRESULT create_performance(compat_mode_t,IHTMLPerformance**) DECLSPEC_HIDDEN;
+HRESULT create_performance(HTMLInnerWindow*,IHTMLPerformance**) DECLSPEC_HIDDEN;
+HRESULT create_performance_timing(HTMLPerformanceTiming**) DECLSPEC_HIDDEN;
 HRESULT create_history(HTMLInnerWindow*,OmHistory**) DECLSPEC_HIDDEN;
 HRESULT create_namespace_collection(compat_mode_t,IHTMLNamespaceCollection**) DECLSPEC_HIDDEN;
 HRESULT create_dom_implementation(HTMLDocumentNode*,IHTMLDOMImplementation**) DECLSPEC_HIDDEN;
 void detach_dom_implementation(IHTMLDOMImplementation*) DECLSPEC_HIDDEN;
 
-HRESULT create_html_storage(compat_mode_t,IHTMLStorage**) DECLSPEC_HIDDEN;
-
-void HTMLDocument_Persist_Init(HTMLDocument*) DECLSPEC_HIDDEN;
-void HTMLDocument_OleCmd_Init(HTMLDocument*) DECLSPEC_HIDDEN;
-void HTMLDocument_OleObj_Init(HTMLDocument*) DECLSPEC_HIDDEN;
-void HTMLDocument_Service_Init(HTMLDocument*) DECLSPEC_HIDDEN;
+HRESULT create_html_storage(HTMLInnerWindow*,BOOL,IHTMLStorage**) DECLSPEC_HIDDEN;
+void detach_html_storage(IHTMLStorage*) DECLSPEC_HIDDEN;
 
 void HTMLDocument_View_Init(HTMLDocumentObj*) DECLSPEC_HIDDEN;
+void HTMLDocumentObj_Persist_Init(HTMLDocumentObj*) DECLSPEC_HIDDEN;
+void HTMLDocumentObj_Service_Init(HTMLDocumentObj*) DECLSPEC_HIDDEN;
+void HTMLDocumentObj_OleCmd_Init(HTMLDocumentObj*) DECLSPEC_HIDDEN;
 void TargetContainer_Init(HTMLDocumentObj*) DECLSPEC_HIDDEN;
 
+void HTMLDocumentNode_Persist_Init(HTMLDocumentNode*) DECLSPEC_HIDDEN;
+void HTMLDocumentNode_Service_Init(HTMLDocumentNode*) DECLSPEC_HIDDEN;
+void HTMLDocumentNode_OleCmd_Init(HTMLDocumentNode*) DECLSPEC_HIDDEN;
+void HTMLDocumentNode_OleObj_Init(HTMLDocumentNode*) DECLSPEC_HIDDEN;
 void HTMLDocumentNode_SecMgr_Init(HTMLDocumentNode*) DECLSPEC_HIDDEN;
 
 HRESULT HTMLCurrentStyle_Create(HTMLElement*,IHTMLCurrentStyle**) DECLSPEC_HIDDEN;
@@ -964,7 +1031,7 @@ compat_mode_t lock_document_mode(HTMLDocumentNode*) DECLSPEC_HIDDEN;
 void init_mutation(nsIComponentManager*) DECLSPEC_HIDDEN;
 void init_document_mutation(HTMLDocumentNode*) DECLSPEC_HIDDEN;
 void release_document_mutation(HTMLDocumentNode*) DECLSPEC_HIDDEN;
-JSContext *get_context_from_document(nsIDOMHTMLDocument*) DECLSPEC_HIDDEN;
+JSContext *get_context_from_document(nsIDOMDocument*) DECLSPEC_HIDDEN;
 
 void HTMLDocument_LockContainer(HTMLDocumentObj*,BOOL) DECLSPEC_HIDDEN;
 void show_context_menu(HTMLDocumentObj*,DWORD,POINT*,IDispatch*) DECLSPEC_HIDDEN;
@@ -994,8 +1061,8 @@ HRESULT nsuri_to_url(LPCWSTR,BOOL,BSTR*) DECLSPEC_HIDDEN;
 void call_property_onchanged(ConnectionPointContainer*,DISPID) DECLSPEC_HIDDEN;
 HRESULT call_set_active_object(IOleInPlaceUIWindow*,IOleInPlaceActiveObject*) DECLSPEC_HIDDEN;
 
-void *nsalloc(size_t) __WINE_ALLOC_SIZE(1) DECLSPEC_HIDDEN;
 void nsfree(void*) DECLSPEC_HIDDEN;
+void *nsalloc(size_t) __WINE_ALLOC_SIZE(1) __WINE_DEALLOC(nsfree) __WINE_MALLOC DECLSPEC_HIDDEN;
 
 BOOL nsACString_Init(nsACString *str, const char *data) DECLSPEC_HIDDEN;
 void nsACString_InitDepend(nsACString*,const char*) DECLSPEC_HIDDEN;
@@ -1029,10 +1096,11 @@ char *get_nscategory_entry(const char*,const char*) DECLSPEC_HIDDEN;
 
 HRESULT create_pending_window(HTMLOuterWindow*,nsChannelBSC*) DECLSPEC_HIDDEN;
 HRESULT start_binding(HTMLInnerWindow*,BSCallback*,IBindCtx*) DECLSPEC_HIDDEN;
-HRESULT async_start_doc_binding(HTMLOuterWindow*,HTMLInnerWindow*) DECLSPEC_HIDDEN;
+HRESULT async_start_doc_binding(HTMLOuterWindow*,HTMLInnerWindow*,DWORD) DECLSPEC_HIDDEN;
 void abort_window_bindings(HTMLInnerWindow*) DECLSPEC_HIDDEN;
 void set_download_state(HTMLDocumentObj*,int) DECLSPEC_HIDDEN;
 void call_docview_84(HTMLDocumentObj*) DECLSPEC_HIDDEN;
+HRESULT reload_page(HTMLOuterWindow*) DECLSPEC_HIDDEN;
 
 void set_ready_state(HTMLOuterWindow*,READYSTATE) DECLSPEC_HIDDEN;
 HRESULT get_readystate_string(READYSTATE,BSTR*) DECLSPEC_HIDDEN;
@@ -1049,7 +1117,7 @@ void detach_document_node(HTMLDocumentNode*) DECLSPEC_HIDDEN;
 void detach_selection(HTMLDocumentNode*) DECLSPEC_HIDDEN;
 void detach_ranges(HTMLDocumentNode*) DECLSPEC_HIDDEN;
 HRESULT get_node_text(HTMLDOMNode*,BSTR*) DECLSPEC_HIDDEN;
-HRESULT replace_node_by_html(nsIDOMHTMLDocument*,nsIDOMNode*,const WCHAR*) DECLSPEC_HIDDEN;
+HRESULT replace_node_by_html(nsIDOMDocument*,nsIDOMNode*,const WCHAR*) DECLSPEC_HIDDEN;
 
 HRESULT create_nselem(HTMLDocumentNode*,const WCHAR*,nsIDOMElement**) DECLSPEC_HIDDEN;
 HRESULT create_element(HTMLDocumentNode*,const WCHAR*,HTMLElement**) DECLSPEC_HIDDEN;
@@ -1143,6 +1211,7 @@ HRESULT HTMLElement_QI(HTMLDOMNode*,REFIID,void**) DECLSPEC_HIDDEN;
 void HTMLElement_destructor(HTMLDOMNode*) DECLSPEC_HIDDEN;
 HRESULT HTMLElement_clone(HTMLDOMNode*,nsIDOMNode*,HTMLDOMNode**) DECLSPEC_HIDDEN;
 HRESULT HTMLElement_get_attr_col(HTMLDOMNode*,HTMLAttributeCollection**) DECLSPEC_HIDDEN;
+HRESULT HTMLElement_dispatch_nsevent_hook(HTMLDOMNode*,DOMEvent*) DECLSPEC_HIDDEN;
 HRESULT HTMLElement_handle_event(HTMLDOMNode*,DWORD,nsIDOMEvent*,BOOL*) DECLSPEC_HIDDEN;
 void HTMLElement_init_dispex_info(dispex_data_t*,compat_mode_t) DECLSPEC_HIDDEN;
 
@@ -1227,10 +1296,13 @@ typedef struct {
     HWND thread_hwnd;
     struct list task_list;
     struct list timer_list;
+    struct wine_rb_tree session_storage_map;
 } thread_data_t;
 
 thread_data_t *get_thread_data(BOOL) DECLSPEC_HIDDEN;
 HWND get_thread_hwnd(void) DECLSPEC_HIDDEN;
+int session_storage_map_cmp(const void*,const struct wine_rb_entry*) DECLSPEC_HIDDEN;
+void destroy_session_storage(thread_data_t*) DECLSPEC_HIDDEN;
 
 LONG get_task_target_magic(void) DECLSPEC_HIDDEN;
 HRESULT push_task(task_t*,task_proc_t,task_proc_t,LONG) DECLSPEC_HIDDEN;
@@ -1245,8 +1317,9 @@ enum timer_type {
 
 HRESULT set_task_timer(HTMLInnerWindow*,LONG,enum timer_type,IDispatch*,LONG*) DECLSPEC_HIDDEN;
 HRESULT clear_task_timer(HTMLInnerWindow*,DWORD) DECLSPEC_HIDDEN;
+HRESULT clear_animation_timer(HTMLInnerWindow*,DWORD) DECLSPEC_HIDDEN;
 
-BOOL parse_compat_version(const WCHAR*,compat_mode_t*) DECLSPEC_HIDDEN;
+const WCHAR *parse_compat_version(const WCHAR*,compat_mode_t*) DECLSPEC_HIDDEN;
 
 const char *debugstr_mshtml_guid(const GUID*) DECLSPEC_HIDDEN;
 
@@ -1268,33 +1341,12 @@ DEFINE_GUID(IID_IDispatchJS,0x719c3050,0xf9d3,0x11cf,0xa4,0x93,0x00,0x40,0x05,0x
 
 /* memory allocation functions */
 
-static inline void * __WINE_ALLOC_SIZE(2) heap_realloc_zero(void *mem, size_t len)
-{
-    return HeapReAlloc(GetProcessHeap(), HEAP_ZERO_MEMORY, mem, len);
-}
-
-static inline LPWSTR heap_strdupW(LPCWSTR str)
+static inline WCHAR *strndupW(LPCWSTR str, unsigned len)
 {
     LPWSTR ret = NULL;
 
     if(str) {
-        DWORD size;
-
-        size = (lstrlenW(str)+1)*sizeof(WCHAR);
-        ret = heap_alloc(size);
-        if(ret)
-            memcpy(ret, str, size);
-    }
-
-    return ret;
-}
-
-static inline LPWSTR heap_strndupW(LPCWSTR str, unsigned len)
-{
-    LPWSTR ret = NULL;
-
-    if(str) {
-        ret = heap_alloc((len+1)*sizeof(WCHAR));
+        ret = malloc((len + 1) * sizeof(WCHAR));
         if(ret)
         {
             memcpy(ret, str, len*sizeof(WCHAR));
@@ -1305,23 +1357,7 @@ static inline LPWSTR heap_strndupW(LPCWSTR str, unsigned len)
     return ret;
 }
 
-static inline char *heap_strdupA(const char *str)
-{
-    char *ret = NULL;
-
-    if(str) {
-        DWORD size;
-
-        size = strlen(str)+1;
-        ret = heap_alloc(size);
-        if(ret)
-            memcpy(ret, str, size);
-    }
-
-    return ret;
-}
-
-static inline WCHAR *heap_strdupAtoW(const char *str)
+static inline WCHAR *strdupAtoW(const char *str)
 {
     LPWSTR ret = NULL;
 
@@ -1329,7 +1365,7 @@ static inline WCHAR *heap_strdupAtoW(const char *str)
         DWORD len;
 
         len = MultiByteToWideChar(CP_ACP, 0, str, -1, NULL, 0);
-        ret = heap_alloc(len*sizeof(WCHAR));
+        ret = malloc(len * sizeof(WCHAR));
         if(ret)
             MultiByteToWideChar(CP_ACP, 0, str, -1, ret, len);
     }
@@ -1337,13 +1373,13 @@ static inline WCHAR *heap_strdupAtoW(const char *str)
     return ret;
 }
 
-static inline char *heap_strdupWtoA(LPCWSTR str)
+static inline char *strdupWtoA(const WCHAR *str)
 {
     char *ret = NULL;
 
     if(str) {
         DWORD size = WideCharToMultiByte(CP_ACP, 0, str, -1, NULL, 0, NULL, NULL);
-        ret = heap_alloc(size);
+        ret = malloc(size);
         if(ret)
             WideCharToMultiByte(CP_ACP, 0, str, -1, ret, size, NULL, NULL);
     }
@@ -1351,7 +1387,7 @@ static inline char *heap_strdupWtoA(LPCWSTR str)
     return ret;
 }
 
-static inline WCHAR *heap_strdupUtoW(const char *str)
+static inline WCHAR *strdupUtoW(const char *str)
 {
     WCHAR *ret = NULL;
 
@@ -1359,7 +1395,7 @@ static inline WCHAR *heap_strdupUtoW(const char *str)
         size_t len;
 
         len = MultiByteToWideChar(CP_UTF8, 0, str, -1, NULL, 0);
-        ret = heap_alloc(len*sizeof(WCHAR));
+        ret = malloc(len * sizeof(WCHAR));
         if(ret)
             MultiByteToWideChar(CP_UTF8, 0, str, -1, ret, len);
     }
@@ -1367,13 +1403,13 @@ static inline WCHAR *heap_strdupUtoW(const char *str)
     return ret;
 }
 
-static inline char *heap_strdupWtoU(const WCHAR *str)
+static inline char *strdupWtoU(const WCHAR *str)
 {
     char *ret = NULL;
 
     if(str) {
         size_t size = WideCharToMultiByte(CP_UTF8, 0, str, -1, NULL, 0, NULL, NULL);
-        ret = heap_alloc(size);
+        ret = malloc(size);
         if(ret)
             WideCharToMultiByte(CP_UTF8, 0, str, -1, ret, size, NULL, NULL);
     }
@@ -1381,16 +1417,16 @@ static inline char *heap_strdupWtoU(const WCHAR *str)
     return ret;
 }
 
-static inline char *heap_strndupWtoU(LPCWSTR str, unsigned len)
+static inline char *strndupWtoU(const WCHAR *str, unsigned len)
 {
     char *ret = NULL;
     DWORD size;
 
-    if(str && len) {
-        size = WideCharToMultiByte(CP_UTF8, 0, str, len, NULL, 0, NULL, NULL);
-        ret = heap_alloc(size + 1);
+    if(str) {
+        size = len ? WideCharToMultiByte(CP_UTF8, 0, str, len, NULL, 0, NULL, NULL) : 0;
+        ret = malloc(size + 1);
         if(ret) {
-            WideCharToMultiByte(CP_UTF8, 0, str, len, ret, size, NULL, NULL);
+            if(len) WideCharToMultiByte(CP_UTF8, 0, str, len, ret, size, NULL, NULL);
             ret[size] = '\0';
         }
     }
@@ -1408,6 +1444,11 @@ static inline BOOL is_digit(WCHAR c)
     return '0' <= c && c <= '9';
 }
 
+static inline BOOL is_power_of_2(unsigned x)
+{
+    return !(x & (x - 1));
+}
+
 #ifdef __i386__
 extern void *call_thiscall_func;
 #endif
@@ -1415,9 +1456,11 @@ extern void *call_thiscall_func;
 compat_mode_t get_max_compat_mode(IUri*) DECLSPEC_HIDDEN;
 UINT cp_from_charset_string(BSTR) DECLSPEC_HIDDEN;
 BSTR charset_string_from_cp(UINT) DECLSPEC_HIDDEN;
+HRESULT get_mime_type_display_name(const WCHAR*,BSTR*) DECLSPEC_HIDDEN;
 HINSTANCE get_shdoclc(void) DECLSPEC_HIDDEN;
 void set_statustext(HTMLDocumentObj*,INT,LPCWSTR) DECLSPEC_HIDDEN;
 IInternetSecurityManager *get_security_manager(void) DECLSPEC_HIDDEN;
 
 extern HINSTANCE hInst DECLSPEC_HIDDEN;
 void create_console(compat_mode_t compat_mode, IWineMSHTMLConsole **ret) DECLSPEC_HIDDEN;
+HRESULT create_media_query_list(HTMLWindow *window, BSTR media_query, IDispatch **ret) DECLSPEC_HIDDEN;
