@@ -52,13 +52,13 @@ void do_ns_command(HTMLDocumentNode *doc, const char *cmd, nsICommandParams *nsp
 
     nsres = get_nsinterface((nsISupports*)doc->browser->webbrowser, &IID_nsICommandManager, (void**)&cmdmgr);
     if(NS_FAILED(nsres)) {
-        ERR("Could not get nsICommandManager: %08x\n", nsres);
+        ERR("Could not get nsICommandManager: %08lx\n", nsres);
         return;
     }
 
     nsres = nsICommandManager_DoCommand(cmdmgr, cmd, nsparam, doc->window->base.outer_window->window_proxy);
     if(NS_FAILED(nsres))
-        ERR("DoCommand(%s) failed: %08x\n", debugstr_a(cmd), nsres);
+        ERR("DoCommand(%s) failed: %08lx\n", debugstr_a(cmd), nsres);
 
     nsICommandManager_Release(cmdmgr);
 }
@@ -69,7 +69,7 @@ static nsIClipboardCommands *get_clipboard_commands(HTMLDocumentNode *doc)
     nsIDocShell *doc_shell;
     nsresult nsres;
 
-    nsres = get_nsinterface((nsISupports*)doc->basedoc.window->nswindow, &IID_nsIDocShell, (void**)&doc_shell);
+    nsres = get_nsinterface((nsISupports*)doc->outer_window->nswindow, &IID_nsIDocShell, (void**)&doc_shell);
     if(NS_FAILED(nsres)) {
         ERR("Could not get nsIDocShell interface\n");
         return NULL;
@@ -89,38 +89,43 @@ static nsIClipboardCommands *get_clipboard_commands(HTMLDocumentNode *doc)
  * IOleCommandTarget implementation
  */
 
-static inline HTMLDocument *impl_from_IOleCommandTarget(IOleCommandTarget *iface)
+static inline HTMLDocumentNode *HTMLDocumentNode_from_IOleCommandTarget(IOleCommandTarget *iface)
 {
-    return CONTAINING_RECORD(iface, HTMLDocument, IOleCommandTarget_iface);
+    return CONTAINING_RECORD(iface, HTMLDocumentNode, IOleCommandTarget_iface);
+}
+
+static inline HTMLDocumentObj *HTMLDocumentObj_from_IOleCommandTarget(IOleCommandTarget *iface)
+{
+    return CONTAINING_RECORD(iface, HTMLDocumentObj, IOleCommandTarget_iface);
 }
 
 static HRESULT exec_open(HTMLDocumentNode *doc, DWORD nCmdexecopt, VARIANT *pvaIn, VARIANT *pvaOut)
 {
-    FIXME("(%p)->(%d %p %p)\n", doc, nCmdexecopt, pvaIn, pvaOut);
+    FIXME("(%p)->(%ld %p %p)\n", doc, nCmdexecopt, pvaIn, pvaOut);
     return E_NOTIMPL;
 }
 
 static HRESULT exec_new(HTMLDocumentNode *doc, DWORD nCmdexecopt, VARIANT *pvaIn, VARIANT *pvaOut)
 {
-    FIXME("(%p)->(%d %p %p)\n", doc, nCmdexecopt, pvaIn, pvaOut);
+    FIXME("(%p)->(%ld %p %p)\n", doc, nCmdexecopt, pvaIn, pvaOut);
     return E_NOTIMPL;
 }
 
 static HRESULT exec_save(HTMLDocumentNode *doc, DWORD nCmdexecopt, VARIANT *pvaIn, VARIANT *pvaOut)
 {
-    FIXME("(%p)->(%d %p %p)\n", doc, nCmdexecopt, pvaIn, pvaOut);
+    FIXME("(%p)->(%ld %p %p)\n", doc, nCmdexecopt, pvaIn, pvaOut);
     return E_NOTIMPL;
 }
 
 static HRESULT exec_save_as(HTMLDocumentNode *doc, DWORD nCmdexecopt, VARIANT *pvaIn, VARIANT *pvaOut)
 {
-    FIXME("(%p)->(%d %p %p)\n", doc, nCmdexecopt, pvaIn, pvaOut);
+    FIXME("(%p)->(%ld %p %p)\n", doc, nCmdexecopt, pvaIn, pvaOut);
     return E_NOTIMPL;
 }
 
 static HRESULT exec_save_copy_as(HTMLDocumentNode *doc, DWORD nCmdexecopt, VARIANT *pvaIn, VARIANT *pvaOut)
 {
-    FIXME("(%p)->(%d %p %p)\n", doc, nCmdexecopt, pvaIn, pvaOut);
+    FIXME("(%p)->(%ld %p %p)\n", doc, nCmdexecopt, pvaIn, pvaOut);
     return E_NOTIMPL;
 }
 
@@ -240,7 +245,7 @@ static HRESULT exec_print(HTMLDocumentNode *doc, DWORD nCmdexecopt, VARIANT *pva
     nsIPrintSettings *settings;
     nsresult nsres;
 
-    TRACE("(%p)->(%d %s %p)\n", doc, nCmdexecopt, debugstr_variant(pvaIn), pvaOut);
+    TRACE("(%p)->(%ld %s %p)\n", doc, nCmdexecopt, debugstr_variant(pvaIn), pvaOut);
 
     if(pvaOut)
         FIXME("unsupported pvaOut\n");
@@ -248,13 +253,13 @@ static HRESULT exec_print(HTMLDocumentNode *doc, DWORD nCmdexecopt, VARIANT *pva
     nsres = get_nsinterface((nsISupports*)doc->browser->webbrowser, &IID_nsIWebBrowserPrint,
             (void**)&nsprint);
     if(NS_FAILED(nsres)) {
-        ERR("Could not get nsIWebBrowserPrint: %08x\n", nsres);
+        ERR("Could not get nsIWebBrowserPrint: %08lx\n", nsres);
         return S_OK;
     }
 
     nsres = nsIWebBrowserPrint_GetGlobalPrintSettings(nsprint, &settings);
     if(NS_FAILED(nsres))
-        ERR("GetCurrentPrintSettings failed: %08x\n", nsres);
+        ERR("GetCurrentPrintSettings failed: %08lx\n", nsres);
 
     set_default_templates(settings);
 
@@ -297,7 +302,7 @@ static HRESULT exec_print(HTMLDocumentNode *doc, DWORD nCmdexecopt, VARIANT *pva
             }
 
             if(opts_cnt >= 3)
-                FIXME("Unsupported opts_cnt %d\n", opts_cnt);
+                FIXME("Unsupported opts_cnt %ld\n", opts_cnt);
 
             SafeArrayUnaccessData(V_ARRAY(pvaIn));
             break;
@@ -309,7 +314,7 @@ static HRESULT exec_print(HTMLDocumentNode *doc, DWORD nCmdexecopt, VARIANT *pva
 
     nsres = nsIWebBrowserPrint_Print(nsprint, settings, NULL);
     if(NS_FAILED(nsres))
-        ERR("Print failed: %08x\n", nsres);
+        ERR("Print failed: %08lx\n", nsres);
 
     nsIWebBrowserPrint_Release(nsprint);
 
@@ -318,37 +323,37 @@ static HRESULT exec_print(HTMLDocumentNode *doc, DWORD nCmdexecopt, VARIANT *pva
 
 static HRESULT exec_print_preview(HTMLDocumentNode *doc, DWORD nCmdexecopt, VARIANT *pvaIn, VARIANT *pvaOut)
 {
-    FIXME("(%p)->(%d %p %p)\n", doc, nCmdexecopt, pvaIn, pvaOut);
+    FIXME("(%p)->(%ld %p %p)\n", doc, nCmdexecopt, pvaIn, pvaOut);
     return E_NOTIMPL;
 }
 
 static HRESULT exec_page_setup(HTMLDocumentNode *doc, DWORD nCmdexecopt, VARIANT *pvaIn, VARIANT *pvaOut)
 {
-    FIXME("(%p)->(%d %p %p)\n", doc, nCmdexecopt, pvaIn, pvaOut);
+    FIXME("(%p)->(%ld %p %p)\n", doc, nCmdexecopt, pvaIn, pvaOut);
     return E_NOTIMPL;
 }
 
 static HRESULT exec_spell(HTMLDocumentNode *doc, DWORD nCmdexecopt, VARIANT *pvaIn, VARIANT *pvaOut)
 {
-    FIXME("(%p)->(%d %p %p)\n", doc, nCmdexecopt, pvaIn, pvaOut);
+    FIXME("(%p)->(%ld %p %p)\n", doc, nCmdexecopt, pvaIn, pvaOut);
     return E_NOTIMPL;
 }
 
 static HRESULT exec_properties(HTMLDocumentNode *doc, DWORD nCmdexecopt, VARIANT *pvaIn, VARIANT *pvaOut)
 {
-    FIXME("(%p)->(%d %p %p)\n", doc, nCmdexecopt, pvaIn, pvaOut);
+    FIXME("(%p)->(%ld %p %p)\n", doc, nCmdexecopt, pvaIn, pvaOut);
     return E_NOTIMPL;
 }
 
 static HRESULT exec_cut(HTMLDocumentNode *doc, DWORD nCmdexecopt, VARIANT *pvaIn, VARIANT *pvaOut)
 {
-    FIXME("(%p)->(%d %p %p)\n", doc, nCmdexecopt, pvaIn, pvaOut);
+    FIXME("(%p)->(%ld %p %p)\n", doc, nCmdexecopt, pvaIn, pvaOut);
     return E_NOTIMPL;
 }
 
 static HRESULT exec_copy(HTMLDocumentNode *doc, DWORD nCmdexecopt, VARIANT *pvaIn, VARIANT *pvaOut)
 {
-    TRACE("(%p)->(%d %s %p)\n", doc, nCmdexecopt, debugstr_variant(pvaIn), pvaOut);
+    TRACE("(%p)->(%ld %s %p)\n", doc, nCmdexecopt, debugstr_variant(pvaIn), pvaOut);
 
     do_ns_command(doc, NSCMD_COPY, NULL);
     return S_OK;
@@ -356,25 +361,25 @@ static HRESULT exec_copy(HTMLDocumentNode *doc, DWORD nCmdexecopt, VARIANT *pvaI
 
 static HRESULT exec_paste(HTMLDocumentNode *doc, DWORD nCmdexecopt, VARIANT *pvaIn, VARIANT *pvaOut)
 {
-    FIXME("(%p)->(%d %p %p)\n", doc, nCmdexecopt, pvaIn, pvaOut);
+    FIXME("(%p)->(%ld %p %p)\n", doc, nCmdexecopt, pvaIn, pvaOut);
     return E_NOTIMPL;
 }
 
 static HRESULT exec_paste_special(HTMLDocumentNode *doc, DWORD nCmdexecopt, VARIANT *pvaIn, VARIANT *pvaOut)
 {
-    FIXME("(%p)->(%d %p %p)\n", doc, nCmdexecopt, pvaIn, pvaOut);
+    FIXME("(%p)->(%ld %p %p)\n", doc, nCmdexecopt, pvaIn, pvaOut);
     return E_NOTIMPL;
 }
 
 static HRESULT exec_undo(HTMLDocumentNode *doc, DWORD nCmdexecopt, VARIANT *pvaIn, VARIANT *pvaOut)
 {
-    FIXME("(%p)->(%d %p %p)\n", doc, nCmdexecopt, pvaIn, pvaOut);
+    FIXME("(%p)->(%ld %p %p)\n", doc, nCmdexecopt, pvaIn, pvaOut);
     return E_NOTIMPL;
 }
 
 static HRESULT exec_rendo(HTMLDocumentNode *doc, DWORD nCmdexecopt, VARIANT *pvaIn, VARIANT *pvaOut)
 {
-    FIXME("(%p)->(%d %p %p)\n", doc, nCmdexecopt, pvaIn, pvaOut);
+    FIXME("(%p)->(%ld %p %p)\n", doc, nCmdexecopt, pvaIn, pvaOut);
     return E_NOTIMPL;
 }
 
@@ -395,19 +400,19 @@ static HRESULT exec_select_all(HTMLDocumentNode *doc, DWORD nCmdexecopt, VARIANT
 
 static HRESULT exec_clear_selection(HTMLDocumentNode *doc, DWORD nCmdexecopt, VARIANT *pvaIn, VARIANT *pvaOut)
 {
-    FIXME("(%p)->(%d %p %p)\n", doc, nCmdexecopt, pvaIn, pvaOut);
+    FIXME("(%p)->(%ld %p %p)\n", doc, nCmdexecopt, pvaIn, pvaOut);
     return E_NOTIMPL;
 }
 
 static HRESULT exec_zoom(HTMLDocumentNode *doc, DWORD nCmdexecopt, VARIANT *pvaIn, VARIANT *pvaOut)
 {
-    FIXME("(%p)->(%d %p %p)\n", doc, nCmdexecopt, pvaIn, pvaOut);
+    FIXME("(%p)->(%ld %p %p)\n", doc, nCmdexecopt, pvaIn, pvaOut);
     return E_NOTIMPL;
 }
 
 static HRESULT exec_get_zoom_range(HTMLDocumentNode *doc, DWORD nCmdexecopt, VARIANT *pvaIn, VARIANT *pvaOut)
 {
-    FIXME("(%p)->(%d %p %p)\n", doc, nCmdexecopt, pvaIn, pvaOut);
+    FIXME("(%p)->(%ld %p %p)\n", doc, nCmdexecopt, pvaIn, pvaOut);
     return E_NOTIMPL;
 }
 
@@ -441,18 +446,31 @@ static void refresh_destr(task_t *_task)
     refresh_task_t *task = (refresh_task_t*)_task;
 
     IHTMLWindow2_Release(&task->window->base.IHTMLWindow2_iface);
-    heap_free(task);
+    free(task);
+}
+
+HRESULT reload_page(HTMLOuterWindow *window)
+{
+    refresh_task_t *task;
+
+    task = malloc(sizeof(*task));
+    if(!task)
+        return E_OUTOFMEMORY;
+
+    IHTMLWindow2_AddRef(&window->base.IHTMLWindow2_iface);
+    task->window = window;
+
+    return push_task(&task->header, refresh_proc, refresh_destr, window->task_magic);
 }
 
 static HRESULT exec_refresh(HTMLDocumentNode *doc, DWORD nCmdexecopt, VARIANT *pvaIn, VARIANT *pvaOut)
 {
     HTMLDocumentObj *doc_obj;
-    refresh_task_t *task;
     HRESULT hres;
 
-    TRACE("(%p)->(%d %s %p)\n", doc, nCmdexecopt, debugstr_variant(pvaIn), pvaOut);
+    TRACE("(%p)->(%ld %s %p)\n", doc, nCmdexecopt, debugstr_variant(pvaIn), pvaOut);
 
-    if(doc != doc->browser->doc->basedoc.doc_node) {
+    if(doc != doc->browser->doc->doc_node) {
         FIXME("Unsupported on frame documents\n");
         return E_NOTIMPL;
     }
@@ -470,52 +488,45 @@ static HRESULT exec_refresh(HTMLDocumentNode *doc, DWORD nCmdexecopt, VARIANT *p
         }
     }
 
-    if(!doc->basedoc.window)
+    if(!doc->outer_window)
         return E_UNEXPECTED;
 
-    task = heap_alloc(sizeof(*task));
-    if(!task)
-        return E_OUTOFMEMORY;
-
-    IHTMLWindow2_AddRef(&doc->basedoc.window->base.IHTMLWindow2_iface);
-    task->window = doc->basedoc.window;
-
-    return push_task(&task->header, refresh_proc, refresh_destr, doc->basedoc.window->task_magic);
+    return reload_page(doc->outer_window);
 }
 
 static HRESULT exec_stop(HTMLDocumentNode *doc, DWORD nCmdexecopt, VARIANT *pvaIn, VARIANT *pvaOut)
 {
-    FIXME("(%p)->(%d %p %p)\n", doc, nCmdexecopt, pvaIn, pvaOut);
+    FIXME("(%p)->(%ld %p %p)\n", doc, nCmdexecopt, pvaIn, pvaOut);
     return E_NOTIMPL;
 }
 
 static HRESULT exec_stop_download(HTMLDocumentNode *doc, DWORD nCmdexecopt, VARIANT *pvaIn, VARIANT *pvaOut)
 {
-    FIXME("(%p)->(%d %p %p)\n", doc, nCmdexecopt, pvaIn, pvaOut);
+    FIXME("(%p)->(%ld %p %p)\n", doc, nCmdexecopt, pvaIn, pvaOut);
     return E_NOTIMPL;
 }
 
 static HRESULT exec_find(HTMLDocumentNode *doc, DWORD nCmdexecopt, VARIANT *pvaIn, VARIANT *pvaOut)
 {
-    FIXME("(%p)->(%d %p %p)\n", doc, nCmdexecopt, pvaIn, pvaOut);
+    FIXME("(%p)->(%ld %p %p)\n", doc, nCmdexecopt, pvaIn, pvaOut);
     return E_NOTIMPL;
 }
 
 static HRESULT exec_delete(HTMLDocumentNode *doc, DWORD nCmdexecopt, VARIANT *pvaIn, VARIANT *pvaOut)
 {
-    FIXME("(%p)->(%d %p %p)\n", doc, nCmdexecopt, pvaIn, pvaOut);
+    FIXME("(%p)->(%ld %p %p)\n", doc, nCmdexecopt, pvaIn, pvaOut);
     return E_NOTIMPL;
 }
 
 static HRESULT exec_enable_interaction(HTMLDocumentNode *doc, DWORD nCmdexecopt, VARIANT *pvaIn, VARIANT *pvaOut)
 {
-    FIXME("(%p)->(%d %p %p)\n", doc, nCmdexecopt, pvaIn, pvaOut);
+    FIXME("(%p)->(%ld %p %p)\n", doc, nCmdexecopt, pvaIn, pvaOut);
     return E_NOTIMPL;
 }
 
 static HRESULT exec_on_unload(HTMLDocumentNode *doc, DWORD nCmdexecopt, VARIANT *pvaIn, VARIANT *pvaOut)
 {
-    TRACE("(%p)->(%d %p %p)\n", doc, nCmdexecopt, pvaIn, pvaOut);
+    TRACE("(%p)->(%ld %p %p)\n", doc, nCmdexecopt, pvaIn, pvaOut);
 
     /* Tests show that we have nothing more to do here */
 
@@ -529,37 +540,37 @@ static HRESULT exec_on_unload(HTMLDocumentNode *doc, DWORD nCmdexecopt, VARIANT
 
 static HRESULT exec_show_page_setup(HTMLDocumentNode *doc, DWORD nCmdexecopt, VARIANT *pvaIn, VARIANT *pvaOut)
 {
-    FIXME("(%p)->(%d %p %p)\n", doc, nCmdexecopt, pvaIn, pvaOut);
+    FIXME("(%p)->(%ld %p %p)\n", doc, nCmdexecopt, pvaIn, pvaOut);
     return E_NOTIMPL;
 }
 
 static HRESULT exec_show_print(HTMLDocumentNode *doc, DWORD nCmdexecopt, VARIANT *pvaIn, VARIANT *pvaOut)
 {
-    FIXME("(%p)->(%d %p %p)\n", doc, nCmdexecopt, pvaIn, pvaOut);
+    FIXME("(%p)->(%ld %p %p)\n", doc, nCmdexecopt, pvaIn, pvaOut);
     return E_NOTIMPL;
 }
 
 static HRESULT exec_close(HTMLDocumentNode *doc, DWORD nCmdexecopt, VARIANT *pvaIn, VARIANT *pvaOut)
 {
-    FIXME("(%p)->(%d %p %p)\n", doc, nCmdexecopt, pvaIn, pvaOut);
+    FIXME("(%p)->(%ld %p %p)\n", doc, nCmdexecopt, pvaIn, pvaOut);
     return E_NOTIMPL;
 }
 
 static HRESULT exec_set_print_template(HTMLDocumentNode *doc, DWORD nCmdexecopt, VARIANT *pvaIn, VARIANT *pvaOut)
 {
-    FIXME("(%p)->(%d %p %p)\n", doc, nCmdexecopt, pvaIn, pvaOut);
+    FIXME("(%p)->(%ld %p %p)\n", doc, nCmdexecopt, pvaIn, pvaOut);
     return E_NOTIMPL;
 }
 
 static HRESULT exec_get_print_template(HTMLDocumentNode *doc, DWORD nCmdexecopt, VARIANT *pvaIn, VARIANT *pvaOut)
 {
-    FIXME("(%p)->(%d %p %p)\n", doc, nCmdexecopt, pvaIn, pvaOut);
+    FIXME("(%p)->(%ld %p %p)\n", doc, nCmdexecopt, pvaIn, pvaOut);
     return E_NOTIMPL;
 }
 
 static HRESULT exec_optical_zoom(HTMLDocumentNode *doc, DWORD nCmdexecopt, VARIANT *pvaIn, VARIANT *pvaOut)
 {
-    TRACE("(%p)->(%d %s %p)\n", doc, nCmdexecopt, debugstr_variant(pvaIn), pvaOut);
+    TRACE("(%p)->(%ld %s %p)\n", doc, nCmdexecopt, debugstr_variant(pvaIn), pvaOut);
 
     if(pvaIn && V_VT(pvaIn) != VT_I4) {
         FIXME("Unsupported argument %s\n", debugstr_variant(pvaIn));
@@ -584,7 +595,7 @@ static HRESULT query_mshtml_copy(HTMLDocumentNode *doc, OLECMD *cmd)
 
 static HRESULT exec_mshtml_copy(HTMLDocumentNode *doc, DWORD cmdexecopt, VARIANT *in, VARIANT *out)
 {
-    TRACE("(%p)->(%08x %p %p)\n", doc, cmdexecopt, in, out);
+    TRACE("(%p)->(%08lx %p %p)\n", doc, cmdexecopt, in, out);
 
     if(doc->browser->usermode == EDITMODE)
         return editor_exec_copy(doc, cmdexecopt, in, out);
@@ -605,7 +616,7 @@ static HRESULT exec_mshtml_cut(HTMLDocumentNode *doc, DWORD cmdexecopt, VARIANT
     nsIClipboardCommands *clipboard_commands;
     nsresult nsres;
 
-    TRACE("(%p)->(%08x %p %p)\n", doc, cmdexecopt, in, out);
+    TRACE("(%p)->(%08lx %p %p)\n", doc, cmdexecopt, in, out);
 
     if(doc->browser->usermode == EDITMODE)
         return editor_exec_cut(doc, cmdexecopt, in, out);
@@ -617,7 +628,7 @@ static HRESULT exec_mshtml_cut(HTMLDocumentNode *doc, DWORD cmdexecopt, VARIANT
     nsres = nsIClipboardCommands_CutSelection(clipboard_commands);
     nsIClipboardCommands_Release(clipboard_commands);
     if(NS_FAILED(nsres)) {
-        ERR("Paste failed: %08x\n", nsres);
+        ERR("Paste failed: %08lx\n", nsres);
         return E_FAIL;
     }
 
@@ -636,7 +647,7 @@ static HRESULT exec_mshtml_paste(HTMLDocumentNode *doc, DWORD cmdexecopt, VARIAN
     nsIClipboardCommands *clipboard_commands;
     nsresult nsres;
 
-    TRACE("(%p)->(%08x %p %p)\n", doc, cmdexecopt, in, out);
+    TRACE("(%p)->(%08lx %p %p)\n", doc, cmdexecopt, in, out);
 
     if(doc->browser->usermode == EDITMODE)
         return editor_exec_paste(doc, cmdexecopt, in, out);
@@ -648,7 +659,7 @@ static HRESULT exec_mshtml_paste(HTMLDocumentNode *doc, DWORD cmdexecopt, VARIAN
     nsres = nsIClipboardCommands_Paste(clipboard_commands);
     nsIClipboardCommands_Release(clipboard_commands);
     if(NS_FAILED(nsres)) {
-        ERR("Paste failed: %08x\n", nsres);
+        ERR("Paste failed: %08lx\n", nsres);
         return E_FAIL;
     }
 
@@ -665,7 +676,7 @@ static HRESULT query_selall_status(HTMLDocumentNode *doc, OLECMD *cmd)
 
 static HRESULT exec_browsemode(HTMLDocumentNode *doc, DWORD cmdexecopt, VARIANT *in, VARIANT *out)
 {
-    WARN("(%p)->(%08x %p %p)\n", doc, cmdexecopt, in, out);
+    WARN("(%p)->(%08lx %p %p)\n", doc, cmdexecopt, in, out);
 
     if(in || out)
         FIXME("unsupported args\n");
@@ -677,7 +688,7 @@ static HRESULT exec_browsemode(HTMLDocumentNode *doc, DWORD cmdexecopt, VARIANT
 
 static HRESULT exec_editmode(HTMLDocumentNode *doc, DWORD cmdexecopt, VARIANT *in, VARIANT *out)
 {
-    TRACE("(%p)->(%08x %p %p)\n", doc, cmdexecopt, in, out);
+    TRACE("(%p)->(%08lx %p %p)\n", doc, cmdexecopt, in, out);
 
     if(in || out)
         FIXME("unsupported args\n");
@@ -687,20 +698,20 @@ static HRESULT exec_editmode(HTMLDocumentNode *doc, DWORD cmdexecopt, VARIANT *i
 
 static HRESULT exec_htmleditmode(HTMLDocumentNode *doc, DWORD cmdexecopt, VARIANT *in, VARIANT *out)
 {
-    FIXME("(%p)->(%08x %p %p)\n", doc, cmdexecopt, in, out);
+    FIXME("(%p)->(%08lx %p %p)\n", doc, cmdexecopt, in, out);
     return S_OK;
 }
 
 static HRESULT exec_baselinefont3(HTMLDocumentNode *doc, DWORD cmdexecopt, VARIANT *in, VARIANT *out)
 {
-    FIXME("(%p)->(%08x %p %p)\n", doc, cmdexecopt, in, out);
+    FIXME("(%p)->(%08lx %p %p)\n", doc, cmdexecopt, in, out);
     return S_OK;
 }
 
 static HRESULT exec_respectvisibility_indesign(HTMLDocumentNode *doc, DWORD cmdexecopt,
         VARIANT *in, VARIANT *out)
 {
-    TRACE("(%p)->(%x %s %p)\n", doc, cmdexecopt, debugstr_variant(in), out);
+    TRACE("(%p)->(%lx %s %p)\n", doc, cmdexecopt, debugstr_variant(in), out);
 
     /* This is turned on by default in Gecko. */
     if(!in || V_VT(in) != VT_BOOL || !V_BOOL(in))
@@ -793,22 +804,22 @@ static const cmdtable_t base_cmds[] = {
     {0,NULL,NULL}
 };
 
-static HRESULT WINAPI OleCommandTarget_QueryInterface(IOleCommandTarget *iface, REFIID riid, void **ppv)
+static HRESULT WINAPI DocNodeOleCommandTarget_QueryInterface(IOleCommandTarget *iface, REFIID riid, void **ppv)
 {
-    HTMLDocument *This = impl_from_IOleCommandTarget(iface);
-    return htmldoc_query_interface(This, riid, ppv);
+    HTMLDocumentNode *This = HTMLDocumentNode_from_IOleCommandTarget(iface);
+    return IHTMLDOMNode_QueryInterface(&This->node.IHTMLDOMNode_iface, riid, ppv);
 }
 
-static ULONG WINAPI OleCommandTarget_AddRef(IOleCommandTarget *iface)
+static ULONG WINAPI DocNodeOleCommandTarget_AddRef(IOleCommandTarget *iface)
 {
-    HTMLDocument *This = impl_from_IOleCommandTarget(iface);
-    return htmldoc_addref(This);
+    HTMLDocumentNode *This = HTMLDocumentNode_from_IOleCommandTarget(iface);
+    return IHTMLDOMNode_AddRef(&This->node.IHTMLDOMNode_iface);
 }
 
-static ULONG WINAPI OleCommandTarget_Release(IOleCommandTarget *iface)
+static ULONG WINAPI DocNodeOleCommandTarget_Release(IOleCommandTarget *iface)
 {
-    HTMLDocument *This = impl_from_IOleCommandTarget(iface);
-    return htmldoc_release(This);
+    HTMLDocumentNode *This = HTMLDocumentNode_from_IOleCommandTarget(iface);
+    return IHTMLDOMNode_Release(&This->node.IHTMLDOMNode_iface);
 }
 
 static HRESULT query_from_table(HTMLDocumentNode *doc, const cmdtable_t *cmdtable, OLECMD *cmd)
@@ -826,17 +837,17 @@ static HRESULT query_from_table(HTMLDocumentNode *doc, const cmdtable_t *cmdtabl
     return iter->query(doc, cmd);
 }
 
-static HRESULT WINAPI OleCommandTarget_QueryStatus(IOleCommandTarget *iface, const GUID *pguidCmdGroup,
+static HRESULT WINAPI DocNodeOleCommandTarget_QueryStatus(IOleCommandTarget *iface, const GUID *pguidCmdGroup,
         ULONG cCmds, OLECMD prgCmds[], OLECMDTEXT *pCmdText)
 {
-    HTMLDocument *This = impl_from_IOleCommandTarget(iface);
+    HTMLDocumentNode *This = HTMLDocumentNode_from_IOleCommandTarget(iface);
     HRESULT hres;
 
-    TRACE("(%p)->(%s %d %p %p)\n", This, debugstr_guid(pguidCmdGroup), cCmds, prgCmds, pCmdText);
+    TRACE("(%p)->(%s %ld %p %p)\n", This, debugstr_guid(pguidCmdGroup), cCmds, prgCmds, pCmdText);
 
     if(pCmdText)
         FIXME("Unsupported pCmdText\n");
-    if(!This->doc_node->browser)
+    if(!This->browser)
         return E_UNEXPECTED;
     if(!cCmds)
         return S_OK;
@@ -846,7 +857,7 @@ static HRESULT WINAPI OleCommandTarget_QueryStatus(IOleCommandTarget *iface, con
 
         for(i=0; i<cCmds; i++) {
             if(prgCmds[i].cmdID < OLECMDID_OPEN || prgCmds[i].cmdID >= ARRAY_SIZE(exec_table)) {
-                WARN("Unsupported cmdID = %d\n", prgCmds[i].cmdID);
+                WARN("Unsupported cmdID = %ld\n", prgCmds[i].cmdID);
                 prgCmds[i].cmdf = 0;
             }else {
                 if(prgCmds[i].cmdID == OLECMDID_OPEN || prgCmds[i].cmdID == OLECMDID_NEW) {
@@ -870,7 +881,7 @@ static HRESULT WINAPI OleCommandTarget_QueryStatus(IOleCommandTarget *iface, con
                     }
                 }else {
                     prgCmds[i].cmdf = exec_table[prgCmds[i].cmdID].cmdf;
-                    TRACE("cmdID = %d  returning %x\n", prgCmds[i].cmdID, prgCmds[i].cmdf);
+                    TRACE("cmdID = %ld  returning %lx\n", prgCmds[i].cmdID, prgCmds[i].cmdf);
                 }
             }
         }
@@ -882,11 +893,11 @@ static HRESULT WINAPI OleCommandTarget_QueryStatus(IOleCommandTarget *iface, con
         ULONG i;
 
         for(i=0; i<cCmds; i++) {
-            hres = query_from_table(This->doc_node, base_cmds, prgCmds+i);
+            hres = query_from_table(This, base_cmds, prgCmds+i);
             if(hres == OLECMDERR_E_NOTSUPPORTED)
-                hres = query_from_table(This->doc_node, editmode_cmds, prgCmds+i);
+                hres = query_from_table(This, editmode_cmds, prgCmds+i);
             if(hres == OLECMDERR_E_NOTSUPPORTED)
-                FIXME("CGID_MSHTML: unsupported cmdID %d\n", prgCmds[i].cmdID);
+                FIXME("CGID_MSHTML: unsupported cmdID %ld\n", prgCmds[i].cmdID);
         }
 
         return (prgCmds[cCmds-1].cmdf & OLECMDF_SUPPORTED) ? S_OK : OLECMDERR_E_NOTSUPPORTED;
@@ -910,37 +921,37 @@ static HRESULT exec_from_table(HTMLDocumentNode *doc, const cmdtable_t *cmdtable
     return iter->exec(doc, cmdexecopt, in, out);
 }
 
-static HRESULT WINAPI OleCommandTarget_Exec(IOleCommandTarget *iface, const GUID *pguidCmdGroup,
+static HRESULT WINAPI DocNodeOleCommandTarget_Exec(IOleCommandTarget *iface, const GUID *pguidCmdGroup,
         DWORD nCmdID, DWORD nCmdexecopt, VARIANT *pvaIn, VARIANT *pvaOut)
 {
-    HTMLDocument *This = impl_from_IOleCommandTarget(iface);
+    HTMLDocumentNode *This = HTMLDocumentNode_from_IOleCommandTarget(iface);
 
-    TRACE("(%p)->(%s %d %d %s %p)\n", This, debugstr_guid(pguidCmdGroup), nCmdID, nCmdexecopt, wine_dbgstr_variant(pvaIn), pvaOut);
+    TRACE("(%p)->(%s %ld %ld %s %p)\n", This, debugstr_guid(pguidCmdGroup), nCmdID, nCmdexecopt, wine_dbgstr_variant(pvaIn), pvaOut);
 
-    if(!This->doc_node->browser)
+    if(!This->browser)
         return E_UNEXPECTED;
 
     if(!pguidCmdGroup) {
         if(nCmdID < OLECMDID_OPEN || nCmdID >= ARRAY_SIZE(exec_table) || !exec_table[nCmdID].func) {
-            WARN("Unsupported cmdID = %d\n", nCmdID);
+            WARN("Unsupported cmdID = %ld\n", nCmdID);
             return OLECMDERR_E_NOTSUPPORTED;
         }
 
-        return exec_table[nCmdID].func(This->doc_node, nCmdexecopt, pvaIn, pvaOut);
+        return exec_table[nCmdID].func(This, nCmdexecopt, pvaIn, pvaOut);
     }else if(IsEqualGUID(&CGID_Explorer, pguidCmdGroup)) {
-        FIXME("unsupported nCmdID %d of CGID_Explorer group\n", nCmdID);
+        FIXME("unsupported nCmdID %ld of CGID_Explorer group\n", nCmdID);
         TRACE("%p %p\n", pvaIn, pvaOut);
         return OLECMDERR_E_NOTSUPPORTED;
     }else if(IsEqualGUID(&CGID_ShellDocView, pguidCmdGroup)) {
-        FIXME("unsupported nCmdID %d of CGID_ShellDocView group\n", nCmdID);
+        FIXME("unsupported nCmdID %ld of CGID_ShellDocView group\n", nCmdID);
         return OLECMDERR_E_NOTSUPPORTED;
     }else if(IsEqualGUID(&CGID_MSHTML, pguidCmdGroup)) {
-        HRESULT hres = exec_from_table(This->doc_node, base_cmds, nCmdID, nCmdexecopt, pvaIn, pvaOut);
+        HRESULT hres = exec_from_table(This, base_cmds, nCmdID, nCmdexecopt, pvaIn, pvaOut);
         if(hres == OLECMDERR_E_NOTSUPPORTED)
-            hres = exec_from_table(This->doc_node, editmode_cmds, nCmdID,
+            hres = exec_from_table(This, editmode_cmds, nCmdID,
                                    nCmdexecopt, pvaIn, pvaOut);
         if(hres == OLECMDERR_E_NOTSUPPORTED)
-            FIXME("unsupported nCmdID %d of CGID_MSHTML group\n", nCmdID);
+            FIXME("unsupported nCmdID %ld of CGID_MSHTML group\n", nCmdID);
 
         return hres;
     }
@@ -949,12 +960,56 @@ static HRESULT WINAPI OleCommandTarget_Exec(IOleCommandTarget *iface, const GUID
     return OLECMDERR_E_UNKNOWNGROUP;
 }
 
-static const IOleCommandTargetVtbl OleCommandTargetVtbl = {
-    OleCommandTarget_QueryInterface,
-    OleCommandTarget_AddRef,
-    OleCommandTarget_Release,
-    OleCommandTarget_QueryStatus,
-    OleCommandTarget_Exec
+static const IOleCommandTargetVtbl DocNodeOleCommandTargetVtbl = {
+    DocNodeOleCommandTarget_QueryInterface,
+    DocNodeOleCommandTarget_AddRef,
+    DocNodeOleCommandTarget_Release,
+    DocNodeOleCommandTarget_QueryStatus,
+    DocNodeOleCommandTarget_Exec
+};
+
+static HRESULT WINAPI DocObjOleCommandTarget_QueryInterface(IOleCommandTarget *iface, REFIID riid, void **ppv)
+{
+    HTMLDocumentObj *This = HTMLDocumentObj_from_IOleCommandTarget(iface);
+    return IUnknown_QueryInterface(This->outer_unk, riid, ppv);
+}
+
+static ULONG WINAPI DocObjOleCommandTarget_AddRef(IOleCommandTarget *iface)
+{
+    HTMLDocumentObj *This = HTMLDocumentObj_from_IOleCommandTarget(iface);
+    return IUnknown_AddRef(This->outer_unk);
+}
+
+static ULONG WINAPI DocObjOleCommandTarget_Release(IOleCommandTarget *iface)
+{
+    HTMLDocumentObj *This = HTMLDocumentObj_from_IOleCommandTarget(iface);
+    return IUnknown_Release(This->outer_unk);
+}
+
+static HRESULT WINAPI DocObjOleCommandTarget_QueryStatus(IOleCommandTarget *iface, const GUID *pguidCmdGroup,
+        ULONG cCmds, OLECMD prgCmds[], OLECMDTEXT *pCmdText)
+{
+    HTMLDocumentObj *This = HTMLDocumentObj_from_IOleCommandTarget(iface);
+
+    return IOleCommandTarget_QueryStatus(&This->doc_node->IOleCommandTarget_iface,
+                                         pguidCmdGroup, cCmds, prgCmds, pCmdText);
+}
+
+static HRESULT WINAPI DocObjOleCommandTarget_Exec(IOleCommandTarget *iface, const GUID *pguidCmdGroup,
+        DWORD nCmdID, DWORD nCmdexecopt, VARIANT *pvaIn, VARIANT *pvaOut)
+{
+    HTMLDocumentObj *This = HTMLDocumentObj_from_IOleCommandTarget(iface);
+
+    return IOleCommandTarget_Exec(&This->doc_node->IOleCommandTarget_iface,
+                                  pguidCmdGroup, nCmdID, nCmdexecopt, pvaIn, pvaOut);
+}
+
+static const IOleCommandTargetVtbl DocObjOleCommandTargetVtbl = {
+    DocObjOleCommandTarget_QueryInterface,
+    DocObjOleCommandTarget_AddRef,
+    DocObjOleCommandTarget_Release,
+    DocObjOleCommandTarget_QueryStatus,
+    DocObjOleCommandTarget_Exec
 };
 
 void show_context_menu(HTMLDocumentObj *This, DWORD dwID, POINT *ppt, IDispatch *elem)
@@ -963,7 +1018,7 @@ void show_context_menu(HTMLDocumentObj *This, DWORD dwID, POINT *ppt, IDispatch
     DWORD cmdid;
 
     if(This->hostui && S_OK == IDocHostUIHandler_ShowContextMenu(This->hostui,
-            dwID, ppt, (IUnknown*)&This->basedoc.IOleCommandTarget_iface, elem))
+            dwID, ppt, (IUnknown*)&This->IOleCommandTarget_iface, elem))
         return;
 
     menu_res = LoadMenuW(get_shdoclc(), MAKEINTRESOURCEW(IDR_BROWSE_CONTEXT_MENU));
@@ -974,11 +1029,16 @@ void show_context_menu(HTMLDocumentObj *This, DWORD dwID, POINT *ppt, IDispatch
     DestroyMenu(menu_res);
 
     if(cmdid)
-        IOleCommandTarget_Exec(&This->basedoc.IOleCommandTarget_iface, &CGID_MSHTML, cmdid, 0,
+        IOleCommandTarget_Exec(&This->IOleCommandTarget_iface, &CGID_MSHTML, cmdid, 0,
                 NULL, NULL);
 }
 
-void HTMLDocument_OleCmd_Init(HTMLDocument *This)
+void HTMLDocumentNode_OleCmd_Init(HTMLDocumentNode *This)
 {
-    This->IOleCommandTarget_iface.lpVtbl = &OleCommandTargetVtbl;
+    This->IOleCommandTarget_iface.lpVtbl = &DocNodeOleCommandTargetVtbl;
+}
+
+void HTMLDocumentObj_OleCmd_Init(HTMLDocumentObj *This)
+{
+    This->IOleCommandTarget_iface.lpVtbl = &DocObjOleCommandTargetVtbl;
 }
