@@ -17,7 +17,6 @@
  */
 
 #include <stdarg.h>
-#include <assert.h>
 
 #define COBJMACROS
 
@@ -130,7 +129,7 @@ static void get_text_node_data(nsIDOMNode *node, nsAString *nsstr, const PRUnich
     nsres = nsIDOMText_GetData(nstext, nsstr);
     nsIDOMText_Release(nstext);
     if(NS_FAILED(nsres))
-        ERR("GetData failed: %08x\n", nsres);
+        ERR("GetData failed: %08lx\n", nsres);
 
     nsAString_GetData(nsstr, str);
 }
@@ -314,14 +313,14 @@ static void set_start_point(HTMLTxtRange *This, const rangepoint_t *start)
 {
     nsresult nsres = nsIDOMRange_SetStart(This->nsrange, start->node, start->off);
     if(NS_FAILED(nsres))
-        ERR("failed: %08x\n", nsres);
+        ERR("failed: %08lx\n", nsres);
 }
 
 static void set_end_point(HTMLTxtRange *This, const rangepoint_t *end)
 {
     nsresult nsres = nsIDOMRange_SetEnd(This->nsrange, end->node, end->off);
     if(NS_FAILED(nsres))
-        ERR("failed: %08x\n", nsres);
+        ERR("failed: %08lx\n", nsres);
 }
 
 static BOOL is_elem_tag(nsIDOMNode *node, LPCWSTR istag)
@@ -352,7 +351,7 @@ static inline BOOL wstrbuf_init(wstrbuf_t *buf)
 {
     buf->len = 0;
     buf->size = 16;
-    buf->buf = heap_alloc(buf->size * sizeof(WCHAR));
+    buf->buf = malloc(buf->size * sizeof(WCHAR));
     if (!buf->buf) return FALSE;
     *buf->buf = 0;
     return TRUE;
@@ -360,14 +359,14 @@ static inline BOOL wstrbuf_init(wstrbuf_t *buf)
 
 static inline void wstrbuf_finish(wstrbuf_t *buf)
 {
-    heap_free(buf->buf);
+    free(buf->buf);
 }
 
 static void wstrbuf_append_len(wstrbuf_t *buf, LPCWSTR str, int len)
 {
     if(buf->len+len >= buf->size) {
         buf->size = 2*buf->size+len;
-        buf->buf = heap_realloc(buf->buf, buf->size * sizeof(WCHAR));
+        buf->buf = realloc(buf->buf, buf->size * sizeof(WCHAR));
     }
 
     memcpy(buf->buf+buf->len, str, len*sizeof(WCHAR));
@@ -384,7 +383,7 @@ static void wstrbuf_append_nodetxt(wstrbuf_t *buf, LPCWSTR str, int len)
 
     if(buf->len+len >= buf->size) {
         buf->size = 2*buf->size+len;
-        buf->buf = heap_realloc(buf->buf, buf->size * sizeof(WCHAR));
+        buf->buf = realloc(buf->buf, buf->size * sizeof(WCHAR));
     }
 
     if(buf->len && iswspace(buf->buf[buf->len-1])) {
@@ -842,7 +841,7 @@ static ULONG WINAPI HTMLTxtRange_AddRef(IHTMLTxtRange *iface)
     HTMLTxtRange *This = impl_from_IHTMLTxtRange(iface);
     LONG ref = InterlockedIncrement(&This->ref);
 
-    TRACE("(%p) ref=%d\n", This, ref);
+    TRACE("(%p) ref=%ld\n", This, ref);
 
     return ref;
 }
@@ -852,7 +851,7 @@ static ULONG WINAPI HTMLTxtRange_Release(IHTMLTxtRange *iface)
     HTMLTxtRange *This = impl_from_IHTMLTxtRange(iface);
     LONG ref = InterlockedDecrement(&This->ref);
 
-    TRACE("(%p) ref=%d\n", This, ref);
+    TRACE("(%p) ref=%ld\n", This, ref);
 
     if(!ref) {
         if(This->nsrange)
@@ -860,7 +859,7 @@ static ULONG WINAPI HTMLTxtRange_Release(IHTMLTxtRange *iface)
         if(This->doc)
             list_remove(&This->entry);
         release_dispex(&This->dispex);
-        heap_free(This);
+        free(This);
     }
 
     return ref;
@@ -950,23 +949,23 @@ static HRESULT WINAPI HTMLTxtRange_put_text(IHTMLTxtRange *iface, BSTR v)
         return MSHTML_E_NODOC;
 
     nsAString_InitDepend(&text_str, v);
-    nsres = nsIDOMHTMLDocument_CreateTextNode(This->doc->nsdoc, &text_str, &text_node);
+    nsres = nsIDOMDocument_CreateTextNode(This->doc->dom_document, &text_str, &text_node);
     nsAString_Finish(&text_str);
     if(NS_FAILED(nsres)) {
-        ERR("CreateTextNode failed: %08x\n", nsres);
+        ERR("CreateTextNode failed: %08lx\n", nsres);
         return S_OK;
     }
     nsres = nsIDOMRange_DeleteContents(This->nsrange);
     if(NS_FAILED(nsres))
-        ERR("DeleteContents failed: %08x\n", nsres);
+        ERR("DeleteContents failed: %08lx\n", nsres);
 
     nsres = nsIDOMRange_InsertNode(This->nsrange, (nsIDOMNode*)text_node);
     if(NS_FAILED(nsres))
-        ERR("InsertNode failed: %08x\n", nsres);
+        ERR("InsertNode failed: %08lx\n", nsres);
 
     nsres = nsIDOMRange_SetEndAfter(This->nsrange, (nsIDOMNode*)text_node);
     if(NS_FAILED(nsres))
-        ERR("SetEndAfter failed: %08x\n", nsres);
+        ERR("SetEndAfter failed: %08lx\n", nsres);
 
     return IHTMLTxtRange_collapse(&This->IHTMLTxtRange_iface, VARIANT_FALSE);
 }
@@ -1065,7 +1064,7 @@ static HRESULT WINAPI HTMLTxtRange_inRange(IHTMLTxtRange *iface, IHTMLTxtRange *
     }
 
     if(NS_FAILED(nsres))
-        ERR("CompareBoundaryPoints failed: %08x\n", nsres);
+        ERR("CompareBoundaryPoints failed: %08lx\n", nsres);
 
     return S_OK;
 }
@@ -1096,7 +1095,7 @@ static HRESULT WINAPI HTMLTxtRange_isEqual(IHTMLTxtRange *iface, IHTMLTxtRange *
     }
 
     if(NS_FAILED(nsres))
-        ERR("CompareBoundaryPoints failed: %08x\n", nsres);
+        ERR("CompareBoundaryPoints failed: %08lx\n", nsres);
 
     return S_OK;
 }
@@ -1160,16 +1159,21 @@ static HRESULT WINAPI HTMLTxtRange_expand(IHTMLTxtRange *iface, BSTR Unit, VARIA
         nsIDOMHTMLElement *nsbody = NULL;
         nsresult nsres;
 
-        nsres = nsIDOMHTMLDocument_GetBody(This->doc->nsdoc, &nsbody);
+        if(!This->doc->html_document) {
+            FIXME("Not implemented for XML document\n");
+            return E_NOTIMPL;
+        }
+
+        nsres = nsIDOMHTMLDocument_GetBody(This->doc->html_document, &nsbody);
         if(NS_FAILED(nsres) || !nsbody) {
-            ERR("Could not get body: %08x\n", nsres);
+            ERR("Could not get body: %08lx\n", nsres);
             break;
         }
 
         nsres = nsIDOMRange_SelectNodeContents(This->nsrange, (nsIDOMNode*)nsbody);
         nsIDOMHTMLElement_Release(nsbody);
         if(NS_FAILED(nsres)) {
-            ERR("Collapse failed: %08x\n", nsres);
+            ERR("Collapse failed: %08lx\n", nsres);
             break;
         }
 
@@ -1190,7 +1194,7 @@ static HRESULT WINAPI HTMLTxtRange_move(IHTMLTxtRange *iface, BSTR Unit,
     HTMLTxtRange *This = impl_from_IHTMLTxtRange(iface);
     range_unit_t unit;
 
-    TRACE("(%p)->(%s %d %p)\n", This, debugstr_w(Unit), Count, ActualCount);
+    TRACE("(%p)->(%s %ld %p)\n", This, debugstr_w(Unit), Count, ActualCount);
 
     unit = string_to_unit(Unit);
     if(unit == RU_UNKNOWN)
@@ -1232,7 +1236,7 @@ static HRESULT WINAPI HTMLTxtRange_move(IHTMLTxtRange *iface, BSTR Unit,
         FIXME("unimplemented unit %s\n", debugstr_w(Unit));
     }
 
-    TRACE("ret %d\n", *ActualCount);
+    TRACE("ret %ld\n", *ActualCount);
     return S_OK;
 }
 
@@ -1242,7 +1246,7 @@ static HRESULT WINAPI HTMLTxtRange_moveStart(IHTMLTxtRange *iface, BSTR Unit,
     HTMLTxtRange *This = impl_from_IHTMLTxtRange(iface);
     range_unit_t unit;
 
-    TRACE("(%p)->(%s %d %p)\n", This, debugstr_w(Unit), Count, ActualCount);
+    TRACE("(%p)->(%s %ld %p)\n", This, debugstr_w(Unit), Count, ActualCount);
 
     unit = string_to_unit(Unit);
     if(unit == RU_UNKNOWN)
@@ -1280,7 +1284,7 @@ static HRESULT WINAPI HTMLTxtRange_moveEnd(IHTMLTxtRange *iface, BSTR Unit,
     HTMLTxtRange *This = impl_from_IHTMLTxtRange(iface);
     range_unit_t unit;
 
-    TRACE("(%p)->(%s %d %p)\n", This, debugstr_w(Unit), Count, ActualCount);
+    TRACE("(%p)->(%s %ld %p)\n", This, debugstr_w(Unit), Count, ActualCount);
 
     unit = string_to_unit(Unit);
     if(unit == RU_UNKNOWN)
@@ -1319,9 +1323,9 @@ static HRESULT WINAPI HTMLTxtRange_select(IHTMLTxtRange *iface)
 
     TRACE("(%p)\n", This);
 
-    nsres = nsIDOMWindow_GetSelection(This->doc->basedoc.window->nswindow, &nsselection);
+    nsres = nsIDOMWindow_GetSelection(This->doc->outer_window->nswindow, &nsselection);
     if(NS_FAILED(nsres)) {
-        ERR("GetSelection failed: %08x\n", nsres);
+        ERR("GetSelection failed: %08lx\n", nsres);
         return E_FAIL;
     }
 
@@ -1347,14 +1351,14 @@ static HRESULT WINAPI HTMLTxtRange_pasteHTML(IHTMLTxtRange *iface, BSTR html)
     nsres = nsIDOMRange_CreateContextualFragment(This->nsrange, &nsstr, &doc_frag);
     nsAString_Finish(&nsstr);
     if(NS_FAILED(nsres)) {
-        ERR("CreateContextualFragment failed: %08x\n", nsres);
+        ERR("CreateContextualFragment failed: %08lx\n", nsres);
         return E_FAIL;
     }
 
     nsres = nsIDOMRange_InsertNode(This->nsrange, (nsIDOMNode*)doc_frag);
     nsIDOMDocumentFragment_Release(doc_frag);
     if(NS_FAILED(nsres)) {
-        ERR("InsertNode failed: %08x\n", nsres);
+        ERR("InsertNode failed: %08lx\n", nsres);
         return E_FAIL;
     }
 
@@ -1377,7 +1381,7 @@ static HRESULT WINAPI HTMLTxtRange_moveToElementText(IHTMLTxtRange *iface, IHTML
 
     nsres = nsIDOMRange_SelectNodeContents(This->nsrange, elem->node.nsnode);
     if(NS_FAILED(nsres)) {
-        ERR("SelectNodeContents failed: %08x\n", nsres);
+        ERR("SelectNodeContents failed: %08lx\n", nsres);
         return E_FAIL;
     }
 
@@ -1390,7 +1394,7 @@ static HRESULT WINAPI HTMLTxtRange_setEndPoint(IHTMLTxtRange *iface, BSTR how,
     HTMLTxtRange *This = impl_from_IHTMLTxtRange(iface);
     HTMLTxtRange *src_range;
     nsIDOMNode *ref_node;
-    INT32 ref_offset;
+    LONG ref_offset;
     BOOL set_start;
     int how_type;
     INT16 cmp;
@@ -1479,7 +1483,7 @@ static HRESULT WINAPI HTMLTxtRange_compareEndPoints(IHTMLTxtRange *iface, BSTR h
 
     nsres = nsIDOMRange_CompareBoundaryPoints(This->nsrange, nscmpt, src_range->nsrange, &nsret);
     if(NS_FAILED(nsres))
-        ERR("CompareBoundaryPoints failed: %08x\n", nsres);
+        ERR("CompareBoundaryPoints failed: %08lx\n", nsres);
 
     *ret = nsret;
     return S_OK;
@@ -1489,14 +1493,14 @@ static HRESULT WINAPI HTMLTxtRange_findText(IHTMLTxtRange *iface, BSTR String,
         LONG count, LONG Flags, VARIANT_BOOL *Success)
 {
     HTMLTxtRange *This = impl_from_IHTMLTxtRange(iface);
-    FIXME("(%p)->(%s %d %08x %p)\n", This, debugstr_w(String), count, Flags, Success);
+    FIXME("(%p)->(%s %ld %08lx %p)\n", This, debugstr_w(String), count, Flags, Success);
     return E_NOTIMPL;
 }
 
 static HRESULT WINAPI HTMLTxtRange_moveToPoint(IHTMLTxtRange *iface, LONG x, LONG y)
 {
     HTMLTxtRange *This = impl_from_IHTMLTxtRange(iface);
-    FIXME("(%p)->(%d %d)\n", This, x, y);
+    FIXME("(%p)->(%ld %ld)\n", This, x, y);
     return E_NOTIMPL;
 }
 
@@ -1646,7 +1650,7 @@ static HRESULT WINAPI RangeCommandTarget_QueryStatus(IOleCommandTarget *iface, c
         ULONG cCmds, OLECMD prgCmds[], OLECMDTEXT *pCmdText)
 {
     HTMLTxtRange *This = impl_from_IOleCommandTarget(iface);
-    FIXME("(%p)->(%s %d %p %p)\n", This, debugstr_guid(pguidCmdGroup), cCmds, prgCmds, pCmdText);
+    FIXME("(%p)->(%s %ld %p %p)\n", This, debugstr_guid(pguidCmdGroup), cCmds, prgCmds, pCmdText);
     return E_NOTIMPL;
 }
 
@@ -1658,8 +1662,8 @@ static HRESULT exec_indent(HTMLTxtRange *This, VARIANT *in, VARIANT *out)
 
     TRACE("(%p)->(%p %p)\n", This, in, out);
 
-    if(!This->doc->nsdoc) {
-        WARN("NULL nsdoc\n");
+    if(!This->doc->dom_document) {
+        WARN("NULL dom_document\n");
         return E_NOTIMPL;
     }
 
@@ -1686,7 +1690,7 @@ static HRESULT WINAPI RangeCommandTarget_Exec(IOleCommandTarget *iface, const GU
 {
     HTMLTxtRange *This = impl_from_IOleCommandTarget(iface);
 
-    TRACE("(%p)->(%s %d %x %p %p)\n", This, debugstr_guid(pguidCmdGroup), nCmdID,
+    TRACE("(%p)->(%s %ld %lx %p %p)\n", This, debugstr_guid(pguidCmdGroup), nCmdID,
           nCmdexecopt, pvaIn, pvaOut);
 
     if(pguidCmdGroup && IsEqualGUID(&CGID_MSHTML, pguidCmdGroup)) {
@@ -1694,10 +1698,10 @@ static HRESULT WINAPI RangeCommandTarget_Exec(IOleCommandTarget *iface, const GU
         case IDM_INDENT:
             return exec_indent(This, pvaIn, pvaOut);
         default:
-            FIXME("Unsupported cmdid %d of CGID_MSHTML\n", nCmdID);
+            FIXME("Unsupported cmdid %ld of CGID_MSHTML\n", nCmdID);
         }
     }else {
-        FIXME("Unsupported cmd %d of group %s\n", nCmdID, debugstr_guid(pguidCmdGroup));
+        FIXME("Unsupported cmd %ld of group %s\n", nCmdID, debugstr_guid(pguidCmdGroup));
     }
 
     return E_NOTIMPL;
@@ -1716,6 +1720,7 @@ static const tid_t HTMLTxtRange_iface_tids[] = {
     0
 };
 static dispex_static_data_t HTMLTxtRange_dispex = {
+    L"TextRange",
     NULL,
     IHTMLTxtRange_tid,
     HTMLTxtRange_iface_tids
@@ -1725,11 +1730,12 @@ HRESULT HTMLTxtRange_Create(HTMLDocumentNode *doc, nsIDOMRange *nsrange, IHTMLTx
 {
     HTMLTxtRange *ret;
 
-    ret = heap_alloc(sizeof(HTMLTxtRange));
+    ret = malloc(sizeof(HTMLTxtRange));
     if(!ret)
         return E_OUTOFMEMORY;
 
-    init_dispex(&ret->dispex, (IUnknown*)&ret->IHTMLTxtRange_iface, &HTMLTxtRange_dispex);
+    init_dispatch(&ret->dispex, (IUnknown*)&ret->IHTMLTxtRange_iface, &HTMLTxtRange_dispex,
+                                 dispex_compat_mode(&doc->node.event_target.dispex));
 
     ret->IHTMLTxtRange_iface.lpVtbl = &HTMLTxtRangeVtbl;
     ret->IOleCommandTarget_iface.lpVtbl = &OleCommandTargetVtbl;
@@ -1778,7 +1784,7 @@ static ULONG WINAPI HTMLDOMRange_AddRef(IHTMLDOMRange *iface)
     HTMLDOMRange *This = impl_from_IHTMLDOMRange(iface);
     LONG ref = InterlockedIncrement(&This->ref);
 
-    TRACE("(%p) ref=%d\n", This, ref);
+    TRACE("(%p) ref=%ld\n", This, ref);
 
     return ref;
 }
@@ -1788,13 +1794,13 @@ static ULONG WINAPI HTMLDOMRange_Release(IHTMLDOMRange *iface)
     HTMLDOMRange *This = impl_from_IHTMLDOMRange(iface);
     LONG ref = InterlockedDecrement(&This->ref);
 
-    TRACE("(%p) ref=%d\n", This, ref);
+    TRACE("(%p) ref=%ld\n", This, ref);
 
     if(!ref) {
         if(This->nsrange)
             nsIDOMRange_Release(This->nsrange);
         release_dispex(&This->dispex);
-        heap_free(This);
+        free(This);
     }
 
     return ref;
@@ -1880,14 +1886,14 @@ static HRESULT WINAPI HTMLDOMRange_get_commonAncestorContainer(IHTMLDOMRange *if
 static HRESULT WINAPI HTMLDOMRange_setStart(IHTMLDOMRange *iface, IDispatch *node, LONG offset)
 {
     HTMLDOMRange *This = impl_from_IHTMLDOMRange(iface);
-    FIXME("(%p)->(%p, %d)\n", This, node, offset);
+    FIXME("(%p)->(%p, %ld)\n", This, node, offset);
     return E_NOTIMPL;
 }
 
 static HRESULT WINAPI HTMLDOMRange_setEnd(IHTMLDOMRange *iface, IDispatch *node, LONG offset)
 {
     HTMLDOMRange *This = impl_from_IHTMLDOMRange(iface);
-    FIXME("(%p)->(%p, %d)\n", This, node, offset);
+    FIXME("(%p)->(%p, %ld)\n", This, node, offset);
     return E_NOTIMPL;
 }
 
@@ -2060,20 +2066,21 @@ static const tid_t HTMLDOMRange_iface_tids[] = {
 };
 
 static dispex_static_data_t HTMLDOMRange_dispex = {
+    L"Range",
     NULL,
     DispHTMLDOMRange_tid,
     HTMLDOMRange_iface_tids
 };
 
-HRESULT HTMLDOMRange_Create(nsIDOMRange *nsrange, IHTMLDOMRange **p)
+HRESULT create_dom_range(nsIDOMRange *nsrange, compat_mode_t compat_mode, IHTMLDOMRange **p)
 {
     HTMLDOMRange *ret;
 
-    ret = heap_alloc(sizeof(*ret));
+    ret = malloc(sizeof(*ret));
     if(!ret)
         return E_OUTOFMEMORY;
 
-    init_dispex(&ret->dispex, (IUnknown*)&ret->IHTMLDOMRange_iface, &HTMLDOMRange_dispex);
+    init_dispatch(&ret->dispex, (IUnknown*)&ret->IHTMLDOMRange_iface, &HTMLDOMRange_dispex, compat_mode);
 
     ret->IHTMLDOMRange_iface.lpVtbl = &HTMLDOMRangeVtbl;
     ret->ref = 1;
@@ -2133,7 +2140,7 @@ static ULONG WINAPI MarkupPointer2_AddRef(IMarkupPointer2 *iface)
     MarkupPointer *This = impl_from_IMarkupPointer2(iface);
     LONG ref = InterlockedIncrement(&This->ref);
 
-    TRACE("(%p) ref=%d\n", This, ref);
+    TRACE("(%p) ref=%ld\n", This, ref);
 
     return ref;
 }
@@ -2143,10 +2150,10 @@ static ULONG WINAPI MarkupPointer2_Release(IMarkupPointer2 *iface)
     MarkupPointer *This = impl_from_IMarkupPointer2(iface);
     LONG ref = InterlockedDecrement(&This->ref);
 
-    TRACE("(%p) ref=%d\n", This, ref);
+    TRACE("(%p) ref=%ld\n", This, ref);
 
     if(!ref)
-        heap_free(This);
+        free(This);
 
     return ref;
 }
@@ -2297,7 +2304,7 @@ static HRESULT WINAPI MarkupPointer2_FindText(IMarkupPointer2 *iface, OLECHAR *t
                                               IMarkupPointer *end_match, IMarkupPointer *end_search)
 {
     MarkupPointer *This = impl_from_IMarkupPointer2(iface);
-    FIXME("(%p)->(%s %x %p %p)\n", This, debugstr_w(text), flags, end_match, end_search);
+    FIXME("(%p)->(%s %lx %p %p)\n", This, debugstr_w(text), flags, end_match, end_search);
     return E_NOTIMPL;
 }
 
@@ -2318,7 +2325,7 @@ static HRESULT WINAPI MarkupPointer2_GetMarkupPosition(IMarkupPointer2 *iface, L
 static HRESULT WINAPI MarkupPointer2_MoveToMarkupPosition(IMarkupPointer2 *iface, IMarkupContainer *container, LONG mp)
 {
     MarkupPointer *This = impl_from_IMarkupPointer2(iface);
-    FIXME("(%p)->(%p %d)\n", This, container, mp);
+    FIXME("(%p)->(%p %ld)\n", This, container, mp);
     return E_NOTIMPL;
 }
 
@@ -2380,7 +2387,7 @@ HRESULT create_markup_pointer(IMarkupPointer **ret)
 {
     MarkupPointer *markup_pointer;
 
-    if(!(markup_pointer = heap_alloc(sizeof(*markup_pointer))))
+    if(!(markup_pointer = malloc(sizeof(*markup_pointer))))
         return E_OUTOFMEMORY;
 
     markup_pointer->IMarkupPointer2_iface.lpVtbl = &MarkupPointer2Vtbl;
