@@ -99,14 +99,14 @@ static BOOL set_script_prop(ScriptHost *script_host, DWORD property, VARIANT *va
     hres = IActiveScript_QueryInterface(script_host->script, &IID_IActiveScriptProperty,
             (void**)&script_prop);
     if(FAILED(hres)) {
-        WARN("Could not get IActiveScriptProperty iface: %08x\n", hres);
+        WARN("Could not get IActiveScriptProperty iface: %08lx\n", hres);
         return FALSE;
     }
 
     hres = IActiveScriptProperty_SetProperty(script_prop, property, NULL, val);
     IActiveScriptProperty_Release(script_prop);
     if(FAILED(hres)) {
-        WARN("SetProperty(%x) failed: %08x\n", property, hres);
+        WARN("SetProperty(%lx) failed: %08lx\n", property, hres);
         return FALSE;
     }
 
@@ -124,19 +124,19 @@ static BOOL init_script_engine(ScriptHost *script_host)
 
     hres = IActiveScript_QueryInterface(script_host->script, &IID_IActiveScriptParse, (void**)&script_host->parse);
     if(FAILED(hres)) {
-        WARN("Could not get IActiveScriptParse: %08x\n", hres);
+        WARN("Could not get IActiveScriptParse: %08lx\n", hres);
         return FALSE;
     }
 
     hres = IActiveScript_QueryInterface(script_host->script, &IID_IObjectSafety, (void**)&safety);
     if(FAILED(hres)) {
-        FIXME("Could not get IObjectSafety: %08x\n", hres);
+        FIXME("Could not get IObjectSafety: %08lx\n", hres);
         return FALSE;
     }
 
     hres = IObjectSafety_GetInterfaceSafetyOptions(safety, &IID_IActiveScriptParse, &supported_opts, &enabled_opts);
     if(FAILED(hres)) {
-        FIXME("GetInterfaceSafetyOptions failed: %08x\n", hres);
+        FIXME("GetInterfaceSafetyOptions failed: %08lx\n", hres);
     }else if(!(supported_opts & INTERFACE_USES_DISPEX)) {
         FIXME("INTERFACE_USES_DISPEX is not supported\n");
     }else {
@@ -144,7 +144,7 @@ static BOOL init_script_engine(ScriptHost *script_host)
                 INTERFACESAFE_FOR_UNTRUSTED_DATA|INTERFACE_USES_DISPEX|INTERFACE_USES_SECURITY_MANAGER,
                 INTERFACESAFE_FOR_UNTRUSTED_DATA|INTERFACE_USES_DISPEX|INTERFACE_USES_SECURITY_MANAGER);
         if(FAILED(hres))
-            FIXME("SetInterfaceSafetyOptions failed: %08x\n", hres);
+            FIXME("SetInterfaceSafetyOptions failed: %08lx\n", hres);
     }
 
     IObjectSafety_Release(safety);
@@ -175,26 +175,26 @@ static BOOL init_script_engine(ScriptHost *script_host)
 
     hres = IActiveScriptParse_InitNew(script_host->parse);
     if(FAILED(hres)) {
-        WARN("InitNew failed: %08x\n", hres);
+        WARN("InitNew failed: %08lx\n", hres);
         return FALSE;
     }
 
     hres = IActiveScript_SetScriptSite(script_host->script, &script_host->IActiveScriptSite_iface);
     if(FAILED(hres)) {
-        WARN("SetScriptSite failed: %08x\n", hres);
+        WARN("SetScriptSite failed: %08lx\n", hres);
         IActiveScript_Close(script_host->script);
         return FALSE;
     }
 
     hres = IActiveScript_GetScriptState(script_host->script, &state);
     if(FAILED(hres))
-        WARN("GetScriptState failed: %08x\n", hres);
+        WARN("GetScriptState failed: %08lx\n", hres);
     else if(state != SCRIPTSTATE_INITIALIZED)
         FIXME("state = %x\n", state);
 
     hres = IActiveScript_SetScriptState(script_host->script, SCRIPTSTATE_STARTED);
     if(FAILED(hres)) {
-        WARN("Starting script failed: %08x\n", hres);
+        WARN("Starting script failed: %08lx\n", hres);
         return FALSE;
     }
 
@@ -205,14 +205,14 @@ static BOOL init_script_engine(ScriptHost *script_host)
         V_BOOL(&var) = VARIANT_TRUE;
         set_script_prop(script_host, SCRIPTPROP_ABBREVIATE_GLOBALNAME_RESOLUTION, &var);
     }else {
-       WARN("AddNamedItem failed: %08x\n", hres);
+       WARN("AddNamedItem failed: %08lx\n", hres);
     }
 
     hres = IActiveScript_QueryInterface(script_host->script, &IID_IActiveScriptParseProcedure2,
                                         (void**)&script_host->parse_proc);
     if(FAILED(hres)) {
         /* FIXME: QI for IActiveScriptParseProcedure */
-        WARN("Could not get IActiveScriptParseProcedure iface: %08x\n", hres);
+        WARN("Could not get IActiveScriptParseProcedure iface: %08lx\n", hres);
     }
 
     return TRUE;
@@ -308,7 +308,7 @@ static ULONG WINAPI ActiveScriptSite_AddRef(IActiveScriptSite *iface)
     ScriptHost *This = impl_from_IActiveScriptSite(iface);
     LONG ref = InterlockedIncrement(&This->ref);
 
-    TRACE("(%p) ref=%d\n", This, ref);
+    TRACE("(%p) ref=%ld\n", This, ref);
 
     return ref;
 }
@@ -318,13 +318,13 @@ static ULONG WINAPI ActiveScriptSite_Release(IActiveScriptSite *iface)
     ScriptHost *This = impl_from_IActiveScriptSite(iface);
     LONG ref = InterlockedDecrement(&This->ref);
 
-    TRACE("(%p) ref=%d\n", This, ref);
+    TRACE("(%p) ref=%ld\n", This, ref);
 
     if(!ref) {
         release_script_engine(This);
         if(This->window)
             list_remove(&This->entry);
-        heap_free(This);
+        free(This);
     }
 
     return ref;
@@ -345,10 +345,10 @@ static HRESULT WINAPI ActiveScriptSite_GetItemInfo(IActiveScriptSite *iface, LPC
 {
     ScriptHost *This = impl_from_IActiveScriptSite(iface);
 
-    TRACE("(%p)->(%s %x %p %p)\n", This, debugstr_w(pstrName), dwReturnMask, ppiunkItem, ppti);
+    TRACE("(%p)->(%s %lx %p %p)\n", This, debugstr_w(pstrName), dwReturnMask, ppiunkItem, ppti);
 
     if(dwReturnMask != SCRIPTINFO_IUNKNOWN) {
-        FIXME("Unsupported mask %x\n", dwReturnMask);
+        FIXME("Unsupported mask %lx\n", dwReturnMask);
         return E_NOTIMPL;
     }
 
@@ -592,7 +592,7 @@ static HRESULT WINAPI ActiveScriptSiteDebug_GetDocumentContextFromPosition(IActi
             CTXARG_T dwSourceContext, ULONG uCharacterOffset, ULONG uNumChars, IDebugDocumentContext **ppsc)
 {
     ScriptHost *This = impl_from_IActiveScriptSiteDebug(iface);
-    FIXME("(%p)->(%s %u %u %p)\n", This, wine_dbgstr_longlong(dwSourceContext), uCharacterOffset,
+    FIXME("(%p)->(%s %lu %lu %p)\n", This, wine_dbgstr_longlong(dwSourceContext), uCharacterOffset,
           uNumChars, ppsc);
     return E_NOTIMPL;
 }
@@ -674,7 +674,7 @@ static HRESULT WINAPI ASServiceProvider_QueryService(IServiceProvider *iface, RE
         if(!This->window || !This->window->doc)
             return E_NOINTERFACE;
 
-        return IHTMLDocument2_QueryInterface(&This->window->doc->basedoc.IHTMLDocument2_iface, riid, ppv);
+        return IHTMLDocument2_QueryInterface(&This->window->doc->IHTMLDocument2_iface, riid, ppv);
     }
 
     FIXME("(%p)->(%s %s %p)\n", This, debugstr_guid(guidService), debugstr_guid(riid), ppv);
@@ -693,7 +693,7 @@ static ScriptHost *create_script_host(HTMLInnerWindow *window, const GUID *guid)
     ScriptHost *ret;
     HRESULT hres;
 
-    ret = heap_alloc_zero(sizeof(*ret));
+    ret = calloc(1, sizeof(*ret));
     if(!ret)
         return NULL;
 
@@ -713,7 +713,7 @@ static ScriptHost *create_script_host(HTMLInnerWindow *window, const GUID *guid)
     hres = CoCreateInstance(&ret->guid, NULL, CLSCTX_INPROC_SERVER|CLSCTX_INPROC_HANDLER,
             &IID_IActiveScript, (void**)&ret->script);
     if(FAILED(hres))
-        WARN("Could not load script engine: %08x\n", hres);
+        WARN("Could not load script engine: %08lx\n", hres);
     else if(!init_script_engine(ret))
         release_script_engine(ret);
 
@@ -782,7 +782,7 @@ static void set_script_elem_readystate(HTMLScriptElement *script_elem, READYSTAT
             if(script_elem->pending_readystatechange_event)
                 return;
 
-            task = heap_alloc(sizeof(*task));
+            task = malloc(sizeof(*task));
             if(!task)
                 return;
 
@@ -817,7 +817,7 @@ static void parse_elem_text(ScriptHost *script_host, HTMLScriptElement *script_e
     if(SUCCEEDED(hres))
         TRACE("<<<\n");
     else
-        WARN("<<< %08x\n", hres);
+        WARN("<<< %08lx\n", hres);
 }
 
 typedef struct {
@@ -838,7 +838,7 @@ static HRESULT get_binding_text(ScriptBSC *bsc, WCHAR **ret)
     WCHAR *text;
 
     if(!bsc->bsc.read) {
-        text = heap_alloc(sizeof(WCHAR));
+        text = malloc(sizeof(WCHAR));
         if(!text)
             return E_OUTOFMEMORY;
         *text = 0;
@@ -853,7 +853,7 @@ static HRESULT get_binding_text(ScriptBSC *bsc, WCHAR **ret)
             return E_FAIL;
         }
 
-        text = heap_alloc(bsc->bsc.read+sizeof(WCHAR));
+        text = malloc(bsc->bsc.read + sizeof(WCHAR));
         if(!text)
             return E_OUTOFMEMORY;
 
@@ -869,7 +869,7 @@ static HRESULT get_binding_text(ScriptBSC *bsc, WCHAR **ret)
         DWORD len;
 
         len = MultiByteToWideChar(cp, 0, bsc->buf, bsc->bsc.read, NULL, 0);
-        text = heap_alloc((len+1)*sizeof(WCHAR));
+        text = malloc((len + 1) * sizeof(WCHAR));
         if(!text)
             return E_OUTOFMEMORY;
 
@@ -906,7 +906,7 @@ static void script_file_available(ScriptBSC *bsc)
 
         TRACE("Adding to queue\n");
 
-        queue = heap_alloc(sizeof(*queue));
+        queue = malloc(sizeof(*queue));
         if(!queue)
             return;
 
@@ -956,8 +956,8 @@ static void ScriptBSC_destroy(BSCallback *bsc)
     if(This->load_group)
         nsILoadGroup_Release(This->load_group);
 
-    heap_free(This->buf);
-    heap_free(This);
+    free(This->buf);
+    free(This);
 }
 
 static HRESULT ScriptBSC_init_bindinfo(BSCallback *bsc)
@@ -977,7 +977,7 @@ static HRESULT ScriptBSC_start_binding(BSCallback *bsc)
         if(NS_SUCCEEDED(nsres)) {
             nsres = nsILoadGroup_AddRequest(This->load_group, This->request, NULL);
             if(NS_FAILED(nsres))
-                ERR("AddRequest failed: %08x\n", nsres);
+                ERR("AddRequest failed: %08lx\n", nsres);
         }
     }
 
@@ -1005,8 +1005,8 @@ static HRESULT ScriptBSC_stop_binding(BSCallback *bsc, HRESULT result)
     if(SUCCEEDED(result)) {
         script_file_available(This);
     }else {
-        FIXME("binding failed %08x\n", result);
-        heap_free(This->buf);
+        FIXME("binding failed %08lx\n", result);
+        free(This->buf);
         This->buf = NULL;
         This->size = 0;
     }
@@ -1014,7 +1014,7 @@ static HRESULT ScriptBSC_stop_binding(BSCallback *bsc, HRESULT result)
     if(This->request) {
         nsres = nsILoadGroup_RemoveRequest(This->load_group, This->request, NULL, NS_OK);
         if(NS_FAILED(nsres))
-            ERR("RemoveRequest failed: %08x\n", nsres);
+            ERR("RemoveRequest failed: %08lx\n", nsres);
         nsIRequest_Release(This->request);
         This->request = NULL;
     }
@@ -1031,7 +1031,7 @@ static HRESULT ScriptBSC_read_data(BSCallback *bsc, IStream *stream)
     HRESULT hres;
 
     if(!This->buf) {
-        This->buf = heap_alloc(128);
+        This->buf = malloc(128);
         if(!This->buf)
             return E_OUTOFMEMORY;
         This->size = 128;
@@ -1040,7 +1040,7 @@ static HRESULT ScriptBSC_read_data(BSCallback *bsc, IStream *stream)
     do {
         if(This->bsc.read >= This->size) {
             void *new_buf;
-            new_buf = heap_realloc(This->buf, This->size << 1);
+            new_buf = realloc(This->buf, This->size << 1);
             if(!new_buf)
                 return E_OUTOFMEMORY;
             This->size <<= 1;
@@ -1053,7 +1053,7 @@ static HRESULT ScriptBSC_read_data(BSCallback *bsc, IStream *stream)
     return S_OK;
 }
 
-static HRESULT ScriptBSC_on_progress(BSCallback *bsc, ULONG status_code, LPCWSTR status_text)
+static HRESULT ScriptBSC_on_progress(BSCallback *bsc, ULONG progress, ULONG total, ULONG status_code, LPCWSTR status_text)
 {
     return S_OK;
 }
@@ -1111,7 +1111,7 @@ HRESULT load_script(HTMLScriptElement *script_elem, const WCHAR *src, BOOL async
         return hres;
     }
 
-    bsc = heap_alloc_zero(sizeof(*bsc));
+    bsc = calloc(1, sizeof(*bsc));
     if(!bsc) {
         IMoniker_Release(mon);
         IUri_Release(uri);
@@ -1123,7 +1123,7 @@ HRESULT load_script(HTMLScriptElement *script_elem, const WCHAR *src, BOOL async
 
     hres = IUri_GetScheme(uri, &bsc->scheme);
     IUri_Release(uri);
-    if(FAILED(hres))
+    if(hres != S_OK)
         bsc->scheme = URL_SCHEME_UNKNOWN;
 
     IHTMLScriptElement_AddRef(&script_elem->IHTMLScriptElement_iface);
@@ -1162,7 +1162,7 @@ static void parse_inline_script(ScriptHost *script_host, HTMLScriptElement *scri
     set_script_elem_readystate(script_elem, READYSTATE_INTERACTIVE);
 
     if(NS_FAILED(nsres)) {
-        ERR("GetText failed: %08x\n", nsres);
+        ERR("GetText failed: %08lx\n", nsres);
     }else if(*text) {
         parse_elem_text(script_host, script_elem, text);
     }
@@ -1189,7 +1189,7 @@ static BOOL parse_script_elem(ScriptHost *script_host, HTMLScriptElement *script
             return FALSE;
         }
     }else {
-        ERR("GetEvent failed: %08x\n", nsres);
+        ERR("GetEvent failed: %08lx\n", nsres);
     }
     nsAString_Finish(&event_str);
 
@@ -1198,7 +1198,7 @@ static BOOL parse_script_elem(ScriptHost *script_host, HTMLScriptElement *script
     nsAString_GetData(&src_str, &src);
 
     if(NS_FAILED(nsres)) {
-        ERR("GetSrc failed: %08x\n", nsres);
+        ERR("GetSrc failed: %08lx\n", nsres);
     }else if(*src) {
         load_script(script_elem, src, FALSE);
         is_complete = script_elem->parsed;
@@ -1269,7 +1269,7 @@ static BOOL get_script_guid(HTMLInnerWindow *window, nsIDOMHTMLScriptElement *ns
             return ret;
         }
     }else {
-        ERR("GetType failed: %08x\n", nsres);
+        ERR("GetType failed: %08lx\n", nsres);
     }
 
     nsres = nsIDOMHTMLScriptElement_QueryInterface(nsscript, &IID_nsIDOMElement, (void**)&nselem);
@@ -1359,7 +1359,7 @@ IDispatch *script_parse_event(HTMLInnerWindow *window, LPCWSTR text)
         LPWSTR language;
         BOOL b;
 
-        language = heap_alloc((ptr-text+1)*sizeof(WCHAR));
+        language = malloc((ptr - text + 1) * sizeof(WCHAR));
         if(!language)
             return NULL;
 
@@ -1368,7 +1368,7 @@ IDispatch *script_parse_event(HTMLInnerWindow *window, LPCWSTR text)
 
         b = get_guid_from_language(language, &guid);
 
-        heap_free(language);
+        free(language);
 
         if(!b) {
             WARN("Could not find language\n");
@@ -1395,7 +1395,7 @@ IDispatch *script_parse_event(HTMLInnerWindow *window, LPCWSTR text)
             NULL, NULL, L"\"", 0 /* FIXME */, 0,
             SCRIPTPROC_HOSTMANAGESSOURCE|SCRIPTPROC_IMPLICIT_THIS|SCRIPTPROC_IMPLICIT_PARENTS, &disp);
     if(FAILED(hres)) {
-        WARN("ParseProcedureText failed: %08x\n", hres);
+        WARN("ParseProcedureText failed: %08lx\n", hres);
         return NULL;
     }
 
@@ -1432,7 +1432,7 @@ HRESULT exec_script(HTMLInnerWindow *window, const WCHAR *code, const WCHAR *lan
     if(SUCCEEDED(hres))
         TRACE("<<<\n");
     else
-        WARN("<<< %08x\n", hres);
+        WARN("<<< %08lx\n", hres);
 
     return hres;
 }
@@ -1463,7 +1463,7 @@ static EventTarget *find_event_target(HTMLDocumentNode *doc, HTMLScriptElement *
     nsAString_Init(&target_id_str, NULL);
     nsres = nsIDOMHTMLScriptElement_GetHtmlFor(script_elem->nsscript, &target_id_str);
     if(NS_FAILED(nsres)) {
-        ERR("GetScriptFor failed: %08x\n", nsres);
+        ERR("GetScriptFor failed: %08lx\n", nsres);
         nsAString_Finish(&target_id_str);
         return NULL;
     }
@@ -1473,7 +1473,7 @@ static EventTarget *find_event_target(HTMLDocumentNode *doc, HTMLScriptElement *
         FIXME("Empty for attribute\n");
     }else if(!wcscmp(target_id, L"document")) {
         event_target = &doc->node.event_target;
-        htmldoc_addref(&doc->basedoc);
+        IHTMLDOMNode_AddRef(&doc->node.IHTMLDOMNode_iface);
     }else if(!wcscmp(target_id, L"window")) {
         if(doc->window) {
             event_target = &doc->window->event_target;
@@ -1542,7 +1542,7 @@ static IDispatch *parse_event_elem(HTMLDocumentNode *doc, HTMLScriptElement *scr
         const PRUnichar *event_val;
 
         nsAString_GetData(&nsstr, &event_val);
-        event = heap_strdupW(event_val);
+        event = wcsdup(event_val);
     }
     nsAString_Finish(&nsstr);
     if(!event)
@@ -1550,7 +1550,7 @@ static IDispatch *parse_event_elem(HTMLDocumentNode *doc, HTMLScriptElement *scr
 
     if(!parse_event_str(event, &args)) {
         WARN("parsing %s failed\n", debugstr_w(event));
-        heap_free(event);
+        free(event);
         return NULL;
     }
 
@@ -1566,12 +1566,12 @@ static IDispatch *parse_event_elem(HTMLDocumentNode *doc, HTMLScriptElement *scr
         if(FAILED(hres))
             disp = NULL;
     }else {
-        ERR("GetText failed: %08x\n", nsres);
+        ERR("GetText failed: %08lx\n", nsres);
         disp = NULL;
     }
     nsAString_Finish(&nsstr);
     if(!disp) {
-        heap_free(event);
+        free(event);
         return NULL;
     }
 
@@ -1596,14 +1596,14 @@ void bind_event_scripts(HTMLDocumentNode *doc)
 
     TRACE("%p\n", doc);
 
-    if(!doc->nsdoc)
+    if(!doc->dom_document)
         return;
 
     nsAString_InitDepend(&selector_str, L"script[event]");
-    nsres = nsIDOMHTMLDocument_QuerySelectorAll(doc->nsdoc, &selector_str, &node_list);
+    nsres = nsIDOMDocument_QuerySelectorAll(doc->dom_document, &selector_str, &node_list);
     nsAString_Finish(&selector_str);
     if(NS_FAILED(nsres)) {
-        ERR("QuerySelectorAll failed: %08x\n", nsres);
+        ERR("QuerySelectorAll failed: %08lx\n", nsres);
         return;
     }
 
@@ -1616,7 +1616,7 @@ void bind_event_scripts(HTMLDocumentNode *doc)
     for(i=0; i < length; i++) {
         nsres = nsIDOMNodeList_Item(node_list, i, &script_node);
         if(NS_FAILED(nsres) || !script_node) {
-            ERR("Item(%d) failed: %08x\n", i, nsres);
+            ERR("Item(%d) failed: %08lx\n", i, nsres);
             continue;
         }
 
@@ -1644,7 +1644,7 @@ void bind_event_scripts(HTMLDocumentNode *doc)
                     node_release(&plugin_container->element.node);
             }
 
-            heap_free(event);
+            free(event);
             IDispatch_Release(event_disp);
         }
 
@@ -1717,13 +1717,13 @@ static BOOL use_gecko_script(IUri *uri)
 
     hres = IInternetSecurityManager_MapUrlToZone(get_security_manager(), display_uri, &zone, 0);
     if(FAILED(hres)) {
-        WARN("Could not map %s to zone: %08x\n", debugstr_w(display_uri), hres);
+        WARN("Could not map %s to zone: %08lx\n", debugstr_w(display_uri), hres);
         SysFreeString(display_uri);
         return TRUE;
     }
 
     SysFreeString(display_uri);
-    TRACE("zone %d\n", zone);
+    TRACE("zone %ld\n", zone);
     return zone == URLZONE_UNTRUSTED;
 }
 
@@ -1752,7 +1752,7 @@ void update_browser_script_mode(GeckoBrowser *browser, IUri *uri)
     }
 
     if(NS_FAILED(nsres))
-        ERR("JavaScript setup failed: %08x\n", nsres);
+        ERR("JavaScript setup failed: %08lx\n", nsres);
 }
 
 void release_script_hosts(HTMLInnerWindow *window)
@@ -1765,7 +1765,7 @@ void release_script_hosts(HTMLInnerWindow *window)
 
         list_remove(&queue_iter->entry);
         IHTMLScriptElement_Release(&queue_iter->script->IHTMLScriptElement_iface);
-        heap_free(queue_iter);
+        free(queue_iter);
     }
 
     while(!list_empty(&window->script_hosts)) {
