@@ -198,6 +198,7 @@ static const NodeImplVtbl SVGElementImplVtbl = {
     HTMLElement_destructor,
     HTMLElement_cpc,
     HTMLElement_clone,
+    HTMLElement_dispatch_nsevent_hook,
     NULL,
     HTMLElement_get_attr_col,
 };
@@ -487,14 +488,14 @@ static HRESULT WINAPI SVGSVGElement_get_currentTranslate(ISVGSVGElement *iface,
 static HRESULT WINAPI SVGSVGElement_suspendRedraw(ISVGSVGElement *iface, ULONG max_wait, ULONG *p)
 {
     SVGSVGElement *This = impl_from_ISVGSVGElement(iface);
-    FIXME("(%p)->(%u %p)\n", This, max_wait, p);
+    FIXME("(%p)->(%lu %p)\n", This, max_wait, p);
     return E_NOTIMPL;
 }
 
 static HRESULT WINAPI SVGSVGElement_unsuspendRedraw(ISVGSVGElement *iface, ULONG id)
 {
     SVGSVGElement *This = impl_from_ISVGSVGElement(iface);
-    FIXME("(%p)->(%u)\n", This, id);
+    FIXME("(%p)->(%lu)\n", This, id);
     return E_NOTIMPL;
 }
 
@@ -739,6 +740,7 @@ static const NodeImplVtbl SVGSVGElementImplVtbl = {
     HTMLElement_destructor,
     HTMLElement_cpc,
     HTMLElement_clone,
+    HTMLElement_dispatch_nsevent_hook,
     NULL,
     HTMLElement_get_attr_col,
 };
@@ -747,7 +749,7 @@ static HRESULT create_viewport_element(HTMLDocumentNode *doc, nsIDOMSVGElement *
 {
     SVGSVGElement *ret;
 
-    ret = heap_alloc_zero(sizeof(SVGSVGElement));
+    ret = calloc(1, sizeof(SVGSVGElement));
     if(!ret)
         return E_OUTOFMEMORY;
 
@@ -908,6 +910,7 @@ static const NodeImplVtbl SVGCircleElementImplVtbl = {
     HTMLElement_destructor,
     HTMLElement_cpc,
     HTMLElement_clone,
+    HTMLElement_dispatch_nsevent_hook,
     NULL,
     HTMLElement_get_attr_col,
 };
@@ -916,7 +919,7 @@ static HRESULT create_circle_element(HTMLDocumentNode *doc, nsIDOMSVGElement *ns
 {
     SVGCircleElement *ret;
 
-    ret = heap_alloc_zero(sizeof(SVGCircleElement));
+    ret = calloc(1, sizeof(SVGCircleElement));
     if(!ret)
         return E_OUTOFMEMORY;
 
@@ -1038,7 +1041,7 @@ static HRESULT WINAPI SVGTextContentElement_getSubStringLength(ISVGTextContentEl
                                                                LONG charnum, LONG nchars, float *p)
 {
     SVGTextContentElement *This = impl_from_ISVGTextContentElement(iface);
-    FIXME("(%p)->(%d %d %p)\n", This, charnum, nchars, p);
+    FIXME("(%p)->(%ld %ld %p)\n", This, charnum, nchars, p);
     return E_NOTIMPL;
 }
 
@@ -1046,7 +1049,7 @@ static HRESULT WINAPI SVGTextContentElement_getStartPositionOfChar(ISVGTextConte
                                                                    LONG charnum, ISVGPoint **p)
 {
     SVGTextContentElement *This = impl_from_ISVGTextContentElement(iface);
-    FIXME("(%p)->(%d %p)\n", This, charnum, p);
+    FIXME("(%p)->(%ld %p)\n", This, charnum, p);
     return E_NOTIMPL;
 }
 
@@ -1054,7 +1057,7 @@ static HRESULT WINAPI SVGTextContentElement_getEndPositionOfChar(ISVGTextContent
                                                                  LONG charnum, ISVGPoint **p)
 {
     SVGTextContentElement *This = impl_from_ISVGTextContentElement(iface);
-    FIXME("(%p)->(%d %p)\n", This, charnum, p);
+    FIXME("(%p)->(%ld %p)\n", This, charnum, p);
     return E_NOTIMPL;
 }
 
@@ -1062,7 +1065,7 @@ static HRESULT WINAPI SVGTextContentElement_getExtentOfChar(ISVGTextContentEleme
                                                             LONG charnum, ISVGRect **p)
 {
     SVGTextContentElement *This = impl_from_ISVGTextContentElement(iface);
-    FIXME("(%p)->(%d %p)\n", This, charnum, p);
+    FIXME("(%p)->(%ld %p)\n", This, charnum, p);
     return E_NOTIMPL;
 }
 
@@ -1070,7 +1073,7 @@ static HRESULT WINAPI SVGTextContentElement_getRotationOfChar(ISVGTextContentEle
                                                               LONG charnum, float *p)
 {
     SVGTextContentElement *This = impl_from_ISVGTextContentElement(iface);
-    FIXME("(%p)->(%d %p)\n", This, charnum, p);
+    FIXME("(%p)->(%ld %p)\n", This, charnum, p);
     return E_NOTIMPL;
 }
 
@@ -1086,7 +1089,7 @@ static HRESULT WINAPI SVGTextContentElement_selectSubString(ISVGTextContentEleme
                                                             LONG charnum, LONG nchars)
 {
     SVGTextContentElement *This = impl_from_ISVGTextContentElement(iface);
-    FIXME("(%p)->(%d %d)\n", This, charnum, nchars);
+    FIXME("(%p)->(%ld %ld)\n", This, charnum, nchars);
     return E_NOTIMPL;
 }
 
@@ -1152,6 +1155,7 @@ static const NodeImplVtbl SVGTSpanElementImplVtbl = {
     HTMLElement_destructor,
     HTMLElement_cpc,
     HTMLElement_clone,
+    HTMLElement_dispatch_nsevent_hook,
     NULL,
     HTMLElement_get_attr_col,
 };
@@ -1160,7 +1164,7 @@ static HRESULT create_tspan_element(HTMLDocumentNode *doc, nsIDOMSVGElement *nse
 {
     SVGTSpanElement *ret;
 
-    ret = heap_alloc_zero(sizeof(SVGTSpanElement));
+    ret = calloc(1, sizeof(SVGTSpanElement));
     if(!ret)
         return E_OUTOFMEMORY;
 
@@ -1185,7 +1189,7 @@ HRESULT create_svg_element(HTMLDocumentNode *doc, nsIDOMSVGElement *dom_element,
     if(!wcscmp(tag_name, L"tspan"))
         return create_tspan_element(doc, dom_element, elem);
 
-    svg_element = heap_alloc_zero(sizeof(*svg_element));
+    svg_element = calloc(1, sizeof(*svg_element));
     if(!svg_element)
         return E_OUTOFMEMORY;
 
