@@ -48,7 +48,7 @@ typedef struct {
 
 static void default_task_destr(task_t *task)
 {
-    heap_free(task);
+    free(task);
 }
 
 HRESULT push_task(task_t *task, task_proc_t proc, task_proc_t destr, LONG magic)
@@ -60,7 +60,7 @@ HRESULT push_task(task_t *task, task_proc_t proc, task_proc_t destr, LONG magic)
         if(destr)
             destr(task);
         else
-            heap_free(task);
+            free(task);
         return E_OUTOFMEMORY;
     }
 
@@ -97,7 +97,7 @@ static void release_task_timer(HWND thread_hwnd, task_timer_t *timer)
 
     IDispatch_Release(timer->disp);
 
-    heap_free(timer);
+    free(timer);
 }
 
 void remove_target_tasks(LONG target)
@@ -174,7 +174,7 @@ HRESULT set_task_timer(HTMLInnerWindow *window, LONG msec, enum timer_type timer
     if(!thread_data)
         return E_OUTOFMEMORY;
 
-    timer = heap_alloc(sizeof(task_timer_t));
+    timer = malloc(sizeof(task_timer_t));
     if(!timer)
         return E_OUTOFMEMORY;
 
@@ -208,7 +208,8 @@ HRESULT clear_task_timer(HTMLInnerWindow *window, DWORD id)
 
     LIST_FOR_EACH_ENTRY(iter, &thread_data->timer_list, task_timer_t, entry) {
         if(iter->id == id && iter->window == window) {
-            release_task_timer(thread_data->thread_hwnd, iter);
+            if(iter->type != TIMER_ANIMATION_FRAME)
+                release_task_timer(thread_data->thread_hwnd, iter);
             return S_OK;
         }
     }
@@ -217,6 +218,26 @@ HRESULT clear_task_timer(HTMLInnerWindow *window, DWORD id)
     return S_OK;
 }
 
+HRESULT clear_animation_timer(HTMLInnerWindow *window, DWORD id)
+{
+    thread_data_t *thread_data = get_thread_data(FALSE);
+    task_timer_t *iter;
+
+    if(!thread_data)
+        return S_OK;
+
+    LIST_FOR_EACH_ENTRY(iter, &thread_data->timer_list, task_timer_t, entry) {
+        if(iter->id == id && iter->window == window) {
+            if(iter->type == TIMER_ANIMATION_FRAME)
+                release_task_timer(thread_data->thread_hwnd, iter);
+            return S_OK;
+        }
+    }
+
+    WARN("timer not found\n");
+    return S_OK;
+}
+
 static const char *debugstr_timer_type(enum timer_type type)
 {
     switch(type) {
@@ -250,7 +271,7 @@ static void call_timer_disp(IDispatch *disp, enum timer_type timer_type)
     if(hres == S_OK)
         TRACE("%p %s <<<\n", disp, debugstr_timer_type(timer_type));
     else
-        WARN("%p %s <<< %08x\n", disp, debugstr_timer_type(timer_type), hres);
+        WARN("%p %s <<< %08lx\n", disp, debugstr_timer_type(timer_type), hres);
 
     VariantClear(&res);
 }
@@ -328,7 +349,7 @@ static LRESULT WINAPI hidden_proc(HWND hwnd, UINT msg, WPARAM wParam, LPARAM lPa
     }
 
     if(msg > WM_USER)
-        FIXME("(%p %d %lx %lx)\n", hwnd, msg, wParam, lParam);
+        FIXME("(%p %d %Ix %Ix)\n", hwnd, msg, wParam, lParam);
 
     return DefWindowProcW(hwnd, msg, wParam, lParam);
 }
@@ -388,13 +409,14 @@ thread_data_t *get_thread_data(BOOL create)
 
     thread_data = TlsGetValue(mshtml_tls);
     if(!thread_data && create) {
-        thread_data = heap_alloc_zero(sizeof(thread_data_t));
+        thread_data = calloc(1, sizeof(thread_data_t));
         if(!thread_data)
             return NULL;
 
         TlsSetValue(mshtml_tls, thread_data);
         list_init(&thread_data->task_list);
         list_init(&thread_data->timer_list);
+        wine_rb_init(&thread_data->session_storage_map, session_storage_map_cmp);
     }
 
     return thread_data;
