@@ -141,21 +141,17 @@ static UINT OpenURLSubkey(HKEY rootkey, HKEY *key, BOOL create)
 /******************************************************************
  *  MsiSourceListEnumMediaDisksA   (MSI.@)
  */
-UINT WINAPI MsiSourceListEnumMediaDisksA(LPCSTR szProductCodeOrPatchCode,
-                                         LPCSTR szUserSid, MSIINSTALLCONTEXT dwContext,
-                                         DWORD dwOptions, DWORD dwIndex, LPDWORD pdwDiskId,
-                                         LPSTR szVolumeLabel, LPDWORD pcchVolumeLabel,
-                                         LPSTR szDiskPrompt, LPDWORD pcchDiskPrompt)
+UINT WINAPI MsiSourceListEnumMediaDisksA( const char *szProductCodeOrPatchCode, const char *szUserSid,
+                                          MSIINSTALLCONTEXT dwContext, DWORD dwOptions, DWORD dwIndex,
+                                          DWORD *pdwDiskId, char *szVolumeLabel, DWORD *pcchVolumeLabel,
+                                          char *szDiskPrompt, DWORD *pcchDiskPrompt )
 {
-    LPWSTR product = NULL;
-    LPWSTR usersid = NULL;
-    LPWSTR volume = NULL;
-    LPWSTR prompt = NULL;
+    WCHAR *product = NULL, *usersid = NULL, *volume = NULL, *prompt = NULL;
     UINT r = ERROR_INVALID_PARAMETER;
 
-    TRACE("(%s, %s, %d, %d, %d, %p, %p, %p, %p, %p)\n", debugstr_a(szProductCodeOrPatchCode),
-          debugstr_a(szUserSid), dwContext, dwOptions, dwIndex, pdwDiskId,
-          szVolumeLabel, pcchVolumeLabel, szDiskPrompt, pcchDiskPrompt);
+    TRACE( "%s, %s, %d, %#lx, %lu, %p, %p, %p, %p, %p\n", debugstr_a(szProductCodeOrPatchCode),
+           debugstr_a(szUserSid), dwContext, dwOptions, dwIndex, pdwDiskId, szVolumeLabel, pcchVolumeLabel,
+           szDiskPrompt, pcchDiskPrompt );
 
     if (szDiskPrompt && !pcchDiskPrompt)
         return ERROR_INVALID_PARAMETER;
@@ -166,10 +162,10 @@ UINT WINAPI MsiSourceListEnumMediaDisksA(LPCSTR szProductCodeOrPatchCode,
     /* FIXME: add tests for an invalid format */
 
     if (pcchVolumeLabel)
-        volume = msi_alloc(*pcchVolumeLabel * sizeof(WCHAR));
+        volume = malloc(*pcchVolumeLabel * sizeof(WCHAR));
 
     if (pcchDiskPrompt)
-        prompt = msi_alloc(*pcchDiskPrompt * sizeof(WCHAR));
+        prompt = malloc(*pcchDiskPrompt * sizeof(WCHAR));
 
     if (volume) *volume = '\0';
     if (prompt) *prompt = '\0';
@@ -188,10 +184,10 @@ UINT WINAPI MsiSourceListEnumMediaDisksA(LPCSTR szProductCodeOrPatchCode,
                             *pcchDiskPrompt + 1, NULL, NULL);
 
 done:
-    msi_free(product);
-    msi_free(usersid);
-    msi_free(volume);
-    msi_free(prompt);
+    free(product);
+    free(usersid);
+    free(volume);
+    free(prompt);
 
     return r;
 }
@@ -199,11 +195,10 @@ done:
 /******************************************************************
  *  MsiSourceListEnumMediaDisksW   (MSI.@)
  */
-UINT WINAPI MsiSourceListEnumMediaDisksW(LPCWSTR szProductCodeOrPatchCode,
-                                         LPCWSTR szUserSid, MSIINSTALLCONTEXT dwContext,
-                                         DWORD dwOptions, DWORD dwIndex, LPDWORD pdwDiskId,
-                                         LPWSTR szVolumeLabel, LPDWORD pcchVolumeLabel,
-                                         LPWSTR szDiskPrompt, LPDWORD pcchDiskPrompt)
+UINT WINAPI MsiSourceListEnumMediaDisksW( const WCHAR *szProductCodeOrPatchCode, const WCHAR *szUserSid,
+                                          MSIINSTALLCONTEXT dwContext, DWORD dwOptions, DWORD dwIndex,
+                                          DWORD *pdwDiskId, WCHAR *szVolumeLabel, DWORD *pcchVolumeLabel,
+                                          WCHAR *szDiskPrompt, DWORD *pcchDiskPrompt )
 {
     WCHAR squashed_pc[SQUASHED_GUID_SIZE], convert[11];
     WCHAR *value = NULL, *data = NULL, *ptr, *ptr2;
@@ -213,9 +208,9 @@ UINT WINAPI MsiSourceListEnumMediaDisksW(LPCWSTR szProductCodeOrPatchCode,
     UINT r;
     static DWORD index = 0;
 
-    TRACE("(%s, %s, %d, %d, %d, %p, %p, %p, %p)\n", debugstr_w(szProductCodeOrPatchCode),
-          debugstr_w(szUserSid), dwContext, dwOptions, dwIndex, szVolumeLabel,
-          pcchVolumeLabel, szDiskPrompt, pcchDiskPrompt);
+    TRACE( "%s, %s, %d, %#lx, %lu, %p, %p, %p, %p\n", debugstr_w(szProductCodeOrPatchCode),
+           debugstr_w(szUserSid), dwContext, dwOptions, dwIndex, szVolumeLabel, pcchVolumeLabel,
+           szDiskPrompt, pcchDiskPrompt );
 
     if (!szProductCodeOrPatchCode || !squash_guid( szProductCodeOrPatchCode, squashed_pc ))
         return ERROR_INVALID_PARAMETER;
@@ -254,8 +249,8 @@ UINT WINAPI MsiSourceListEnumMediaDisksW(LPCWSTR szProductCodeOrPatchCode,
         goto done;
     }
 
-    value = msi_alloc(++valuesz * sizeof(WCHAR));
-    data = msi_alloc(++datasz * sizeof(WCHAR));
+    value = malloc(++valuesz * sizeof(WCHAR));
+    data = malloc(++datasz * sizeof(WCHAR));
     if (!value || !data)
     {
         r = ERROR_OUTOFMEMORY;
@@ -321,8 +316,8 @@ UINT WINAPI MsiSourceListEnumMediaDisksW(LPCWSTR szProductCodeOrPatchCode,
     index++;
 
 done:
-    msi_free(value);
-    msi_free(data);
+    free(value);
+    free(data);
     RegCloseKey(source);
 
     return r;
@@ -331,20 +326,17 @@ done:
 /******************************************************************
  *  MsiSourceListEnumSourcesA   (MSI.@)
  */
-UINT WINAPI MsiSourceListEnumSourcesA(LPCSTR szProductCodeOrPatch, LPCSTR szUserSid,
-                                      MSIINSTALLCONTEXT dwContext,
-                                      DWORD dwOptions, DWORD dwIndex,
-                                      LPSTR szSource, LPDWORD pcchSource)
+UINT WINAPI MsiSourceListEnumSourcesA( const char *szProductCodeOrPatch, const char *szUserSid,
+                                       MSIINSTALLCONTEXT dwContext, DWORD dwOptions, DWORD dwIndex, char *szSource,
+                                       DWORD *pcchSource )
 {
-    LPWSTR product = NULL;
-    LPWSTR usersid = NULL;
-    LPWSTR source = NULL;
+    WCHAR *product = NULL, *usersid = NULL, *source = NULL;
     DWORD len = 0;
     UINT r = ERROR_INVALID_PARAMETER;
     static DWORD index = 0;
 
-    TRACE("(%s, %s, %d, %d, %d, %p, %p)\n", debugstr_a(szProductCodeOrPatch),
-          debugstr_a(szUserSid), dwContext, dwOptions, dwIndex, szSource, pcchSource);
+    TRACE( "%s, %s, %d, %#lx, %lu, %p, %p)\n", debugstr_a(szProductCodeOrPatch), debugstr_a(szUserSid), dwContext,
+           dwOptions, dwIndex, szSource, pcchSource );
 
     if (dwIndex == 0)
         index = 0;
@@ -363,7 +355,7 @@ UINT WINAPI MsiSourceListEnumSourcesA(LPCSTR szProductCodeOrPatch, LPCSTR szUser
     if (r != ERROR_SUCCESS)
         goto done;
 
-    source = msi_alloc(++len * sizeof(WCHAR));
+    source = malloc(++len * sizeof(WCHAR));
     if (!source)
     {
         r = ERROR_OUTOFMEMORY;
@@ -386,9 +378,9 @@ UINT WINAPI MsiSourceListEnumSourcesA(LPCSTR szProductCodeOrPatch, LPCSTR szUser
         *pcchSource = len - 1;
 
 done:
-    msi_free(product);
-    msi_free(usersid);
-    msi_free(source);
+    free(product);
+    free(usersid);
+    free(source);
 
     if (r == ERROR_SUCCESS)
     {
@@ -403,10 +395,9 @@ done:
 /******************************************************************
  *  MsiSourceListEnumSourcesW   (MSI.@)
  */
-UINT WINAPI MsiSourceListEnumSourcesW(LPCWSTR szProductCodeOrPatch, LPCWSTR szUserSid,
-                                      MSIINSTALLCONTEXT dwContext,
-                                      DWORD dwOptions, DWORD dwIndex,
-                                      LPWSTR szSource, LPDWORD pcchSource)
+UINT WINAPI MsiSourceListEnumSourcesW( const WCHAR *szProductCodeOrPatch, const WCHAR *szUserSid,
+                                       MSIINSTALLCONTEXT dwContext, DWORD dwOptions, DWORD dwIndex, WCHAR *szSource,
+                                       DWORD *pcchSource )
 {
     WCHAR squashed_pc[SQUASHED_GUID_SIZE], name[32];
     HKEY source = NULL, subkey = NULL;
@@ -414,8 +405,8 @@ UINT WINAPI MsiSourceListEnumSourcesW(LPCWSTR szProductCodeOrPatch, LPCWSTR szUs
     UINT r = ERROR_INVALID_PARAMETER;
     static DWORD index = 0;
 
-    TRACE("(%s, %s, %d, %d, %d, %p, %p)\n", debugstr_w(szProductCodeOrPatch),
-          debugstr_w(szUserSid), dwContext, dwOptions, dwIndex, szSource, pcchSource);
+    TRACE( "%s, %s, %d, %#lx, %lu, %p, %p\n", debugstr_w(szProductCodeOrPatch), debugstr_w(szUserSid), dwContext,
+           dwOptions, dwIndex, szSource, pcchSource );
 
     if (dwIndex == 0)
         index = 0;
@@ -500,7 +491,7 @@ UINT WINAPI MsiSourceListGetInfoA( LPCSTR szProduct, LPCSTR szUserSid,
     if (ret != ERROR_SUCCESS)
         goto done;
 
-    value = msi_alloc(++len * sizeof(WCHAR));
+    value = malloc(++len * sizeof(WCHAR));
     if (!value)
         return ERROR_OUTOFMEMORY;
 
@@ -519,10 +510,10 @@ UINT WINAPI MsiSourceListGetInfoA( LPCSTR szProduct, LPCSTR szUserSid,
     *pcchValue = len - 1;
 
 done:
-    msi_free(product);
-    msi_free(usersid);
-    msi_free(property);
-    msi_free(value);
+    free(product);
+    free(usersid);
+    free(property);
+    free(value);
     return ret;
 }
 
@@ -592,13 +583,13 @@ UINT WINAPI MsiSourceListGetInfoW( LPCWSTR szProduct, LPCWSTR szUserSid,
             goto output_out;
         }
 
-        source = msi_alloc(size);
+        source = malloc(size);
         RegQueryValueExW(sourcekey, INSTALLPROPERTY_LASTUSEDSOURCEW,
                          0, 0, (LPBYTE)source, &size);
 
         if (!*source)
         {
-            msi_free(source);
+            free(source);
             RegCloseKey(sourcekey);
             return ERROR_SUCCESS;
         }
@@ -607,7 +598,7 @@ UINT WINAPI MsiSourceListGetInfoW( LPCWSTR szProduct, LPCWSTR szUserSid,
         {
             if (*source != 'n' && *source != 'u' && *source != 'm')
             {
-                msi_free(source);
+                free(source);
                 RegCloseKey(sourcekey);
                 return ERROR_SUCCESS;
             }
@@ -633,7 +624,7 @@ output_out:
         }
 
         *pcchValue = lstrlenW(ptr);
-        msi_free(source);
+        free(source);
     }
     else if (!wcscmp( szProperty, INSTALLPROPERTY_PACKAGENAMEW ))
     {
@@ -684,10 +675,10 @@ UINT WINAPI MsiSourceListSetInfoA(LPCSTR szProduct, LPCSTR szUserSid,
     ret = MsiSourceListSetInfoW(product, usersid, dwContext, dwOptions,
                                 property, value);
 
-    msi_free(product);
-    msi_free(usersid);
-    msi_free(property);
-    msi_free(value);
+    free(product);
+    free(usersid);
+    free(property);
+    free(value);
 
     return ret;
 }
@@ -729,14 +720,14 @@ UINT msi_set_last_used_source(LPCWSTR product, LPCWSTR usersid,
     }
 
     size = lstrlenW(L"%c;%d;%s") + lstrlenW(value) + 7;
-    buffer = msi_alloc(size * sizeof(WCHAR));
+    buffer = malloc(size * sizeof(WCHAR));
     if (!buffer)
         return ERROR_OUTOFMEMORY;
 
     r = OpenSourceKey(product, &source, MSICODE_PRODUCT, context, FALSE);
     if (r != ERROR_SUCCESS)
     {
-        msi_free(buffer);
+        free(buffer);
         return r;
     }
 
@@ -745,7 +736,7 @@ UINT msi_set_last_used_source(LPCWSTR product, LPCWSTR usersid,
     size = (lstrlenW(buffer) + 1) * sizeof(WCHAR);
     r = RegSetValueExW(source, INSTALLPROPERTY_LASTUSEDSOURCEW, 0,
                        REG_SZ, (LPBYTE)buffer, size);
-    msi_free(buffer);
+    free(buffer);
 
     RegCloseKey(source);
     return r;
@@ -754,17 +745,16 @@ UINT msi_set_last_used_source(LPCWSTR product, LPCWSTR usersid,
 /******************************************************************
  *  MsiSourceListSetInfoW   (MSI.@)
  */
-UINT WINAPI MsiSourceListSetInfoW( LPCWSTR szProduct, LPCWSTR szUserSid,
-                                   MSIINSTALLCONTEXT dwContext, DWORD dwOptions,
-                                   LPCWSTR szProperty, LPCWSTR szValue)
+UINT WINAPI MsiSourceListSetInfoW( const WCHAR *szProduct, const WCHAR *szUserSid, MSIINSTALLCONTEXT dwContext,
+                                   DWORD dwOptions, const WCHAR *szProperty, const WCHAR *szValue )
 {
     WCHAR squashed_pc[SQUASHED_GUID_SIZE];
     HKEY sourcekey, media;
     LPCWSTR property;
     UINT rc;
 
-    TRACE("%s %s %x %x %s %s\n", debugstr_w(szProduct), debugstr_w(szUserSid),
-            dwContext, dwOptions, debugstr_w(szProperty), debugstr_w(szValue));
+    TRACE( "%s, %s, %d, %#lx, %s, %s\n", debugstr_w(szProduct), debugstr_w(szUserSid), dwContext, dwOptions,
+           debugstr_w(szProperty), debugstr_w(szValue) );
 
     if (!szProduct || !squash_guid( szProduct, squashed_pc ))
         return ERROR_INVALID_PARAMETER;
@@ -861,12 +851,12 @@ UINT WINAPI MsiSourceListAddSourceW( LPCWSTR szProduct, LPCWSTR szUserName,
     {
         if (LookupAccountNameW(NULL, szUserName, NULL, &sidsize, NULL, &domsize, NULL))
         {
-            PSID psid = msi_alloc(sidsize);
+            PSID psid = malloc(sidsize);
 
             if (LookupAccountNameW(NULL, szUserName, psid, &sidsize, NULL, &domsize, NULL))
                 ConvertSidToStringSidW(psid, &sidstr);
 
-            msi_free(psid);
+            free(psid);
         }
 
         r = MSIREG_OpenProductKey(szProduct, NULL,
@@ -913,9 +903,9 @@ UINT WINAPI MsiSourceListAddSourceA( LPCSTR szProduct, LPCSTR szUserName,
 
     ret = MsiSourceListAddSourceW(szwproduct, szwusername, dwReserved, szwsource);
 
-    msi_free(szwproduct);
-    msi_free(szwusername);
-    msi_free(szwsource);
+    free(szwproduct);
+    free(szwusername);
+    free(szwsource);
 
     return ret;
 }
@@ -936,9 +926,9 @@ UINT WINAPI MsiSourceListAddSourceExA(LPCSTR szProduct, LPCSTR szUserSid,
     ret = MsiSourceListAddSourceExW(product, usersid, dwContext,
                                     dwOptions, source, dwIndex);
 
-    msi_free(product);
-    msi_free(usersid);
-    msi_free(source);
+    free(product);
+    free(usersid);
+    free(source);
 
     return ret;
 }
@@ -949,8 +939,8 @@ static void free_source_list(struct list *sourcelist)
     {
         media_info *info = LIST_ENTRY(list_head(sourcelist), media_info, entry);
         list_remove(&info->entry);
-        msi_free(info->path);
-        msi_free(info);
+        free(info->path);
+        free(info);
     }
 }
 
@@ -1004,14 +994,14 @@ static UINT fill_source_list(struct list *sourcelist, HKEY sourcekey, DWORD *cou
         if (r != ERROR_SUCCESS)
             return r;
 
-        entry = msi_alloc(sizeof(media_info));
+        entry = malloc(sizeof(media_info));
         if (!entry)
             goto error;
 
-        entry->path = msi_alloc(val_size);
+        entry->path = malloc(val_size);
         if (!entry->path)
         {
-            msi_free(entry);
+            free(entry);
             goto error;
         }
 
@@ -1023,8 +1013,8 @@ static UINT fill_source_list(struct list *sourcelist, HKEY sourcekey, DWORD *cou
                           NULL, (LPBYTE)entry->path, &val_size);
         if (r != ERROR_SUCCESS)
         {
-            msi_free(entry->path);
-            msi_free(entry);
+            free(entry->path);
+            free(entry);
             goto error;
         }
 
@@ -1041,9 +1031,8 @@ error:
 /******************************************************************
  *  MsiSourceListAddSourceExW (MSI.@)
  */
-UINT WINAPI MsiSourceListAddSourceExW( LPCWSTR szProduct, LPCWSTR szUserSid,
-        MSIINSTALLCONTEXT dwContext, DWORD dwOptions, LPCWSTR szSource,
-        DWORD dwIndex)
+UINT WINAPI MsiSourceListAddSourceExW( const WCHAR *szProduct, const WCHAR *szUserSid, MSIINSTALLCONTEXT dwContext,
+                                       DWORD dwOptions, const WCHAR *szSource, DWORD dwIndex )
 {
     HKEY sourcekey, typekey;
     UINT rc;
@@ -1053,8 +1042,8 @@ UINT WINAPI MsiSourceListAddSourceExW( LPCWSTR szProduct, LPCWSTR szUserSid,
     LPCWSTR postfix;
     DWORD size, count, index;
 
-    TRACE("%s %s %x %x %s %i\n", debugstr_w(szProduct), debugstr_w(szUserSid),
-          dwContext, dwOptions, debugstr_w(szSource), dwIndex);
+    TRACE( "%s, %s, %d, %#lx, %s, %lu\n", debugstr_w(szProduct), debugstr_w(szUserSid), dwContext, dwOptions,
+           debugstr_w(szSource), dwIndex );
 
     if (!szProduct || !squash_guid( szProduct, squashed_pc ))
         return ERROR_INVALID_PARAMETER;
@@ -1086,7 +1075,7 @@ UINT WINAPI MsiSourceListAddSourceExW( LPCWSTR szProduct, LPCWSTR szUserSid,
         rc = OpenMediaSubkey(sourcekey, &typekey, TRUE);
     else
     {
-        ERR("unknown media type: %08x\n", dwOptions);
+        ERR( "unknown media type: %#lx\n", dwOptions );
         RegCloseKey(sourcekey);
         return ERROR_FUNCTION_FAILED;
     }
@@ -1099,11 +1088,11 @@ UINT WINAPI MsiSourceListAddSourceExW( LPCWSTR szProduct, LPCWSTR szUserSid,
 
     postfix = (dwOptions & MSISOURCETYPE_NETWORK) ? L"\\" : L"/";
     if (szSource[lstrlenW(szSource) - 1] == *postfix)
-        source = strdupW(szSource);
+        source = wcsdup(szSource);
     else
     {
         size = lstrlenW(szSource) + 2;
-        source = msi_alloc(size * sizeof(WCHAR));
+        source = malloc(size * sizeof(WCHAR));
         lstrcpyW(source, szSource);
         lstrcatW(source, postfix);
     }
@@ -1129,14 +1118,14 @@ UINT WINAPI MsiSourceListAddSourceExW( LPCWSTR szProduct, LPCWSTR szUserSid,
     else
     {
         swprintf(name, ARRAY_SIZE(name), L"%d", dwIndex);
-        info = msi_alloc(sizeof(media_info));
+        info = malloc(sizeof(media_info));
         if (!info)
         {
             rc = ERROR_OUTOFMEMORY;
             goto done;
         }
 
-        info->path = strdupW(source);
+        info->path = wcsdup(source);
         lstrcpyW(info->szIndex, name);
         info->index = dwIndex;
         add_source_to_list(&sourcelist, info, &index);
@@ -1156,7 +1145,7 @@ UINT WINAPI MsiSourceListAddSourceExW( LPCWSTR szProduct, LPCWSTR szUserSid,
 
 done:
     free_source_list(&sourcelist);
-    msi_free(source);
+    free(source);
     RegCloseKey(typekey);
     RegCloseKey(sourcekey);
     return rc;
@@ -1183,10 +1172,10 @@ UINT WINAPI MsiSourceListAddMediaDiskA(LPCSTR szProduct, LPCSTR szUserSid,
     r = MsiSourceListAddMediaDiskW(product, usersid, dwContext, dwOptions,
                                      dwDiskId, volume, prompt);
 
-    msi_free(product);
-    msi_free(usersid);
-    msi_free(volume);
-    msi_free(prompt);
+    free(product);
+    free(usersid);
+    free(volume);
+    free(prompt);
 
     return r;
 }
@@ -1194,18 +1183,17 @@ UINT WINAPI MsiSourceListAddMediaDiskA(LPCSTR szProduct, LPCSTR szUserSid,
 /******************************************************************
  *  MsiSourceListAddMediaDiskW (MSI.@)
  */
-UINT WINAPI MsiSourceListAddMediaDiskW(LPCWSTR szProduct, LPCWSTR szUserSid,
-        MSIINSTALLCONTEXT dwContext, DWORD dwOptions, DWORD dwDiskId,
-        LPCWSTR szVolumeLabel, LPCWSTR szDiskPrompt)
+UINT WINAPI MsiSourceListAddMediaDiskW( const WCHAR *szProduct, const WCHAR *szUserSid, MSIINSTALLCONTEXT dwContext,
+                                        DWORD dwOptions, DWORD dwDiskId, const WCHAR *szVolumeLabel,
+                                        const WCHAR *szDiskPrompt )
 {
     HKEY sourcekey, mediakey;
     UINT rc;
     WCHAR *buffer, squashed_pc[SQUASHED_GUID_SIZE], szIndex[10];
     DWORD size;
 
-    TRACE("%s %s %x %x %i %s %s\n", debugstr_w(szProduct),
-            debugstr_w(szUserSid), dwContext, dwOptions, dwDiskId,
-            debugstr_w(szVolumeLabel), debugstr_w(szDiskPrompt));
+    TRACE( "%s, %s, %d, %#lx, %lu, %s, %s\n", debugstr_w(szProduct), debugstr_w(szUserSid), dwContext, dwOptions,
+           dwDiskId, debugstr_w(szVolumeLabel), debugstr_w(szDiskPrompt) );
 
     if (!szProduct || !squash_guid( szProduct, squashed_pc ))
         return ERROR_INVALID_PARAMETER;
@@ -1238,7 +1226,7 @@ UINT WINAPI MsiSourceListAddMediaDiskW(LPCWSTR szProduct, LPCWSTR szUserSid,
     if (szDiskPrompt) size += lstrlenW(szDiskPrompt);
 
     size *= sizeof(WCHAR);
-    buffer = msi_alloc(size);
+    buffer = malloc(size);
     *buffer = '\0';
 
     if (szVolumeLabel) lstrcpyW(buffer, szVolumeLabel);
@@ -1246,7 +1234,7 @@ UINT WINAPI MsiSourceListAddMediaDiskW(LPCWSTR szProduct, LPCWSTR szUserSid,
     if (szDiskPrompt) lstrcatW(buffer, szDiskPrompt);
 
     RegSetValueExW(mediakey, szIndex, 0, REG_SZ, (LPBYTE)buffer, size);
-    msi_free(buffer);
+    free(buffer);
 
     RegCloseKey(sourcekey);
     RegCloseKey(mediakey);
@@ -1257,81 +1245,77 @@ UINT WINAPI MsiSourceListAddMediaDiskW(LPCWSTR szProduct, LPCWSTR szUserSid,
 /******************************************************************
  *  MsiSourceListClearAllA (MSI.@)
  */
-UINT WINAPI MsiSourceListClearAllA( LPCSTR szProduct, LPCSTR szUserName, DWORD dwReserved )
+UINT WINAPI MsiSourceListClearAllA( const char *szProduct, const char *szUserName, DWORD dwReserved )
 {
-    FIXME("(%s %s %d)\n", debugstr_a(szProduct), debugstr_a(szUserName), dwReserved);
+    FIXME( "%s, %s, %#lx\n", debugstr_a(szProduct), debugstr_a(szUserName), dwReserved );
     return ERROR_SUCCESS;
 }
 
 /******************************************************************
  *  MsiSourceListClearAllW (MSI.@)
  */
-UINT WINAPI MsiSourceListClearAllW( LPCWSTR szProduct, LPCWSTR szUserName, DWORD dwReserved )
+UINT WINAPI MsiSourceListClearAllW( const WCHAR *szProduct, const WCHAR *szUserName, DWORD dwReserved )
 {
-    FIXME("(%s %s %d)\n", debugstr_w(szProduct), debugstr_w(szUserName), dwReserved);
+    FIXME( "%s, %s, %#lx\n", debugstr_w(szProduct), debugstr_w(szUserName), dwReserved );
     return ERROR_SUCCESS;
 }
 
 /******************************************************************
  *  MsiSourceListClearAllExA (MSI.@)
  */
-UINT WINAPI MsiSourceListClearAllExA( LPCSTR szProduct, LPCSTR szUserSid,
-    MSIINSTALLCONTEXT dwContext, DWORD dwOptions )
+UINT WINAPI MsiSourceListClearAllExA( const char *szProduct, const char *szUserSid, MSIINSTALLCONTEXT dwContext,
+                                      DWORD dwOptions )
 {
-    FIXME("(%s %s %d %08x)\n", debugstr_a(szProduct), debugstr_a(szUserSid),
-          dwContext, dwOptions);
+    FIXME( "%s, %s, %d, %#lx\n", debugstr_a(szProduct), debugstr_a(szUserSid), dwContext, dwOptions );
     return ERROR_SUCCESS;
 }
 
 /******************************************************************
  *  MsiSourceListClearAllExW (MSI.@)
  */
-UINT WINAPI MsiSourceListClearAllExW( LPCWSTR szProduct, LPCWSTR szUserSid,
-    MSIINSTALLCONTEXT dwContext, DWORD dwOptions )
+UINT WINAPI MsiSourceListClearAllExW( const WCHAR *szProduct, const WCHAR *szUserSid, MSIINSTALLCONTEXT dwContext,
+                                      DWORD dwOptions )
 {
-    FIXME("(%s %s %d %08x)\n", debugstr_w(szProduct), debugstr_w(szUserSid),
-          dwContext, dwOptions);
+    FIXME( "%s, %s, %d, %#lx\n", debugstr_w(szProduct), debugstr_w(szUserSid), dwContext, dwOptions );
     return ERROR_SUCCESS;
 }
 
 /******************************************************************
  *  MsiSourceListClearSourceA (MSI.@)
  */
-UINT WINAPI MsiSourceListClearSourceA(LPCSTR szProductCodeOrPatchCode, LPCSTR szUserSid,
-                                      MSIINSTALLCONTEXT dwContext, DWORD dwOptions,
-                                      LPCSTR szSource)
+UINT WINAPI MsiSourceListClearSourceA( const char *szProductCodeOrPatchCode, const char *szUserSid,
+                                       MSIINSTALLCONTEXT dwContext, DWORD dwOptions, const char *szSource )
 {
-    FIXME("(%s %s %x %x %s)\n", debugstr_a(szProductCodeOrPatchCode), debugstr_a(szUserSid),
-          dwContext, dwOptions, debugstr_a(szSource));
+    FIXME( "%s, %s, %d, %#lx, %s\n", debugstr_a(szProductCodeOrPatchCode), debugstr_a(szUserSid), dwContext,
+           dwOptions, debugstr_a(szSource) );
     return ERROR_SUCCESS;
 }
 
 /******************************************************************
  *  MsiSourceListClearSourceW (MSI.@)
  */
-UINT WINAPI MsiSourceListClearSourceW(LPCWSTR szProductCodeOrPatchCode, LPCWSTR szUserSid,
-                                      MSIINSTALLCONTEXT dwContext, DWORD dwOptions,
-                                      LPCWSTR szSource)
+UINT WINAPI MsiSourceListClearSourceW( const WCHAR *szProductCodeOrPatchCode, const WCHAR *szUserSid,
+                                       MSIINSTALLCONTEXT dwContext, DWORD dwOptions, LPCWSTR szSource )
 {
-    FIXME("(%s %s %x %x %s)\n", debugstr_w(szProductCodeOrPatchCode), debugstr_w(szUserSid),
-          dwContext, dwOptions, debugstr_w(szSource));
+    FIXME( "%s, %s, %d, %#lx, %s\n", debugstr_w(szProductCodeOrPatchCode), debugstr_w(szUserSid), dwContext,
+           dwOptions, debugstr_w(szSource) );
     return ERROR_SUCCESS;
 }
 
 /******************************************************************
  *  MsiSourceListForceResolutionA (MSI.@)
  */
-UINT WINAPI MsiSourceListForceResolutionA(const CHAR *product, const CHAR *user, DWORD reserved)
+UINT WINAPI MsiSourceListForceResolutionA( const char *product, const char *user, DWORD reserved )
 {
-    FIXME("(%s %s %x)\n", debugstr_a(product), debugstr_a(user), reserved);
+    FIXME( "%s, %s, %#lx\n", debugstr_a(product), debugstr_a(user), reserved );
     return ERROR_SUCCESS;
 }
 
 /******************************************************************
  *  MsiSourceListForceResolutionW (MSI.@)
  */
-UINT WINAPI MsiSourceListForceResolutionW(const WCHAR *product, const WCHAR *user, DWORD reserved)
+UINT WINAPI MsiSourceListForceResolutionW( const WCHAR *product, const WCHAR *user, DWORD reserved )
 {
-    FIXME("(%s %s %x)\n", debugstr_w(product), debugstr_w(user), reserved);
+    FIXME( "%s, %s, %#lx\n", debugstr_w(product), debugstr_w(user), reserved );
     return ERROR_SUCCESS;
 }
