@@ -91,7 +91,7 @@ static HRESULT (WINAPI *pPropVariantChangeType)
 static void free_prop( PROPVARIANT *prop )
 {
     if (prop->vt == VT_LPSTR )
-        msi_free( prop->pszVal );
+        free( prop->pszVal );
     prop->vt = VT_EMPTY;
 }
 
@@ -184,14 +184,14 @@ static void read_properties_from_data( PROPVARIANT *prop, LPBYTE data, DWORD sz
     {
         if( idofs[i].propid >= MSI_MAX_PROPS )
         {
-            ERR("Unknown property ID %d\n", idofs[i].propid );
+            ERR( "unknown property ID %lu\n", idofs[i].propid );
             break;
         }
 
         type = get_type( idofs[i].propid );
         if( type == VT_EMPTY )
         {
-            ERR("propid %d has unknown type\n", idofs[i].propid);
+            ERR( "propid %lu has unknown type\n", idofs[i].propid );
             break;
         }
 
@@ -210,7 +210,7 @@ static void read_properties_from_data( PROPVARIANT *prop, LPBYTE data, DWORD sz
         property.vt = propdata->type;
         if( propdata->type == VT_LPSTR )
         {
-            LPSTR str = msi_alloc( propdata->u.str.len );
+            char *str = malloc( propdata->u.str.len );
             memcpy( str, propdata->u.str.str, propdata->u.str.len );
             str[ propdata->u.str.len - 1 ] = 0;
             property.pszVal = str;
@@ -282,11 +282,11 @@ static UINT load_summary_info( MSISUMMARYINFO *si, IStream *stm )
 
     if( section_hdr.cProperties > MSI_MAX_PROPS )
     {
-        ERR("too many properties %d\n", section_hdr.cProperties);
+        ERR( "too many properties %lu\n", section_hdr.cProperties );
         return ERROR_FUNCTION_FAILED;
     }
 
-    data = msi_alloc( section_hdr.cbSection);
+    data = malloc( section_hdr.cbSection );
     if( !data )
         return ERROR_FUNCTION_FAILED;
 
@@ -298,9 +298,9 @@ static UINT load_summary_info( MSISUMMARYINFO *si, IStream *stm )
     if( SUCCEEDED(r) && count == sz )
         read_properties_from_data( si->property, data, sz + SECT_HDR_SIZE );
     else
-        ERR("failed to read properties %d %d\n", count, sz);
+        ERR( "failed to read properties %lu %lu\n", count, sz );
 
-    msi_free( data );
+    free( data );
     return ERROR_SUCCESS;
 }
 
@@ -406,7 +406,7 @@ static UINT save_summary_info( const MSISUMMARYINFO * si, IStream *stm )
         section_hdr.cbSection += sz;
     }
 
-    data = msi_alloc_zero( section_hdr.cbSection );
+    data = calloc( 1, section_hdr.cbSection );
 
     sz = 0;
     memcpy( &data[sz], &section_hdr, sizeof section_hdr );
@@ -420,7 +420,7 @@ static UINT save_summary_info( const MSISUMMARYINFO * si, IStream *stm )
         sz += write_property_to_data( &si->property[i], &data[sz] );
 
     r = IStream_Write( stm, data, sz, &count );
-    msi_free( data );
+    free( data );
     if( FAILED(r) || count != sz )
         return ret;
 
@@ -498,15 +498,14 @@ UINT msi_get_db_suminfo( MSIDATABASE *db, UINT uiUpdateCount, MSISUMMARYINFO **r
     return ERROR_SUCCESS;
 }
 
-UINT WINAPI MsiGetSummaryInformationW( MSIHANDLE hDatabase,
-              LPCWSTR szDatabase, UINT uiUpdateCount, MSIHANDLE *pHandle )
+UINT WINAPI MsiGetSummaryInformationW( MSIHANDLE hDatabase, const WCHAR *szDatabase, UINT uiUpdateCount,
+                                       MSIHANDLE *pHandle )
 {
     MSISUMMARYINFO *si;
     MSIDATABASE *db;
     UINT ret;
 
-    TRACE("%d %s %d %p\n", hDatabase, debugstr_w(szDatabase),
-           uiUpdateCount, pHandle);
+    TRACE( "%lu, %s, %u, %p\n", hDatabase, debugstr_w(szDatabase), uiUpdateCount, pHandle );
 
     if( !pHandle )
         return ERROR_INVALID_PARAMETER;
@@ -569,14 +568,13 @@ UINT WINAPI MsiGetSummaryInformationW( MSIHANDLE hDatabase,
     return ret;
 }
 
-UINT WINAPI MsiGetSummaryInformationA(MSIHANDLE hDatabase,
-              LPCSTR szDatabase, UINT uiUpdateCount, MSIHANDLE *pHandle)
+UINT WINAPI MsiGetSummaryInformationA( MSIHANDLE hDatabase, const char *szDatabase, UINT uiUpdateCount,
+                                       MSIHANDLE *pHandle )
 {
-    LPWSTR szwDatabase = NULL;
+    WCHAR *szwDatabase = NULL;
     UINT ret;
 
-    TRACE("%d %s %d %p\n", hDatabase, debugstr_a(szDatabase),
-          uiUpdateCount, pHandle);
+    TRACE( "%lu, %s, %u, %p\n", hDatabase, debugstr_a(szDatabase), uiUpdateCount, pHandle );
 
     if( szDatabase )
     {
@@ -587,16 +585,16 @@ UINT WINAPI MsiGetSummaryInformationA(MSIHANDLE hDatabase,
 
     ret = MsiGetSummaryInformationW(hDatabase, szwDatabase, uiUpdateCount, pHandle);
 
-    msi_free( szwDatabase );
+    free( szwDatabase );
 
     return ret;
 }
 
-UINT WINAPI MsiSummaryInfoGetPropertyCount(MSIHANDLE hSummaryInfo, PUINT pCount)
+UINT WINAPI MsiSummaryInfoGetPropertyCount( MSIHANDLE hSummaryInfo, UINT *pCount )
 {
     MSISUMMARYINFO *si;
 
-    TRACE("%d %p\n", hSummaryInfo, pCount);
+    TRACE( "%lu, %p\n", hSummaryInfo, pCount );
 
     si = msihandle2msiinfo( hSummaryInfo, MSIHANDLETYPE_SUMMARYINFO );
     if( !si )
@@ -723,16 +721,15 @@ LPWSTR msi_get_suminfo_product( IStorage *stg )
     return prod;
 }
 
-UINT WINAPI MsiSummaryInfoGetPropertyA(
-      MSIHANDLE handle, UINT uiProperty, PUINT puiDataType, LPINT piValue,
-      FILETIME *pftValue, LPSTR szValueBuf, LPDWORD pcchValueBuf)
+UINT WINAPI MsiSummaryInfoGetPropertyA( MSIHANDLE handle, UINT uiProperty, UINT *puiDataType, INT *piValue,
+                                        FILETIME *pftValue, char *szValueBuf, DWORD *pcchValueBuf )
 {
     MSISUMMARYINFO *si;
     awstring str;
     UINT r;
 
-    TRACE("%u, %u, %p, %p, %p, %p, %p\n", handle, uiProperty, puiDataType,
-          piValue, pftValue, szValueBuf, pcchValueBuf );
+    TRACE( "%lu, %u, %p, %p, %p, %p, %p\n", handle, uiProperty, puiDataType, piValue, pftValue, szValueBuf,
+           pcchValueBuf );
 
     if (uiProperty >= MSI_MAX_PROPS)
     {
@@ -775,16 +772,15 @@ UINT WINAPI MsiSummaryInfoGetPropertyA(
     return r;
 }
 
-UINT WINAPI MsiSummaryInfoGetPropertyW(
-      MSIHANDLE handle, UINT uiProperty, PUINT puiDataType, LPINT piValue,
-      FILETIME *pftValue, LPWSTR szValueBuf, LPDWORD pcchValueBuf)
+UINT WINAPI MsiSummaryInfoGetPropertyW( MSIHANDLE handle, UINT uiProperty, UINT *puiDataType, INT *piValue,
+                                        FILETIME *pftValue, WCHAR *szValueBuf, DWORD *pcchValueBuf )
 {
     MSISUMMARYINFO *si;
     awstring str;
     UINT r;
 
-    TRACE("%u, %u, %p, %p, %p, %p, %p\n", handle, uiProperty, puiDataType,
-          piValue, pftValue, szValueBuf, pcchValueBuf );
+    TRACE( "%lu, %u, %p, %p, %p, %p, %p\n", handle, uiProperty, puiDataType, piValue, pftValue, szValueBuf,
+           pcchValueBuf );
 
     if (uiProperty >= MSI_MAX_PROPS)
     {
@@ -863,14 +859,14 @@ static UINT set_prop( MSISUMMARYINFO *si, UINT uiProperty, UINT type,
         {
             len = WideCharToMultiByte( CP_ACP, 0, str->str.w, -1,
                                        NULL, 0, NULL, NULL );
-            prop->pszVal = msi_alloc( len );
+            prop->pszVal = malloc( len );
             WideCharToMultiByte( CP_ACP, 0, str->str.w, -1,
                                  prop->pszVal, len, NULL, NULL );
         }
         else
         {
             len = lstrlenA( str->str.a ) + 1;
-            prop->pszVal = msi_alloc( len );
+            prop->pszVal = malloc( len );
             lstrcpyA( prop->pszVal, str->str.a );
         }
         break;
@@ -895,15 +891,14 @@ static UINT msi_set_prop( MSISUMMARYINFO *si, UINT uiProperty, UINT uiDataType,
     return set_prop( si, uiProperty, type, iValue, pftValue, str );
 }
 
-UINT WINAPI MsiSummaryInfoSetPropertyW( MSIHANDLE handle, UINT uiProperty, UINT uiDataType,
-                                        INT iValue, FILETIME *pftValue, LPCWSTR szValue )
+UINT WINAPI MsiSummaryInfoSetPropertyW( MSIHANDLE handle, UINT uiProperty, UINT uiDataType, INT iValue,
+                                        FILETIME *pftValue, const WCHAR *szValue )
 {
     awcstring str;
     MSISUMMARYINFO *si;
     UINT ret;
 
-    TRACE("%u, %u, %u, %d, %p, %s\n", handle, uiProperty, uiDataType, iValue, pftValue,
-          debugstr_w(szValue) );
+    TRACE( "%lu, %u, %u, %d, %p, %s\n", handle, uiProperty, uiDataType, iValue, pftValue, debugstr_w(szValue) );
 
     if (!(si = msihandle2msiinfo( handle, MSIHANDLETYPE_SUMMARYINFO )))
     {
@@ -926,15 +921,14 @@ UINT WINAPI MsiSummaryInfoSetPropertyW( MSIHANDLE handle, UINT uiProperty, UINT
     return ret;
 }
 
-UINT WINAPI MsiSummaryInfoSetPropertyA( MSIHANDLE handle, UINT uiProperty, UINT uiDataType,
-                                        INT iValue, FILETIME *pftValue, LPCSTR szValue )
+UINT WINAPI MsiSummaryInfoSetPropertyA( MSIHANDLE handle, UINT uiProperty, UINT uiDataType, INT iValue,
+                                        FILETIME *pftValue, const char *szValue )
 {
     awcstring str;
     MSISUMMARYINFO *si;
     UINT ret;
 
-    TRACE("%u, %u, %u, %d, %p, %s\n", handle, uiProperty, uiDataType, iValue, pftValue,
-          debugstr_a(szValue) );
+    TRACE( "%lu, %u, %u, %d, %p, %s\n", handle, uiProperty, uiDataType, iValue, pftValue, debugstr_a(szValue) );
 
     if (!(si = msihandle2msiinfo( handle, MSIHANDLETYPE_SUMMARYINFO )))
     {
@@ -1103,12 +1097,12 @@ static UINT save_prop( MSISUMMARYINFO *si, HANDLE handle, UINT row )
     static const char fmt_begin[] = "%u\t";
     static const char data_end[] = "\r\n";
     static const char fmt_int[] = "%u";
-    UINT r, data_type, len;
+    UINT r, data_type;
     SYSTEMTIME system_time;
     FILETIME file_time;
     INT int_value;
     awstring str;
-    DWORD sz;
+    DWORD len, sz;
 
     str.unicode = FALSE;
     str.str.a = NULL;
@@ -1132,21 +1126,21 @@ static UINT save_prop( MSISUMMARYINFO *si, HANDLE handle, UINT row )
         break;
     case VT_LPSTR:
         len++;
-        if (!(str.str.a = msi_alloc( len )))
+        if (!(str.str.a = malloc( len )))
             return ERROR_OUTOFMEMORY;
         r = get_prop( si, row, NULL, NULL, NULL, &str, &len );
         if (r != ERROR_SUCCESS)
         {
-            msi_free( str.str.a );
+            free( str.str.a );
             return r;
         }
         sz = len;
         if (!WriteFile( handle, str.str.a, sz, &sz, NULL ))
         {
-            msi_free( str.str.a );
+            free( str.str.a );
             return ERROR_WRITE_FAULT;
         }
-        msi_free( str.str.a );
+        free( str.str.a );
         break;
     case VT_FILETIME:
         if (!FileTimeToSystemTime( &file_time, &system_time ))
@@ -1209,7 +1203,7 @@ UINT WINAPI MsiSummaryInfoPersist( MSIHANDLE handle )
     MSISUMMARYINFO *si;
     UINT ret;
 
-    TRACE("%d\n", handle );
+    TRACE( "%lu\n", handle );
 
     si = msihandle2msiinfo( handle, MSIHANDLETYPE_SUMMARYINFO );
     if( !si )
@@ -1221,24 +1215,26 @@ UINT WINAPI MsiSummaryInfoPersist( MSIHANDLE handle )
     return ret;
 }
 
-UINT WINAPI MsiCreateTransformSummaryInfoA( MSIHANDLE db, MSIHANDLE db_ref, LPCSTR transform, int error, int validation )
+UINT WINAPI MsiCreateTransformSummaryInfoA( MSIHANDLE db, MSIHANDLE db_ref, const char *transform, int error,
+                                            int validation )
 {
     UINT r;
     WCHAR *transformW = NULL;
 
-    TRACE("%u, %u, %s, %d, %d\n", db, db_ref, debugstr_a(transform), error, validation);
+    TRACE( "%lu, %lu, %s, %d, %d\n", db, db_ref, debugstr_a(transform), error, validation );
 
     if (transform && !(transformW = strdupAtoW( transform )))
         return ERROR_OUTOFMEMORY;
 
     r = MsiCreateTransformSummaryInfoW( db, db_ref, transformW, error, validation );
-    msi_free( transformW );
+    free( transformW );
     return r;
 }
 
-UINT WINAPI MsiCreateTransformSummaryInfoW( MSIHANDLE db, MSIHANDLE db_ref, LPCWSTR transform, int error, int validation )
+UINT WINAPI MsiCreateTransformSummaryInfoW( MSIHANDLE db, MSIHANDLE db_ref, const WCHAR *transform, int error,
+                                            int validation )
 {
-    FIXME("%u, %u, %s, %d, %d\n", db, db_ref, debugstr_w(transform), error, validation);
+    FIXME( "%lu, %lu, %s, %d, %d\n", db, db_ref, debugstr_w(transform), error, validation );
     return ERROR_FUNCTION_FAILED;
 }
 
@@ -1246,7 +1242,8 @@ UINT msi_load_suminfo_properties( MSIPACKAGE *package )
 {
     MSISUMMARYINFO *si;
     WCHAR *package_code;
-    UINT r, len;
+    UINT r;
+    DWORD len;
     awstring str;
     INT count;
 
@@ -1273,19 +1270,19 @@ UINT msi_load_suminfo_properties( MSIPACKAGE *package )
     }
 
     len++;
-    if (!(package_code = msi_alloc( len * sizeof(WCHAR) ))) return ERROR_OUTOFMEMORY;
+    if (!(package_code = malloc( len * sizeof(WCHAR) ))) return ERROR_OUTOFMEMORY;
     str.str.w = package_code;
 
     r = get_prop( si, PID_REVNUMBER, NULL, NULL, NULL, &str, &len );
     if (r != ERROR_SUCCESS)
     {
-        msi_free( package_code );
+        free( package_code );
         msiobj_release( &si->hdr );
         return r;
     }
 
     r = msi_set_property( package->db, L"PackageCode", package_code, len );
-    msi_free( package_code );
+    free( package_code );
 
     count = 0;
     get_prop( si, PID_WORDCOUNT, NULL, &count, NULL, NULL, NULL );
