@@ -197,7 +197,8 @@ NTSTATUS WINAPI RtlDosPathNameToNtPathName_U_WithStatus(const WCHAR *dos_path, U
         return STATUS_OBJECT_NAME_INVALID;
 
     if (!memcmp(dos_path, global_prefix, sizeof(global_prefix)) ||
-        (!memcmp(dos_path, global_prefix2, sizeof(global_prefix2)) && dos_path[4]))
+        (!memcmp(dos_path, global_prefix2, sizeof(global_prefix2)) && dos_path[4]) ||
+        !wcsicmp( dos_path, L"\\\\.\\CON" ))
     {
         ntpath->Length = wcslen(dos_path) * sizeof(WCHAR);
         ntpath->MaximumLength = ntpath->Length + sizeof(WCHAR);
@@ -205,6 +206,7 @@ NTSTATUS WINAPI RtlDosPathNameToNtPathName_U_WithStatus(const WCHAR *dos_path, U
         if (!ntpath->Buffer) return STATUS_NO_MEMORY;
         memcpy( ntpath->Buffer, dos_path, ntpath->MaximumLength );
         ntpath->Buffer[1] = '?';  /* change \\?\ to \??\ */
+        ntpath->Buffer[2] = '?';
         if (file_part)
         {
             if ((ptr = wcsrchr( ntpath->Buffer, '\\' )) && ptr[1]) *file_part = ptr + 1;
@@ -328,6 +330,15 @@ NTSTATUS WINAPI RtlDosPathNameToRelativeNtPathName_U_WithStatus(const WCHAR *dos
     return RtlDosPathNameToNtPathName_U_WithStatus(dos_path, ntpath, file_part, NULL);
 }
 
+/**************************************************************************
+ *        RtlDosPathNameToRelativeNtPathName_U [NTDLL.@]
+ */
+BOOLEAN WINAPI RtlDosPathNameToRelativeNtPathName_U(const WCHAR *dos_path, UNICODE_STRING *ntpath,
+    WCHAR **file_part, RTL_RELATIVE_NAME *relative)
+{
+    return RtlDosPathNameToRelativeNtPathName_U_WithStatus(dos_path, ntpath, file_part, relative) == STATUS_SUCCESS;
+}
+
 /**************************************************************************
  *        RtlReleaseRelativeName [NTDLL.@]
  */
@@ -606,18 +617,23 @@ static ULONG get_full_path_helper(LPCWSTR name, LPWSTR buffer, ULONG size)
         {
             char *unix_name;
             WCHAR *nt_str;
-            SIZE_T buflen;
+            ULONG buflen;
             NTSTATUS status;
+            UNICODE_STRING str;
+            OBJECT_ATTRIBUTES attr;
 
-            unix_name = RtlAllocateHeap( GetProcessHeap(), 0, 3 * wcslen(name) + 1 );
-            ntdll_wcstoumbs( name, wcslen(name) + 1, unix_name, 3 * wcslen(name) + 1, FALSE );
-            buflen = strlen(unix_name) + 10;
-            for (;;)
+            nt_str = RtlAllocateHeap( GetProcessHeap(), 0, (wcslen(name) + 9) * sizeof(WCHAR) );
+            wcscpy( nt_str, L"\\??\\unix" );
+            wcscat( nt_str, name );
+            RtlInitUnicodeString( &str, nt_str );
+            InitializeObjectAttributes( &attr, &str, 0, 0, NULL );
+            buflen = 3 * wcslen(name) + 1;
+            unix_name = RtlAllocateHeap( GetProcessHeap(), 0, buflen );
+            status = wine_nt_to_unix_file_name( &attr, unix_name, &buflen, FILE_OPEN_IF );
+            if (!status || status == STATUS_NO_SUCH_FILE)
             {
-                if (!(nt_str = RtlAllocateHeap( GetProcessHeap(), 0, buflen * sizeof(WCHAR) ))) break;
+                buflen = wcslen(name) + 9;
                 status = wine_unix_to_nt_file_name( unix_name, nt_str, &buflen );
-                if (status != STATUS_BUFFER_TOO_SMALL) break;
-                RtlFreeHeap( GetProcessHeap(), 0, nt_str );
             }
             RtlFreeHeap( GetProcessHeap(), 0, unix_name );
             if (!status && buflen > 6 && nt_str[5] == ':')
@@ -707,7 +723,7 @@ DWORD WINAPI RtlGetFullPathName_U(const WCHAR* name, ULONG size, WCHAR* buffer,
     DWORD       dosdev;
     DWORD       reqsize;
 
-    TRACE("(%s %u %p %p)\n", debugstr_w(name), size, buffer, file_part);
+    TRACE("(%s %lu %p %p)\n", debugstr_w(name), size, buffer, file_part);
 
     if (!name || !*name) return 0;
 
@@ -765,6 +781,25 @@ DWORD WINAPI RtlGetLongestNtPathLength(void)
     return MAX_NT_PATH_LENGTH;
 }
 
+
+/******************************************************************
+ *             RtlDoesFileExists_U   (NTDLL.@)
+ */
+BOOLEAN WINAPI RtlDoesFileExists_U(LPCWSTR file_name)
+{
+    UNICODE_STRING nt_name;
+    FILE_BASIC_INFORMATION basic_info;
+    OBJECT_ATTRIBUTES attr;
+    NTSTATUS status;
+
+    if (!RtlDosPathNameToNtPathName_U( file_name, &nt_name, NULL, NULL )) return FALSE;
+    InitializeObjectAttributes( &attr, &nt_name, OBJ_CASE_INSENSITIVE, 0, NULL );
+    status = NtQueryAttributesFile(&attr, &basic_info);
+    RtlFreeUnicodeString( &nt_name );
+    return !status;
+}
+
+
 /******************************************************************
  *             RtlIsNameLegalDOS8Dot3   (NTDLL.@)
  *
@@ -844,7 +879,7 @@ ULONG WINAPI RtlGetCurrentDirectory_U(ULONG buflen, LPWSTR buf)
     UNICODE_STRING*     us;
     ULONG               len;
 
-    TRACE("(%u %p)\n", buflen, buf);
+    TRACE("(%lu %p)\n", buflen, buf);
 
     RtlAcquirePebLock();
 
