@@ -74,7 +74,7 @@ static const signed char NTDLL_mostSignificant[16] = {
  */
 VOID WINAPI RtlInitializeBitMap(PRTL_BITMAP lpBits, PULONG lpBuff, ULONG ulSize)
 {
-  TRACE("(%p,%p,%u)\n", lpBits,lpBuff,ulSize);
+  TRACE("(%p,%p,%lu)\n", lpBits,lpBuff,ulSize);
   lpBits->SizeOfBitMap = ulSize;
   lpBits->Buffer = lpBuff;
 }
@@ -130,7 +130,7 @@ VOID WINAPI RtlSetBits(PRTL_BITMAP lpBits, ULONG ulStart, ULONG ulCount)
 {
   LPBYTE lpOut;
 
-  TRACE("(%p,%u,%u)\n", lpBits, ulStart, ulCount);
+  TRACE("(%p,%lu,%lu)\n", lpBits, ulStart, ulCount);
 
   if (!lpBits || !ulCount ||
       ulStart >= lpBits->SizeOfBitMap ||
@@ -191,7 +191,7 @@ VOID WINAPI RtlClearBits(PRTL_BITMAP lpBits, ULONG ulStart, ULONG ulCount)
 {
   LPBYTE lpOut;
 
-  TRACE("(%p,%u,%u)\n", lpBits, ulStart, ulCount);
+  TRACE("(%p,%lu,%lu)\n", lpBits, ulStart, ulCount);
 
   if (!lpBits || !ulCount ||
       ulStart >= lpBits->SizeOfBitMap ||
@@ -254,7 +254,7 @@ BOOLEAN WINAPI RtlAreBitsSet(PCRTL_BITMAP lpBits, ULONG ulStart, ULONG ulCount)
   LPBYTE lpOut;
   ULONG ulRemainder;
 
-  TRACE("(%p,%u,%u)\n", lpBits, ulStart, ulCount);
+  TRACE("(%p,%lu,%lu)\n", lpBits, ulStart, ulCount);
 
   if (!lpBits || !ulCount ||
       ulStart >= lpBits->SizeOfBitMap ||
@@ -327,7 +327,7 @@ BOOLEAN WINAPI RtlAreBitsClear(PCRTL_BITMAP lpBits, ULONG ulStart, ULONG ulCount
   LPBYTE lpOut;
   ULONG ulRemainder;
 
-  TRACE("(%p,%u,%u)\n", lpBits, ulStart, ulCount);
+  TRACE("(%p,%lu,%lu)\n", lpBits, ulStart, ulCount);
 
   if (!lpBits || !ulCount ||
       ulStart >= lpBits->SizeOfBitMap ||
@@ -395,7 +395,7 @@ ULONG WINAPI RtlFindSetBits(PCRTL_BITMAP lpBits, ULONG ulCount, ULONG ulHint)
 {
   ULONG ulPos, ulEnd;
 
-  TRACE("(%p,%u,%u)\n", lpBits, ulCount, ulHint);
+  TRACE("(%p,%lu,%lu)\n", lpBits, ulCount, ulHint);
 
   if (!lpBits || !ulCount || ulCount > lpBits->SizeOfBitMap)
     return ~0U;
@@ -442,7 +442,7 @@ ULONG WINAPI RtlFindClearBits(PCRTL_BITMAP lpBits, ULONG ulCount, ULONG ulHint)
 {
   ULONG ulPos, ulEnd;
 
-  TRACE("(%p,%u,%u)\n", lpBits, ulCount, ulHint);
+  TRACE("(%p,%lu,%lu)\n", lpBits, ulCount, ulHint);
 
   if (!lpBits || !ulCount || ulCount > lpBits->SizeOfBitMap)
     return ~0U;
@@ -489,7 +489,7 @@ ULONG WINAPI RtlFindSetBitsAndClear(PRTL_BITMAP lpBits, ULONG ulCount, ULONG ulH
 {
   ULONG ulPos;
 
-  TRACE("(%p,%u,%u)\n", lpBits, ulCount, ulHint);
+  TRACE("(%p,%lu,%lu)\n", lpBits, ulCount, ulHint);
 
   ulPos = RtlFindSetBits(lpBits, ulCount, ulHint);
   if (ulPos != ~0U)
@@ -514,7 +514,7 @@ ULONG WINAPI RtlFindClearBitsAndSet(PRTL_BITMAP lpBits, ULONG ulCount, ULONG ulH
 {
   ULONG ulPos;
 
-  TRACE("(%p,%u,%u)\n", lpBits, ulCount, ulHint);
+  TRACE("(%p,%lu,%lu)\n", lpBits, ulCount, ulHint);
 
   ulPos = RtlFindClearBits(lpBits, ulCount, ulHint);
   if (ulPos != ~0U)
@@ -882,7 +882,7 @@ ULONG WINAPI RtlFindNextForwardRunSet(PCRTL_BITMAP lpBits, ULONG ulStart, PULONG
 {
   ULONG ulSize = 0;
 
-  TRACE("(%p,%u,%p)\n", lpBits, ulStart, lpPos);
+  TRACE("(%p,%lu,%p)\n", lpBits, ulStart, lpPos);
 
   if (lpBits && ulStart < lpBits->SizeOfBitMap && lpPos)
     *lpPos = NTDLL_FindSetRun(lpBits, ulStart, &ulSize);
@@ -909,7 +909,7 @@ ULONG WINAPI RtlFindNextForwardRunClear(PCRTL_BITMAP lpBits, ULONG ulStart, PULO
 {
   ULONG ulSize = 0;
 
-  TRACE("(%p,%u,%p)\n", lpBits, ulStart, lpPos);
+  TRACE("(%p,%lu,%p)\n", lpBits, ulStart, lpPos);
 
   if (lpBits && ulStart < lpBits->SizeOfBitMap && lpPos)
     *lpPos = NTDLL_FindClearRun(lpBits, ulStart, &ulSize);
@@ -934,7 +934,7 @@ ULONG WINAPI RtlFindNextForwardRunClear(PCRTL_BITMAP lpBits, ULONG ulStart, PULO
  */
 ULONG WINAPI RtlFindLastBackwardRunSet(PCRTL_BITMAP lpBits, ULONG ulStart, PULONG lpPos)
 {
-  FIXME("(%p,%u,%p)-stub!\n", lpBits, ulStart, lpPos);
+  FIXME("(%p,%lu,%p)-stub!\n", lpBits, ulStart, lpPos);
   return 0;
 }
 
@@ -955,7 +955,7 @@ ULONG WINAPI RtlFindLastBackwardRunSet(PCRTL_BITMAP lpBits, ULONG ulStart, PULON
  */
 ULONG WINAPI RtlFindLastBackwardRunClear(PCRTL_BITMAP lpBits, ULONG ulStart, PULONG lpPos)
 {
-  FIXME("(%p,%u,%p)-stub!\n", lpBits, ulStart, lpPos);
+  FIXME("(%p,%lu,%p)-stub!\n", lpBits, ulStart, lpPos);
   return 0;
 }
 
@@ -971,7 +971,7 @@ static ULONG NTDLL_FindRuns(PCRTL_BITMAP lpBits, PRTL_BITMAP_RUN lpSeries,
   BOOL bNeedSort = ulCount > 1;
   ULONG ulPos = 0, ulRuns = 0;
 
-  TRACE("(%p,%p,%d,%d)\n", lpBits, lpSeries, ulCount, bLongest);
+  TRACE("(%p,%p,%ld,%d)\n", lpBits, lpSeries, ulCount, bLongest);
 
   if (!ulCount)
     return ~0U;
@@ -1033,7 +1033,7 @@ static ULONG NTDLL_FindRuns(PCRTL_BITMAP lpBits, PRTL_BITMAP_RUN lpSeries,
 ULONG WINAPI RtlFindSetRuns(PCRTL_BITMAP lpBits, PRTL_BITMAP_RUN lpSeries,
                             ULONG ulCount, BOOLEAN bLongest)
 {
-  TRACE("(%p,%p,%u,%d)\n", lpBits, lpSeries, ulCount, bLongest);
+  TRACE("(%p,%p,%lu,%d)\n", lpBits, lpSeries, ulCount, bLongest);
 
   return NTDLL_FindRuns(lpBits, lpSeries, ulCount, bLongest, NTDLL_FindSetRun);
 }
@@ -1055,7 +1055,7 @@ ULONG WINAPI RtlFindSetRuns(PCRTL_BITMAP lpBits, PRTL_BITMAP_RUN lpSeries,
 ULONG WINAPI RtlFindClearRuns(PCRTL_BITMAP lpBits, PRTL_BITMAP_RUN lpSeries,
                               ULONG ulCount, BOOLEAN bLongest)
 {
-  TRACE("(%p,%p,%u,%d)\n", lpBits, lpSeries, ulCount, bLongest);
+  TRACE("(%p,%p,%lu,%d)\n", lpBits, lpSeries, ulCount, bLongest);
 
   return NTDLL_FindRuns(lpBits, lpSeries, ulCount, bLongest, NTDLL_FindClearRun);
 }
