@@ -56,10 +56,10 @@ NTSTATUS open_hkcu_key( const char *path, HANDLE *key )
 
     sid = ((TOKEN_USER *)sid_data)->User.Sid;
     len = sprintf( buffer, "\\Registry\\User\\S-%u-%u", sid->Revision,
-                 MAKELONG( MAKEWORD( sid->IdentifierAuthority.Value[5], sid->IdentifierAuthority.Value[4] ),
-                           MAKEWORD( sid->IdentifierAuthority.Value[3], sid->IdentifierAuthority.Value[2] )));
+                   (int)MAKELONG( MAKEWORD( sid->IdentifierAuthority.Value[5], sid->IdentifierAuthority.Value[4] ),
+                                  MAKEWORD( sid->IdentifierAuthority.Value[3], sid->IdentifierAuthority.Value[2] )));
     for (i = 0; i < sid->SubAuthorityCount; i++)
-        len += sprintf( buffer + len, "-%u", sid->SubAuthority[i] );
+        len += sprintf( buffer + len, "-%u", (int)sid->SubAuthority[i] );
     len += sprintf( buffer + len, "\\%s", path );
 
     ascii_to_unicode( bufferW, buffer, len + 1 );
@@ -75,16 +75,18 @@ NTSTATUS open_hkcu_key( const char *path, HANDLE *key )
 NTSTATUS WINAPI NtCreateKey( HANDLE *key, ACCESS_MASK access, const OBJECT_ATTRIBUTES *attr,
                              ULONG index, const UNICODE_STRING *class, ULONG options, ULONG *dispos )
 {
-    NTSTATUS ret;
+    unsigned int ret;
     data_size_t len;
     struct object_attributes *objattr;
 
     *key = 0;
     if (attr->Length != sizeof(OBJECT_ATTRIBUTES)) return STATUS_INVALID_PARAMETER;
+    if (!attr->ObjectName->Length && !attr->RootDirectory) return STATUS_OBJECT_PATH_SYNTAX_BAD;
     if ((ret = alloc_object_attributes( attr, &objattr, &len ))) return ret;
+    objattr->attributes |= OBJ_OPENIF | OBJ_CASE_INSENSITIVE;
 
     TRACE( "(%p,%s,%s,%x,%x,%p)\n", attr->RootDirectory, debugstr_us(attr->ObjectName),
-           debugstr_us(class), options, access, key );
+           debugstr_us(class), (int)options, (int)access, key );
 
     SERVER_START_REQ( create_key )
     {
@@ -94,10 +96,19 @@ NTSTATUS WINAPI NtCreateKey( HANDLE *key, ACCESS_MASK access, const OBJECT_ATTRI
         if (class) wine_server_add_data( req, class->Buffer, class->Length );
         ret = wine_server_call( req );
         *key = wine_server_ptr_handle( reply->hkey );
-        if (dispos && !ret) *dispos = reply->created ? REG_CREATED_NEW_KEY : REG_OPENED_EXISTING_KEY;
     }
     SERVER_END_REQ;
 
+    if (ret == STATUS_OBJECT_NAME_EXISTS)
+    {
+        if (dispos) *dispos = REG_OPENED_EXISTING_KEY;
+        ret = STATUS_SUCCESS;
+    }
+    else if (ret == STATUS_SUCCESS)
+    {
+        if (dispos) *dispos = REG_CREATED_NEW_KEY;
+    }
+
     TRACE( "<- %p\n", *key );
     free( objattr );
     return ret;
@@ -112,7 +123,7 @@ NTSTATUS WINAPI NtCreateKeyTransacted( HANDLE *key, ACCESS_MASK access, const OB
                                        HANDLE transacted, ULONG *dispos )
 {
     FIXME( "(%p,%s,%s,%x,%x,%p,%p)\n", attr->RootDirectory, debugstr_us(attr->ObjectName),
-           debugstr_us(class), options, access, transacted, key );
+           debugstr_us(class), (int)options, (int)access, transacted, key );
     return STATUS_NOT_IMPLEMENTED;
 }
 
@@ -122,21 +133,24 @@ NTSTATUS WINAPI NtCreateKeyTransacted( HANDLE *key, ACCESS_MASK access, const OB
  */
 NTSTATUS WINAPI NtOpenKeyEx( HANDLE *key, ACCESS_MASK access, const OBJECT_ATTRIBUTES *attr, ULONG options )
 {
-    NTSTATUS ret;
+    unsigned int ret;
+    ULONG attributes;
 
     *key = 0;
     if (attr->Length != sizeof(*attr)) return STATUS_INVALID_PARAMETER;
     if (attr->ObjectName->Length & 1) return STATUS_OBJECT_NAME_INVALID;
 
-    TRACE( "(%p,%s,%x,%p)\n", attr->RootDirectory, debugstr_us(attr->ObjectName), access, key );
+    TRACE( "(%p,%s,%x,%p)\n", attr->RootDirectory, debugstr_us(attr->ObjectName), (int)access, key );
 
-    if (options & ~REG_OPTION_OPEN_LINK) FIXME( "options %x not implemented\n", options );
+    if (options & ~REG_OPTION_OPEN_LINK) FIXME( "options %x not implemented\n", (int)options );
+
+    attributes = attr->Attributes | OBJ_CASE_INSENSITIVE;
 
     SERVER_START_REQ( open_key )
     {
         req->parent     = wine_server_obj_handle( attr->RootDirectory );
         req->access     = access;
-        req->attributes = attr->Attributes;
+        req->attributes = attributes;
         wine_server_add_data( req, attr->ObjectName->Buffer, attr->ObjectName->Length );
         ret = wine_server_call( req );
         *key = wine_server_ptr_handle( reply->hkey );
@@ -162,7 +176,7 @@ NTSTATUS WINAPI NtOpenKey( HANDLE *key, ACCESS_MASK access, const OBJECT_ATTRIBU
 NTSTATUS WINAPI NtOpenKeyTransactedEx( HANDLE *key, ACCESS_MASK access, const OBJECT_ATTRIBUTES *attr,
                                        ULONG options, HANDLE transaction )
 {
-    FIXME( "(%p %x %p %x %p)\n", key, access, attr, options, transaction );
+    FIXME( "(%p %x %p %x %p)\n", key, (int)access, attr, (int)options, transaction );
     return STATUS_NOT_IMPLEMENTED;
 }
 
@@ -182,7 +196,7 @@ NTSTATUS WINAPI NtOpenKeyTransacted( HANDLE *key, ACCESS_MASK access, const OBJE
  */
 NTSTATUS WINAPI NtDeleteKey( HANDLE key )
 {
-    NTSTATUS ret;
+    unsigned int ret;
 
     TRACE( "(%p)\n", key );
 
@@ -199,10 +213,23 @@ NTSTATUS WINAPI NtDeleteKey( HANDLE key )
 /******************************************************************************
  *              NtRenameKey  (NTDLL.@)
  */
-NTSTATUS WINAPI NtRenameKey( HANDLE handle, UNICODE_STRING *name )
+NTSTATUS WINAPI NtRenameKey( HANDLE key, UNICODE_STRING *name )
 {
-    FIXME( "(%p %s)\n", handle, debugstr_us(name) );
-    return STATUS_NOT_IMPLEMENTED;
+    unsigned int ret;
+
+    TRACE( "(%p %s)\n", key, debugstr_us(name) );
+
+    if (!name) return STATUS_ACCESS_VIOLATION;
+    if (!name->Buffer || !name->Length) return STATUS_INVALID_PARAMETER;
+
+    SERVER_START_REQ( rename_key )
+    {
+        req->hkey = wine_server_obj_handle( key );
+        wine_server_add_data( req, name->Buffer, name->Length );
+        ret = wine_server_call( req );
+    }
+    SERVER_END_REQ;
+    return ret;
 }
 
 
@@ -215,7 +242,7 @@ static NTSTATUS enumerate_key( HANDLE handle, int index, KEY_INFORMATION_CLASS i
                                void *info, DWORD length, DWORD *result_len )
 
 {
-    NTSTATUS ret;
+    unsigned int ret;
     void *data_ptr;
     size_t fixed_size;
 
@@ -245,7 +272,6 @@ static NTSTATUS enumerate_key( HANDLE handle, int index, KEY_INFORMATION_CLASS i
             case KeyBasicInformation:
             {
                 KEY_BASIC_INFORMATION keyinfo;
-                fixed_size = (char *)keyinfo.Name - (char *)&keyinfo;
                 keyinfo.LastWriteTime.QuadPart = reply->modif;
                 keyinfo.TitleIndex = 0;
                 keyinfo.NameLength = reply->namelen;
@@ -256,7 +282,6 @@ static NTSTATUS enumerate_key( HANDLE handle, int index, KEY_INFORMATION_CLASS i
             case KeyFullInformation:
             {
                 KEY_FULL_INFORMATION keyinfo;
-                fixed_size = (char *)keyinfo.Class - (char *)&keyinfo;
                 keyinfo.LastWriteTime.QuadPart = reply->modif;
                 keyinfo.TitleIndex = 0;
                 keyinfo.ClassLength = wine_server_reply_size(reply);
@@ -274,7 +299,6 @@ static NTSTATUS enumerate_key( HANDLE handle, int index, KEY_INFORMATION_CLASS i
             case KeyNodeInformation:
             {
                 KEY_NODE_INFORMATION keyinfo;
-                fixed_size = (char *)keyinfo.Name - (char *)&keyinfo;
                 keyinfo.LastWriteTime.QuadPart = reply->modif;
                 keyinfo.TitleIndex = 0;
                 if (reply->namelen < wine_server_reply_size(reply))
@@ -295,7 +319,6 @@ static NTSTATUS enumerate_key( HANDLE handle, int index, KEY_INFORMATION_CLASS i
             case KeyNameInformation:
             {
                 KEY_NAME_INFORMATION keyinfo;
-                fixed_size = (char *)keyinfo.Name - (char *)&keyinfo;
                 keyinfo.NameLength = reply->namelen;
                 memcpy( info, &keyinfo, min( length, fixed_size ) );
                 break;
@@ -304,7 +327,6 @@ static NTSTATUS enumerate_key( HANDLE handle, int index, KEY_INFORMATION_CLASS i
             case KeyCachedInformation:
             {
                 KEY_CACHED_INFORMATION keyinfo;
-                fixed_size = sizeof(keyinfo);
                 keyinfo.LastWriteTime.QuadPart = reply->modif;
                 keyinfo.TitleIndex = 0;
                 keyinfo.SubKeys = reply->subkeys;
@@ -321,7 +343,8 @@ static NTSTATUS enumerate_key( HANDLE handle, int index, KEY_INFORMATION_CLASS i
                 break;
             }
             *result_len = fixed_size + reply->total;
-            if (length < *result_len) ret = STATUS_BUFFER_OVERFLOW;
+            if (length < fixed_size) ret = STATUS_BUFFER_TOO_SMALL;
+            else if (length < *result_len) ret = STATUS_BUFFER_OVERFLOW;
         }
     }
     SERVER_END_REQ;
@@ -356,7 +379,7 @@ NTSTATUS WINAPI NtQueryKey( HANDLE handle, KEY_INFORMATION_CLASS info_class,
  */
 NTSTATUS WINAPI NtSetInformationKey( HANDLE key, int class, void *info, ULONG length )
 {
-    FIXME( "(%p,0x%08x,%p,0x%08x) stub\n", key, class, info, length );
+    FIXME( "(%p,0x%08x,%p,0x%08x) stub\n", key, class, info, (int)length );
     return STATUS_SUCCESS;
 }
 
@@ -414,11 +437,11 @@ static void copy_key_value_info( KEY_VALUE_INFORMATION_CLASS info_class, void *i
 NTSTATUS WINAPI NtEnumerateValueKey( HANDLE handle, ULONG index, KEY_VALUE_INFORMATION_CLASS info_class,
                                      void *info, DWORD length, DWORD *result_len )
 {
-    NTSTATUS ret;
+    unsigned int ret;
     void *ptr;
     size_t fixed_size;
 
-    TRACE( "(%p,%u,%d,%p,%d)\n", handle, index, info_class, info, length );
+    TRACE( "(%p,%u,%d,%p,%d)\n", handle, (int)index, info_class, info, (int)length );
 
     /* compute the length we want to retrieve */
     switch (info_class)
@@ -458,11 +481,11 @@ NTSTATUS WINAPI NtQueryValueKey( HANDLE handle, const UNICODE_STRING *name,
                                  KEY_VALUE_INFORMATION_CLASS info_class,
                                  void *info, DWORD length, DWORD *result_len )
 {
-    NTSTATUS ret;
+    unsigned int ret;
     UCHAR *data_ptr;
     unsigned int fixed_size, min_size;
 
-    TRACE( "(%p,%s,%d,%p,%d)\n", handle, debugstr_us(name), info_class, info, length );
+    TRACE( "(%p,%s,%d,%p,%d)\n", handle, debugstr_us(name), info_class, info, (int)length );
 
     if (name->Length > MAX_VALUE_LENGTH) return STATUS_OBJECT_NAME_NOT_FOUND;
 
@@ -526,7 +549,7 @@ NTSTATUS WINAPI NtQueryValueKey( HANDLE handle, const UNICODE_STRING *name,
 NTSTATUS WINAPI NtQueryMultipleValueKey( HANDLE key, KEY_MULTIPLE_VALUE_INFORMATION *info,
                                          ULONG count, void *buffer, ULONG length, ULONG *retlen )
 {
-    FIXME( "(%p,%p,0x%08x,%p,0x%08x,%p) stub!\n", key, info, count, buffer, length, retlen );
+    FIXME( "(%p,%p,0x%08x,%p,0x%08x,%p) stub!\n", key, info, (int)count, buffer, (int)length, retlen );
     return STATUS_SUCCESS;
 }
 
@@ -537,9 +560,9 @@ NTSTATUS WINAPI NtQueryMultipleValueKey( HANDLE key, KEY_MULTIPLE_VALUE_INFORMAT
 NTSTATUS WINAPI NtSetValueKey( HANDLE key, const UNICODE_STRING *name, ULONG index,
                                ULONG type, const void *data, ULONG count )
 {
-    NTSTATUS ret;
+    unsigned int ret;
 
-    TRACE( "(%p,%s,%d,%p,%d)\n", key, debugstr_us(name), type, data, count );
+    TRACE( "(%p,%s,%d,%p,%d)\n", key, debugstr_us(name), (int)type, data, (int)count );
 
     if (name->Length > MAX_VALUE_LENGTH) return STATUS_INVALID_PARAMETER;
 
@@ -562,7 +585,7 @@ NTSTATUS WINAPI NtSetValueKey( HANDLE key, const UNICODE_STRING *name, ULONG ind
  */
 NTSTATUS WINAPI NtDeleteValueKey( HANDLE key, const UNICODE_STRING *name )
 {
-    NTSTATUS ret;
+    unsigned int ret;
 
     TRACE( "(%p,%s)\n", key, debugstr_us(name) );
 
@@ -587,10 +610,11 @@ NTSTATUS WINAPI NtNotifyChangeMultipleKeys( HANDLE key, ULONG count, OBJECT_ATTR
                                             IO_STATUS_BLOCK *io, ULONG filter, BOOLEAN subtree,
                                             void *buffer, ULONG length, BOOLEAN async )
 {
-    NTSTATUS ret;
+    unsigned int ret;
 
     TRACE( "(%p,%u,%p,%p,%p,%p,%p,0x%08x, 0x%08x,%p,0x%08x,0x%08x)\n",
-           key, count, attr, event, apc, apc_context, io, filter, async, buffer, length, subtree );
+           key, (int)count, attr, event, apc, apc_context, io,
+           (int)filter, async, buffer, (int)length, subtree );
 
     if (count || attr || apc || apc_context || buffer || length)
         FIXME( "Unimplemented optional parameter\n" );
@@ -639,7 +663,7 @@ NTSTATUS WINAPI NtNotifyChangeKey( HANDLE key, HANDLE event, PIO_APC_ROUTINE apc
  */
 NTSTATUS WINAPI NtFlushKey( HANDLE key )
 {
-    NTSTATUS ret;
+    unsigned int ret;
 
     TRACE( "key=%p\n", key );
 
@@ -658,7 +682,25 @@ NTSTATUS WINAPI NtFlushKey( HANDLE key )
  */
 NTSTATUS WINAPI NtLoadKey( const OBJECT_ATTRIBUTES *attr, OBJECT_ATTRIBUTES *file )
 {
-    NTSTATUS ret;
+    TRACE( "(%p,%p)\n", attr, file );
+    return NtLoadKeyEx( attr, file, 0, 0, 0, 0, NULL, NULL );
+}
+
+/******************************************************************************
+ *              NtLoadKey2  (NTDLL.@)
+ */
+NTSTATUS WINAPI NtLoadKey2( const OBJECT_ATTRIBUTES *attr, OBJECT_ATTRIBUTES *file, ULONG flags )
+{
+    return NtLoadKeyEx( attr, file, flags, 0, 0, 0, NULL, NULL );
+}
+
+/******************************************************************************
+ *              NtLoadKeyEx  (NTDLL.@)
+ */
+NTSTATUS WINAPI NtLoadKeyEx( const OBJECT_ATTRIBUTES *attr, OBJECT_ATTRIBUTES *file, ULONG flags, HANDLE trustkey,
+                             HANDLE event, ACCESS_MASK access, HANDLE *roothandle, IO_STATUS_BLOCK *iostatus )
+{
+    unsigned int ret;
     HANDLE key;
     data_size_t len;
     struct object_attributes *objattr;
@@ -666,7 +708,15 @@ NTSTATUS WINAPI NtLoadKey( const OBJECT_ATTRIBUTES *attr, OBJECT_ATTRIBUTES *fil
     UNICODE_STRING nt_name;
     OBJECT_ATTRIBUTES new_attr = *file;
 
-    TRACE("(%p,%p)\n", attr, file);
+    TRACE( "(%p,%p,0x%x,%p,%p,0x%x,%p,%p)\n",
+           attr, file, (int)flags, trustkey, event, (int)access, roothandle, iostatus );
+
+    if (flags) FIXME( "flags %x not handled\n", (int)flags );
+    if (trustkey) FIXME("trustkey parameter not supported\n");
+    if (event) FIXME("event parameter not supported\n");
+    if (access) FIXME("access parameter not supported\n");
+    if (roothandle) FIXME("roothandle is not filled\n");
+    if (iostatus) FIXME("iostatus is not filled\n");
 
     get_redirect( &new_attr, &nt_name );
     if (!(ret = nt_to_unix_file_name( &new_attr, &unix_name, FILE_OPEN )))
@@ -680,12 +730,14 @@ NTSTATUS WINAPI NtLoadKey( const OBJECT_ATTRIBUTES *attr, OBJECT_ATTRIBUTES *fil
     if (ret) return ret;
 
     if ((ret = alloc_object_attributes( attr, &objattr, &len ))) return ret;
+    objattr->attributes |= OBJ_OPENIF | OBJ_CASE_INSENSITIVE;
 
     SERVER_START_REQ( load_registry )
     {
         req->file = wine_server_obj_handle( key );
         wine_server_add_data( req, objattr, len );
         ret = wine_server_call( req );
+        if (ret == STATUS_OBJECT_NAME_EXISTS) ret = STATUS_SUCCESS;
     }
     SERVER_END_REQ;
 
@@ -694,23 +746,12 @@ NTSTATUS WINAPI NtLoadKey( const OBJECT_ATTRIBUTES *attr, OBJECT_ATTRIBUTES *fil
     return ret;
 }
 
-
-/******************************************************************************
- *              NtLoadKey2  (NTDLL.@)
- */
-NTSTATUS WINAPI NtLoadKey2( const OBJECT_ATTRIBUTES *attr, OBJECT_ATTRIBUTES *file, ULONG flags )
-{
-    FIXME( "(%p,%p,0x%08x) semi-stub: ignoring flags\n", attr, file, flags );
-    return NtLoadKey( attr, file );
-}
-
-
 /******************************************************************************
  *              NtUnloadKey  (NTDLL.@)
  */
 NTSTATUS WINAPI NtUnloadKey( OBJECT_ATTRIBUTES *attr )
 {
-    NTSTATUS ret;
+    unsigned int ret;
 
     TRACE( "(%p)\n", attr );
 
@@ -735,7 +776,7 @@ NTSTATUS WINAPI NtUnloadKey( OBJECT_ATTRIBUTES *attr )
  */
 NTSTATUS WINAPI NtSaveKey( HANDLE key, HANDLE file )
 {
-    NTSTATUS ret;
+    unsigned int ret;
 
     TRACE( "(%p,%p)\n", key, file );
 
@@ -755,7 +796,7 @@ NTSTATUS WINAPI NtSaveKey( HANDLE key, HANDLE file )
  */
 NTSTATUS WINAPI NtRestoreKey( HANDLE key, HANDLE file, ULONG flags )
 {
-    FIXME( "(%p,%p,0x%08x) stub\n", key, file, flags );
+    FIXME( "(%p,%p,0x%08x) stub\n", key, file, (int)flags );
     return STATUS_SUCCESS;
 }
 
