@@ -51,9 +51,9 @@ NTSTATUS WINAPI NtOpenProcessToken( HANDLE process, DWORD access, HANDLE *handle
  */
 NTSTATUS WINAPI NtOpenProcessTokenEx( HANDLE process, DWORD access, DWORD attributes, HANDLE *handle )
 {
-    NTSTATUS ret;
+    unsigned int ret;
 
-    TRACE( "(%p,0x%08x,0x%08x,%p)\n", process, access, attributes, handle );
+    TRACE( "(%p,0x%08x,0x%08x,%p)\n", process, (int)access, (int)attributes, handle );
 
     *handle = 0;
 
@@ -86,9 +86,9 @@ NTSTATUS WINAPI NtOpenThreadToken( HANDLE thread, DWORD access, BOOLEAN self, HA
 NTSTATUS WINAPI NtOpenThreadTokenEx( HANDLE thread, DWORD access, BOOLEAN self, DWORD attributes,
                                      HANDLE *handle )
 {
-    NTSTATUS ret;
+    unsigned int ret;
 
-    TRACE( "(%p,0x%08x,%u,0x%08x,%p)\n", thread, access, self, attributes, handle );
+    TRACE( "(%p,0x%08x,%u,0x%08x,%p)\n", thread, (int)access, self, (int)attributes, handle );
 
     *handle = 0;
 
@@ -113,7 +113,7 @@ NTSTATUS WINAPI NtOpenThreadTokenEx( HANDLE thread, DWORD access, BOOLEAN self,
 NTSTATUS WINAPI NtDuplicateToken( HANDLE token, ACCESS_MASK access, OBJECT_ATTRIBUTES *attr,
                                   SECURITY_IMPERSONATION_LEVEL level, TOKEN_TYPE type, HANDLE *handle )
 {
-    NTSTATUS status;
+    unsigned int status;
     data_size_t len;
     struct object_attributes *objattr;
 
@@ -124,7 +124,7 @@ NTSTATUS WINAPI NtDuplicateToken( HANDLE token, ACCESS_MASK access, OBJECT_ATTRI
     {
         SECURITY_QUALITY_OF_SERVICE *qos = attr->SecurityQualityOfService;
         TRACE( "ObjectAttributes->SecurityQualityOfService = {%d, %d, %d, %s}\n",
-               qos->Length, qos->ImpersonationLevel, qos->ContextTrackingMode,
+               (int)qos->Length, qos->ImpersonationLevel, qos->ContextTrackingMode,
                qos->EffectiveOnly ? "TRUE" : "FALSE");
         level = qos->ImpersonationLevel;
     }
@@ -198,9 +198,9 @@ NTSTATUS WINAPI NtQueryInformationToken( HANDLE token, TOKEN_INFORMATION_CLASS c
     };
 
     ULONG len = 0;
-    NTSTATUS status = STATUS_SUCCESS;
+    unsigned int status = STATUS_SUCCESS;
 
-    TRACE( "(%p,%d,%p,%d,%p)\n", token, class, info, length, retlen );
+    TRACE( "(%p,%d,%p,%d,%p)\n", token, class, info, (int)length, retlen );
 
     if (class < MaxTokenInfoClass) len = info_len[class];
     if (retlen) *retlen = len;
@@ -230,46 +230,43 @@ NTSTATUS WINAPI NtQueryInformationToken( HANDLE token, TOKEN_INFORMATION_CLASS c
         break;
 
     case TokenGroups:
+    case TokenLogonSid:
     {
         /* reply buffer is always shorter than output one */
         void *buffer = malloc( length );
+        TOKEN_GROUPS *groups = info;
+        ULONG i, count, needed_size;
 
         SERVER_START_REQ( get_token_groups )
         {
-            TOKEN_GROUPS *groups = info;
-
             req->handle = wine_server_obj_handle( token );
+            req->attr_mask = (class == TokenLogonSid) ? SE_GROUP_LOGON_ID : 0;
             wine_server_set_reply( req, buffer, length );
             status = wine_server_call( req );
-            if (status == STATUS_BUFFER_TOO_SMALL)
+
+            count = reply->attr_len / sizeof(unsigned int);
+            needed_size = offsetof( TOKEN_GROUPS, Groups[count] ) + reply->sid_len;
+            if (status == STATUS_SUCCESS && needed_size > length) status = STATUS_BUFFER_TOO_SMALL;
+
+            if (status == STATUS_SUCCESS)
             {
-                if (retlen) *retlen = reply->user_len;
-            }
-            else if (status == STATUS_SUCCESS)
-            {
-                struct token_groups *tg = buffer;
-                unsigned int *attr = (unsigned int *)(tg + 1);
-                ULONG i;
-                const int non_sid_portion = (sizeof(struct token_groups) + tg->count * sizeof(unsigned int));
-                SID *sids = (SID *)((char *)info + FIELD_OFFSET( TOKEN_GROUPS, Groups[tg->count] ));
+                unsigned int *attr = buffer;
+                SID *sids = (SID *)&groups->Groups[count];
 
-                if (retlen) *retlen = reply->user_len;
-
-                groups->GroupCount = tg->count;
-                memcpy( sids, (char *)buffer + non_sid_portion,
-                        reply->user_len - offsetof( TOKEN_GROUPS, Groups[tg->count] ));
-
-                for (i = 0; i < tg->count; i++)
+                groups->GroupCount = count;
+                memcpy( sids, attr + count, reply->sid_len );
+                for (i = 0; i < count; i++)
                 {
                     groups->Groups[i].Attributes = attr[i];
                     groups->Groups[i].Sid = sids;
                     sids = (SID *)((char *)sids + offsetof( SID, SubAuthority[sids->SubAuthorityCount] ));
                 }
              }
-             else if (retlen) *retlen = 0;
+            else if (status != STATUS_BUFFER_TOO_SMALL) needed_size = 0;
         }
         SERVER_END_REQ;
         free( buffer );
+        if (retlen) *retlen = needed_size;
         break;
     }
 
@@ -469,28 +466,6 @@ NTSTATUS WINAPI NtQueryInformationToken( HANDLE token, TOKEN_INFORMATION_CLASS c
             break;
         }
 
-    case TokenLogonSid:
-        SERVER_START_REQ( get_token_sid )
-        {
-            TOKEN_GROUPS * groups = info;
-            PSID sid = groups + 1;
-            DWORD sid_len = length < sizeof(TOKEN_GROUPS) ? 0 : length - sizeof(TOKEN_GROUPS);
-
-            req->handle = wine_server_obj_handle( token );
-            req->which_sid = class;
-            wine_server_set_reply( req, sid, sid_len );
-            status = wine_server_call( req );
-            if (retlen) *retlen = reply->sid_len + sizeof(TOKEN_GROUPS);
-            if (status == STATUS_SUCCESS)
-            {
-                groups->GroupCount = 1;
-                groups->Groups[0].Sid = sid;
-                groups->Groups[0].Attributes = 0;
-            }
-        }
-        SERVER_END_REQ;
-        break;
-
     case TokenLinkedToken:
         SERVER_START_REQ( create_linked_token )
         {
@@ -517,9 +492,9 @@ NTSTATUS WINAPI NtQueryInformationToken( HANDLE token, TOKEN_INFORMATION_CLASS c
 NTSTATUS WINAPI NtSetInformationToken( HANDLE token, TOKEN_INFORMATION_CLASS class,
                                        void *info, ULONG length )
 {
-    NTSTATUS ret = STATUS_NOT_IMPLEMENTED;
+    unsigned int ret = STATUS_NOT_IMPLEMENTED;
 
-    TRACE( "%p %d %p %u\n", token, class, info, length );
+    TRACE( "%p %d %p %u\n", token, class, info, (int)length );
 
     switch (class)
     {
@@ -584,7 +559,8 @@ NTSTATUS WINAPI NtCreateLowBoxToken( HANDLE *token_handle, HANDLE token, ACCESS_
                                      SID_AND_ATTRIBUTES *capabilities, ULONG handle_count, HANDLE *handle )
 {
     FIXME("(%p, %p, %x, %p, %p, %u, %p, %u, %p): stub\n",
-          token_handle, token, access, attr, sid, count, capabilities, handle_count, handle );
+          token_handle, token, (int)access, attr, sid,
+          (int)count, capabilities, (int)handle_count, handle );
 
     /* we need to return a NULL handle since later it will be passed to NtClose and that must not fail */
     *token_handle = NULL;
@@ -598,7 +574,7 @@ NTSTATUS WINAPI NtCreateLowBoxToken( HANDLE *token_handle, HANDLE token, ACCESS_
 NTSTATUS WINAPI NtAdjustGroupsToken( HANDLE token, BOOLEAN reset, TOKEN_GROUPS *groups,
                                      ULONG length, TOKEN_GROUPS *prev, ULONG *retlen )
 {
-    FIXME( "%p %d %p %u %p %p\n", token, reset, groups, length, prev, retlen );
+    FIXME( "%p %d %p %u %p %p\n", token, reset, groups, (int)length, prev, retlen );
     return STATUS_NOT_IMPLEMENTED;
 }
 
@@ -609,9 +585,9 @@ NTSTATUS WINAPI NtAdjustGroupsToken( HANDLE token, BOOLEAN reset, TOKEN_GROUPS *
 NTSTATUS WINAPI NtAdjustPrivilegesToken( HANDLE token, BOOLEAN disable, TOKEN_PRIVILEGES *privs,
                                          DWORD length, TOKEN_PRIVILEGES *prev, DWORD *retlen )
 {
-    NTSTATUS ret;
+    unsigned int ret;
 
-    TRACE( "(%p,0x%08x,%p,0x%08x,%p,%p)\n", token, disable, privs, length, prev, retlen );
+    TRACE( "(%p,0x%08x,%p,0x%08x,%p,%p)\n", token, disable, privs, (int)length, prev, retlen );
 
     SERVER_START_REQ( adjust_token_privileges )
     {
@@ -645,13 +621,13 @@ NTSTATUS WINAPI NtFilterToken( HANDLE token, ULONG flags, TOKEN_GROUPS *disable_
     data_size_t privileges_len = 0;
     data_size_t sids_len = 0;
     SID *sids = NULL;
-    NTSTATUS status;
+    unsigned int status;
 
-    TRACE( "%p %#x %p %p %p %p\n", token, flags, disable_sids, privileges,
+    TRACE( "%p %#x %p %p %p %p\n", token, (int)flags, disable_sids, privileges,
            restrict_sids, new_token );
 
     if (flags)
-        FIXME( "flags %#x unsupported\n", flags );
+        FIXME( "flags %#x unsupported\n", (int)flags );
 
     if (restrict_sids)
         FIXME( "support for restricting sids not yet implemented\n" );
@@ -704,7 +680,7 @@ NTSTATUS WINAPI NtFilterToken( HANDLE token, ULONG flags, TOKEN_GROUPS *disable_
  */
 NTSTATUS WINAPI NtPrivilegeCheck( HANDLE token, PRIVILEGE_SET *privs, BOOLEAN *res )
 {
-    NTSTATUS status;
+    unsigned int status;
 
     SERVER_START_REQ( check_token_privileges )
     {
@@ -740,11 +716,11 @@ NTSTATUS WINAPI NtAccessCheck( PSECURITY_DESCRIPTOR descr, HANDLE token, ACCESS_
     struct object_attributes *objattr;
     data_size_t len;
     OBJECT_ATTRIBUTES attr;
-    NTSTATUS status;
+    unsigned int status;
     ULONG priv_len;
 
     TRACE( "(%p, %p, %08x, %p, %p, %p, %p, %p)\n",
-           descr, token, access, mapping, privs, retlen, access_granted, access_status );
+           descr, token, (int)access, mapping, privs, retlen, access_granted, access_status );
 
     if (!privs || !retlen) return STATUS_ACCESS_VIOLATION;
     priv_len = *retlen;
@@ -795,7 +771,7 @@ NTSTATUS WINAPI NtAccessCheckAndAuditAlarm( UNICODE_STRING *subsystem, HANDLE ha
                                             BOOLEAN *onclose )
 {
     FIXME( "(%s, %p, %s, %p, 0x%08x, %p, %d, %p, %p, %p), stub\n",
-           debugstr_us(subsystem), handle, debugstr_us(typename), descr, access,
+           debugstr_us(subsystem), handle, debugstr_us(typename), descr, (int)access,
            mapping, creation, access_granted, access_status, onclose );
     return STATUS_NOT_IMPLEMENTED;
 }
@@ -808,11 +784,11 @@ NTSTATUS WINAPI NtQuerySecurityObject( HANDLE handle, SECURITY_INFORMATION info,
                                        PSECURITY_DESCRIPTOR descr, ULONG length, ULONG *retlen )
 {
     SECURITY_DESCRIPTOR_RELATIVE *psd = descr;
-    NTSTATUS status;
+    unsigned int status;
     void *buffer;
     unsigned int buffer_size = 512;
 
-    TRACE( "(%p,0x%08x,%p,0x%08x,%p)\n", handle, info, descr, length, retlen );
+    TRACE( "(%p,0x%08x,%p,0x%08x,%p)\n", handle, (int)info, descr, (int)length, retlen );
 
     for (;;)
     {
@@ -870,9 +846,9 @@ NTSTATUS WINAPI NtSetSecurityObject( HANDLE handle, SECURITY_INFORMATION info, P
     struct security_descriptor *sd;
     data_size_t len;
     OBJECT_ATTRIBUTES attr;
-    NTSTATUS status;
+    unsigned int status;
 
-    TRACE( "%p 0x%08x %p\n", handle, info, descr );
+    TRACE( "%p 0x%08x %p\n", handle, (int)info, descr );
 
     if (!descr) return STATUS_ACCESS_VIOLATION;
 
@@ -911,7 +887,7 @@ NTSTATUS WINAPI NtSetSecurityObject( HANDLE handle, SECURITY_INFORMATION info, P
  */
 NTSTATUS WINAPI NtAllocateLocallyUniqueId( LUID *luid )
 {
-    NTSTATUS status;
+    unsigned int status;
 
     TRACE( "%p\n", luid );
 
